module.exports = function(deps, opts) {
var Module = opts || {};

// hide node/commonjs globals so emscripten doesn't get confused
var process = null; 
var require = null; 

var pathGetFilenameRegex = /\/([^\/]+)$/;

function pathGetFilename(path) {
  var matches = path.match(pathGetFilenameRegex);
  if (matches && matches.length) {
    return matches[1];
  } else {
    return path;
  }
}

function addAutoloader(module) {
  var loadDatafiles = function() {
    module.autoloadFiles.forEach(function(filepath) {
      module.FS_createPreloadedFile('/', pathGetFilename(filepath), filepath, true, true);
    });
  };

  if (module.autoloadFiles) {
    module.preRun = module.preRun || [];
    module.preRun.unshift(loadDatafiles);
  }

  return module;
}

// inject extra behaviours
addAutoloader(Module);

// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = (typeof Module !== 'undefined' ? Module : null) || {};

// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  if (!Module['print']) Module['print'] = function print(x) {
    process['stdout'].write(x + '\n');
  };
  if (!Module['printErr']) Module['printErr'] = function printErr(x) {
    process['stderr'].write(x + '\n');
  };

  var nodeFS = require('fs');
  var nodePath = require('path');

  Module['read'] = function read(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };

  Module['readBinary'] = function readBinary(filename) { return Module['read'](filename, true) };

  Module['load'] = function load(f) {
    globalEval(read(f));
  };

  Module['arguments'] = process['argv'].slice(2);

  module['exports'] = Module;
}
else if (ENVIRONMENT_IS_SHELL) {
  if (!Module['print']) Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function read() { throw 'no read() available (jsc?)' };
  }

  Module['readBinary'] = function readBinary(f) {
    return read(f, 'binary');
  };

  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  this['Module'] = Module;

  eval("if (typeof gc === 'function' && gc.toString().indexOf('[native code]') > 0) var gc = undefined"); // wipe out the SpiderMonkey shell 'gc' function, which can confuse closure (uses it as a minified name, and it is then initted to a non-falsey value unexpectedly)
}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function read(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof console !== 'undefined') {
    if (!Module['print']) Module['print'] = function print(x) {
      console.log(x);
    };
    if (!Module['printErr']) Module['printErr'] = function printErr(x) {
      console.log(x);
    };
  } else {
    // Probably a worker, and without console.log. We can do very little here...
    var TRY_USE_DUMP = false;
    if (!Module['print']) Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  if (ENVIRONMENT_IS_WEB) {
    window['Module'] = Module;
  } else {
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function load(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];

// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}



// === Auto-generated preamble library stuff ===

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  setTempRet0: function (value) {
    tempRet0 = value;
  },
  getTempRet0: function () {
    return tempRet0;
  },
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      return '(((' +target + ')+' + (quantum-1) + ')&' + -quantum + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?\{ ?[^}]* ?\}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type) {
    switch (type) {
      case 'i1': case 'i8': return 1;
      case 'i16': return 2;
      case 'i32': return 4;
      case 'i64': return 8;
      case 'float': return 4;
      case 'double': return 8;
      default: {
        if (type[type.length-1] === '*') {
          return Runtime.QUANTUM_SIZE; // A pointer
        } else if (type[0] === 'i') {
          var bits = parseInt(type.substr(1));
          assert(bits % 8 === 0);
          return bits/8;
        } else {
          return 0;
        }
      }
    }
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (!vararg && (type == 'i64' || type == 'double')) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    var index = 0;
    type.flatIndexes = type.fields.map(function(field) {
      index++;
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        if (field[1] === '0') {
          // this is [0 x something]. When inside another structure like here, it must be at the end,
          // and it adds no size
          // XXX this happens in java-nbody for example... assert(index === type.fields.length, 'zero-length in the middle!');
          size = 0;
          if (Types.types[field]) {
            alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
          } else {
            alignSize = type.alignSize || QUANTUM_SIZE;
          }
        } else {
          size = Types.types[field].flatSize;
          alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
        }
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else if (field[0] === '<') {
        // vector type
        size = alignSize = Types.types[field].flatSize; // fully aligned
      } else if (field[0] === 'i') {
        // illegal integer field, that could not be legalized because it is an internal structure field
        // it is ok to have such fields, if we just use them as markers of field size and nothing more complex
        size = alignSize = parseInt(field.substr(1))/8;
        assert(size % 1 === 0, 'cannot handle non-byte-size field ' + field);
      } else {
        assert(false, 'invalid type for calculateStructAlignment');
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    if (type.name_ && type.name_[0] === '[') {
      // arrays have 2 elements, so we get the proper difference. then we scale here. that way we avoid
      // allocating a potentially huge array for [999999 x i8] etc.
      type.flatSize = parseInt(type.name_.substr(1))*type.flatSize/2;
    }
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2*(1 + i);
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  getAsmConst: function (code, numArgs) {
    // code is a constant string on the heap, so we can cache these
    if (!Runtime.asmConstCache) Runtime.asmConstCache = {};
    var func = Runtime.asmConstCache[code];
    if (func) return func;
    var args = [];
    for (var i = 0; i < numArgs; i++) {
      args.push(String.fromCharCode(36) + i); // $0, $1 etc
    }
    var source = Pointer_stringify(code);
    if (source[0] === '"') {
      // tolerate EM_ASM("..code..") even though EM_ASM(..code..) is correct
      if (source.indexOf('"', 1) === source.length-1) {
        source = source.substr(1, source.length-2);
      } else {
        // something invalid happened, e.g. EM_ASM("..code($0)..", input)
        abort('invalid EM_ASM input |' + source + '|. Please use EM_ASM(..code..) (no quotes) or EM_ASM({ ..code($0).. }, input) (to input values)');
      }
    }
    try {
      var evalled = eval('(function(' + args.join(',') + '){ ' + source + ' })'); // new Function does not allow upvars in node
    } catch(e) {
      Module.printErr('error in executing inline EM_ASM code: ' + e + ' on: \n\n' + source + '\n\nwith args |' + args + '| (make sure to use the right one out of EM_ASM, EM_ASM_ARGS, etc.)');
      throw e;
    }
    return Runtime.asmConstCache[code] = evalled;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function dynCall_wrapper() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;

      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }

      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }

      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          Math.floor((codePoint - 0x10000) / 0x400) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function processJSString(string) {
      /* TODO: use TextEncoder when present,
        var encoder = new TextEncoder();
        encoder['encoding'] = "utf-8";
        var utf8Array = encoder['encode'](aMsg.data);
      */
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  getCompilerSetting: function (name) {
    throw 'You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work';
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = (((STACKTOP)+7)&-8); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = (((STATICTOP)+7)&-8); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = (((DYNAMICTOP)+7)&-8); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+((low>>>0)))+((+((high>>>0)))*(+4294967296))) : ((+((low>>>0)))+((+((high|0)))*(+4294967296)))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}


Module['Runtime'] = Runtime;









//========================================
// Runtime essentials
//========================================

var __THREW__ = 0; // Used in checking for thrown exceptions.

var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;

var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD, tempDouble, tempFloat;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;

function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = Module['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      value = intArrayFromString(value);
      type = 'array';
    }
    if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}

// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;

// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[((ptr)>>0)]=value; break;
      case 'i8': HEAP8[((ptr)>>0)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;

// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[((ptr)>>0)];
      case 'i8': return HEAP8[((ptr)>>0)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)>>0)]=0;
    }
    return ret;
  }

  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }

  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);

    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }

  return ret;
}
Module['allocate'] = allocate;

function Pointer_stringify(ptr, /* optional */ length) {
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))>>0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;

  var ret = '';

  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }

  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))>>0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;

// Given a pointer 'ptr' to a null-terminated UTF16LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.
function UTF16ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
    if (codeUnit == 0)
      return str;
    ++i;
    // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
    str += String.fromCharCode(codeUnit);
  }
}
Module['UTF16ToString'] = UTF16ToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF16LE form. The copy will require at most (str.length*2+1)*2 bytes of space in the HEAP.
function stringToUTF16(str, outPtr) {
  for(var i = 0; i < str.length; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[(((outPtr)+(i*2))>>1)]=codeUnit;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[(((outPtr)+(str.length*2))>>1)]=0;
}
Module['stringToUTF16'] = stringToUTF16;

// Given a pointer 'ptr' to a null-terminated UTF32LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.
function UTF32ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}
Module['UTF32ToString'] = UTF32ToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF32LE form. The copy will require at most (str.length+1)*4 bytes of space in the HEAP,
// but can use less, since str.length does not return the number of characters in the string, but the number of UTF-16 code units in the string.
function stringToUTF32(str, outPtr) {
  var iChar = 0;
  for(var iCodeUnit = 0; iCodeUnit < str.length; ++iCodeUnit) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    var codeUnit = str.charCodeAt(iCodeUnit); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++iCodeUnit);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[(((outPtr)+(iChar*4))>>2)]=codeUnit;
    ++iChar;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[(((outPtr)+(iChar*4))>>2)]=0;
}
Module['stringToUTF32'] = stringToUTF32;

function demangle(func) {
  var i = 3;
  // params, etc.
  var basicTypes = {
    'v': 'void',
    'b': 'bool',
    'c': 'char',
    's': 'short',
    'i': 'int',
    'l': 'long',
    'f': 'float',
    'd': 'double',
    'w': 'wchar_t',
    'a': 'signed char',
    'h': 'unsigned char',
    't': 'unsigned short',
    'j': 'unsigned int',
    'm': 'unsigned long',
    'x': 'long long',
    'y': 'unsigned long long',
    'z': '...'
  };
  var subs = [];
  var first = true;
  function dump(x) {
    //return;
    if (x) Module.print(x);
    Module.print(func);
    var pre = '';
    for (var a = 0; a < i; a++) pre += ' ';
    Module.print (pre + '^');
  }
  function parseNested() {
    i++;
    if (func[i] === 'K') i++; // ignore const
    var parts = [];
    while (func[i] !== 'E') {
      if (func[i] === 'S') { // substitution
        i++;
        var next = func.indexOf('_', i);
        var num = func.substring(i, next) || 0;
        parts.push(subs[num] || '?');
        i = next+1;
        continue;
      }
      if (func[i] === 'C') { // constructor
        parts.push(parts[parts.length-1]);
        i += 2;
        continue;
      }
      var size = parseInt(func.substr(i));
      var pre = size.toString().length;
      if (!size || !pre) { i--; break; } // counter i++ below us
      var curr = func.substr(i + pre, size);
      parts.push(curr);
      subs.push(curr);
      i += pre + size;
    }
    i++; // skip E
    return parts;
  }
  function parse(rawList, limit, allowVoid) { // main parser
    limit = limit || Infinity;
    var ret = '', list = [];
    function flushList() {
      return '(' + list.join(', ') + ')';
    }
    var name;
    if (func[i] === 'N') {
      // namespaced N-E
      name = parseNested().join('::');
      limit--;
      if (limit === 0) return rawList ? [name] : name;
    } else {
      // not namespaced
      if (func[i] === 'K' || (first && func[i] === 'L')) i++; // ignore const and first 'L'
      var size = parseInt(func.substr(i));
      if (size) {
        var pre = size.toString().length;
        name = func.substr(i + pre, size);
        i += pre + size;
      }
    }
    first = false;
    if (func[i] === 'I') {
      i++;
      var iList = parse(true);
      var iRet = parse(true, 1, true);
      ret += iRet[0] + ' ' + name + '<' + iList.join(', ') + '>';
    } else {
      ret = name;
    }
    paramLoop: while (i < func.length && limit-- > 0) {
      //dump('paramLoop');
      var c = func[i++];
      if (c in basicTypes) {
        list.push(basicTypes[c]);
      } else {
        switch (c) {
          case 'P': list.push(parse(true, 1, true)[0] + '*'); break; // pointer
          case 'R': list.push(parse(true, 1, true)[0] + '&'); break; // reference
          case 'L': { // literal
            i++; // skip basic type
            var end = func.indexOf('E', i);
            var size = end - i;
            list.push(func.substr(i, size));
            i += size + 2; // size + 'EE'
            break;
          }
          case 'A': { // array
            var size = parseInt(func.substr(i));
            i += size.toString().length;
            if (func[i] !== '_') throw '?';
            i++; // skip _
            list.push(parse(true, 1, true)[0] + ' [' + size + ']');
            break;
          }
          case 'E': break paramLoop;
          default: ret += '?' + c; break paramLoop;
        }
      }
    }
    if (!allowVoid && list.length === 1 && list[0] === 'void') list = []; // avoid (void)
    if (rawList) {
      if (ret) {
        list.push(ret + '?');
      }
      return list;
    } else {
      return ret + flushList();
    }
  }
  try {
    // Special-case the entry point, since its name differs from other name mangling.
    if (func == 'Object._main' || func == '_main') {
      return 'main()';
    }
    if (typeof func === 'number') func = Pointer_stringify(func);
    if (func[0] !== '_') return func;
    if (func[1] !== '_') return func; // C function
    if (func[2] !== 'Z') return func;
    switch (func[3]) {
      case 'n': return 'operator new()';
      case 'd': return 'operator delete()';
    }
    return parse();
  } catch(e) {
    return func;
  }
}

function demangleAll(text) {
  return text.replace(/__Z[\w\d_]+/g, function(x) { var y = demangle(x); return x === y ? x : (x + ' [' + y + ']') });
}

function stackTrace() {
  var stack = new Error().stack;
  return stack ? demangleAll(stack) : '(no stack trace available)'; // Stack trace is not available at least on IE10 and Safari 6.
}

// Memory management

var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return (x+4095)&-4096;
}

var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk

function enlargeMemory() {
  abort('Cannot enlarge memory arrays. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value ' + TOTAL_MEMORY + ', (2) compile with ALLOW_MEMORY_GROWTH which adjusts the size at runtime but prevents some optimizations, or (3) set Module.TOTAL_MEMORY before the program runs.');
}

var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 134217728;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;

var totalMemory = 4096;
while (totalMemory < TOTAL_MEMORY || totalMemory < 2*TOTAL_STACK) {
  if (totalMemory < 16*1024*1024) {
    totalMemory *= 2;
  } else {
    totalMemory += 16*1024*1024
  }
}
if (totalMemory !== TOTAL_MEMORY) {
  Module.printErr('increasing TOTAL_MEMORY to ' + totalMemory + ' to be more reasonable');
  TOTAL_MEMORY = totalMemory;
}

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(typeof Int32Array !== 'undefined' && typeof Float64Array !== 'undefined' && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'JS engine does not provide full typed array support');

var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);

// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');

Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited

var runtimeInitialized = false;

function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}

function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;

function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;

function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;

// Tools

// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;

// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))>>0)]=chr;
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))>>0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;

function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; i++) {
    HEAP8[(((buffer)+(i))>>0)]=str.charCodeAt(i);
  }
  if (!dontAddNull) HEAP8[(((buffer)+(str.length))>>0)]=0;
}
Module['writeAsciiToMemory'] = writeAsciiToMemory;

function unSign(value, bits, ignore) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}

// check for imul support, and also for correctness ( https://bugs.webkit.org/show_bug.cgi?id=126345 )
if (!Math['imul'] || Math['imul'](0xffffffff, 5) !== -5) Math['imul'] = function imul(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];


var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_min = Math.min;

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled

function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}
Module['removeRunDependency'] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data


var memoryInitializer = null;

// === Body ===





STATIC_BASE = 8;

STATICTOP = STATIC_BASE + Runtime.alignMemory(63531);
/* global initializers */ __ATINIT__.push();


/* memory initializer */ allocate([97,100,98,58,32,117,110,107,110,111,119,110,32,99,109,100,32,40,37,48,50,88,41,10,0,0,0,0,0,0,0,0,105,103,110,111,114,105,110,103,32,112,99,101,32,107,101,121,58,32,48,120,37,48,52,120,32,40,37,115,41,10,0,0,60,110,111,110,101,62,0,0,1,0,0,0,53,0,0,0,2,0,0,0,122,0,0,0,3,0,0,0,120,0,0,0,4,0,0,0,99,0,0,0,5,0,0,0,118,0,0,0,6,0,0,0,96,0,0,0,7,0,0,0,97,0,0,0,8,0,0,0,98,0,0,0,9,0,0,0,100,0,0,0,10,0,0,0,101,0,0,0,11,0,0,0,109,0,0,0,12,0,0,0,103,0,0,0,13,0,0,0,111,0,0,0,17,0,0,0,50,0,0,0,18,0,0,0,18,0,0,0,19,0,0,0,19,0,0,0,20,0,0,0,20,0,0,0,21,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,23,0,0,0,22,0,0,0,24,0,0,0,26,0,0,0,25,0,0,0,28,0,0,0,26,0,0,0,25,0,0,0,27,0,0,0,29,0,0,0,28,0,0,0,27,0,0,0,29,0,0,0,24,0,0,0,30,0,0,0,51,0,0,0,31,0,0,0,48,0,0,0,32,0,0,0,12,0,0,0,33,0,0,0,13,0,0,0,34,0,0,0,14,0,0,0,35,0,0,0,15,0,0,0,36,0,0,0,17,0,0,0,37,0,0,0,16,0,0,0,38,0,0,0,32,0,0,0,39,0,0,0,34,0,0,0,40,0,0,0,31,0,0,0,41,0,0,0,35,0,0,0,42,0,0,0,33,0,0,0,43,0,0,0,30,0,0,0,57,0,0,0,42,0,0,0,45,0,0,0,57,0,0,0,46,0,0,0,0,0,0,0,47,0,0,0,1,0,0,0,48,0,0,0,2,0,0,0,49,0,0,0,3,0,0,0,50,0,0,0,5,0,0,0,51,0,0,0,4,0,0,0,52,0,0,0,38,0,0,0,53,0,0,0,40,0,0,0,54,0,0,0,37,0,0,0,55,0,0,0,41,0,0,0,56,0,0,0,39,0,0,0,44,0,0,0,36,0,0,0,58,0,0,0,56,0,0,0,60,0,0,0,6,0,0,0,61,0,0,0,7,0,0,0,62,0,0,0,8,0,0,0,63,0,0,0,9,0,0,0,64,0,0,0,11,0,0,0,66,0,0,0,45,0,0,0,65,0,0,0,46,0,0,0,67,0,0,0,43,0,0,0,68,0,0,0,47,0,0,0,69,0,0,0,44,0,0,0,70,0,0,0,56,0,0,0,71,0,0,0,54,0,0,0,72,0,0,0,58,0,0,0,74,0,0,0,58,0,0,0,75,0,0,0,55,0,0,0,76,0,0,0,49,0,0,0,77,0,0,0,55,0,0,0,81,0,0,0,54,0,0,0,99,0,0,0,114,0,0,0,100,0,0,0,115,0,0,0,101,0,0,0,116,0,0,0,102,0,0,0,117,0,0,0,103,0,0,0,119,0,0,0,104,0,0,0,121,0,0,0,105,0,0,0,62,0,0,0,106,0,0,0,59,0,0,0,108,0,0,0,60,0,0,0,107,0,0,0,61,0,0,0,82,0,0,0,71,0,0,0,83,0,0,0,75,0,0,0,84,0,0,0,67,0,0,0,86,0,0,0,89,0,0,0,87,0,0,0,91,0,0,0,88,0,0,0,92,0,0,0,85,0,0,0,78,0,0,0,90,0,0,0,86,0,0,0,91,0,0,0,87,0,0,0,92,0,0,0,88,0,0,0,89,0,0,0,69,0,0,0,93,0,0,0,83,0,0,0,94,0,0,0,84,0,0,0,95,0,0,0,85,0,0,0,96,0,0,0,76,0,0,0,97,0,0,0,82,0,0,0,98,0,0,0,65,0,0,0,0,0,0,0,0,0,0,0,97,100,98,45,107,98,100,58,32,108,105,115,116,101,110,32,37,117,10,0,0,0,0,0,97,100,98,45,107,98,100,58,32,116,97,108,107,32,37,117,10,0,0,0,0,0,0,0,97,100,98,45,107,98,100,58,32,116,97,108,107,32,50,10,0,0,0,0,0,0,0,0,86,0,0,0,89,0,0,0,87,0,0,0,91,0,0,0,88,0,0,0,92,0,0,0,90,0,0,0,86,0,0,0,91,0,0,0,87,0,0,0,92,0,0,0,88,0,0,0,93,0,0,0,83,0,0,0,94,0,0,0,84,0,0,0,95,0,0,0,85,0,0,0,97,0,0,0,82,0,0,0,98,0,0,0,65,0,0,0,96,0,0,0,76,0,0,0,0,0,0,0,0,0,0,0,86,0,0,0,115,0,0,0,87,0,0,0,62,0,0,0,88,0,0,0,116,0,0,0,90,0,0,0,59,0,0,0,91,0,0,0,87,0,0,0,92,0,0,0,60,0,0,0,93,0,0,0,119,0,0,0,94,0,0,0,61,0,0,0,95,0,0,0,121,0,0,0,97,0,0,0,114,0,0,0,98,0,0,0,117,0,0,0,96,0,0,0,36,0,0,0,0,0,0,0,0,0,0,0,99,0,0,0,0,0,0,0,91,99,110,116,93,0,0,0,99,108,111,99,107,0,0,0,103,98,0,0,0,0,0,0,91,97,100,100,114,46,46,93,0,0,0,0,0,0,0,0,114,117,110,32,119,105,116,104,32,98,114,101,97,107,112,111,105,110,116,115,32,97,116,32,97,100,100,114,0,0,0,0,103,101,0,0,0,0,0,0,91,101,120,99,101,112,116,105,111,110,93,0,0,0,0,0,114,117,110,32,117,110,116,105,108,32,101,120,99,101,112,116,105,111,110,0,0,0,0,0,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,117,110,0,0,0,0,0,104,97,108,116,0,0,0,0,91,118,97,108,93,0,0,0,115,101,116,32,104,97,108,116,32,115,116,97,116,101,32,91,50,93,0,0,0,0,0,0,112,0,0,0,0,0,0,0,101,120,101,99,117,116,101,32,99,110,116,32,105,110,115,116,114,117,99,116,105,111,110,115,44,32,115,107,105,112,32,99,97,108,108,115,32,91,49,93,0,0,0,0,0,0,0,0,114,101,115,101,116,0,0,0,114,116,101,0,0,0,0,0,101,120,101,99,117,116,101,32,116,111,32,110,101,120,116,32,114,116,101,0,0,0,0,0,114,0,0,0,0,0,0,0,114,101,103,32,91,118,97,108,93,0,0,0,0,0,0,0,103,101,116,32,111,114,32,115,101,116,32,97,32,114,101,103,105,115,116,101,114,0,0,0,115,0,0,0,0,0,0,0,91,119,104,97,116,93,0,0,112,114,105,110,116,32,115,116,97,116,117,115,32,40,99,112,117,124,109,101,109,124,115,99,99,124,118,105,97,41,0,0,116,0,0,0,0,0,0,0,101,120,101,99,117,116,101,32,99,110,116,32,105,110,115,116,114,117,99,116,105,111,110,115,32,91,49,93,0,0,0,0,117,0,0,0,0,0,0,0,91,91,45,93,97,100,100,114,32,91,99,110,116,93,93,0,100,105,115,97,115,115,101,109,98,108,101,0,0,0,0,0,144,4,0,0,152,4,0,0,160,4,0,0,168,4,0,0,176,4,0,0,192,4,0,0,224,4,0,0,232,4,0,0,248,4,0,0,16,5,0,0,24,5,0,0,32,5,0,0,40,5,0,0,48,5,0,0,56,5,0,0,80,5,0,0,152,4,0,0,88,5,0,0,136,5,0,0,24,5,0,0,136,5,0,0,144,5,0,0,24,5,0,0,152,5,0,0,176,5,0,0,184,5,0,0,200,5,0,0,224,5,0,0,232,5,0,0,240,5,0,0,16,6,0,0,152,4,0,0,24,6,0,0,56,6,0,0,64,6,0,0,80,6,0,0,99,112,117,0,0,0,0,0,109,101,109,0,0,0,0,0,115,99,99,0,0,0,0,0,118,105,97,0,0,0,0,0,117,110,107,110,111,119,110,32,99,111,109,112,111,110,101,110,116,32,40,37,115,41,10,0,0,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,49,0,0,0,0,0,0,0,37,48,56,108,88,58,32,101,120,99,101,112,116,105,111,110,32,37,48,50,88,32,40,37,115,41,32,73,87,61,37,48,52,88,10,0,0,0,0,0,37,48,56,108,88,58,32,117,110,100,101,102,105,110,101,100,32,111,112,101,114,97,116,105,111,110,58,32,37,48,52,108,88,32,91,37,48,52,88,32,37,48,52,88,32,37,48,52,88,32,37,48,52,88,32,37,48,52,88,93,10,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,37,48,56,108,88,32,32,37,115,10,0,0,0,0,0,0,37,48,52,88,32,0,0,0,32,32,32,32,32,0,0,0,37,45,56,115,32,37,115,0,37,45,56,115,32,37,115,44,32,37,115,0,0,0,0,0,37,45,56,115,32,37,115,44,32,37,115,44,32,37,115,0,59,32,0,0,0,0,0,0,109,105,115,115,105,110,103,32,114,101,103,105,115,116,101,114,10,0,0,0,0,0,0,0,98,97,100,32,114,101,103,105,115,116,101,114,32,40,37,115,41,10,0,0,0,0,0,0,37,48,56,108,88,10,0,0,109,105,115,115,105,110,103,32,118,97,108,117,101,10,0,0,101,0,0,0,0,0,0,0,101,120,99,101,112,116,105,111,110,32,37,48,50,88,32,40,37,115,41,10,0,0,0,0,54,53,50,50,45,86,73,65,0,0,0,0,0,0,0,0,32,80,67,82,61,37,48,50,88,32,32,65,67,82,61,37,48,50,88,32,32,73,70,82,61,37,48,50,88,32,32,73,69,82,61,37,48,50,88,32,32,73,82,81,61,37,117,10,0,0,0,0,0,0,0,0,68,68,82,65,61,37,48,50,88,32,68,68,82,66,61,37,48,50,88,32,32,67,65,49,61,37,88,32,32,32,84,49,76,61,37,48,52,88,32,83,72,70,84,61,37,48,50,88,47,37,117,10,0,0,0,0,32,73,82,65,61,37,48,50,88,32,32,73,82,66,61,37,48,50,88,32,32,67,65,50,61,37,88,32,32,37,99,84,49,86,61,37,48,52,88,10,0,0,0,0,0,0,0,0,32,79,82,65,61,37,48,50,88,32,32,79,82,66,61,37,48,50,88,32,32,67,66,49,61,37,88,32,32,32,84,50,76,61,37,48,52,88,10,0,32,32,80,65,61,37,48,50,88,32,32,32,80,66,61,37,48,50,88,32,32,67,66,50,61,37,88,32,32,37,99,84,50,86,61,37,48,52,88,10,0,0,0,0,0,0,0,0,56,53,51,48,45,83,67,67,0,0,0,0,0,0,0,0,32,32,73,82,81,61,37,117,10,0,0,0,0,0,0,0,87,82,37,48,50,117,65,61,37,48,50,88,32,32,82,82,37,48,50,117,65,61,37,48,50,88,32,32,87,82,37,48,50,117,66,61,37,48,50,88,32,32,82,82,37,48,50,117,66,61,37,48,50,88,10,0,77,69,77,0,0,0,0,0,54,56,48,48,48,0,0,0,67,76,75,61,37,108,120,32,32,79,80,61,37,108,120,32,32,68,76,89,61,37,108,117,32,32,67,80,73,61,37,46,52,102,10,0,0,0,0,0,32,83,82,61,37,48,52,88,91,37,99,37,99,93,32,32,67,67,61,37,48,50,88,91,37,99,37,99,37,99,37,99,37,99,93,32,69,88,61,37,48,50,88,40,37,45,52,115,41,32,84,82,80,61,37,48,52,88,32,73,77,76,61,37,88,32,73,80,76,61,37,88,10,0,0,0,0,0,0,0,32,68,48,61,37,48,56,108,88,32,32,68,52,61,37,48,56,108,88,32,32,65,48,61,37,48,56,108,88,32,32,65,52,61,37,48,56,108,88,32,32,32,80,67,61,37,48,56,108,88,10,0,0,0,0,0,32,68,49,61,37,48,56,108,88,32,32,68,53,61,37,48,56,108,88,32,32,65,49,61,37,48,56,108,88,32,32,65,53,61,37,48,56,108,88,32,32,76,80,67,61,37,48,56,108,88,10,0,0,0,0,0,32,68,50,61,37,48,56,108,88,32,32,68,54,61,37,48,56,108,88,32,32,65,50,61,37,48,56,108,88,32,32,65,54,61,37,48,56,108,88,32,32,85,83,80,61,37,48,56,108,88,10,0,0,0,0,0,32,68,51,61,37,48,56,108,88,32,32,68,55,61,37,48,56,108,88,32,32,65,51,61,37,48,56,108,88,32,32,65,55,61,37,48,56,108,88,32,32,83,83,80,61,37,48,56,108,88,10,0,0,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,109,97,114,107,58,32,80,67,61,37,48,54,108,88,10,0,117,110,104,97,110,100,108,101,100,32,104,111,111,107,32,40,37,48,52,88,41,10,0,0,109,97,99,46,105,110,115,101,114,116,0,0,0,0,0,0,49,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,107,101,121,112,97,100,32,109,111,100,101,58,32,109,111,116,105,111,110,10,0,0,0,0,107,101,121,112,97,100,32,109,111,100,101,58,32,107,101,121,112,97,100,10,0,0,0,0,117,110,104,97,110,100,108,101,100,32,109,97,103,105,99,32,107,101,121,32,40,37,117,41,10,0,0,0,0,0,0,0,105,119,109,58,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,37,117,32,40,112,114,105,41,10,0,0,0,0,105,119,109,58,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,37,117,32,40,100,105,115,107,41,10,0,0,0,105,119,109,58,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,37,117,32,102,97,105,108,101,100,10,0,0,0,105,119,109,58,32,115,97,118,105,110,103,32,100,114,105,118,101,32,37,117,10,0,0,0,105,119,109,58,32,115,97,118,105,110,103,32,100,114,105,118,101,32,37,117,32,102,97,105,108,101,100,32,40,112,114,105,41,10,0,0,0,0,0,0,105,119,109,58,32,115,97,118,105,110,103,32,100,114,105,118,101,32,37,117,32,102,97,105,108,101,100,32,40,100,105,115,107,41,10,0,0,0,0,0,0,43,48,42,47,4,53,41,46,12,58,3,52,25,9,40,45,55,14,11,57,32,30,2,51,28,17,24,8,21,63,39,44,49,5,54,13,59,26,10,56,15,33,31,29,18,22,1,50,6,60,27,16,34,19,23,7,61,35,20,62,36,37,38,105,119,109,58,32,100,114,105,118,101,32,37,117,32,101,106,101,99,116,10,0,0,0,0,73,87,77,58,32,68,37,117,32,84,114,97,99,107,32,37,117,32,32,32,32,13,0,0,230,41,1,0,14,17,1,0,52,248,0,0,102,223,0,0,150,198,0,0,0,0,0,0,17,0,0,0,1,0,101,0,0,0,0,0,0,0,1,0,229,0,0,0,0,0,0,0,18,0,0,0,1,0,37,0,0,0,0,0,0,0,1,0,165,0,0,0,0,0,0,0,19,0,0,0,1,0,39,0,0,0,0,0,0,0,1,0,167,0,0,0,0,0,0,0,20,0,0,0,1,0,41,0,0,0,0,0,0,0,1,0,169,0,0,0,0,0,0,0,21,0,0,0,1,0,43,0,0,0,0,0,0,0,1,0,171,0,0,0,0,0,0,0,22,0,0,0,1,0,47,0,0,0,0,0,0,0,1,0,175,0,0,0,0,0,0,0,23,0,0,0,1,0,45,0,0,0,0,0,0,0,1,0,173,0,0,0,0,0,0,0,24,0,0,0,1,0,53,0,0,0,0,0,0,0,1,0,181,0,0,0,0,0,0,0,25,0,0,0,1,0,57,0,0,0,0,0,0,0,1,0,185,0,0,0,0,0,0,0,26,0,0,0,1,0,51,0,0,0,0,0,0,0,1,0,179,0,0,0,0,0,0,0,27,0,0,0,1,0,59,0,0,0,0,0,0,0,1,0,187,0,0,0,0,0,0,0,28,0,0,0,1,0,55,0,0,0,0,0,0,0,1,0,183,0,0,0,0,0,0,0,29,0,0,0,1,0,49,0,0,0,0,0,0,0,1,0,177,0,0,0,0,0,0,0,30,0,0,0,1,0,103,0,0,0,0,0,0,0,1,0,231,0,0,0,0,0,0,0,31,0,0,0,1,0,97,0,0,0,0,0,0,0,1,0,225,0,0,0,0,0,0,0,32,0,0,0,1,0,25,0,0,0,0,0,0,0,1,0,153,0,0,0,0,0,0,0,33,0,0,0,1,0,27,0,0,0,0,0,0,0,1,0,155,0,0,0,0,0,0,0,34,0,0,0,1,0,29,0,0,0,0,0,0,0,1,0,157,0,0,0,0,0,0,0,35,0,0,0,1,0,31,0,0,0,0,0,0,0,1,0,159,0,0,0,0,0,0,0,36,0,0,0,1,0,35,0,0,0,0,0,0,0,1,0,163,0,0,0,0,0,0,0,37,0,0,0,1,0,33,0,0,0,0,0,0,0,1,0,161,0,0,0,0,0,0,0,38,0,0,0,1,0,65,0,0,0,0,0,0,0,1,0,193,0,0,0,0,0,0,0,39,0,0,0,1,0,69,0,0,0,0,0,0,0,1,0,197,0,0,0,0,0,0,0,40,0,0,0,1,0,63,0,0,0,0,0,0,0,1,0,191,0,0,0,0,0,0,0,41,0,0,0,1,0,71,0,0,0,0,0,0,0,1,0,199,0,0,0,0,0,0,0,42,0,0,0,1,0,67,0,0,0,0,0,0,0,1,0,195,0,0,0,0,0,0,0,43,0,0,0,1,0,61,0,0,0,0,0,0,0,1,0,189,0,0,0,0,0,0,0,57,0,0,0,1,0,85,0,0,0,0,0,0,0,1,0,213,0,0,0,0,0,0,0,44,0,0,0,1,0,73,0,0,0,0,0,0,0,1,0,201,0,0,0,0,0,0,0,45,0,0,0,1,0,115,0,0,0,0,0,0,0,1,0,243,0,0,0,0,0,0,0,46,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,129,0,0,0,0,0,0,0,47,0,0,0,1,0,3,0,0,0,0,0,0,0,1,0,131,0,0,0,0,0,0,0,48,0,0,0,1,0,5,0,0,0,0,0,0,0,1,0,133,0,0,0,0,0,0,0,49,0,0,0,1,0,7,0,0,0,0,0,0,0,1,0,135,0,0,0,0,0,0,0,50,0,0,0,1,0,11,0,0,0,0,0,0,0,1,0,139,0,0,0,0,0,0,0,51,0,0,0,1,0,9,0,0,0,0,0,0,0,1,0,137,0,0,0,0,0,0,0,52,0,0,0,1,0,77,0,0,0,0,0,0,0,1,0,205,0,0,0,0,0,0,0,53,0,0,0,1,0,81,0,0,0,0,0,0,0,1,0,209,0,0,0,0,0,0,0,54,0,0,0,1,0,75,0,0,0,0,0,0,0,1,0,203,0,0,0,0,0,0,0,55,0,0,0,1,0,83,0,0,0,0,0,0,0,1,0,211,0,0,0,0,0,0,0,56,0,0,0,1,0,79,0,0,0,0,0,0,0,1,0,207,0,0,0,0,0,0,0,58,0,0,0,1,0,113,0,0,0,0,0,0,0,1,0,241,0,0,0,0,0,0,0,70,0,0,0,1,0,113,0,0,0,0,0,0,0,1,0,241,0,0,0,0,0,0,0,60,0,0,0,1,0,13,0,0,0,0,0,0,0,1,0,141,0,0,0,0,0,0,0,61,0,0,0,1,0,15,0,0,0,0,0,0,0,1,0,143,0,0,0,0,0,0,0,62,0,0,0,1,0,17,0,0,0,0,0,0,0,1,0,145,0,0,0,0,0,0,0,63,0,0,0,1,0,19,0,0,0,0,0,0,0,1,0,147,0,0,0,0,0,0,0,64,0,0,0,1,0,23,0,0,0,0,0,0,0,1,0,151,0,0,0,0,0,0,0,66,0,0,0,1,0,91,0,0,0,0,0,0,0,1,0,219,0,0,0,0,0,0,0,65,0,0,0,1,0,93,0,0,0,0,0,0,0,1,0,221,0,0,0,0,0,0,0,67,0,0,0,1,0,87,0,0,0,0,0,0,0,1,0,215,0,0,0,0,0,0,0,68,0,0,0,1,0,95,0,0,0,0,0,0,0,1,0,223,0,0,0,0,0,0,0,69,0,0,0,1,0,89,0,0,0,0,0,0,0,1,0,217,0,0,0,0,0,0,0,71,0,0,0,1,0,117,0,0,0,0,0,0,0,1,0,245,0,0,0,0,0,0,0,81,0,0,0,1,0,117,0,0,0,0,0,0,0,1,0,245,0,0,0,0,0,0,0,75,0,0,0,1,0,111,0,0,0,0,0,0,0,1,0,239,0,0,0,0,0,0,0,77,0,0,0,1,0,105,0,0,0,0,0,0,0,1,0,233,0,0,0,0,0,0,0,76,0,0,0,1,0,99,0,0,0,0,0,0,0,1,0,227,0,0,0,0,0,0,0,82,0,0,0,2,0,121,15,0,0,0,0,0,0,2,0,121,143,0,0,0,0,0,0,83,0,0,0,3,0,113,121,27,0,0,0,0,0,3,0,121,155,241,0,0,0,0,0,84,0,0,0,3,0,113,121,5,0,0,0,0,0,3,0,121,133,241,0,0,0,0,0,85,0,0,0,2,0,121,29,0,0,0,0,0,0,2,0,121,157,0,0,0,0,0,0,86,0,0,0,2,0,121,51,0,0,0,0,0,0,2,0,121,179,0,0,0,0,0,0,87,0,0,0,2,0,121,55,0,0,0,0,0,0,2,0,121,183,0,0,0,0,0,0,88,0,0,0,2,0,121,57,0,0,0,0,0,0,2,0,121,185,0,0,0,0,0,0,89,0,0,0,3,0,113,121,13,0,0,0,0,0,3,0,121,141,241,0,0,0,0,0,90,0,0,0,2,0,121,45,0,0,0,0,0,0,2,0,121,173,0,0,0,0,0,0,91,0,0,0,2,0,121,47,0,0,0,0,0,0,2,0,121,175,0,0,0,0,0,0,92,0,0,0,2,0,121,49,0,0,0,0,0,0,2,0,121,177,0,0,0,0,0,0,93,0,0,0,2,0,121,39,0,0,0,0,0,0,2,0,121,167,0,0,0,0,0,0,94,0,0,0,2,0,121,41,0,0,0,0,0,0,2,0,121,169,0,0,0,0,0,0,95,0,0,0,2,0,121,43,0,0,0,0,0,0,2,0,121,171,0,0,0,0,0,0,96,0,0,0,2,0,121,25,0,0,0,0,0,0,2,0,121,153,0,0,0,0,0,0,97,0,0,0,2,0,121,37,0,0,0,0,0,0,2,0,121,165,0,0,0,0,0,0,98,0,0,0,2,0,121,3,0,0,0,0,0,0,2,0,121,131,0,0,0,0,0,0,105,0,0,0,2,0,121,27,0,0,0,0,0,0,2,0,121,155,0,0,0,0,0,0,106,0,0,0,2,0,121,13,0,0,0,0,0,0,2,0,121,141,0,0,0,0,0,0,108,0,0,0,2,0,121,5,0,0,0,0,0,0,2,0,121,133,0,0,0,0,0,0,107,0,0,0,2,0,121,17,0,0,0,0,0,0,2,0,121,145,0,0,0,0,0,0,100,0,0,0,2,0,121,103,0,0,0,0,0,0,2,0,121,231,0,0,0,0,0,0,103,0,0,0,2,0,121,111,0,0,0,0,0,0,2,0,121,239,0,0,0,0,0,0,101,0,0,0,2,0,121,105,0,0,0,0,0,0,2,0,121,233,0,0,0,0,0,0,104,0,0,0,2,0,121,115,0,0,0,0,0,0,2,0,121,243,0,0,0,0,0,0,99,0,0,0,2,0,121,101,0,0,0,0,0,0,2,0,121,101,0,0,0,0,0,0,102,0,0,0,2,0,121,107,0,0,0,0,0,0,2,0,121,235,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,0,0,1,0,101,0,0,0,0,0,0,0,1,0,229,0,0,0,0,0,0,0,18,0,0,0,1,0,39,0,0,0,0,0,0,0,1,0,167,0,0,0,0,0,0,0,19,0,0,0,1,0,39,0,0,0,0,0,0,0,1,0,167,0,0,0,0,0,0,0,20,0,0,0,1,0,41,0,0,0,0,0,0,0,1,0,169,0,0,0,0,0,0,0,21,0,0,0,1,0,43,0,0,0,0,0,0,0,1,0,171,0,0,0,0,0,0,0,22,0,0,0,1,0,47,0,0,0,0,0,0,0,1,0,175,0,0,0,0,0,0,0,23,0,0,0,1,0,45,0,0,0,0,0,0,0,1,0,173,0,0,0,0,0,0,0,24,0,0,0,1,0,53,0,0,0,0,0,0,0,1,0,181,0,0,0,0,0,0,0,25,0,0,0,1,0,57,0,0,0,0,0,0,0,1,0,185,0,0,0,0,0,0,0,26,0,0,0,1,0,51,0,0,0,0,0,0,0,1,0,179,0,0,0,0,0,0,0,27,0,0,0,1,0,59,0,0,0,0,0,0,0,1,0,187,0,0,0,0,0,0,0,28,0,0,0,1,0,55,0,0,0,0,0,0,0,1,0,183,0,0,0,0,0,0,0,29,0,0,0,1,0,49,0,0,0,0,0,0,0,1,0,177,0,0,0,0,0,0,0,30,0,0,0,1,0,103,0,0,0,0,0,0,0,1,0,231,0,0,0,0,0,0,0,31,0,0,0,1,0,97,0,0,0,0,0,0,0,1,0,225,0,0,0,0,0,0,0,32,0,0,0,1,0,25,0,0,0,0,0,0,0,1,0,153,0,0,0,0,0,0,0,33,0,0,0,1,0,27,0,0,0,0,0,0,0,1,0,155,0,0,0,0,0,0,0,34,0,0,0,1,0,29,0,0,0,0,0,0,0,1,0,157,0,0,0,0,0,0,0,35,0,0,0,1,0,31,0,0,0,0,0,0,0,1,0,159,0,0,0,0,0,0,0,36,0,0,0,1,0,35,0,0,0,0,0,0,0,1,0,163,0,0,0,0,0,0,0,37,0,0,0,1,0,33,0,0,0,0,0,0,0,1,0,161,0,0,0,0,0,0,0,38,0,0,0,1,0,65,0,0,0,0,0,0,0,1,0,193,0,0,0,0,0,0,0,39,0,0,0,1,0,69,0,0,0,0,0,0,0,1,0,197,0,0,0,0,0,0,0,40,0,0,0,1,0,63,0,0,0,0,0,0,0,1,0,191,0,0,0,0,0,0,0,41,0,0,0,1,0,71,0,0,0,0,0,0,0,1,0,199,0,0,0,0,0,0,0,42,0,0,0,1,0,67,0,0,0,0,0,0,0,1,0,195,0,0,0,0,0,0,0,43,0,0,0,1,0,61,0,0,0,0,0,0,0,1,0,189,0,0,0,0,0,0,0,44,0,0,0,1,0,85,0,0,0,0,0,0,0,1,0,213,0,0,0,0,0,0,0,45,0,0,0,1,0,115,0,0,0,0,0,0,0,1,0,243,0,0,0,0,0,0,0,46,0,0,0,1,0,1,0,0,0,0,0,0,0,1,0,129,0,0,0,0,0,0,0,47,0,0,0,1,0,3,0,0,0,0,0,0,0,1,0,131,0,0,0,0,0,0,0,48,0,0,0,1,0,5,0,0,0,0,0,0,0,1,0,133,0,0,0,0,0,0,0,49,0,0,0,1,0,7,0,0,0,0,0,0,0,1,0,135,0,0,0,0,0,0,0,50,0,0,0,1,0,11,0,0,0,0,0,0,0,1,0,139,0,0,0,0,0,0,0,51,0,0,0,1,0,9,0,0,0,0,0,0,0,1,0,137,0,0,0,0,0,0,0,52,0,0,0,1,0,77,0,0,0,0,0,0,0,1,0,205,0,0,0,0,0,0,0,53,0,0,0,1,0,81,0,0,0,0,0,0,0,1,0,209,0,0,0,0,0,0,0,54,0,0,0,1,0,75,0,0,0,0,0,0,0,1,0,203,0,0,0,0,0,0,0,55,0,0,0,1,0,83,0,0,0,0,0,0,0,1,0,211,0,0,0,0,0,0,0,56,0,0,0,1,0,79,0,0,0,0,0,0,0,1,0,207,0,0,0,0,0,0,0,57,0,0,0,1,0,73,0,0,0,0,0,0,0,1,0,201,0,0,0,0,0,0,0,58,0,0,0,1,0,113,0,0,0,0,0,0,0,1,0,241,0,0,0,0,0,0,0,70,0,0,0,1,0,113,0,0,0,0,0,0,0,1,0,241,0,0,0,0,0,0,0,59,0,0,0,1,0,13,0,0,0,0,0,0,0,1,0,141,0,0,0,0,0,0,0,60,0,0,0,1,0,15,0,0,0,0,0,0,0,1,0,143,0,0,0,0,0,0,0,61,0,0,0,1,0,17,0,0,0,0,0,0,0,1,0,145,0,0,0,0,0,0,0,62,0,0,0,1,0,19,0,0,0,0,0,0,0,1,0,147,0,0,0,0,0,0,0,63,0,0,0,1,0,23,0,0,0,0,0,0,0,1,0,151,0,0,0,0,0,0,0,64,0,0,0,1,0,91,0,0,0,0,0,0,0,1,0,219,0,0,0,0,0,0,0,66,0,0,0,1,0,93,0,0,0,0,0,0,0,1,0,221,0,0,0,0,0,0,0,65,0,0,0,1,0,87,0,0,0,0,0,0,0,1,0,215,0,0,0,0,0,0,0,67,0,0,0,1,0,95,0,0,0,0,0,0,0,1,0,223,0,0,0,0,0,0,0,68,0,0,0,1,0,89,0,0,0,0,0,0,0,1,0,217,0,0,0,0,0,0,0,69,0,0,0,1,0,21,0,0,0,0,0,0,0,1,0,149,0,0,0,0,0,0,0,71,0,0,0,1,0,117,0,0,0,0,0,0,0,1,0,245,0,0,0,0,0,0,0,81,0,0,0,1,0,117,0,0,0,0,0,0,0,1,0,245,0,0,0,0,0,0,0,75,0,0,0,1,0,111,0,0,0,0,0,0,0,1,0,239,0,0,0,0,0,0,0,77,0,0,0,1,0,99,0,0,0,0,0,0,0,1,0,227,0,0,0,0,0,0,0,76,0,0,0,1,0,105,0,0,0,0,0,0,0,1,0,233,0,0,0,0,0,0,0,82,0,0,0,2,0,121,15,0,0,0,0,0,0,2,0,121,143,0,0,0,0,0,0,83,0,0,0,3,0,113,121,27,0,0,0,0,0,3,0,121,155,241,0,0,0,0,0,84,0,0,0,3,0,113,121,5,0,0,0,0,0,3,0,121,133,241,0,0,0,0,0,85,0,0,0,2,0,121,29,0,0,0,0,0,0,2,0,121,157,0,0,0,0,0,0,86,0,0,0,2,0,121,51,0,0,0,0,0,0,2,0,121,179,0,0,0,0,0,0,87,0,0,0,2,0,121,55,0,0,0,0,0,0,2,0,121,183,0,0,0,0,0,0,88,0,0,0,2,0,121,57,0,0,0,0,0,0,2,0,121,185,0,0,0,0,0,0,89,0,0,0,3,0,113,121,13,0,0,0,0,0,3,0,121,141,241,0,0,0,0,0,90,0,0,0,2,0,121,45,0,0,0,0,0,0,2,0,121,173,0,0,0,0,0,0,91,0,0,0,2,0,121,47,0,0,0,0,0,0,2,0,121,175,0,0,0,0,0,0,92,0,0,0,2,0,121,49,0,0,0,0,0,0,2,0,121,177,0,0,0,0,0,0,93,0,0,0,2,0,121,39,0,0,0,0,0,0,2,0,121,167,0,0,0,0,0,0,94,0,0,0,2,0,121,41,0,0,0,0,0,0,2,0,121,169,0,0,0,0,0,0,95,0,0,0,2,0,121,43,0,0,0,0,0,0,2,0,121,171,0,0,0,0,0,0,96,0,0,0,2,0,121,25,0,0,0,0,0,0,2,0,121,153,0,0,0,0,0,0,97,0,0,0,2,0,121,37,0,0,0,0,0,0,2,0,121,165,0,0,0,0,0,0,98,0,0,0,2,0,121,3,0,0,0,0,0,0,2,0,121,131,0,0,0,0,0,0,105,0,0,0,2,0,121,27,0,0,0,0,0,0,2,0,121,155,0,0,0,0,0,0,106,0,0,0,2,0,121,13,0,0,0,0,0,0,2,0,121,141,0,0,0,0,0,0,108,0,0,0,2,0,121,5,0,0,0,0,0,0,2,0,121,133,0,0,0,0,0,0,107,0,0,0,2,0,121,17,0,0,0,0,0,0,2,0,121,145,0,0,0,0,0,0,100,0,0,0,2,0,121,103,0,0,0,0,0,0,2,0,121,231,0,0,0,0,0,0,103,0,0,0,2,0,121,111,0,0,0,0,0,0,2,0,121,239,0,0,0,0,0,0,101,0,0,0,2,0,121,105,0,0,0,0,0,0,2,0,121,233,0,0,0,0,0,0,104,0,0,0,2,0,121,115,0,0,0,0,0,0,2,0,121,243,0,0,0,0,0,0,99,0,0,0,2,0,121,101,0,0,0,0,0,0,2,0,121,229,0,0,0,0,0,0,102,0,0,0,2,0,121,107,0,0,0,0,0,0,2,0,121,235,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,0,0,0,2,0,121,103,0,0,0,0,0,0,2,0,121,231,0,0,0,0,0,0,87,0,0,0,2,0,121,27,0,0,0,0,0,0,2,0,121,155,0,0,0,0,0,0,88,0,0,0,2,0,121,105,0,0,0,0,0,0,2,0,121,233,0,0,0,0,0,0,90,0,0,0,2,0,121,13,0,0,0,0,0,0,2,0,121,141,0,0,0,0,0,0,91,0,0,0,2,0,121,25,0,0,0,0,0,0,2,0,121,153,0,0,0,0,0,0,92,0,0,0,2,0,121,5,0,0,0,0,0,0,2,0,121,133,0,0,0,0,0,0,93,0,0,0,2,0,121,111,0,0,0,0,0,0,2,0,121,239,0,0,0,0,0,0,94,0,0,0,2,0,121,17,0,0,0,0,0,0,2,0,121,145,0,0,0,0,0,0,95,0,0,0,2,0,121,115,0,0,0,0,0,0,2,0,121,243,0,0,0,0,0,0,97,0,0,0,2,0,121,101,0,0,0,0,0,0,2,0,121,101,0,0,0,0,0,0,98,0,0,0,2,0,121,107,0,0,0,0,0,0,2,0,121,235,0,0,0,0,0,0,96,0,0,0,1,0,73,0,0,0,0,0,0,0,1,0,201,0,0,0,0,0,0,0,100,0,0,0,2,0,121,51,0,0,0,0,0,0,2,0,121,179,0,0,0,0,0,0,105,0,0,0,2,0,121,55,0,0,0,0,0,0,2,0,121,183,0,0,0,0,0,0,101,0,0,0,2,0,121,57,0,0,0,0,0,0,2,0,121,185,0,0,0,0,0,0,106,0,0,0,2,0,121,45,0,0,0,0,0,0,2,0,121,173,0,0,0,0,0,0,108,0,0,0,2,0,121,49,0,0,0,0,0,0,2,0,121,177,0,0,0,0,0,0,103,0,0,0,2,0,121,39,0,0,0,0,0,0,2,0,121,167,0,0,0,0,0,0,107,0,0,0,2,0,121,41,0,0,0,0,0,0,2,0,121,169,0,0,0,0,0,0,104,0,0,0,2,0,121,43,0,0,0,0,0,0,2,0,121,171,0,0,0,0,0,0,99,0,0,0,2,0,121,37,0,0,0,0,0,0,2,0,121,165,0,0,0,0,0,0,102,0,0,0,2,0,121,3,0,0,0,0,0,0,2,0,121,131,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,86,0,0,0,2,0,121,51,0,0,0,0,0,0,2,0,121,179,0,0,0,0,0,0,87,0,0,0,2,0,121,55,0,0,0,0,0,0,2,0,121,183,0,0,0,0,0,0,88,0,0,0,2,0,121,57,0,0,0,0,0,0,2,0,121,185,0,0,0,0,0,0,90,0,0,0,2,0,121,45,0,0,0,0,0,0,2,0,121,173,0,0,0,0,0,0,91,0,0,0,2,0,121,47,0,0,0,0,0,0,2,0,121,175,0,0,0,0,0,0,92,0,0,0,2,0,121,49,0,0,0,0,0,0,2,0,121,177,0,0,0,0,0,0,93,0,0,0,2,0,121,39,0,0,0,0,0,0,2,0,121,167,0,0,0,0,0,0,94,0,0,0,2,0,121,41,0,0,0,0,0,0,2,0,121,169,0,0,0,0,0,0,95,0,0,0,2,0,121,43,0,0,0,0,0,0,2,0,121,171,0,0,0,0,0,0,97,0,0,0,2,0,121,37,0,0,0,0,0,0,2,0,121,165,0,0,0,0,0,0,98,0,0,0,2,0,121,3,0,0,0,0,0,0,2,0,121,131,0,0,0,0,0,0,96,0,0,0,2,0,121,25,0,0,0,0,0,0,2,0,121,153,0,0,0,0,0,0,100,0,0,0,2,0,121,103,0,0,0,0,0,0,2,0,121,231,0,0,0,0,0,0,105,0,0,0,2,0,121,27,0,0,0,0,0,0,2,0,121,155,0,0,0,0,0,0,101,0,0,0,2,0,121,105,0,0,0,0,0,0,2,0,121,233,0,0,0,0,0,0,106,0,0,0,2,0,121,13,0,0,0,0,0,0,2,0,121,141,0,0,0,0,0,0,108,0,0,0,2,0,121,5,0,0,0,0,0,0,2,0,121,133,0,0,0,0,0,0,103,0,0,0,2,0,121,111,0,0,0,0,0,0,2,0,121,239,0,0,0,0,0,0,107,0,0,0,2,0,121,17,0,0,0,0,0,0,2,0,121,145,0,0,0,0,0,0,104,0,0,0,2,0,121,115,0,0,0,0,0,0,2,0,121,243,0,0,0,0,0,0,99,0,0,0,2,0,121,101,0,0,0,0,0,0,2,0,121,101,0,0,0,0,0,0,102,0,0,0,2,0,121,107,0,0,0,0,0,0,2,0,121,235,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,103,110,111,114,105,110,103,32,112,99,101,32,107,101,121,58,32,37,48,52,120,32,40,37,115,41,10,0,0,0,0,60,110,111,110,101,62,0,0,107,98,100,58,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,32,40,37,48,50,88,41,10,0,0,0,0,116,101,114,109,46,116,105,116,108,101,0,0,0,0,0,0,112,99,101,45,109,97,99,112,108,117,115,0,0,0,0,0,54,56,48,48,48,0,0,0,54,56,48,49,48,0,0,0,54,56,48,50,48,0,0,0,109,97,99,58,32,114,101,115,101,116,10,0,0,0,0,0,115,121,115,116,101,109,32,116,111,111,32,115,108,111,119,44,32,115,107,105,112,112,105,110,103,32,49,32,115,101,99,111,110,100,10,0,0,0,0,0,115,112,101,101,100,58,32,37,117,10,0,0,0,0,0,0,118,105,100,101,111,0,0,0,97,100,100,114,101,115,115,0,119,105,100,116,104,0,0,0,104,101,105,103,104,116,0,0,99,111,108,111,114,48,0,0,99,111,108,111,114,49,0,0,98,114,105,103,104,116,110,101,115,115,0,0,0,0,0,0,86,73,68,69,79,58,0,0,97,100,100,114,61,48,120,37,48,54,108,88,32,119,61,37,117,32,104,61,37,117,32,98,114,105,103,104,116,61,37,117,37,37,10,0,0,0,0,0,0,1,59,2,60,40,54,3,61,32,49,41,55,19,35,4,62,52,30,33,50,12,14,42,56,16,27,20,36,23,44,5,63,58,39,53,31,48,18,34,51,29,11,13,15,26,22,43,57,38,47,17,28,10,25,21,37,46,9,24,45,8,7,6,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,49,0,0,0,0,0,0,0,115,111,117,110,100,0,0,0,108,111,119,112,97,115,115,0,100,114,105,118,101,114,0,0,83,79,85,78,68,58,0,0,97,100,100,114,61,48,120,37,48,54,108,88,32,108,111,119,112,97,115,115,61,37,108,117,32,100,114,105,118,101,114,61,37,115,10,0,0,0,0,0,60,110,111,110,101,62,0,0,42,42,42,32,115,101,116,116,105,110,103,32,115,111,117,110,100,32,100,114,105,118,101,114,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,115,111,110,121,0,0,0,0,105,110,115,101,114,116,95,100,101,108,97,121,0,0,0,0,102,111,114,109,97,116,95,104,100,95,97,115,95,100,100,0,105,110,115,101,114,116,95,100,101,108,97,121,95,37,117,0,83,79,78,89,58,0,0,0,100,114,105,118,101,61,37,117,32,100,101,108,97,121,61,37,108,117,10,0,0,0,0,0,115,99,115,105,0,0,0,0,115,105,122,101,0,0,0,0,83,67,83,73,58,0,0,0,97,100,100,114,61,48,120,37,48,54,108,120,32,115,105,122,101,61,48,120,37,108,120,10,0,0,0,0,0,0,0,0,100,101,118,105,99,101,0,0,105,100,0,0,0,0,0,0,100,114,105,118,101,0,0,0,118,101,110,100,111,114,0,0,80,67,69,0,0,0,0,0,112,114,111,100,117,99,116,0,80,67,69,68,73,83,75,0,105,100,61,37,117,32,100,114,105,118,101,61,37,117,32,118,101,110,100,111,114,61,34,37,115,34,32,112,114,111,100,117,99,116,61,34,37,115,34,10,0,0,0,0,0,0,0,0,105,119,109,0,0,0,0,0,73,87,77,58,0,0,0,0,97,100,100,114,61,48,120,37,48,54,108,120,10,0,0,0,100,105,115,107,0,0,0,0,102,105,108,101,0,0,0,0,115,105,110,103,108,101,95,115,105,100,101,100,0,0,0,0,108,111,99,107,101,100,0,0,105,110,115,101,114,116,101,100,0,0,0,0,0,0,0,0,97,117,116,111,95,114,111,116,97,116,101,0,0,0,0,0,100,114,105,118,101,61,37,117,32,115,105,122,101,61,37,117,75,32,108,111,99,107,101,100,61,37,100,32,114,111,116,97,116,101,61,37,100,32,100,105,115,107,61,37,117,32,102,105,108,101,61,37,115,10,0,0,97,100,98,0,0,0,0,0,109,111,117,115,101,0,0,0,107,101,121,98,111,97,114,100,0,0,0,0,0,0,0,0,107,101,121,112,97,100,95,109,111,116,105,111,110,0,0,0,65,68,66,58,0,0,0,0,101,110,97,98,108,101,100,10,0,0,0,0,0,0,0,0,42,42,42,32,99,97,110,39,116,32,99,114,101,97,116,101,32,97,100,98,10,0,0,0,109,111,117,115,101,10,0,0,107,101,121,98,111,97,114,100,32,107,101,121,112,97,100,95,109,111,100,101,61,37,115,10,0,0,0,0,0,0,0,0,109,111,116,105,111,110,0,0,107,101,121,112,97,100,0,0,109,111,100,101,108,0,0,0,105,110,116,108,0,0,0,0,75,69,89,66,79,65,82,68,58,0,0,0,0,0,0,0,109,111,100,101,108,61,37,117,32,105,110,116,101,114,110,97,116,105,111,110,97,108,61,37,100,32,107,101,121,112,97,100,61,37,115,10,0,0,0,0,114,116,99,0,0,0,0,0,112,114,97,109,46,100,97,116,0,0,0,0,0,0,0,0,114,101,97,108,116,105,109,101,0,0,0,0,0,0,0,0,114,111,109,100,105,115,107,0,115,116,97,114,116,0,0,0,82,84,67,58,0,0,0,0,102,105,108,101,61,37,115,32,114,101,97,108,116,105,109,101,61,37,100,32,115,116,97,114,116,61,37,115,32,114,111,109,100,105,115,107,61,37,100,10,0,0,0,0,0,0,0,0,60,110,111,119,62,0,0,0,42,42,42,32,114,101,97,100,105,110,103,32,114,116,99,32,102,105,108,101,32,102,97,105,108,101,100,10,0,0,0,0,115,101,114,105,97,108,0,0,112,111,114,116,0,0,0,0,109,117,108,116,105,99,104,97,114,0,0,0,0,0,0,0,83,69,82,73,65,76,58,0,112,111,114,116,61,37,117,32,109,117,108,116,105,99,104,97,114,61,37,117,32,100,114,105,118,101,114,61,37,115,10,0,42,42,42,32,98,97,100,32,112,111,114,116,32,110,117,109,98,101,114,32,40,37,117,41,10,0,0,0,0,0,0,0,42,42,42,32,99,97,110,39,116,32,111,112,101,110,32,100,114,105,118,101,114,32,40,37,115,41,10,0,0,0,0,0,115,99,99,0,0,0,0,0,83,67,67,58,0,0,0,0,118,105,97,0,0,0,0,0,86,73,65,58,0,0,0,0,109,97,105,110,32,118,105,100,101,111,32,98,117,102,102,101,114,10,0,0,0,0,0,0,97,108,116,101,114,110,97,116,101,32,118,105,100,101,111,32,98,117,102,102,101,114,10,0,109,97,105,110,32,115,111,117,110,100,32,98,117,102,102,101,114,10,0,0,0,0,0,0,97,108,116,101,114,110,97,116], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE);
/* memory initializer */ allocate([101,32,115,111,117,110,100,32,98,117,102,102,101,114,10,0,99,112,117,0,0,0,0,0,115,112,101,101,100,0,0,0,67,80,85,58,0,0,0,0,109,111,100,101,108,61,37,115,32,115,112,101,101,100,61,37,100,10,0,0,0,0,0,0,42,42,42,32,117,110,107,110,111,119,110,32,99,112,117,32,109,111,100,101,108,32,40,37,115,41,10,0,0,0,0,0,42,42,42,32,82,65,77,32,110,111,116,32,102,111,117,110,100,32,97,116,32,48,48,48,48,48,48,10,0,0,0,0,42,42,42,32,82,79,77,32,110,111,116,32,102,111,117,110,100,32,97,116,32,52,48,48,48,48,48,10,0,0,0,0,109,101,109,116,101,115,116,0,82,65,77,58,0,0,0,0,100,105,115,97,98,108,105,110,103,32,109,101,109,111,114,121,32,116,101,115,116,10,0,0,115,121,115,116,101,109,0,0,109,97,99,45,112,108,117,115,0,0,0,0,0,0,0,0,83,89,83,84,69,77,58,0,109,111,100,101,108,61,37,115,10,0,0,0,0,0,0,0,109,97,99,45,115,101,0,0,109,97,99,45,99,108,97,115,115,105,99,0,0,0,0,0,42,42,42,32,117,110,107,110,111,119,110,32,109,111,100,101,108,32,40,37,115,41,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,45,109,97,99,112,108,117,115,58,32,115,101,103,109,101,110,116,97,116,105,111,110,32,102,97,117,108,116,10,0,0,0,0,0,0,0,0,99,112,117,0,0,0,0,0,112,99,101,45,109,97,99,112,108,117,115,58,32,115,105,103,110,97,108,32,37,100,10,0,91,37,48,54,108,88,93,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,99,101,45,99,111,110,102,105,103,46,99,102,103,0,0,63,0,0,0,16,45,0,0,0,0,0,0,24,45,0,0,98,0,1,0,48,45,0,0,64,45,0,0,72,45,0,0,66,0,2,0,112,45,0,0,128,45,0,0,144,45,0,0,99,0,1,0,168,45,0,0,176,45,0,0,184,45,0,0,100,0,1,0,216,45,0,0,176,45,0,0,224,45,0,0,105,0,1,0,8,46,0,0,176,45,0,0,24,46,0,0,73,0,1,0,72,46,0,0,176,45,0,0,88,46,0,0,108,0,1,0,128,46,0,0,176,45,0,0,136,46,0,0,112,0,1,0,128,41,0,0,176,45,0,0,168,46,0,0,113,0,0,0,192,46,0,0,0,0,0,0,200,46,0,0,114,0,0,0,232,46,0,0,0,0,0,0,240,46,0,0,82,0,0,0,16,47,0,0,0,0,0,0,32,47,0,0,115,0,1,0,56,47,0,0,64,47,0,0,72,47,0,0,116,0,1,0,96,47,0,0,176,45,0,0,112,47,0,0,118,0,0,0,136,47,0,0,0,0,0,0,144,47,0,0,86,0,0,0,176,47,0,0,0,0,0,0,184,47,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,115,58,32,98,97,100,32,100,114,105,118,101,32,110,117,109,98,101,114,32,40,37,117,41,10,0,0,0,0,0,0,37,115,58,32,101,114,114,111,114,32,112,97,114,115,105,110,103,32,105,110,105,32,115,116,114,105,110,103,32,40,37,115,41,10,0,0,0,0,0,0,10,0,0,0,0,0,0,0,99,112,117,46,109,111,100,101,108,32,61,32,34,0,0,0,34,10,0,0,0,0,0,0,99,112,117,46,115,112,101,101,100,32,61,32,0,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,111,112,116,105,111,110,32,40,37,115,41,10,0,0,0,0,0,0,0,0,109,97,99,112,108,117,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,67,79,78,70,73,71,58,0,102,105,108,101,61,34,37,115,34,10,0,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,99,111,110,102,105,103,32,102,105,108,101,32,102,97,105,108,101,100,10,0,112,99,101,45,109,97,99,112,108,117,115,32,118,101,114,115,105,111,110,32,50,48,49,52,48,53,48,57,45,98,50,98,49,99,97,54,45,109,111,100,10,67,111,112,121,114,105,103,104,116,32,40,67,41,32,50,48,48,55,45,50,48,49,50,32,72,97,109,112,97,32,72,117,103,32,60,104,97,109,112,97,64,104,97,109,112,97,46,99,104,62,10,0,0,0,0,112,99,101,45,109,97,99,112,108,117,115,32,118,101,114,115,105,111,110,32,50,48,49,52,48,53,48,57,45,98,50,98,49,99,97,54,45,109,111,100,10,10,67,111,112,121,114,105,103,104,116,32,40,67,41,32,50,48,48,55,45,50,48,49,50,32,72,97,109,112,97,32,72,117,103,32,60,104,97,109,112,97,64,104,97,109,112,97,46,99,104,62,10,0,0,0,112,99,101,45,109,97,99,112,108,117,115,58,32,77,97,99,105,110,116,111,115,104,32,80,108,117,115,32,101,109,117,108,97,116,111,114,0,0,0,0,117,115,97,103,101,58,32,112,99,101,45,109,97,99,112,108,117,115,32,91,111,112,116,105,111,110,115,93,0,0,0,0,104,101,108,112,0,0,0,0,80,114,105,110,116,32,117,115,97,103,101,32,105,110,102,111,114,109,97,116,105,111,110,0,100,105,115,107,45,100,101,108,97,121,45,49,0,0,0,0,100,101,108,97,121,0,0,0,83,101,116,32,116,104,101,32,100,105,115,107,32,100,101,108,97,121,32,102,111,114,32,100,114,105,118,101,32,49,32,91,51,48,93,0,0,0,0,0,100,105,115,107,45,100,101,108,97,121,0,0,0,0,0,0,100,114,105,118,101,32,100,101,108,97,121,0,0,0,0,0,83,101,116,32,116,104,101,32,100,105,115,107,32,100,101,108,97,121,32,91,51,48,93,0,99,111,110,102,105,103,0,0,115,116,114,105,110,103,0,0,83,101,116,32,116,104,101,32,99,111,110,102,105,103,32,102,105,108,101,32,110,97,109,101,32,91,110,111,110,101,93,0,112,97,116,104,0,0,0,0,65,100,100,32,97,32,100,105,114,101,99,116,111,114,121,32,116,111,32,116,104,101,32,115,101,97,114,99,104,32,112,97,116,104,0,0,0,0,0,0,105,110,105,45,112,114,101,102,105,120,0,0,0,0,0,0,65,100,100,32,97,110,32,105,110,105,32,115,116,114,105,110,103,32,98,101,102,111,114,101,32,116,104,101,32,99,111,110,102,105,103,32,102,105,108,101,0,0,0,0,0,0,0,0,105,110,105,45,97,112,112,101,110,100,0,0,0,0,0,0,65,100,100,32,97,110,32,105,110,105,32,115,116,114,105,110,103,32,97,102,116,101,114,32,116,104,101,32,99,111,110,102,105,103,32,102,105,108,101,0,108,111,103,0,0,0,0,0,83,101,116,32,116,104,101,32,108,111,103,32,102,105,108,101,32,110,97,109,101,32,91,110,111,110,101,93,0,0,0,0,83,101,116,32,116,104,101,32,67,80,85,32,109,111,100,101,108,0,0,0,0,0,0,0,113,117,105,101,116,0,0,0,83,101,116,32,116,104,101,32,108,111,103,32,108,101,118,101,108,32,116,111,32,101,114,114,111,114,32,91,110,111,93,0,114,117,110,0,0,0,0,0,83,116,97,114,116,32,114,117,110,110,105,110,103,32,105,109,109,101,100,105,97,116,101,108,121,32,91,110,111,93,0,0,110,111,45,109,111,110,105,116,111,114,0,0,0,0,0,0,78,101,118,101,114,32,115,116,111,112,32,114,117,110,110,105,110,103,32,91,110,111,93,0,115,112,101,101,100,0,0,0,105,110,116,0,0,0,0,0,83,101,116,32,116,104,101,32,67,80,85,32,115,112,101,101,100,0,0,0,0,0,0,0,116,101,114,109,105,110,97,108,0,0,0,0,0,0,0,0,83,101,116,32,116,104,101,32,116,101,114,109,105,110,97,108,32,100,101,118,105,99,101,0,118,101,114,98,111,115,101,0,83,101,116,32,116,104,101,32,108,111,103,32,108,101,118,101,108,32,116,111,32,100,101,98,117,103,32,91,110,111,93,0,118,101,114,115,105,111,110,0,80,114,105,110,116,32,118,101,114,115,105,111,110,32,105,110,102,111,114,109,97,116,105,111,110,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,48,0,0,1,0,0,0,168,48,0,0,2,0,0,0,184,48,0,0,3,0,0,0,208,48,0,0,4,0,0,0,224,48,0,0,5,0,0,0,240,48,0,0,6,0,0,0,0,49,0,0,7,0,0,0,16,49,0,0,8,0,0,0,32,49,0,0,9,0,0,0,48,49,0,0,10,0,0,0,64,49,0,0,11,0,0,0,80,49,0,0,12,0,0,0,96,49,0,0,13,0,0,0,112,49,0,0,14,0,0,0,136,49,0,0,15,0,0,0,152,49,0,0,16,0,0,0,176,49,0,0,17,0,0,0,192,49,0,0,18,0,0,0,216,49,0,0,19,0,0,0,240,49,0,0,20,0,0,0,0,50,0,0,21,0,0,0,24,50,0,0,22,0,0,0,0,0,0,0,0,0,0,0,101,109,117,46,99,112,117,46,109,111,100,101,108,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,46,115,116,101,112,0,0,0,0,0,0,101,109,117,46,100,105,115,107,46,99,111,109,109,105,116,0,101,109,117,46,100,105,115,107,46,101,106,101,99,116,0,0,101,109,117,46,100,105,115,107,46,105,110,115,101,114,116,0,101,109,117,46,100,105,115,107,46,114,111,0,0,0,0,0,101,109,117,46,100,105,115,107,46,114,119,0,0,0,0,0,101,109,117,46,105,119,109,46,114,111,0,0,0,0,0,0,101,109,117,46,105,119,109,46,114,119,0,0,0,0,0,0,101,109,117,46,105,119,109,46,115,116,97,116,117,115,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,101,109,117,46,112,97,117,115,101,0,0,0,0,0,0,0,101,109,117,46,112,97,117,115,101,46,116,111,103,103,108,101,0,0,0,0,0,0,0,0,101,109,117,46,114,101,97,108,116,105,109,101,0,0,0,0,101,109,117,46,114,101,97,108,116,105,109,101,46,116,111,103,103,108,101,0,0,0,0,0,101,109,117,46,114,101,115,101,116,0,0,0,0,0,0,0,101,109,117,46,115,101,114,112,111,114,116,46,100,114,105,118,101,114,0,0,0,0,0,0,101,109,117,46,115,101,114,112,111,114,116,46,102,105,108,101,0,0,0,0,0,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,101,109,117,46,118,105,100,101,111,46,98,114,105,103,104,116,110,101,115,115,0,0,0,0,109,97,99,46,105,110,115,101,114,116,0,0,0,0,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,49,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,32,9,0,0,0,0,0,0,73,87,77,32,100,114,105,118,101,32,37,117,58,32,108,111,99,107,101,100,61,37,100,10,0,0,0,0,0,0,0,0,115,101,116,116,105,110,103,32,97,108,108,32,105,119,109,32,100,114,105,118,101,115,32,116,111,32,114,101,97,100,47,119,114,105,116,101,10,0,0,0,115,101,116,116,105,110,103,32,105,119,109,32,100,114,105,118,101,32,37,108,117,32,116,111,32,114,101,97,100,47,119,114,105,116,101,10,0,0,0,0,115,101,116,116,105,110,103,32,97,108,108,32,105,119,109,32,100,114,105,118,101,115,32,116,111,32,114,101,97,100,45,111,110,108,121,10,0,0,0,0,115,101,116,116,105,110,103,32,105,119,109,32,100,114,105,118,101,32,37,108,117,32,116,111,32,114,101,97,100,45,111,110,108,121,10,0,0,0,0,0,115,101,116,116,105,110,103,32,114,101,97,100,47,119,114,105,116,101,32,100,114,105,118,101,32,37,108,117,10,0,0,0,115,101,116,116,105,110,103,32,114,101,97,100,111,110,108,121,32,100,114,105,118,101,32,37,108,117,10,0,0,0,0,0,42,42,42,32,100,105,115,107,32,101,106,101,99,116,32,101,114,114,111,114,58,32,98,97,100,32,100,114,105,118,101,32,40,37,115,41,10,0,0,0,42,42,42,32,100,105,115,107,32,101,106,101,99,116,32,101,114,114,111,114,58,32,110,111,32,115,117,99,104,32,100,105,115,107,32,40,37,108,117,41,10,0,0,0,0,0,0,0,101,106,101,99,116,105,110,103,32,100,114,105,118,101,32,37,108,117,10,0,0,0,0,0,97,108,108,0,0,0,0,0,99,111,109,109,105,116,105,110,103,32,97,108,108,32,100,114,105,118,101,115,10,0,0,0,42,42,42,32,99,111,109,109,105,116,32,102,97,105,108,101,100,32,102,111,114,32,97,116,32,108,101,97,115,116,32,111,110,101,32,100,105,115,107,10,0,0,0,0,0,0,0,0,42,42,42,32,99,111,109,109,105,116,32,101,114,114,111,114,58,32,98,97,100,32,100,114,105,118,101,32,40,37,115,41,10,0,0,0,0,0,0,0,99,111,109,109,105,116,105,110,103,32,100,114,105,118,101,32,37,117,10,0,0,0,0,0,99,111,109,109,105,116,0,0,42,42,42,32,99,111,109,109,105,116,32,101,114,114,111,114,32,102,111,114,32,100,114,105,118,101,32,37,117,10,0,0,117,110,107,110,111,119,110,32,67,80,85,32,109,111,100,101,108,32,40,37,115,41,10,0,114,98,0,0,0,0,0,0,31,0,0,0,28,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,29,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,80,67,69,68,73,83,75,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,0,115,99,115,105,58,32,103,101,116,32,32,56,58,32,37,48,52,108,88,32,45,62,32,37,48,50,88,10,0,0,0,0,115,99,115,105,58,32,115,101,116,32,32,56,58,32,37,48,52,108,88,32,60,45,32,37,48,50,88,10,0,0,0,0,115,99,115,105,58,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,32,40,37,48,50,88,41,10,0,0,0,115,99,115,105,58,32,119,114,105,116,101,32,98,108,111,99,107,32,99,111,117,110,116,32,37,117,10,0,0,0,0,0,115,99,115,105,58,32,119,114,105,116,101,32,115,105,122,101,32,109,105,115,109,97,116,99,104,32,40,37,117,32,47,32,37,117,41,10,0,0,0,0,115,99,115,105,58,32,119,114,105,116,101,32,101,114,114,111,114,10,0,0,0,0,0,0,115,99,115,105,58,32,116,111,111,32,109,97,110,121,32,98,108,111,99,107,115,32,40,37,117,41,10,0,0,0,0,0,115,99,115,105,58,32,114,101,97,100,32,101,114,114,111,114,32,97,116,32,37,108,117,32,43,32,37,108,117,10,0,0,115,116,111,112,32,109,111,116,111,114,0,0,0,0,0,0,115,116,97,114,116,32,109,111,116,111,114,0,0,0,0,0,101,106,101,99,116,32,109,101,100,105,97,0,0,0,0,0,108,111,97,100,32,109,101,100,105,97,0,0,0,0,0,0,115,99,115,105,58,32,115,116,97,114,116,47,115,116,111,112,32,117,110,105,116,32,37,117,32,40,37,115,41,10,0,0,65,80,80,76,69,32,67,79,77,80,85,84,69,82,44,32,73,78,67,0,0,0,0,0,115,99,115,105,58,32,109,111,100,101,32,115,101,110,115,101,58,32,117,110,107,110,111,119,110,32,109,111,100,101,32,112,97,103,101,32,40,37,48,50,88,41,10,0,0,0,0,0,115,116,100,105,111,58,102,105,108,101,61,0,0,0,0,0,83,79,78,89,58,0,0,0,80,67,69,32,82,79,77,32,101,120,116,101,110,115,105,111,110,32,110,111,116,32,102,111,117,110,100,10,0,0,0,0,80,67,69,32,82,79,77,32,101,120,116,101,110,115,105,111,110,32,97,116,32,48,120,37,48,54,108,120,10,0,0,0,115,111,110,121,32,100,114,105,118,101,114,32,110,111,116,32,102,111,117,110,100,10,0,0,115,111,110,121,32,100,114,105,118,101,114,32,97,116,32,48,120,37,48,54,108,120,10,0,105,110,115,101,114,116,32,100,114,105,118,101,32,37,117,10,0,0,0,0,0,0,0,0,115,111,110,121,58,32,115,116,97,116,117,115,58,32,117,110,107,110,111,119,110,32,40,99,115,61,48,120,37,48,52,120,41,10,0,0,0,0,0,0,115,111,110,121,58,32,99,111,110,116,114,111,108,58,32,117,110,107,110,111,119,110,32,40,111,112,99,111,100,101,61,48,120,37,48,52,120,41,10,0,115,111,110,121,58,32,119,114,105,116,101,32,101,114,114,111,114,32,97,116,32,37,117,47,37,117,47,37,117,10,0,0,115,111,110,121,58,32,99,104,115,32,101,114,114,111,114,32,40,98,108,107,61,37,108,117,44,32,108,98,97,61,37,108,117,41,10,0,0,0,0,0,115,111,110,121,58,32,102,111,114,109,97,116,116,101,100,32,100,105,115,107,32,40,37,108,117,32,98,108,111,99,107,115,41,10,0,0,0,0,0,0,115,111,110,121,58,32,112,114,105,109,101,58,32,117,110,107,110,111,119,110,32,40,116,114,97,112,61,48,120,37,48,52,120,41,10,0,0,0,0,0,115,111,110,121,58,32,110,111,110,45,97,108,105,103,110,101,100,32,119,114,105,116,101,10,0,0,0,0,0,0,0,0,115,111,110,121,58,32,119,114,105,116,101,32,101,114,114,111,114,10,0,0,0,0,0,0,115,111,110,121,58,32,110,111,110,45,97,108,105,103,110,101,100,32,114,101,97,100,10,0,115,111,110,121,58,32,114,101,97,100,32,101,114,114,111,114,10,0,0,0,0,0,0,0,115,111,110,121,58,32,114,101,97,100,32,101,114,114,111,114,32,97,116,32,37,117,47,37,117,47,37,117,10,0,0,0,0,168,0,0,160,87,0,0,1,168,0,0,176,87,0,0,2,168,0,0,200,87,0,0,3,168,0,0,216,87,0,0,4,168,0,0,232,87,0,0,5,168,0,0,248,87,0,0,6,168,0,0,0,88,0,0,7,168,0,0,16,88,0,0,8,168,0,0,32,88,0,0,9,168,0,0,48,88,0,0,10,168,0,0,64,88,0,0,11,168,0,0,80,88,0,0,12,168,0,0,96,88,0,0,13,168,0,0,112,88,0,0,14,168,0,0,128,88,0,0,15,168,0,0,144,88,0,0,16,168,0,0,160,88,0,0,17,168,0,0,176,88,0,0,18,168,0,0,192,88,0,0,19,168,0,0,208,88,0,0,20,168,0,0,224,88,0,0,21,168,0,0,240,88,0,0,22,168,0,0,0,89,0,0,23,168,0,0,8,89,0,0,24,168,0,0,24,89,0,0,25,168,0,0,40,89,0,0,26,168,0,0,48,89,0,0,27,168,0,0,64,89,0,0,28,168,0,0,80,89,0,0,29,168,0,0,96,89,0,0,31,168,0,0,112,89,0,0,32,168,0,0,128,89,0,0,33,168,0,0,152,89,0,0,34,168,0,0,168,89,0,0,35,168,0,0,192,89,0,0,38,168,0,0,208,89,0,0,39,168,0,0,224,89,0,0,40,168,0,0,240,89,0,0,41,168,0,0,0,90,0,0,42,168,0,0,16,90,0,0,43,168,0,0,40,90,0,0,44,168,0,0,48,90,0,0,45,168,0,0,56,90,0,0,46,168,0,0,64,90,0,0,47,168,0,0,72,90,0,0,48,168,0,0,80,90,0,0,49,168,0,0,88,90,0,0,51,168,0,0,96,90,0,0,52,168,0,0,112,90,0,0,53,168,0,0,136,90,0,0,54,168,0,0,152,90,0,0,55,168,0,0,168,90,0,0,56,168,0,0,184,90,0,0,57,168,0,0,200,90,0,0,58,168,0,0,216,90,0,0,59,168,0,0,232,90,0,0,60,168,0,0,248,90,0,0,61,168,0,0,8,91,0,0,62,168,0,0,24,91,0,0,63,168,0,0,40,91,0,0,64,168,0,0,56,91,0,0,65,168,0,0,72,91,0,0,66,168,0,0,88,91,0,0,67,168,0,0,104,91,0,0,68,168,0,0,112,91,0,0,69,168,0,0,120,91,0,0,70,168,0,0,128,91,0,0,71,168,0,0,136,91,0,0,72,168,0,0,144,91,0,0,73,168,0,0,152,91,0,0,74,168,0,0,168,91,0,0,75,168,0,0,176,91,0,0,76,168,0,0,184,91,0,0,77,168,0,0,200,91,0,0,78,168,0,0,208,91,0,0,79,168,0,0,224,91,0,0,80,168,0,0,240,91,0,0,81,168,0,0,0,92,0,0,82,168,0,0,16,92,0,0,83,168,0,0,32,92,0,0,84,168,0,0,48,92,0,0,85,168,0,0,64,92,0,0,86,168,0,0,80,92,0,0,88,168,0,0,96,92,0,0,89,168,0,0,104,92,0,0,90,168,0,0,112,92,0,0,91,168,0,0,120,92,0,0,92,168,0,0,128,92,0,0,93,168,0,0,144,92,0,0,94,168,0,0,152,92,0,0,95,168,0,0,160,92,0,0,96,168,0,0,168,92,0,0,97,168,0,0,184,92,0,0,98,168,0,0,192,92,0,0,99,168,0,0,208,92,0,0,100,168,0,0,224,92,0,0,101,168,0,0,240,92,0,0,102,168,0,0,0,93,0,0,103,168,0,0,16,93,0,0,104,168,0,0,24,93,0,0,105,168,0,0,32,93,0,0,106,168,0,0,48,93,0,0,107,168,0,0,56,93,0,0,108,168,0,0,64,93,0,0,109,168,0,0,80,93,0,0,110,168,0,0,96,93,0,0,111,168,0,0,112,93,0,0,112,168,0,0,128,93,0,0,113,168,0,0,144,93,0,0,114,168,0,0,160,93,0,0,115,168,0,0,176,93,0,0,116,168,0,0,184,93,0,0,117,168,0,0,192,93,0,0,118,168,0,0,208,93,0,0,119,168,0,0,224,93,0,0,120,168,0,0,240,93,0,0,121,168,0,0,0,94,0,0,122,168,0,0,8,94,0,0,123,168,0,0,16,94,0,0,124,168,0,0,32,94,0,0,125,168,0,0,40,94,0,0,125,168,0,0,56,94,0,0,126,168,0,0,72,94,0,0,127,168,0,0,80,94,0,0,128,168,0,0,88,94,0,0,129,168,0,0,96,94,0,0,130,168,0,0,104,94,0,0,131,168,0,0,112,94,0,0,132,168,0,0,128,94,0,0,133,168,0,0,144,94,0,0,134,168,0,0,160,94,0,0,135,168,0,0,176,94,0,0,136,168,0,0,192,94,0,0,137,168,0,0,208,94,0,0,138,168,0,0,224,94,0,0,139,168,0,0,240,94,0,0,140,168,0,0,0,95,0,0,141,168,0,0,16,95,0,0,142,168,0,0,32,95,0,0,143,168,0,0,48,95,0,0,144,168,0,0,64,95,0,0,145,168,0,0,72,95,0,0,146,168,0,0,80,95,0,0,147,168,0,0,88,95,0,0,148,168,0,0,96,95,0,0,149,168,0,0,104,95,0,0,150,168,0,0,120,95,0,0,151,168,0,0,128,95,0,0,152,168,0,0,136,95,0,0,153,168,0,0,152,95,0,0,154,168,0,0,168,95,0,0,155,168,0,0,176,95,0,0,156,168,0,0,184,95,0,0,157,168,0,0,192,95,0,0,158,168,0,0,200,95,0,0,159,168,0,0,216,95,0,0,160,168,0,0,232,95,0,0,161,168,0,0,240,95,0,0,162,168,0,0,0,96,0,0,163,168,0,0,16,96,0,0,164,168,0,0,32,96,0,0,165,168,0,0,48,96,0,0,166,168,0,0,64,96,0,0,167,168,0,0,80,96,0,0,168,168,0,0,88,96,0,0,169,168,0,0,104,96,0,0,170,168,0,0,120,96,0,0,171,168,0,0,136,96,0,0,172,168,0,0,152,96,0,0,173,168,0,0,160,96,0,0,174,168,0,0,176,96,0,0,175,168,0,0,192,96,0,0,176,168,0,0,208,96,0,0,177,168,0,0,224,96,0,0,178,168,0,0,240,96,0,0,179,168,0,0,0,97,0,0,180,168,0,0,16,97,0,0,181,168,0,0,32,97,0,0,182,168,0,0,48,97,0,0,183,168,0,0,56,97,0,0,184,168,0,0,72,97,0,0,185,168,0,0,88,97,0,0,186,168,0,0,104,97,0,0,187,168,0,0,120,97,0,0,188,168,0,0,136,97,0,0,189,168,0,0,152,97,0,0,190,168,0,0,160,97,0,0,191,168,0,0,176,97,0,0,192,168,0,0,192,97,0,0,193,168,0,0,208,97,0,0,194,168,0,0,224,97,0,0,195,168,0,0,232,97,0,0,196,168,0,0,248,97,0,0,197,168,0,0,8,98,0,0,198,168,0,0,16,98,0,0,199,168,0,0,32,98,0,0,200,168,0,0,48,98,0,0,201,168,0,0,64,98,0,0,202,168,0,0,80,98,0,0,203,168,0,0,96,98,0,0,204,168,0,0,112,98,0,0,205,168,0,0,128,98,0,0,206,168,0,0,144,98,0,0,207,168,0,0,160,98,0,0,208,168,0,0,176,98,0,0,209,168,0,0,192,98,0,0,210,168,0,0,200,98,0,0,211,168,0,0,216,98,0,0,212,168,0,0,232,98,0,0,213,168,0,0,248,98,0,0,214,168,0,0,8,99,0,0,215,168,0,0,16,99,0,0,216,168,0,0,32,99,0,0,217,168,0,0,40,99,0,0,218,168,0,0,56,99,0,0,219,168,0,0,64,99,0,0,220,168,0,0,80,99,0,0,221,168,0,0,88,99,0,0,222,168,0,0,104,99,0,0,223,168,0,0,120,99,0,0,224,168,0,0,128,99,0,0,225,168,0,0,144,99,0,0,226,168,0,0,160,99,0,0,227,168,0,0,176,99,0,0,228,168,0,0,192,99,0,0,229,168,0,0,200,99,0,0,230,168,0,0,216,99,0,0,231,168,0,0,224,99,0,0,232,168,0,0,232,99,0,0,233,168,0,0,240,99,0,0,234,168,0,0,0,100,0,0,235,168,0,0,16,100,0,0,236,168,0,0,24,100,0,0,237,168,0,0,40,100,0,0,238,168,0,0,56,100,0,0,239,168,0,0,72,100,0,0,240,168,0,0,88,100,0,0,241,168,0,0,104,100,0,0,242,168,0,0,120,100,0,0,243,168,0,0,136,100,0,0,244,168,0,0,152,100,0,0,245,168,0,0,168,100,0,0,246,168,0,0,184,100,0,0,247,168,0,0,200,100,0,0,248,168,0,0,208,100,0,0,249,168,0,0,216,100,0,0,250,168,0,0,224,100,0,0,251,168,0,0,232,100,0,0,252,168,0,0,240,100,0,0,253,168,0,0,248,100,0,0,254,168,0,0,0,101,0,0,255,168,0,0,16,101,0,0,0,169,0,0,32,101,0,0,1,169,0,0,40,101,0,0,2,169,0,0,56,101,0,0,3,169,0,0,72,101,0,0,4,169,0,0,88,101,0,0,5,169,0,0,104,101,0,0,6,169,0,0,120,101,0,0,7,169,0,0,136,101,0,0,8,169,0,0,152,101,0,0,9,169,0,0,168,101,0,0,10,169,0,0,176,101,0,0,11,169,0,0,192,101,0,0,12,169,0,0,208,101,0,0,13,169,0,0,224,101,0,0,14,169,0,0,240,101,0,0,15,169,0,0,248,101,0,0,16,169,0,0,0,102,0,0,17,169,0,0,16,102,0,0,18,169,0,0,32,102,0,0,19,169,0,0,48,102,0,0,20,169,0,0,64,102,0,0,21,169,0,0,80,102,0,0,22,169,0,0,96,102,0,0,23,169,0,0,112,102,0,0,24,169,0,0,128,102,0,0,25,169,0,0,144,102,0,0,26,169,0,0,160,102,0,0,27,169,0,0,176,102,0,0,28,169,0,0,192,102,0,0,29,169,0,0,208,102,0,0,30,169,0,0,224,102,0,0,31,169,0,0,240,102,0,0,32,169,0,0,0,103,0,0,33,169,0,0,16,103,0,0,34,169,0,0,32,103,0,0,35,169,0,0,48,103,0,0,36,169,0,0,64,103,0,0,37,169,0,0,80,103,0,0,38,169,0,0,96,103,0,0,39,169,0,0,112,103,0,0,40,169,0,0,128,103,0,0,41,169,0,0,144,103,0,0,42,169,0,0,160,103,0,0,43,169,0,0,176,103,0,0,44,169,0,0,192,103,0,0,45,169,0,0,208,103,0,0,46,169,0,0,224,103,0,0,47,169,0,0,240,103,0,0,48,169,0,0,0,104,0,0,49,169,0,0,16,104,0,0,50,169,0,0,24,104,0,0,51,169,0,0,40,104,0,0,52,169,0,0,56,104,0,0,53,169,0,0,72,104,0,0,54,169,0,0,88,104,0,0,55,169,0,0,104,104,0,0,56,169,0,0,120,104,0,0,57,169,0,0,136,104,0,0,58,169,0,0,152,104,0,0,59,169,0,0,168,104,0,0,60,169,0,0,184,104,0,0,61,169,0,0,200,104,0,0,62,169,0,0,216,104,0,0,63,169,0,0,224,104,0,0,64,169,0,0,240,104,0,0,65,169,0,0,0,105,0,0,66,169,0,0,16,105,0,0,67,169,0,0,32,105,0,0,68,169,0,0,48,105,0,0,69,169,0,0,64,105,0,0,70,169,0,0,80,105,0,0,71,169,0,0,88,105,0,0,72,169,0,0,96,105,0,0,73,169,0,0,112,105,0,0,74,169,0,0,128,105,0,0,75,169,0,0,144,105,0,0,76,169,0,0,160,105,0,0,77,169,0,0,176,105,0,0,78,169,0,0,192,105,0,0,79,169,0,0,200,105,0,0,80,169,0,0,216,105,0,0,81,169,0,0,232,105,0,0,82,169,0,0,248,105,0,0,83,169,0,0,8,106,0,0,84,169,0,0,24,106,0,0,85,169,0,0,40,106,0,0,86,169,0,0,56,106,0,0,87,169,0,0,72,106,0,0,88,169,0,0,88,106,0,0,89,169,0,0,104,106,0,0,90,169,0,0,120,106,0,0,91,169,0,0,136,106,0,0,92,169,0,0,152,106,0,0,93,169,0,0,168,106,0,0,94,169,0,0,184,106,0,0,95,169,0,0,200,106,0,0,96,169,0,0,216,106,0,0,97,169,0,0,232,106,0,0,98,169,0,0,248,106,0,0,99,169,0,0,8,107,0,0,100,169,0,0,24,107,0,0,101,169,0,0,40,107,0,0,102,169,0,0,56,107,0,0,103,169,0,0,72,107,0,0,104,169,0,0,88,107,0,0,105,169,0,0,104,107,0,0,106,169,0,0,120,107,0,0,107,169,0,0,136,107,0,0,108,169,0,0,152,107,0,0,109,169,0,0,168,107,0,0,110,169,0,0,184,107,0,0,111,169,0,0,192,107,0,0,112,169,0,0,200,107,0,0,113,169,0,0,216,107,0,0,114,169,0,0,232,107,0,0,115,169,0,0,248,107,0,0,116,169,0,0,8,108,0,0,117,169,0,0,16,108,0,0,118,169,0,0,32,108,0,0,119,169,0,0,40,108,0,0,120,169,0,0,56,108,0,0,121,169,0,0,72,108,0,0,122,169,0,0,88,108,0,0,123,169,0,0,104,108,0,0,124,169,0,0,120,108,0,0,125,169,0,0,136,108,0,0,126,169,0,0,152,108,0,0,127,169,0,0,168,108,0,0,128,169,0,0,184,108,0,0,129,169,0,0,200,108,0,0,130,169,0,0,216,108,0,0,131,169,0,0,232,108,0,0,132,169,0,0,248,108,0,0,133,169,0,0,8,109,0,0,134,169,0,0,16,109,0,0,135,169,0,0,32,109,0,0,136,169,0,0,48,109,0,0,137,169,0,0,64,109,0,0,138,169,0,0,80,109,0,0,139,169,0,0,96,109,0,0,140,169,0,0,112,109,0,0,141,169,0,0,128,109,0,0,142,169,0,0,144,109,0,0,143,169,0,0,160,109,0,0,144,169,0,0,176,109,0,0,145,169,0,0,192,109,0,0,146,169,0,0,208,109,0,0,147,169,0,0,224,109,0,0,148,169,0,0,240,109,0,0,149,169,0,0,0,110,0,0,150,169,0,0,16,110,0,0,151,169,0,0,32,110,0,0,152,169,0,0,48,110,0,0,153,169,0,0,64,110,0,0,154,169,0,0,80,110,0,0,155,169,0,0,96,110,0,0,156,169,0,0,112,110,0,0,157,169,0,0,128,110,0,0,158,169,0,0,144,110,0,0,159,169,0,0,160,110,0,0,160,169,0,0,176,110,0,0,161,169,0,0,192,110,0,0,162,169,0,0,216,110,0,0,163,169,0,0,232,110,0,0,164,169,0,0,248,110,0,0,165,169,0,0,8,111,0,0,166,169,0,0,24,111,0,0,167,169,0,0,40,111,0,0,168,169,0,0,56,111,0,0,169,169,0,0,72,111,0,0,170,169,0,0,88,111,0,0,171,169,0,0,104,111,0,0,172,169,0,0,120,111,0,0,173,169,0,0,136,111,0,0,174,169,0,0,152,111,0,0,175,169,0,0,168,111,0,0,176,169,0,0,184,111,0,0,177,169,0,0,200,111,0,0,178,169,0,0,216,111,0,0,179,169,0,0,232,111,0,0,180,169,0,0,248,111,0,0,181,169,0,0,8,112,0,0,182,169,0,0,24,112,0,0,183,169,0,0,40,112,0,0,184,169,0,0,56,112,0,0,185,169,0,0,72,112,0,0,186,169,0,0,88,112,0,0,187,169,0,0,104,112,0,0,188,169,0,0,112,112,0,0,189,169,0,0,128,112,0,0,190,169,0,0,144,112,0,0,191,169,0,0,160,112,0,0,192,169,0,0,176,112,0,0,193,169,0,0,192,112,0,0,194,169,0,0,208,112,0,0,195,169,0,0,216,112,0,0,196,169,0,0,232,112,0,0,197,169,0,0,248,112,0,0,198,169,0,0,8,113,0,0,199,169,0,0,24,113,0,0,200,169,0,0,40,113,0,0,201,169,0,0,48,113,0,0,202,169,0,0,64,113,0,0,203,169,0,0,72,113,0,0,204,169,0,0,88,113,0,0,205,169,0,0,96,113,0,0,206,169,0,0,112,113,0,0,207,169,0,0,120,113,0,0,208,169,0,0,136,113,0,0,209,169,0,0,152,113,0,0,210,169,0,0,168,113,0,0,211,169,0,0,176,113,0,0,212,169,0,0,192,113,0,0,213,169,0,0,200,113,0,0,214,169,0,0,208,113,0,0,215,169,0,0,216,113,0,0,216,169,0,0,232,113,0,0,217,169,0,0,248,113,0,0,218,169,0,0,8,114,0,0,219,169,0,0,16,114,0,0,220,169,0,0,24,114,0,0,221,169,0,0,32,114,0,0,222,169,0,0,48,114,0,0,223,169,0,0,64,114,0,0,224,169,0,0,80,114,0,0,225,169,0,0,88,114,0,0,226,169,0,0,104,114,0,0,227,169,0,0,120,114,0,0,228,169,0,0,136,114,0,0,229,169,0,0,152,114,0,0,230,169,0,0,168,114,0,0,231,169,0,0,184,114,0,0,232,169,0,0,192,114,0,0,233,169,0,0,200,114,0,0,234,169,0,0,208,114,0,0,235,169,0,0,216,114,0,0,235,169,0,0,224,114,0,0,236,169,0,0,232,114,0,0,236,169,0,0,248,114,0,0,237,169,0,0,0,115,0,0,238,169,0,0,8,115,0,0,239,169,0,0,16,115,0,0,240,169,0,0,32,115,0,0,241,169,0,0,40,115,0,0,242,169,0,0,56,115,0,0,243,169,0,0,64,115,0,0,244,169,0,0,72,115,0,0,245,169,0,0,88,115,0,0,246,169,0,0,104,115,0,0,247,169,0,0,120,115,0,0,248,169,0,0,136,115,0,0,249,169,0,0,152,115,0,0,250,169,0,0,168,115,0,0,251,169,0,0,184,115,0,0,252,169,0,0,200,115,0,0,253,169,0,0,216,115,0,0,254,169,0,0,232,115,0,0,255,169,0,0,248,115,0,0,0,170,0,0,8,116,0,0,1,170,0,0,24,116,0,0,3,170,0,0,40,116,0,0,4,170,0,0,56,116,0,0,5,170,0,0,72,116,0,0,6,170,0,0,88,116,0,0,7,170,0,0,104,116,0,0,8,170,0,0,120,116,0,0,9,170,0,0,136,116,0,0,10,170,0,0,152,116,0,0,11,170,0,0,168,116,0,0,12,170,0,0,184,116,0,0,13,170,0,0,200,116,0,0,14,170,0,0,216,116,0,0,15,170,0,0,232,116,0,0,16,170,0,0,248,116,0,0,17,170,0,0,8,117,0,0,18,170,0,0,24,117,0,0,19,170,0,0,40,117,0,0,20,170,0,0,56,117,0,0,21,170,0,0,72,117,0,0,22,170,0,0,88,117,0,0,23,170,0,0,104,117,0,0,24,170,0,0,120,117,0,0,25,170,0,0,136,117,0,0,26,170,0,0,152,117,0,0,27,170,0,0,168,117,0,0,28,170,0,0,184,117,0,0,29,170,0,0,200,117,0,0,30,170,0,0,216,117,0,0,31,170,0,0,232,117,0,0,33,170,0,0,248,117,0,0,34,170,0,0,0,118,0,0,35,170,0,0,16,118,0,0,36,170,0,0,32,118,0,0,37,170,0,0,48,118,0,0,38,170,0,0,64,118,0,0,39,170,0,0,80,118,0,0,40,170,0,0,96,118,0,0,41,170,0,0,112,118,0,0,42,170,0,0,128,118,0,0,43,170,0,0,144,118,0,0,44,170,0,0,160,118,0,0,45,170,0,0,184,118,0,0,46,170,0,0,208,118,0,0,47,170,0,0,224,118,0,0,48,170,0,0,240,118,0,0,49,170,0,0,0,119,0,0,50,170,0,0,16,119,0,0,51,170,0,0,32,119,0,0,52,170,0,0,48,119,0,0,53,170,0,0,64,119,0,0,54,170,0,0,80,119,0,0,55,170,0,0,96,119,0,0,56,170,0,0,112,119,0,0,57,170,0,0,128,119,0,0,58,170,0,0,144,119,0,0,59,170,0,0,160,119,0,0,60,170,0,0,168,119,0,0,61,170,0,0,184,119,0,0,62,170,0,0,200,119,0,0,63,170,0,0,216,119,0,0,64,170,0,0,232,119,0,0,65,170,0,0,240,119,0,0,66,170,0,0,0,120,0,0,67,170,0,0,16,120,0,0,68,170,0,0,32,120,0,0,69,170,0,0,48,120,0,0,70,170,0,0,64,120,0,0,71,170,0,0,80,120,0,0,72,170,0,0,96,120,0,0,73,170,0,0,112,120,0,0,74,170,0,0,128,120,0,0,75,170,0,0,144,120,0,0,76,170,0,0,160,120,0,0,77,170,0,0,176,120,0,0,78,170,0,0,184,120,0,0,79,170,0,0,200,120,0,0,80,170,0,0,216,120,0,0,81,170,0,0,232,120,0,0,82,170,0,0,248,120,0,0,96,170,0,0,16,121,0,0,97,170,0,0,32,121,0,0,98,170,0,0,48,121,0,0,99,170,0,0,64,121,0,0,100,170,0,0,80,121,0,0,101,170,0,0,96,121,0,0,102,170,0,0,112,121,0,0,103,170,0,0,128,121,0,0,104,170,0,0,152,121,0,0,0,0,0,0,0,0,0,0,0,160,0,0,248,79,0,0,1,160,0,0,0,80,0,0,2,160,0,0,8,80,0,0,3,160,0,0,16,80,0,0,4,160,0,0,24,80,0,0,5,160,0,0,32,80,0,0,6,160,0,0,40,80,0,0,7,160,0,0,48,80,0,0,8,160,0,0,64,80,0,0,9,160,0,0,72,80,0,0,10,160,0,0,80,80,0,0,11,160,0,0,88,80,0,0,12,160,0,0,96,80,0,0,13,160,0,0,112,80,0,0,14,160,0,0,128,80,0,0,15,160,0,0,144,80,0,0,16,160,0,0,160,80,0,0,17,160,0,0,176,80,0,0,18,160,0,0,184,80,0,0,19,160,0,0,192,80,0,0,20,160,0,0,208,80,0,0,21,160,0,0,216,80,0,0,22,160,0,0,224,80,0,0,23,160,0,0,240,80,0,0,24,160,0,0,248,80,0,0,25,160,0,0,0,81,0,0,26,160,0,0,16,81,0,0,27,160,0,0,24,81,0,0,28,160,0,0,32,81,0,0,29,160,0,0,40,81,0,0,30,160,0,0,48,81,0,0,31,160,0,0,56,81,0,0,32,160,0,0,72,81,0,0,33,160,0,0,88,81,0,0,34,160,0,0,104,81,0,0,35,160,0,0,120,81,0,0,36,160,0,0,136,81,0,0,37,160,0,0,152,81,0,0,38,160,0,0,168,81,0,0,39,160,0,0,184,81,0,0,40,160,0,0,200,81,0,0,41,160,0,0,216,81,0,0,42,160,0,0,224,81,0,0,43,160,0,0,232,81,0,0,44,160,0,0,248,81,0,0,45,160,0,0,8,82,0,0,46,160,0,0,24,82,0,0,47,160,0,0,40,82,0,0,48,160,0,0,56,82,0,0,49,160,0,0,72,82,0,0,50,160,0,0,88,82,0,0,51,160,0,0,104,82,0,0,52,160,0,0,120,82,0,0,53,160,0,0,128,82,0,0,54,160,0,0,136,82,0,0,56,160,0,0,152,82,0,0,57,160,0,0,168,82,0,0,58,160,0,0,184,82,0,0,59,160,0,0,200,82,0,0,60,160,0,0,208,82,0,0,61,160,0,0,224,82,0,0,62,160,0,0,240,82,0,0,63,160,0,0,0,83,0,0,64,160,0,0,16,83,0,0,65,160,0,0,32,83,0,0,66,160,0,0,48,83,0,0,67,160,0,0,64,83,0,0,68,160,0,0,80,83,0,0,69,160,0,0,88,83,0,0,70,160,0,0,104,83,0,0,71,160,0,0,120,83,0,0,72,160,0,0,136,83,0,0,73,160,0,0,144,83,0,0,74,160,0,0,152,83,0,0,75,160,0,0,168,83,0,0,76,160,0,0,184,83,0,0,77,160,0,0,200,83,0,0,78,160,0,0,216,83,0,0,79,160,0,0,232,83,0,0,80,160,0,0,248,83,0,0,81,160,0,0,8,84,0,0,82,160,0,0,24,84,0,0,84,160,0,0,40,84,0,0,85,160,0,0,56,84,0,0,86,160,0,0,72,84,0,0,87,160,0,0,88,84,0,0,88,160,0,0,104,84,0,0,89,160,0,0,112,84,0,0,90,160,0,0,120,84,0,0,91,160,0,0,136,84,0,0,92,160,0,0,152,84,0,0,93,160,0,0,168,84,0,0,94,160,0,0,184,84,0,0,95,160,0,0,200,84,0,0,96,160,0,0,216,84,0,0,97,160,0,0,232,84,0,0,98,160,0,0,248,84,0,0,99,160,0,0,8,85,0,0,100,160,0,0,24,85,0,0,101,160,0,0,32,85,0,0,102,160,0,0,48,85,0,0,103,160,0,0,64,85,0,0,104,160,0,0,80,85,0,0,105,160,0,0,96,85,0,0,106,160,0,0,112,85,0,0,108,160,0,0,128,85,0,0,109,160,0,0,136,85,0,0,110,160,0,0,152,85,0,0,111,160,0,0,168,85,0,0,112,160,0,0,184,85,0,0,113,160,0,0,200,85,0,0,114,160,0,0,216,85,0,0,117,160,0,0,232,85,0,0,118,160,0,0,248,85,0,0,119,160,0,0,8,86,0,0,120,160,0,0,24,86,0,0,121,160,0,0,40,86,0,0,122,160,0,0,56,86,0,0,123,160,0,0,72,86,0,0,124,160,0,0,88,86,0,0,125,160,0,0,96,86,0,0,126,160,0,0,120,86,0,0,127,160,0,0,144,86,0,0,128,160,0,0,160,86,0,0,129,160,0,0,176,86,0,0,130,160,0,0,192,86,0,0,131,160,0,0,208,86,0,0,132,160,0,0,224,86,0,0,133,160,0,0,240,86,0,0,134,160,0,0,248,86,0,0,135,160,0,0,8,87,0,0,136,160,0,0,24,87,0,0,138,160,0,0,40,87,0,0,139,160,0,0,48,87,0,0,141,160,0,0,72,87,0,0,143,160,0,0,88,87,0,0,144,160,0,0,104,87,0,0,145,160,0,0,120,87,0,0,146,160,0,0,136,87,0,0,152,160,0,0,152,87,0,0,0,0,0,0,0,0,0,0,79,112,101,110,0,0,0,0,67,108,111,115,101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+10240);
/* memory initializer */ allocate([82,101,97,100,0,0,0,0,87,114,105,116,101,0,0,0,67,111,110,116,114,111,108,0,83,116,97,116,117,115,0,0,75,105,108,108,73,79,0,0,71,101,116,86,111,108,73,110,102,111,0,0,0,0,0,0,67,114,101,97,116,101,0,0,68,101,108,101,116,101,0,0,79,112,101,110,82,70,0,0,82,101,110,97,109,101,0,0,71,101,116,70,105,108,101,73,110,102,111,0,0,0,0,0,83,101,116,70,105,108,101,73,110,102,111,0,0,0,0,0,85,110,109,111,117,110,116,86,111,108,0,0,0,0,0,0,77,111,117,110,116,86,111,108,0,0,0,0,0,0,0,0,65,108,108,111,99,97,116,101,0,0,0,0,0,0,0,0,71,101,116,69,79,70,0,0,83,101,116,69,79,70,0,0,70,108,117,115,104,86,111,108,0,0,0,0,0,0,0,0,71,101,116,86,111,108,0,0,83,101,116,86,111,108,0,0,73,110,105,116,81,117,101,117,101,0,0,0,0,0,0,0,69,106,101,99,116,0,0,0,71,101,116,70,80,111,115,0,73,110,105,116,90,111,110,101,0,0,0,0,0,0,0,0,71,101,116,90,111,110,101,0,83,101,116,90,111,110,101,0,70,114,101,101,77,101,109,0,77,97,120,77,101,109,0,0,78,101,119,80,116,114,0,0,68,105,115,112,111,115,80,116,114,0,0,0,0,0,0,0,83,101,116,80,116,114,83,105,122,101,0,0,0,0,0,0,71,101,116,80,116,114,83,105,122,101,0,0,0,0,0,0,78,101,119,72,97,110,100,108,101,0,0,0,0,0,0,0,68,105,115,112,111,115,72,97,110,100,108,101,0,0,0,0,83,101,116,72,97,110,100,108,101,83,105,122,101,0,0,0,71,101,116,72,97,110,100,108,101,83,105,122,101,0,0,0,72,97,110,100,108,101,90,111,110,101,0,0,0,0,0,0,82,101,97,108,108,111,99,72,97,110,100,108,101,0,0,0,82,101,99,111,118,101,114,72,97,110,100,108,101,0,0,0,72,76,111,99,107,0,0,0,72,85,110,108,111,99,107,0,69,109,112,116,121,72,97,110,100,108,101,0,0,0,0,0,73,110,105,116,65,112,112,108,90,111,110,101,0,0,0,0,83,101,116,65,112,112,108,76,105,109,105,116,0,0,0,0,66,108,111,99,107,77,111,118,101,0,0,0,0,0,0,0,80,111,115,116,69,118,101,110,116,0,0,0,0,0,0,0,79,83,69,118,101,110,116,65,118,97,105,108,0,0,0,0,71,101,116,79,83,69,118,101,110,116,0,0,0,0,0,0,70,108,117,115,104,69,118,101,110,116,115,0,0,0,0,0,86,73,110,115,116,97,108,108,0,0,0,0,0,0,0,0,86,82,101,109,111,118,101,0,79,102,102,108,105,110,101,0,77,111,114,101,77,97,115,116,101,114,115,0,0,0,0,0,87,114,105,116,101,80,97,114,97,109,0,0,0,0,0,0,82,101,97,100,68,97,116,101,84,105,109,101,0,0,0,0,83,101,116,68,97,116,101,84,105,109,101,0,0,0,0,0,68,101,108,97,121,0,0,0,67,109,112,83,116,114,105,110,103,0,0,0,0,0,0,0,68,114,118,114,73,110,115,116,97,108,108,0,0,0,0,0,68,114,118,114,82,101,109,111,118,101,0,0,0,0,0,0,73,110,105,116,85,116,105,108,0,0,0,0,0,0,0,0,82,101,115,114,118,77,101,109,0,0,0,0,0,0,0,0,83,101,116,70,105,108,76,111,99,107,0,0,0,0,0,0,82,115,116,70,105,108,76,111,99,107,0,0,0,0,0,0,83,101,116,70,105,108,84,121,112,101,0,0,0,0,0,0,83,101,116,70,80,111,115,0,70,108,117,115,104,70,105,108,101,0,0,0,0,0,0,0,71,101,116,84,114,97,112,65,100,100,114,101,115,115,0,0,83,101,116,84,114,97,112,65,100,100,114,101,115,115,0,0,80,116,114,90,111,110,101,0,72,80,117,114,103,101,0,0,72,78,111,80,117,114,103,101,0,0,0,0,0,0,0,0,83,101,116,71,114,111,119,90,111,110,101,0,0,0,0,0,67,111,109,112,97,99,116,77,101,109,0,0,0,0,0,0,80,117,114,103,101,77,101,109,0,0,0,0,0,0,0,0,65,100,100,68,114,105,118,101,0,0,0,0,0,0,0,0,82,68,114,118,114,73,110,115,116,97,108,108,0,0,0,0,82,101,108,83,116,114,105,110,103,0,0,0,0,0,0,0,82,101,97,100,88,80,114,97,109,0,0,0,0,0,0,0,87,114,105,116,101,88,80,114,97,109,0,0,0,0,0,0,85,112,114,83,116,114,105,110,103,0,0,0,0,0,0,0,83,116,114,105,112,65,100,100,114,101,115,115,0,0,0,0,76,111,119,101,114,84,101,120,116,0,0,0,0,0,0,0,83,101,116,65,112,112,66,97,115,101,0,0,0,0,0,0,73,110,115,84,105,109,101,0,82,109,118,84,105,109,101,0,80,114,105,109,101,84,105,109,101,0,0,0,0,0,0,0,80,111,119,101,114,79,102,102,0,0,0,0,0,0,0,0,77,101,109,111,114,121,68,105,115,112,97,116,99,104,0,0,83,119,97,112,77,77,85,77,111,100,101,0,0,0,0,0,78,77,73,110,115,116,97,108,108,0,0,0,0,0,0,0,78,77,82,101,109,111,118,101,0,0,0,0,0,0,0,0,72,70,83,68,105,115,112,97,116,99,104,0,0,0,0,0,77,97,120,66,108,111,99,107,0,0,0,0,0,0,0,0,80,117,114,103,101,83,112,97,99,101,0,0,0,0,0,0,77,97,120,65,112,112,108,90,111,110,101,0,0,0,0,0,77,111,118,101,72,72,105,0,83,116,97,99,107,83,112,97,99,101,0,0,0,0,0,0,78,101,119,69,109,112,116,121,72,97,110,100,108,101,0,0,72,83,101,116,82,66,105,116,0,0,0,0,0,0,0,0,72,67,108,114,82,66,105,116,0,0,0,0,0,0,0,0,72,71,101,116,83,116,97,116,101,0,0,0,0,0,0,0,72,83,101,116,83,116,97,116,101,0,0,0,0,0,0,0,73,110,105,116,70,83,0,0,73,110,105,116,69,118,101,110,116,115,0,0,0,0,0,0,83,108,111,116,77,97,110,97,103,101,114,0,0,0,0,0,83,108,111,116,86,73,110,115,116,97,108,108,0,0,0,0,83,108,111,116,86,82,101,109,111,118,101,0,0,0,0,0,65,116,116,97,99,104,86,66,76,0,0,0,0,0,0,0,68,111,86,66,76,84,97,115,107,0,0,0,0,0,0,0,83,73,110,116,73,110,115,116,97,108,108,0,0,0,0,0,83,73,110,116,82,101,109,111,118,101,0,0,0,0,0,0,67,111,117,110,116,65,68,66,115,0,0,0,0,0,0,0,71,101,116,73,110,100,65,68,66,0,0,0,0,0,0,0,71,101,116,65,68,66,73,110,102,111,0,0,0,0,0,0,83,101,116,65,68,66,73,110,102,111,0,0,0,0,0,0,65,68,66,82,101,73,110,105,116,0,0,0,0,0,0,0,65,68,66,79,112,0,0,0,71,101,116,68,101,102,97,117,108,116,83,116,97,114,116,117,112,0,0,0,0,0,0,0,83,101,116,68,101,102,97,117,108,116,83,116,97,114,116,117,112,0,0,0,0,0,0,0,73,110,116,101,114,110,97,108,87,97,105,116,0,0,0,0,71,101,116,86,105,100,101,111,68,101,102,97,117,108,116,0,83,101,116,86,105,100,101,111,68,101,102,97,117,108,116,0,68,84,73,110,115,116,97,108,108,0,0,0,0,0,0,0,83,101,116,79,83,68,101,102,97,117,108,116,0,0,0,0,71,101,116,79,83,68,101,102,97,117,108,116,0,0,0,0,80,77,103,114,79,112,0,0,73,79,80,73,110,102,111,65,99,99,101,115,115,0,0,0,73,79,80,77,115,103,82,101,113,117,101,115,116,0,0,0,73,79,80,77,111,118,101,68,97,116,97,0,0,0,0,0,83,108,101,101,112,0,0,0,67,111,109,109,84,111,111,108,98,111,120,68,105,115,112,97,116,99,104,0,0,0,0,0,68,101,98,117,103,85,116,105,108,0,0,0,0,0,0,0,68,101,102,101,114,85,115,101,114,70,110,0,0,0,0,0,83,121,115,69,110,118,105,114,111,110,115,0,0,0,0,0,84,114,97,110,115,108,97,116,101,50,52,116,111,51,50,0,69,103,114,101,116,68,105,115,112,97,116,99,104,0,0,0,72,87,80,114,105,118,0,0,83,111,117,110,100,68,105,115,112,97,116,99,104,0,0,0,83,110,100,68,105,115,112,111,115,101,67,104,97,110,110,101,108,0,0,0,0,0,0,0,83,110,100,65,100,100,77,111,100,105,102,105,101,114,0,0,83,110,100,68,111,67,111,109,109,97,110,100,0,0,0,0,83,110,100,68,111,73,109,109,101,100,105,97,116,101,0,0,83,110,100,80,108,97,121,0,83,110,100,67,111,110,116,114,111,108,0,0,0,0,0,0,83,110,100,78,101,119,67,104,97,110,110,101,108,0,0,0,73,110,105,116,80,114,111,99,77,101,110,117,0,0,0,0,71,101,116,67,86,97,114,105,97,110,116,0,0,0,0,0,71,101,116,87,86,97,114,105,97,110,116,0,0,0,0,0,80,111,112,85,112,77,101,110,117,83,101,108,101,99,116,0,82,71,101,116,82,101,115,111,117,114,99,101,0,0,0,0,67,111,117,110,116,49,82,101,115,111,117,114,99,101,115,0,71,101,116,49,73,120,82,101,115,111,117,114,99,101,0,0,71,101,116,49,73,120,84,121,112,101,0,0,0,0,0,0,85,110,105,113,117,101,49,73,68,0,0,0,0,0,0,0,84,69,83,101,108,86,105,101,119,0,0,0,0,0,0,0,84,69,80,105,110,83,99,114,111,108,108,0,0,0,0,0,84,69,65,117,116,111,86,105,101,119,0,0,0,0,0,0,83,101,116,70,114,97,99,116,69,110,97,98,108,101,0,0,83,67,83,73,68,105,115,112,97,116,99,104,0,0,0,0,80,97,99,107,56,0,0,0,67,111,112,121,77,97,115,107,0,0,0,0,0,0,0,0,70,105,120,65,116,97,110,50,0,0,0,0,0,0,0,0,88,77,117,110,103,101,114,0,72,79,112,101,110,82,101,115,70,105,108,101,0,0,0,0,72,67,114,101,97,116,101,82,101,115,70,105,108,101,0,0,67,111,117,110,116,49,84,121,112,101,115,0,0,0,0,0,73,110,118,97,108,77,101,110,117,66,97,114,0,0,0,0,71,101,116,49,82,101,115,111,117,114,99,101,0,0,0,0,71,101,116,49,78,97,109,101,100,82,101,115,111,117,114,99,101,0,0,0,0,0,0,0,77,97,120,83,105,122,101,82,115,114,99,0,0,0,0,0,82,101,115,111,117,114,99,101,68,105,115,112,97,116,99,104,0,0,0,0,0,0,0,0,65,108,105,97,115,68,105,115,112,97,116,99,104,0,0,0,73,110,115,77,101,110,117,73,116,101,109,0,0,0,0,0,72,105,100,101,68,73,116,101,109,0,0,0,0,0,0,0,83,104,111,119,68,73,116,101,109,0,0,0,0,0,0,0,76,97,121,101,114,68,105,115,112,97,116,99,104,0,0,0,67,111,109,112,111,110,101,110,116,68,105,115,112,97,116,99,104,0,0,0,0,0,0,0,80,97,99,107,57,0,0,0,80,97,99,107,49,48,0,0,80,97,99,107,49,49,0,0,80,97,99,107,49,50,0,0,80,97,99,107,49,51,0,0,80,97,99,107,49,52,0,0,80,97,99,107,49,53,0,0,83,99,114,110,66,105,116,77,97,112,0,0,0,0,0,0,83,101,116,70,83,99,97,108,101,68,105,115,97,98,108,101,0,0,0,0,0,0,0,0,70,111,110,116,77,101,116,114,105,99,115,0,0,0,0,0,71,101,116,77,97,115,107,84,97,98,108,101,0,0,0,0,77,101,97,115,117,114,101,84,101,120,116,0,0,0,0,0,67,97,108,99,77,97,115,107,0,0,0,0,0,0,0,0,83,101,101,100,70,105,108,108,0,0,0,0,0,0,0,0,90,111,111,109,87,105,110,100,111,119,0,0,0,0,0,0,84,114,97,99,107,66,111,120,0,0,0,0,0,0,0,0,84,69,71,101,116,79,102,102,115,101,116,0,0,0,0,0,84,69,68,105,115,112,97,116,99,104,0,0,0,0,0,0,84,69,83,116,121,108,101,78,101,119,0,0,0,0,0,0,76,111,110,103,50,70,105,120,0,0,0,0,0,0,0,0,70,105,120,50,76,111,110,103,0,0,0,0,0,0,0,0,70,105,120,50,70,114,97,99,0,0,0,0,0,0,0,0,70,114,97,99,50,70,105,120,0,0,0,0,0,0,0,0,70,105,120,50,88,0,0,0,88,50,70,105,120,0,0,0,70,114,97,99,50,88,0,0,88,50,70,114,97,99,0,0,70,114,97,99,67,111,115,0,70,114,97,99,83,105,110,0,70,114,97,99,83,113,114,116,0,0,0,0,0,0,0,0,70,114,97,99,77,117,108,0,70,114,97,99,68,105,118,0,85,115,101,114,68,101,108,97,121,0,0,0,0,0,0,0,70,105,120,68,105,118,0,0,71,101,116,73,116,101,109,67,109,100,0,0,0,0,0,0,83,101,116,73,116,101,109,67,109,100,0,0,0,0,0,0,73,110,105,116,67,117,114,115,111,114,0,0,0,0,0,0,83,101,116,67,117,114,115,111,114,0,0,0,0,0,0,0,72,105,100,101,67,117,114,115,111,114,0,0,0,0,0,0,83,104,111,119,67,117,114,115,111,114,0,0,0,0,0,0,70,111,110,116,68,105,115,112,97,116,99,104,0,0,0,0,83,104,105,101,108,100,67,117,114,115,111,114,0,0,0,0,79,98,115,99,117,114,101,67,117,114,115,111,114,0,0,0,66,105,116,65,110,100,0,0,66,105,116,88,111,114,0,0,66,105,116,78,111,116,0,0,66,105,116,79,114,0,0,0,66,105,116,83,104,105,102,116,0,0,0,0,0,0,0,0,66,105,116,84,115,116,0,0,66,105,116,83,101,116,0,0,66,105,116,67,108,114,0,0,87,97,105,116,78,101,120,116,69,118,101,110,116,0,0,0,82,97,110,100,111,109,0,0,70,111,114,101,67,111,108,111,114,0,0,0,0,0,0,0,66,97,99,107,67,111,108,111,114,0,0,0,0,0,0,0,67,111,108,111,114,66,105,116,0,0,0,0,0,0,0,0,71,101,116,80,105,120,101,108,0,0,0,0,0,0,0,0,83,116,117,102,102,72,101,120,0,0,0,0,0,0,0,0,76,111,110,103,77,117,108,0,70,105,120,77,117,108,0,0,70,105,120,82,97,116,105,111,0,0,0,0,0,0,0,0,72,105,87,111,114,100,0,0,76,111,87,111,114,100,0,0,70,105,120,82,111,117,110,100,0,0,0,0,0,0,0,0,73,110,105,116,80,111,114,116,0,0,0,0,0,0,0,0,73,110,105,116,71,114,97,102,0,0,0,0,0,0,0,0,79,112,101,110,80,111,114,116,0,0,0,0,0,0,0,0,76,111,99,97,108,84,111,71,108,111,98,97,108,0,0,0,71,108,111,98,97,108,84,111,76,111,99,97,108,0,0,0,71,114,97,102,68,101,118,105,99,101,0,0,0,0,0,0,83,101,116,80,111,114,116,0,71,101,116,80,111,114,116,0,83,101,116,80,66,105,116,115,0,0,0,0,0,0,0,0,80,111,114,116,83,105,122,101,0,0,0,0,0,0,0,0,77,111,118,101,80,111,114,116,84,111,0,0,0,0,0,0,83,101,116,79,114,105,103,105,110,0,0,0,0,0,0,0,83,101,116,67,108,105,112,0,71,101,116,67,108,105,112,0,67,108,105,112,82,101,99,116,0,0,0,0,0,0,0,0,66,97,99,107,80,97,116,0,67,108,111,115,101,80,111,114,116,0,0,0,0,0,0,0,67,108,111,115,101,67,80,111,114,116,0,0,0,0,0,0,65,100,100,80,116,0,0,0,83,117,98,80,116,0,0,0,83,101,116,80,116,0,0,0,69,113,117,97,108,80,116,0,83,116,100,84,101,120,116,0,68,114,97,119,67,104,97,114,0,0,0,0,0,0,0,0,68,114,97,119,83,116,114,105,110,103,0,0,0,0,0,0,68,114,97,119,84,101,120,116,0,0,0,0,0,0,0,0,84,101,120,116,87,105,100,116,104,0,0,0,0,0,0,0,84,101,120,116,70,111,110,116,0,0,0,0,0,0,0,0,84,101,120,116,70,97,99,101,0,0,0,0,0,0,0,0,84,101,120,116,77,111,100,101,0,0,0,0,0,0,0,0,84,101,120,116,83,105,122,101,0,0,0,0,0,0,0,0,71,101,116,70,111,110,116,73,110,102,111,0,0,0,0,0,83,116,114,105,110,103,87,105,100,116,104,0,0,0,0,0,67,104,97,114,87,105,100,116,104,0,0,0,0,0,0,0,83,112,97,99,101,69,120,116,114,97,0,0,0,0,0,0,79,83,68,105,115,112,97,116,99,104,0,0,0,0,0,0,83,116,100,76,105,110,101,0,76,105,110,101,84,111,0,0,76,105,110,101,0,0,0,0,77,111,118,101,84,111,0,0,77,111,118,101,0,0,0,0,83,104,117,116,100,111,119,110,0,0,0,0,0,0,0,0,72,105,100,101,80,101,110,0,83,104,111,119,80,101,110,0,71,101,116,80,101,110,83,116,97,116,101,0,0,0,0,0,83,101,116,80,101,110,83,116,97,116,101,0,0,0,0,0,71,101,116,80,101,110,0,0,80,101,110,83,105,122,101,0,80,101,110,77,111,100,101,0,80,101,110,80,97,116,0,0,80,101,110,78,111,114,109,97,108,0,0,0,0,0,0,0,85,110,105,109,112,108,101,109,101,110,116,101,100,0,0,0,83,116,100,82,101,99,116,0,70,114,97,109,101,82,101,99,116,0,0,0,0,0,0,0,80,97,105,110,116,82,101,99,116,0,0,0,0,0,0,0,69,114,97,115,101,82,101,99,116,0,0,0,0,0,0,0,73,110,118,101,114,82,101,99,116,0,0,0,0,0,0,0,70,105,108,108,82,101,99,116,0,0,0,0,0,0,0,0,69,113,117,97,108,82,101,99,116,0,0,0,0,0,0,0,83,101,116,82,101,99,116,0,79,102,102,115,101,116,82,101,99,116,0,0,0,0,0,0,73,110,115,101,116,82,101,99,116,0,0,0,0,0,0,0,83,101,99,116,82,101,99,116,0,0,0,0,0,0,0,0,85,110,105,111,110,82,101,99,116,0,0,0,0,0,0,0,80,116,50,82,101,99,116,0,80,116,73,110,82,101,99,116,0,0,0,0,0,0,0,0,69,109,112,116,121,82,101,99,116,0,0,0,0,0,0,0,83,116,100,82,82,101,99,116,0,0,0,0,0,0,0,0,70,114,97,109,101,82,111,117,110,100,82,101,99,116,0,0,80,97,105,110,116,82,111,117,110,100,82,101,99,116,0,0,69,114,97,115,101,82,111,117,110,100,82,101,99,116,0,0,73,110,118,101,114,82,111,117,110,100,82,101,99,116,0,0,70,105,108,108,82,111,117,110,100,82,101,99,116,0,0,0,83,99,114,105,112,116,85,116,105,108,0,0,0,0,0,0,83,116,100,79,118,97,108,0,70,114,97,109,101,79,118,97,108,0,0,0,0,0,0,0,80,97,105,110,116,79,118,97,108,0,0,0,0,0,0,0,69,114,97,115,101,79,118,97,108,0,0,0,0,0,0,0,73,110,118,101,114,116,79,118,97,108,0,0,0,0,0,0,70,105,108,108,79,118,97,108,0,0,0,0,0,0,0,0,83,108,111,112,101,70,114,111,109,65,110,103,108,101,0,0,83,116,100,65,114,99,0,0,70,114,97,109,101,65,114,99,0,0,0,0,0,0,0,0,80,97,105,110,116,65,114,99,0,0,0,0,0,0,0,0,69,114,97,115,101,65,114,99,0,0,0,0,0,0,0,0,73,110,118,101,114,116,65,114,99,0,0,0,0,0,0,0,70,105,108,108,65,114,99,0,80,116,84,111,65,110,103,108,101,0,0,0,0,0,0,0,65,110,103,108,101,70,114,111,109,83,108,111,112,101,0,0,83,116,100,80,111,108,121,0,70,114,97,109,101,80,111,108,121,0,0,0,0,0,0,0,80,97,105,110,116,80,111,108,121,0,0,0,0,0,0,0,69,114,97,115,101,80,111,108,121,0,0,0,0,0,0,0,73,110,118,101,114,116,80,111,108,121,0,0,0,0,0,0,70,105,108,108,80,111,108,121,0,0,0,0,0,0,0,0,79,112,101,110,80,111,108,121,0,0,0,0,0,0,0,0,67,108,111,115,101,80,103,111,110,0,0,0,0,0,0,0,75,105,108,108,80,111,108,121,0,0,0,0,0,0,0,0,79,102,102,115,101,116,80,111,108,121,0,0,0,0,0,0,80,97,99,107,66,105,116,115,0,0,0,0,0,0,0,0,85,110,112,97,99,107,66,105,116,115,0,0,0,0,0,0,83,116,100,82,103,110,0,0,70,114,97,109,101,82,103,110,0,0,0,0,0,0,0,0,80,97,105,110,116,82,103,110,0,0,0,0,0,0,0,0,69,114,97,115,101,82,103,110,0,0,0,0,0,0,0,0,73,110,118,101,114,82,103,110,0,0,0,0,0,0,0,0,70,105,108,108,82,103,110,0,66,105,116,77,97,112,84,111,82,101,103,105,111,110,0,0,78,101,119,82,103,110,0,0,68,105,115,112,111,115,82,103,110,0,0,0,0,0,0,0,79,112,101,110,82,103,110,0,67,108,111,115,101,82,103,110,0,0,0,0,0,0,0,0,67,111,112,121,82,103,110,0,83,101,116,69,109,112,116,121,82,103,110,0,0,0,0,0,83,101,116,82,101,99,82,103,110,0,0,0,0,0,0,0,82,101,99,116,82,103,110,0,79,102,115,101,116,82,103,110,0,0,0,0,0,0,0,0,73,110,115,101,116,82,103,110,0,0,0,0,0,0,0,0,69,109,112,116,121,82,103,110,0,0,0,0,0,0,0,0,69,113,117,97,108,82,103,110,0,0,0,0,0,0,0,0,83,101,99,116,82,103,110,0,85,110,105,111,110,82,103,110,0,0,0,0,0,0,0,0,68,105,102,102,82,103,110,0,88,111,114,82,103,110,0,0,80,116,73,110,82,103,110,0,82,101,99,116,73,110,82,103,110,0,0,0,0,0,0,0,83,101,116,83,116,100,80,114,111,99,115,0,0,0,0,0,83,116,100,66,105,116,115,0,67,111,112,121,66,105,116,115,0,0,0,0,0,0,0,0,83,116,100,84,120,77,101,97,115,0,0,0,0,0,0,0,83,116,100,71,101,116,80,105,99,0,0,0,0,0,0,0,83,99,114,111,108,108,82,101,99,116,0,0,0,0,0,0,83,116,100,80,117,116,80,105,99,0,0,0,0,0,0,0,83,116,100,67,111,109,109,101,110,116,0,0,0,0,0,0,80,105,99,67,111,109,109,101,110,116,0,0,0,0,0,0,79,112,101,110,80,105,99,116,117,114,101,0,0,0,0,0,67,108,111,115,101,80,105,99,116,117,114,101,0,0,0,0,75,105,108,108,80,105,99,116,117,114,101,0,0,0,0,0,68,114,97,119,80,105,99,116,117,114,101,0,0,0,0,0,76,97,121,111,117,116,0,0,83,99,97,108,101,80,116,0,77,97,112,80,116,0,0,0,77,97,112,82,101,99,116,0,77,97,112,82,103,110,0,0,77,97,112,80,111,108,121,0,80,114,71,108,117,101,0,0,73,110,105,116,70,111,110,116,115,0,0,0,0,0,0,0,71,101,116,70,78,97,109,101,0,0,0,0,0,0,0,0,71,101,116,70,78,117,109,0,70,77,83,119,97,112,70,111,110,116,0,0,0,0,0,0,82,101,97,108,70,111,110,116,0,0,0,0,0,0,0,0,83,101,116,70,111,110,116,76,111,99,107,0,0,0,0,0,68,114,97,119,71,114,111,119,73,99,111,110,0,0,0,0,68,114,97,103,71,114,97,121,82,103,110,0,0,0,0,0,78,101,119,83,116,114,105,110,103,0,0,0,0,0,0,0,83,101,116,83,116,114,105,110,103,0,0,0,0,0,0,0,83,104,111,119,72,105,100,101,0,0,0,0,0,0,0,0,67,97,108,99,86,105,115,0,67,97,108,99,86,66,101,104,105,110,100,0,0,0,0,0,67,108,105,112,65,98,111,118,101,0,0,0,0,0,0,0,80,97,105,110,116,79,110,101,0,0,0,0,0,0,0,0,80,97,105,110,116,66,101,104,105,110,100,0,0,0,0,0,83,97,118,101,79,108,100,0,68,114,97,119,78,101,119,0,71,101,116,87,77,103,114,80,111,114,116,0,0,0,0,0,67,104,101,99,107,85,112,100,97,116,101,0,0,0,0,0,73,110,105,116,87,105,110,100,111,119,115,0,0,0,0,0,78,101,119,87,105,110,100,111,119,0,0,0,0,0,0,0,68,105,115,112,111,115,87,105,110,100,111,119,0,0,0,0,83,104,111,119,87,105,110,100,111,119,0,0,0,0,0,0,72,105,100,101,87,105,110,100,111,119,0,0,0,0,0,0,71,101,116,87,82,101,102,67,111,110,0,0,0,0,0,0,83,101,116,87,82,101,102,67,111,110,0,0,0,0,0,0,71,101,116,87,84,105,116,108,101,0,0,0,0,0,0,0,83,101,116,87,84,105,116,108,101,0,0,0,0,0,0,0,77,111,118,101,87,105,110,100,111,119,0,0,0,0,0,0,72,105,108,105,116,101,87,105,110,100,111,119,0,0,0,0,83,105,122,101,87,105,110,100,111,119,0,0,0,0,0,0,84,114,97,99,107,71,111,65,119,97,121,0,0,0,0,0,83,101,108,101,99,116,87,105,110,100,111,119,0,0,0,0,66,114,105,110,103,84,111,70,114,111,110,116,0,0,0,0,83,101,110,100,66,101,104,105,110,100,0,0,0,0,0,0,66,101,103,105,110,85,112,100,97,116,101,0,0,0,0,0,69,110,100,85,112,100,97,116,101,0,0,0,0,0,0,0,70,114,111,110,116,87,105,110,100,111,119,0,0,0,0,0,68,114,97,103,87,105,110,100,111,119,0,0,0,0,0,0,68,114,97,103,84,104,101,82,103,110,0,0,0,0,0,0,73,110,118,97,108,82,103,110,0,0,0,0,0,0,0,0,73,110,118,97,108,82,101,99,116,0,0,0,0,0,0,0,86,97,108,105,100,82,103,110,0,0,0,0,0,0,0,0,86,97,108,105,100,82,101,99,116,0,0,0,0,0,0,0,71,114,111,119,87,105,110,100,111,119,0,0,0,0,0,0,70,105,110,100,87,105,110,100,111,119,0,0,0,0,0,0,67,108,111,115,101,87,105,110,100,111,119,0,0,0,0,0,83,101,116,87,105,110,100,111,119,80,105,99,0,0,0,0,71,101,116,87,105,110,100,111,119,80,105,99,0,0,0,0,73,110,105,116,77,101,110,117,115,0,0,0,0,0,0,0,78,101,119,77,101,110,117,0,68,105,115,112,111,115,77,101,110,117,0,0,0,0,0,0,65,112,112,101,110,100,77,101,110,117,0,0,0,0,0,0,67,108,101,97,114,77,101,110,117,66,97,114,0,0,0,0,73,110,115,101,114,116,77,101,110,117,0,0,0,0,0,0,68,101,108,101,116,101,77,101,110,117,0,0,0,0,0,0,68,114,97,119,77,101,110,117,66,97,114,0,0,0,0,0,72,105,108,105,116,101,77,101,110,117,0,0,0,0,0,0,69,110,97,98,108,101,73,116,101,109,0,0,0,0,0,0,68,105,115,97,98,108,101,73,116,101,109,0,0,0,0,0,71,101,116,77,101,110,117,66,97,114,0,0,0,0,0,0,83,101,116,77,101,110,117,66,97,114,0,0,0,0,0,0,77,101,110,117,83,101,108,101,99,116,0,0,0,0,0,0,77,101,110,117,75,101,121,0,71,101,116,73,116,109,73,99,111,110,0,0,0,0,0,0,83,101,116,73,116,109,73,99,111,110,0,0,0,0,0,0,71,101,116,73,116,109,83,116,121,108,101,0,0,0,0,0,83,101,116,73,116,109,83,116,121,108,101,0,0,0,0,0,71,101,116,73,116,109,77,97,114,107,0,0,0,0,0,0,83,101,116,73,116,109,77,97,114,107,0,0,0,0,0,0,67,104,101,99,107,73,116,101,109,0,0,0,0,0,0,0,71,101,116,73,116,101,109,0,83,101,116,73,116,101,109,0,67,97,108,99,77,101,110,117,83,105,122,101,0,0,0,0,71,101,116,77,72,97,110,100,108,101,0,0,0,0,0,0,83,101,116,77,70,108,97,115,104,0,0,0,0,0,0,0,80,108,111,116,73,99,111,110,0,0,0,0,0,0,0,0,70,108,97,115,104,77,101,110,117,66,97,114,0,0,0,0,65,100,100,82,101,115,77,101,110,117,0,0,0,0,0,0,80,105,110,82,101,99,116,0,68,101,108,116,97,80,111,105,110,116,0,0,0,0,0,0,67,111,117,110,116,77,73,116,101,109,115,0,0,0,0,0,73,110,115,101,114,116,82,101,115,77,101,110,117,0,0,0,68,101,108,77,101,110,117,73,116,101,109,0,0,0,0,0,85,112,100,116,67,111,110,116,114,111,108,0,0,0,0,0,78,101,119,67,111,110,116,114,111,108,0,0,0,0,0,0,68,105,115,112,111,115,67,111,110,116,114,111,108,0,0,0,75,105,108,108,67,111,110,116,114,111,108,115,0,0,0,0,83,104,111,119,67,111,110,116,114,111,108,0,0,0,0,0,72,105,100,101,67,111,110,116,114,111,108,0,0,0,0,0,77,111,118,101,67,111,110,116,114,111,108,0,0,0,0,0,71,101,116,67,82,101,102,67,111,110,0,0,0,0,0,0,83,101,116,67,82,101,102,67,111,110,0,0,0,0,0,0,83,105,122,101,67,111,110,116,114,111,108,0,0,0,0,0,72,105,108,105,116,101,67,111,110,116,114,111,108,0,0,0,71,101,116,67,84,105,116,108,101,0,0,0,0,0,0,0,83,101,116,67,84,105,116,108,101,0,0,0,0,0,0,0,71,101,116,67,116,108,86,97,108,117,101,0,0,0,0,0,71,101,116,77,105,110,67,116,108,0,0,0,0,0,0,0,71,101,116,77,97,120,67,116,108,0,0,0,0,0,0,0,83,101,116,67,116,108,86,97,108,117,101,0,0,0,0,0,83,101,116,77,105,110,67,116,108,0,0,0,0,0,0,0,83,101,116,77,97,120,67,116,108,0,0,0,0,0,0,0,84,101,115,116,67,111,110,116,114,111,108,0,0,0,0,0,68,114,97,103,67,111,110,116,114,111,108,0,0,0,0,0,84,114,97,99,107,67,111,110,116,114,111,108,0,0,0,0,68,114,97,119,67,111,110,116,114,111,108,115,0,0,0,0,71,101,116,67,116,108,65,99,116,105,111,110,0,0,0,0,83,101,116,67,116,108,65,99,116,105,111,110,0,0,0,0,70,105,110,100,67,111,110,116,114,111,108,0,0,0,0,0,68,114,97,119,49,67,111,110,116,114,111,108,0,0,0,0,68,101,113,117,101,117,101,0,69,110,113,117,101,117,101,0,71,101,116,78,101,120,116,69,118,101,110,116,0,0,0,0,69,118,101,110,116,65,118,97,105,108,0,0,0,0,0,0,71,101,116,77,111,117,115,101,0,0,0,0,0,0,0,0,83,116,105,108,108,68,111,119,110,0,0,0,0,0,0,0,66,117,116,116,111,110,0,0,84,105,99,107,67,111,117,110,116,0,0,0,0,0,0,0,71,101,116,75,101,121,115,0,87,97,105,116,77,111,117,115,101,85,112,0,0,0,0,0,85,112,100,116,68,105,97,108,111,103,0,0,0,0,0,0,67,111,117,108,100,68,105,97,108,111,103,0,0,0,0,0,70,114,101,101,68,105,97,108,111,103,0,0,0,0,0,0,73,110,105,116,68,105,97,108,111,103,115,0,0,0,0,0,71,101,116,78,101,119,68,105,97,108,111,103,0,0,0,0,78,101,119,68,105,97,108,111,103,0,0,0,0,0,0,0,83,101,108,73,84,101,120,116,0,0,0,0,0,0,0,0,73,115,68,105,97,108,111,103,69,118,101,110,116,0,0,0,68,105,97,108,111,103,83,101,108,101,99,116,0,0,0,0,68,114,97,119,68,105,97,108,111,103,0,0,0,0,0,0,67,108,111,115,101,68,105,97,108,111,103,0,0,0,0,0,68,105,115,112,111,115,68,105,97,108,111,103,0,0,0,0,70,105,110,100,68,73,116,101,109,0,0,0,0,0,0,0,65,108,101,114,116,0,0,0,83,116,111,112,65,108,101,114,116,0,0,0,0,0,0,0,78,111,116,101,65,108,101,114,116,0,0,0,0,0,0,0,67,97,117,116,105,111,110,65,108,101,114,116,0,0,0,0,67,111,117,108,100,65,108,101,114,116,0,0,0,0,0,0,70,114,101,101,65,108,101,114,116,0,0,0,0,0,0,0,80,97,114,97,109,84,101,120,116,0,0,0,0,0,0,0,69,114,114,111,114,83,111,117,110,100,0,0,0,0,0,0,71,101,116,68,73,116,101,109,0,0,0,0,0,0,0,0,83,101,116,68,73,116,101,109,0,0,0,0,0,0,0,0,83,101,116,73,84,101,120,116,0,0,0,0,0,0,0,0,71,101,116,73,84,101,120,116,0,0,0,0,0,0,0,0,77,111,100,97,108,68,105,97,108,111,103,0,0,0,0,0,68,101,116,97,99,104,82,101,115,111,117,114,99,101,0,0,83,101,116,82,101,115,80,117,114,103,101,0,0,0,0,0,67,117,114,82,101,115,70,105,108,101,0,0,0,0,0,0,73,110,105,116,82,101,115,111,117,114,99,101,115,0,0,0,82,115,114,99,90,111,110,101,73,110,105,116,0,0,0,0,79,112,101,110,82,101,115,70,105,108,101,0,0,0,0,0,85,115,101,82,101,115,70,105,108,101,0,0,0,0,0,0,85,112,100,97,116,101,82,101,115,70,105,108,101,0,0,0,67,108,111,115,101,82,101,115,70,105,108,101,0,0,0,0,83,101,116,82,101,115,76,111,97,100,0,0,0,0,0,0,67,111,117,110,116,82,101,115,111,117,114,99,101,115,0,0,71,101,116,73,110,100,82,101,115,111,117,114,99,101,0,0,67,111,117,110,116,84,121,112,101,115,0,0,0,0,0,0,71,101,116,73,110,100,84,121,112,101,0,0,0,0,0,0,71,101,116,82,101,115,111,117,114,99,101,0,0,0,0,0,71,101,116,78,97,109,101,100,82,101,115,111,117,114,99,101,0,0,0,0,0,0,0,0,76,111,97,100,82,101,115,111,117,114,99,101,0,0,0,0,82,101,108,101,97,115,101,82,101,115,111,117,114,99,101,0,72,111,109,101,82,101,115,70,105,108,101,0,0,0,0,0,83,105,122,101,82,115,114,99,0,0,0,0,0,0,0,0,71,101,116,82,101,115,65,116,116,114,115,0,0,0,0,0,83,101,116,82,101,115,65,116,116,114,115,0,0,0,0,0,71,101,116,82,101,115,73,110,102,111,0,0,0,0,0,0,83,101,116,82,101,115,73,110,102,111,0,0,0,0,0,0,67,104,97,110,103,101,100,82,101,115,111,117,114,99,101,0,65,100,100,82,101,115,111,117,114,99,101,0,0,0,0,0,65,100,100,82,101,102,101,114,101,110,99,101,0,0,0,0,82,109,118,101,82,101,115,111,117,114,99,101,0,0,0,0,82,109,118,101,82,101,102,101,114,101,110,99,101,0,0,0,82,101,115,69,114,114,111,114,0,0,0,0,0,0,0,0,87,114,105,116,101,82,101,115,111,117,114,99,101,0,0,0,67,114,101,97,116,101,82,101,115,70,105,108,101,0,0,0,83,121,115,116,101,109,69,118,101,110,116,0,0,0,0,0,83,121,115,116,101,109,67,108,105,99,107,0,0,0,0,0,83,121,115,116,101,109,84,97,115,107,0,0,0,0,0,0,83,121,115,116,101,109,77,101,110,117,0,0,0,0,0,0,79,112,101,110,68,101,115,107,65,99,99,0,0,0,0,0,67,108,111,115,101,68,101,115,107,65,99,99,0,0,0,0,71,101,116,80,97,116,116,101,114,110,0,0,0,0,0,0,71,101,116,67,117,114,115,111,114,0,0,0,0,0,0,0,71,101,116,83,116,114,105,110,103,0,0,0,0,0,0,0,71,101,116,73,99,111,110,0,71,101,116,80,105,99,116,117,114,101,0,0,0,0,0,0,71,101,116,78,101,119,87,105,110,100,111,119,0,0,0,0,71,101,116,78,101,119,67,111,110,116,114,111,108,0,0,0,71,101,116,82,77,101,110,117,0,0,0,0,0,0,0,0,71,101,116,78,101,119,77,66,97,114,0,0,0,0,0,0,85,110,105,113,117,101,73,68,0,0,0,0,0,0,0,0,83,121,115,69,100,105,116,0,75,101,121,84,114,97,110,115,0,0,0,0,0,0,0,0,79,112,101,110,82,70,80,101,114,109,0,0,0,0,0,0,82,115,114,99,77,97,112,69,110,116,114,121,0,0,0,0,83,101,99,115,50,68,97,116,101,0,0,0,0,0,0,0,68,97,116,101,50,83,101,99,0,0,0,0,0,0,0,0,83,121,115,66,101,101,112,0,83,121,115,69,114,114,111,114,0,0,0,0,0,0,0,0,80,117,116,73,99,111,110,0,84,69,71,101,116,84,101,120,116,0,0,0,0,0,0,0,84,69,73,110,105,116,0,0,84,69,68,105,115,112,111,115,101,0,0,0,0,0,0,0,84,101,120,116,66,111,120,0,84,69,83,101,116,84,101,120,116,0,0,0,0,0,0,0,84,69,67,97,108,84,101,120,116,0,0,0,0,0,0,0,84,69,83,101,116,83,101,108,101,99,116,0,0,0,0,0,84,69,78,101,119,0,0,0,84,69,85,112,100,97,116,101,0,0,0,0,0,0,0,0,84,69,67,108,105,99,107,0,84,69,67,111,112,121,0,0,84,69,67,117,116,0,0,0,84,69,68,101,108,101,116,101,0,0,0,0,0,0,0,0,84,69,65,99,116,105,118,97,116,101,0,0,0,0,0,0,84,69,68,101,97,99,116,105,118,97,116,101,0,0,0,0,84,69,73,100,108,101,0,0,84,69,80,97,115,116,101,0,84,69,75,101,121,0,0,0,84,69,83,99,114,111,108,108,0,0,0,0,0,0,0,0,84,69,73,110,115,101,114,116,0,0,0,0,0,0,0,0,84,69,83,101,116,74,117,115,116,0,0,0,0,0,0,0,77,117,110,103,101,114,0,0,72,97,110,100,84,111,72,97,110,100,0,0,0,0,0,0,80,116,114,84,111,88,72,97,110,100,0,0,0,0,0,0,80,116,114,84,111,72,97,110,100,0,0,0,0,0,0,0,72,97,110,100,65,110,100,72,97,110,100,0,0,0,0,0,73,110,105,116,80,97,99,107,0,0,0,0,0,0,0,0,73,110,105,116,65,108,108,80,97,99,107,115,0,0,0,0,80,97,99,107,48,0,0,0,80,97,99,107,49,0,0,0,80,97,99,107,50,0,0,0,80,97,99,107,51,0,0,0,70,80,54,56,75,0,0,0,80,97,99,107,52,0,0,0,69,108,101,109,115,54,56,75,0,0,0,0,0,0,0,0,80,97,99,107,53,0,0,0,80,97,99,107,54,0,0,0,80,97,99,107,55,0,0,0,80,116,114,65,110,100,72,97,110,100,0,0,0,0,0,0,76,111,97,100,83,101,103,0,85,110,108,111,97,100,83,101,103,0,0,0,0,0,0,0,76,97,117,110,99,104,0,0,67,104,97,105,110,0,0,0,69,120,105,116,84,111,83,104,101,108,108,0,0,0,0,0,71,101,116,65,112,112,80,97,114,109,115,0,0,0,0,0,71,101,116,82,101,115,70,105,108,101,65,116,116,114,115,0,83,101,116,82,101,115,70,105,108,101,65,116,116,114,115,0,77,101,116,104,111,100,68,105,115,112,97,116,99,104,0,0,73,110,102,111,83,99,114,97,112,0,0,0,0,0,0,0,85,110,108,111,100,101,83,99,114,97,112,0,0,0,0,0,76,111,100,101,83,99,114,97,112,0,0,0,0,0,0,0,90,101,114,111,83,99,114,97,112,0,0,0,0,0,0,0,71,101,116,83,99,114,97,112,0,0,0,0,0,0,0,0,80,117,116,83,99,114,97,112,0,0,0,0,0,0,0,0,68,101,98,117,103,103,101,114,0,0,0,0,0,0,0,0,79,112,101,110,67,112,111,114,116,0,0,0,0,0,0,0,73,110,105,116,67,112,111,114,116,0,0,0,0,0,0,0,78,101,119,80,105,120,77,97,112,0,0,0,0,0,0,0,68,105,115,112,111,115,80,105,120,77,97,112,0,0,0,0,67,111,112,121,80,105,120,77,97,112,0,0,0,0,0,0,83,101,116,67,80,111,114,116,80,105,120,0,0,0,0,0,78,101,119,80,105,120,80,97,116,0,0,0,0,0,0,0,68,105,115,112,111,115,80,105,120,80,97,116,0,0,0,0,67,111,112,121,80,105,120,80,97,116,0,0,0,0,0,0,80,101,110,80,105,120,80,97,116,0,0,0,0,0,0,0,66,97,99,107,80,105,120,80,97,116,0,0,0,0,0,0,71,101,116,80,105,120,80,97,116,0,0,0,0,0,0,0,77,97,107,101,82,71,66,80,97,116,0,0,0,0,0,0,70,105,108,108,67,82,101,99,116,0,0,0,0,0,0,0,70,105,108,108,67,79,118,97,108,0,0,0,0,0,0,0,70,105,108,108,67,82,111,117,110,100,82,101,99,116,0,0,70,105,108,108,67,65,114,99,0,0,0,0,0,0,0,0,70,105,108,108,67,82,103,110,0,0,0,0,0,0,0,0,70,105,108,108,67,80,111,108,121,0,0,0,0,0,0,0,82,71,66,70,111,114,101,67,111,108,111,114,0,0,0,0,82,71,66,66,97,99,107,67,111,108,111,114,0,0,0,0,83,101,116,67,80,105,120,101,108,0,0,0,0,0,0,0,71,101,116,67,80,105,120,101,108,0,0,0,0,0,0,0,71,101,116,67,84,97,98,108,101,0,0,0,0,0,0,0,71,101,116,70,111,114,101,67,111,108,111,114,0,0,0,0,71,101,116,66,97,99,107,67,111,108,111,114,0,0,0,0,71,101,116,67,67,117,114,115,111,114,0,0,0,0,0,0,83,101,116,67,67,117,114,115,111,114,0,0,0,0,0,0,65,108,108,111,99,67,117,114,115,111,114,0,0,0,0,0,71,101,116,67,73,99,111,110,0,0,0,0,0,0,0,0,80,108,111,116,67,73,99,111,110,0,0,0,0,0,0,0,79,112,67,111,108,111,114,0,72,105,108,105,116,101,67,111,108,111,114,0,0,0,0,0,67,104,97,114,69,120,116,114,97,0,0,0,0,0,0,0,68,105,115,112,111,115,67,84,97,98,108,101,0,0,0,0,68,105,115,112,111,115,67,73,99,111,110,0,0,0,0,0,68,105,115,112,111,115,67,67,117,114,115,111,114,0,0,0,71,101,116,77,97,120,68,101,118,105,99,101,0,0,0,0,71,101,116,67,84,83,101,101,100,0,0,0,0,0,0,0,71,101,116,68,101,118,105,99,101,76,105,115,116,0,0,0,71,101,116,77,97,105,110,68,101,118,105,99,101,0,0,0,71,101,116,78,101,120,116,68,101,118,105,99,101,0,0,0,84,101,115,116,68,101,118,105,99,101,65,116,116,114,105,98,117,116,101,0,0,0,0,0,83,101,116,68,101,118,105,99,101,65,116,116,114,105,98,117,116,101,0,0,0,0,0,0,73,110,105,116,71,68,101,118,105,99,101,0,0,0,0,0,78,101,119,71,68,101,118,105,99,101,0,0,0,0,0,0,68,105,115,112,111,115,71,68,101,118,105,99,101,0,0,0,83,101,116,71,68,101,118,105,99,101,0,0,0,0,0,0,71,101,116,71,68,101,118,105,99,101,0,0,0,0,0,0,67,111,108,111,114,50,73,110,100,101,120,0,0,0,0,0,73,110,100,101,120,50,67,111,108,111,114,0,0,0,0,0,73,110,118,101,114,116,67,111,108,111,114,0,0,0,0,0,82,101,97,108,67,111,108,111,114,0,0,0,0,0,0,0,71,101,116,83,117,98,84,97,98,108,101,0,0,0,0,0,85,112,100,97,116,101,80,105,120,77,97,112,0,0,0,0,77,97,107,101,73,84,97,98,108,101,0,0,0,0,0,0,65,100,100,83,101,97,114,99,104,0,0,0,0,0,0,0,65,100,100,67,111,109,112,0,83,101,116,67,108,105,101,110,116,73,68,0,0,0,0,0,80,114,111,116,101,99,116,69,110,116,114,121,0,0,0,0,82,101,115,101,114,118,101,69,110,116,114,121,0,0,0,0,83,101,116,69,110,116,114,105,101,115,0,0,0,0,0,0,81,68,69,114,114,111,114,0,83,101,116,87,105,110,67,111,108,111,114,0,0,0,0,0,71,101,116,65,117,120,87,105], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+20480);
/* memory initializer */ allocate([110,0,0,0,0,0,0,0,83,101,116,67,116,108,67,111,108,111,114,0,0,0,0,0,71,101,116,65,117,120,67,116,108,0,0,0,0,0,0,0,78,101,119,67,87,105,110,100,111,119,0,0,0,0,0,0,71,101,116,78,101,119,67,87,105,110,100,111,119,0,0,0,83,101,116,68,101,115,107,67,80,97,116,0,0,0,0,0,71,101,116,67,87,77,103,114,80,111,114,116,0,0,0,0,83,97,118,101,69,110,116,114,105,101,115,0,0,0,0,0,82,101,115,116,111,114,101,69,110,116,114,105,101,115,0,0,78,101,119,67,68,105,97,108,111,103,0,0,0,0,0,0,68,101,108,83,101,97,114,99,104,0,0,0,0,0,0,0,68,101,108,67,111,109,112,0,83,101,116,83,116,100,67,80,114,111,99,115,0,0,0,0,67,97,108,99,67,77,97,115,107,0,0,0,0,0,0,0,83,101,101,100,67,70,105,108,108,0,0,0,0,0,0,0,67,111,112,121,68,101,101,112,77,97,115,107,0,0,0,0,72,105,103,104,76,101,118,101,108,70,83,68,105,115,112,97,116,99,104,0,0,0,0,0,68,101,108,77,67,69,110,116,114,105,101,115,0,0,0,0,71,101,116,77,67,73,110,102,111,0,0,0,0,0,0,0,83,101,116,77,67,73,110,102,111,0,0,0,0,0,0,0,68,105,115,112,77,67,69,110,116,114,105,101,115,0,0,0,71,101,116,77,67,69,110,116,114,121,0,0,0,0,0,0,83,101,116,77,67,69,110,116,114,105,101,115,0,0,0,0,77,101,110,117,67,104,111,105,99,101,0,0,0,0,0,0,77,111,100,97,108,68,105,97,108,111,103,77,101,110,117,83,101,116,117,112,0,0,0,0,68,105,97,108,111,103,68,105,115,112,97,116,99,104,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,24,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,25,0,0,0,26,0,0,0,27,0,0,0,20,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,28,0,0,0,29,0,0,0,30,0,0,0,20,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,31,0,0,0,32,0,0,0,33,0,0,0,34,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,37,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,37,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,37,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,37,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,37,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,37,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,37,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,36,0,0,0,38,0,0,0,39,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,39,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,39,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,39,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,39,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,39,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,39,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,39,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,38,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,20,0,0,0,20,0,0,0,44,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,49,0,0,0,20,0,0,0,20,0,0,0,44,0,0,0,45,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,53,0,0,0,20,0,0,0,20,0,0,0,44,0,0,0,45,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,57,0,0,0,20,0,0,0,20,0,0,0,44,0,0,0,45,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,20,0,0,0,20,0,0,0,44,0,0,0,62,0,0,0,63,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,20,0,0,0,20,0,0,0,44,0,0,0,45,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,20,0,0,0,20,0,0,0,44,0,0,0,45,0,0,0,20,0,0,0,71,0,0,0,72,0,0,0,34,0,0,0,20,0,0,0,20,0,0,0,44,0,0,0,45,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,76,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,76,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,76,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,76,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,76,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,76,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,76,0,0,0,73,0,0,0,74,0,0,0,75,0,0,0,76,0,0,0,77,0,0,0,78,0,0,0,79,0,0,0,76,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,80,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,81,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,20,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,82,0,0,0,83,0,0,0,84,0,0,0,85,0,0,0,86,0,0,0,87,0,0,0,88,0,0,0,89,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,90,0,0,0,91,0,0,0,92,0,0,0,93,0,0,0,94,0,0,0,95,0,0,0,96,0,0,0,97,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,99,0,0,0,100,0,0,0,101,0,0,0,102,0,0,0,103,0,0,0,104,0,0,0,105,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,131,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,132,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,133,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,134,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,135,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,136,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,137,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,138,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,139,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,140,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,141,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,20,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,142,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,143,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,144,0,0,0,37,48,52,88,0,0,0,0,66,70,73,78,83,0,0,0,35,37,115,37,48,52,88,0,68,37,117,0,0,0,0,0,65,37,117,0,0,0,0,0,37,115,37,117,0,0,0,0,65,0,0,0,0,0,0,0,68,0,0,0,0,0,0,0,40,65,37,117,41,43,0,0,45,40,65,37,117,41,0,0,37,115,37,115,37,48,52,88,40,65,37,117,41,0,0,0,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,37,115,37,48,50,88,0,35,37,115,37,48,56,108,88,0,0,0,0,0,0,0,0,35,37,115,37,88,0,0,0,37,115,37,48,56,108,88,0,83,82,0,0,0,0,0,0,85,83,80,0,0,0,0,0,68,37,117,58,68,37,117,0,37,117,0,0,0,0,0,0,83,70,67,0,0,0,0,0,68,70,67,0,0,0,0,0,86,66,82,0,0,0,0,0,67,82,40,37,117,41,0,0,37,115,37,117,45,37,115,37,117,0,0,0,0,0,0,0,37,115,37,117,47,37,115,37,117,0,0,0,0,0,0,0,40,65,37,117,41,0,0,0,37,115,37,115,37,48,50,88,40,65,37,117,44,32,37,115,37,117,37,115,42,37,117,41,0,0,0,0,0,0,0,0,46,76,0,0,0,0,0,0,46,87,0,0,0,0,0,0,37,115,37,115,37,48,52,88,0,0,0,0,0,0,0,0,37,115,37,48,56,108,88,40,80,67,41,0,0,0,0,0,37,115,37,115,37,48,50,88,40,80,67,44,32,37,115,37,117,37,115,42,37,117,41,0,60,69,65,62,40,37,48,50,88,41,0,0,0,0,0,0,80,67,0,0,0,0,0,0,37,115,37,117,37,115,0,0,42,37,117,0,0,0,0,0,37,115,37,115,37,48,56,88,0,0,0,0,0,0,0,0,40,91,37,115,44,32,37,115,93,44,32,37,115,37,115,44,32,37,115,41,0,0,0,0,40,91,37,115,44,32,37,115,44,32,37,115,37,115,93,44,32,37,115,41,0,0,0,0,36,0,0,0,0,0,0,0,66,70,83,69,84,0,0,0,66,70,67,76,82,0,0,0,66,70,69,88,84,83,0,0,66,70,67,72,71,0,0,0,66,70,69,88,84,85,0,0,66,70,84,83,84,0,0,0,82,79,76,46,87,0,0,0,82,79,82,46,87,0,0,0,82,79,88,76,46,87,0,0,82,79,88,82,46,87,0,0,76,83,76,46,87,0,0,0,76,83,82,46,87,0,0,0,65,83,76,46,87,0,0,0,65,83,76,46,76,0,0,0,76,83,76,46,76,0,0,0,82,79,88,76,46,76,0,0,82,79,76,46,76,0,0,0,68,87,0,0,0,0,0,0,65,83,76,46,66,0,0,0,76,83,76,46,66,0,0,0,82,79,88,76,46,66,0,0,82,79,76,46,66,0,0,0,65,83,82,46,87,0,0,0,65,83,82,46,76,0,0,0,76,83,82,46,76,0,0,0,82,79,88,82,46,76,0,0,82,79,82,46,76,0,0,0,65,83,82,46,66,0,0,0,76,83,82,46,66,0,0,0,82,79,88,82,46,66,0,0,82,79,82,46,66,0,0,0,65,68,68,65,46,76,0,0,65,68,68,88,46,76,0,0,65,68,68,46,76,0,0,0,65,68,68,88,46,87,0,0,65,68,68,46,87,0,0,0,65,68,68,88,46,66,0,0,65,68,68,46,66,0,0,0,65,68,68,65,46,87,0,0,77,85,76,83,46,87,0,0,65,78,68,46,76,0,0,0,65,78,68,46,87,0,0,0,65,66,67,68,46,66,0,0,65,78,68,46,66,0,0,0,77,85,76,85,46,87,0,0,67,77,80,65,46,76,0,0,67,77,80,77,46,76,0,0,69,79,82,46,76,0,0,0,67,77,80,77,46,87,0,0,69,79,82,46,87,0,0,0,67,77,80,77,46,66,0,0,69,79,82,46,66,0,0,0,67,77,80,65,46,87,0,0,67,77,80,46,76,0,0,0,67,77,80,46,87,0,0,0,67,77,80,46,66,0,0,0,83,85,66,65,46,76,0,0,83,85,66,88,46,76,0,0,83,85,66,46,76,0,0,0,83,85,66,88,46,87,0,0,83,85,66,46,87,0,0,0,83,85,66,88,46,66,0,0,83,85,66,46,66,0,0,0,83,85,66,65,46,87,0,0,68,73,86,83,46,87,0,0,79,82,46,76,0,0,0,0,79,82,46,87,0,0,0,0,83,66,67,68,46,66,0,0,79,82,46,66,0,0,0,0,68,73,86,85,46,87,0,0,77,79,86,69,81,0,0,0,0,142,0,0,8,142,0,0,16,142,0,0,24,142,0,0,32,142,0,0,40,142,0,0,48,142,0,0,56,142,0,0,64,142,0,0,72,142,0,0,80,142,0,0,88,142,0,0,96,142,0,0,104,142,0,0,112,142,0,0,120,142,0,0,46,83,0,0,0,0,0,0,66,82,65,0,0,0,0,0,66,83,82,0,0,0,0,0,66,72,73,0,0,0,0,0,66,76,83,0,0,0,0,0,66,67,67,0,0,0,0,0,66,67,83,0,0,0,0,0,66,78,69,0,0,0,0,0,66,69,81,0,0,0,0,0,66,86,67,0,0,0,0,0,66,86,83,0,0,0,0,0,66,80,76,0,0,0,0,0,66,77,73,0,0,0,0,0,66,71,69,0,0,0,0,0,66,76,84,0,0,0,0,0,66,71,84,0,0,0,0,0,66,76,69,0,0,0,0,0,83,85,66,81,46,76,0,0,83,85,66,81,46,87,0,0,83,85,66,81,46,66,0,0,88,144,0,0,96,144,0,0,104,144,0,0,112,144,0,0,120,144,0,0,128,144,0,0,136,144,0,0,144,144,0,0,152,144,0,0,160,144,0,0,168,144,0,0,176,144,0,0,184,144,0,0,192,144,0,0,200,144,0,0,208,144,0,0,216,143,0,0,224,143,0,0,232,143,0,0,240,143,0,0,248,143,0,0,0,144,0,0,8,144,0,0,16,144,0,0,24,144,0,0,32,144,0,0,40,144,0,0,48,144,0,0,56,144,0,0,64,144,0,0,72,144,0,0,80,144,0,0,88,143,0,0,96,143,0,0,104,143,0,0,112,143,0,0,120,143,0,0,128,143,0,0,136,143,0,0,144,143,0,0,152,143,0,0,160,143,0,0,168,143,0,0,176,143,0,0,184,143,0,0,192,143,0,0,200,143,0,0,208,143,0,0,83,84,0,0,0,0,0,0,83,70,0,0,0,0,0,0,83,72,73,0,0,0,0,0,83,76,83,0,0,0,0,0,83,67,67,0,0,0,0,0,83,67,83,0,0,0,0,0,83,78,69,0,0,0,0,0,83,69,81,0,0,0,0,0,83,86,67,0,0,0,0,0,83,86,83,0,0,0,0,0,83,80,76,0,0,0,0,0,83,77,73,0,0,0,0,0,83,71,69,0,0,0,0,0,83,76,84,0,0,0,0,0,83,71,84,0,0,0,0,0,83,76,69,0,0,0,0,0,68,66,84,0,0,0,0,0,68,66,70,0,0,0,0,0,68,66,72,73,0,0,0,0,68,66,76,83,0,0,0,0,68,66,67,67,0,0,0,0,68,66,67,83,0,0,0,0,68,66,78,69,0,0,0,0,68,66,69,81,0,0,0,0,68,66,86,67,0,0,0,0,68,66,86,83,0,0,0,0,68,66,80,76,0,0,0,0,68,66,77,73,0,0,0,0,68,66,71,69,0,0,0,0,68,66,76,84,0,0,0,0,68,66,71,84,0,0,0,0,68,66,76,69,0,0,0,0,84,82,65,80,84,0,0,0,84,82,65,80,70,0,0,0,84,82,65,80,72,73,0,0,84,82,65,80,76,83,0,0,84,82,65,80,67,67,0,0,84,82,65,80,67,83,0,0,84,82,65,80,78,69,0,0,84,82,65,80,69,81,0,0,84,82,65,80,86,67,0,0,84,82,65,80,86,83,0,0,84,82,65,80,80,76,0,0,84,82,65,80,77,73,0,0,84,82,65,80,71,69,0,0,84,82,65,80,76,84,0,0,84,82,65,80,71,84,0,0,84,82,65,80,76,69,0,0,65,68,68,81,46,76,0,0,65,68,68,81,46,87,0,0,65,68,68,81,46,66,0,0,82,69,83,69,84,0,0,0,83,84,79,80,0,0,0,0,84,82,65,80,86,0,0,0,77,79,86,69,67,0,0,0,84,82,65,80,0,0,0,0,76,73,78,75,0,0,0,0,85,78,76,75,0,0,0,0,77,79,86,69,0,0,0,0,68,73,86,85,46,76,0,0,77,85,76,85,46,76,0,0,84,83,84,46,76,0,0,0,84,83,84,46,87,0,0,0,84,83,84,46,66,0,0,0,69,88,84,66,46,76,0,0,69,88,84,46,76,0,0,0,69,88,84,46,87,0,0,0,83,87,65,80,0,0,0,0,78,66,67,68,46,66,0,0,77,79,86,69,46,87,0,0,78,79,84,46,76,0,0,0,78,79,84,46,87,0,0,0,78,79,84,46,66,0,0,0,78,69,71,46,76,0,0,0,78,69,71,46,87,0,0,0,78,69,71,46,66,0,0,0,67,76,82,46,76,0,0,0,67,76,82,46,87,0,0,0,67,76,82,46,66,0,0,0,78,69,71,88,46,76,0,0,78,69,71,88,46,87,0,0,78,69,71,88,46,66,0,0,77,79,86,69,46,76,0,0,77,79,86,69,46,66,0,0,77,79,86,83,46,76,0,0,77,79,86,83,46,87,0,0,77,79,86,83,46,66,0,0,67,77,80,73,46,76,0,0,67,77,80,73,46,87,0,0,67,77,80,73,46,66,0,0,69,79,82,73,46,76,0,0,69,79,82,73,46,87,0,0,69,79,82,73,46,66,0,0,66,83,69,84,0,0,0,0,66,67,76,82,0,0,0,0,66,67,72,71,0,0,0,0,66,84,83,84,0,0,0,0,65,68,68,73,46,76,0,0,65,68,68,73,46,87,0,0,65,68,68,73,46,66,0,0,67,72,75,50,46,76,0,0,67,77,80,50,46,76,0,0,83,85,66,73,46,76,0,0,83,85,66,73,46,87,0,0,83,85,66,73,46,66,0,0,67,72,75,50,46,87,0,0,67,77,80,50,46,87,0,0,65,78,68,73,46,76,0,0,65,78,68,73,46,87,0,0,65,78,68,73,46,66,0,0,67,72,75,50,46,66,0,0,67,77,80,50,46,66,0,0,79,82,73,46,76,0,0,0,79,82,73,46,87,0,0,0,79,82,73,46,66,0,0,0,110,111,110,101,0,0,0,0,112,99,0,0,0,0,0,0,108,112,99,0,0,0,0,0,115,114,0,0,0,0,0,0,115,112,0,0,0,0,0,0,99,99,114,0,0,0,0,0,117,115,112,0,0,0,0,0,115,115,112,0,0,0,0,0,82,83,69,84,0,0,0,0,66,85,83,69,0,0,0,0,65,68,68,82,0,0,0,0,73,76,76,71,0,0,0,0,68,73,86,90,0,0,0,0,67,72,75,0,0,0,0,0,79,70,76,87,0,0,0,0,80,82,73,86,0,0,0,0,84,82,65,67,69,0,0,0,65,88,88,88,0,0,0,0,70,88,88,88,0,0,0,0,70,82,77,84,0,0,0,0,65,86,69,67,0,0,0,0,84,82,65,80,0,0,0,0,73,78,84,82,0,0,0,0,119,97,114,110,105,110,103,58,32,100,101,108,97,121,32,61,61,32,48,32,97,116,32,37,48,56,108,120,10,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,14,0,0,0,15,0,0,0,16,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,17,0,0,0,18,0,0,0,19,0,0,0,20,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,21,0,0,0,22,0,0,0,23,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,24,0,0,0,25,0,0,0,26,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,27,0,0,0,28,0,0,0,29,0,0,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,30,0,0,0,0,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,0,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,0,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,0,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,0,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,0,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,0,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,0,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,30,0,0,0,31,0,0,0,32,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,32,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,32,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,32,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,32,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,32,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,32,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,32,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,31,0,0,0,33,0,0,0,34,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,34,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,33,0,0,0,35,0,0,0,36,0,0,0,37,0,0,0,38,0,0,0,0,0,0,0,0,0,0,0,39,0,0,0,40,0,0,0,41,0,0,0,42,0,0,0,43,0,0,0,44,0,0,0,0,0,0,0,0,0,0,0,39,0,0,0,40,0,0,0,45,0,0,0,46,0,0,0,47,0,0,0,48,0,0,0,0,0,0,0,0,0,0,0,39,0,0,0,40,0,0,0,49,0,0,0,50,0,0,0,51,0,0,0,52,0,0,0,0,0,0,0,0,0,0,0,39,0,0,0,40,0,0,0,53,0,0,0,54,0,0,0,55,0,0,0,56,0,0,0,0,0,0,0,0,0,0,0,39,0,0,0,57,0,0,0,58,0,0,0,59,0,0,0,60,0,0,0,61,0,0,0,0,0,0,0,0,0,0,0,39,0,0,0,40,0,0,0,0,0,0,0,0,0,0,0,62,0,0,0,63,0,0,0,0,0,0,0,0,0,0,0,39,0,0,0,40,0,0,0,0,0,0,0,64,0,0,0,65,0,0,0,66,0,0,0,0,0,0,0,0,0,0,0,39,0,0,0,40,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,70,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,74,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,75,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,76,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,77,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,78,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,79,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,80,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,81,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,82,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,83,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,84,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,85,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,86,0,0,0,67,0,0,0,68,0,0,0,69,0,0,0,87,0,0,0,71,0,0,0,72,0,0,0,73,0,0,0,88,0,0,0,89,0,0,0,89,0,0,0,89,0,0,0,89,0,0,0,90,0,0,0,90,0,0,0,90,0,0,0,90,0,0,0,91,0,0,0,91,0,0,0,91,0,0,0,91,0,0,0,92,0,0,0,92,0,0,0,92,0,0,0,92,0,0,0,93,0,0,0,93,0,0,0,93,0,0,0,93,0,0,0,94,0,0,0,94,0,0,0,94,0,0,0,94,0,0,0,95,0,0,0,95,0,0,0,95,0,0,0,95,0,0,0,96,0,0,0,96,0,0,0,96,0,0,0,96,0,0,0,97,0,0,0,97,0,0,0,97,0,0,0,97,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,98,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,99,0,0,0,100,0,0,0,100,0,0,0,100,0,0,0,100,0,0,0,101,0,0,0,101,0,0,0,101,0,0,0,101,0,0,0,102,0,0,0,102,0,0,0,102,0,0,0,102,0,0,0,103,0,0,0,103,0,0,0,103,0,0,0,103,0,0,0,104,0,0,0,104,0,0,0,104,0,0,0,104,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,106,0,0,0,107,0,0,0,108,0,0,0,109,0,0,0,110,0,0,0,111,0,0,0,112,0,0,0,113,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,114,0,0,0,115,0,0,0,116,0,0,0,117,0,0,0,118,0,0,0,119,0,0,0,120,0,0,0,121,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,122,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,123,0,0,0,124,0,0,0,125,0,0,0,126,0,0,0,127,0,0,0,128,0,0,0,129,0,0,0,130,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+30720);
/* memory initializer */ allocate([131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,131,0,0,0,132,0,0,0,133,0,0,0,134,0,0,0,135,0,0,0,136,0,0,0,137,0,0,0,138,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,139,0,0,0,140,0,0,0,141,0,0,0,142,0,0,0,143,0,0,0,144,0,0,0,145,0,0,0,146,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,150,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,154,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,155,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,156,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,157,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,158,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,159,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,160,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,0,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,0,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,0,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,0,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,0,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,0,0,0,0,147,0,0,0,148,0,0,0,149,0,0,0,0,0,0,0,151,0,0,0,152,0,0,0,153,0,0,0,0,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,161,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,164,0,0,0,165,0,0,0,166,0,0,0,0,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,167,0,0,0,168,0,0,0,0,0,0,0,0,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,169,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,170,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,175,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,177,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,178,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,179,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,180,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,181,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,183,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,0,0,0,185,0,0,0,185,0,0,0,185,0,0,0,185,0,0,0,186,0,0,0,186,0,0,0,186,0,0,0,186,0,0,0,187,0,0,0,187,0,0,0,187,0,0,0,187,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,188,0,0,0,189,0,0,0,189,0,0,0,189,0,0,0,189,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,190,0,0,0,191,0,0,0,191,0,0,0,191,0,0,0,191,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,192,0,0,0,193,0,0,0,193,0,0,0,193,0,0,0,193,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,194,0,0,0,195,0,0,0,195,0,0,0,195,0,0,0,195,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,196,0,0,0,197,0,0,0,197,0,0,0,197,0,0,0,197,0,0,0,198,0,0,0,198,0,0,0,198,0,0,0,198,0,0,0,199,0,0,0,199,0,0,0,199,0,0,0,199,0,0,0,200,0,0,0,200,0,0,0,200,0,0,0,200], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+40960);
/* memory initializer */ allocate([201,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,203,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,204,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,205,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,206,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,207,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,15,0,0,0,15,0,0,0,66,76,75,32,37,48,52,88,58,32,65,49,61,37,48,56,108,88,32,65,50,61,37,48,56,108,88,32,83,61,37,48,56,108,88,32,82,79,61,37,100,10,0,0,0,0,0,0,114,98,0,0,0,0,0,0,114,43,98,0,0,0,0,0,99,111,109,109,105,116,0,0,100,105,115,107,32,37,117,58,32,119,114,105,116,105,110,103,32,98,97,99,107,32,102,100,99,32,105,109,97,103,101,10,0,0,0,0,0,0,0,0,100,105,115,107,32,37,117,58,32,119,114,105,116,105,110,103,32,98,97,99,107,32,102,97,105,108,101,100,10,0,0,0,99,111,109,109,105,116,0,0,0,0,0,0,0,0,0,0,68,79,83,69,77,85,0,0,114,98,0,0,0,0,0,0,114,43,98,0,0,0,0,0,114,98,0,0,0,0,0,0,114,43,98,0,0,0,0,0,99,111,109,109,105,116,0,0,114,98,0,0,0,0,0,0,114,43,98,0,0,0,0,0,119,98,0,0,0,0,0,0,99,111,109,109,105,116,0,0,113,101,100,58,32,117,110,107,110,111,119,110,32,102,101,97,116,117,114,101,115,32,40,48,120,37,48,56,108,108,120,41,10,0,0,0,0,0,0,0,114,98,0,0,0,0,0,0,114,43,98,0,0,0,0,0,109,111,117,115,101,0,0,0,110,117,108,108,0,0,0,0,112,111,115,105,120,0,0,0,115,101,114,99,111,110,0,0,112,116,121,0,0,0,0,0,115,116,100,105,111,0,0,0,240,181,0,0,1,0,0,0,248,181,0,0,2,0,0,0,0,182,0,0,3,0,0,0,8,182,0,0,3,0,0,0,16,182,0,0,4,0,0,0,24,182,0,0,5,0,0,0,0,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,108,111,103,0,0,0,0,0,78,0,0,0,0,0,0,0,79,0,0,0,0,0,0,0,69,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,45,45,32,37,108,117,32,37,117,37,115,37,117,10,0,0,67,84,83,0,0,0,0,0,68,84,82,0,0,0,0,0,82,84,83,0,0,0,0,0,68,83,82,0,0,0,0,0,67,68,0,0,0,0,0,0,82,73,0,0,0,0,0,0,45,45,32,37,115,61,37,100,10,0,0,0,0,0,0,0,37,115,32,37,48,50,88,0,45,62,0,0,0,0,0,0,60,45,0,0,0,0,0,0,32,37,48,50,88,0,0,0,32,32,32,0,0,0,0,0,32,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,114,111,116,111,99,111,108,0,0,0,0,0,0,0,0,109,105,99,114,111,115,111,102,116,0,0,0,0,0,0,0,109,115,121,115,0,0,0,0,120,109,117,108,0,0,0,0,120,100,105,118,0,0,0,0,121,109,117,108,0,0,0,0,121,100,105,118,0,0,0,0,102,105,108,101,0,0,0,0,114,101,97,100,0,0,0,0,119,114,105,116,101,0,0,0,45,0,0,0,0,0,0,0,45,45,0,0,0,0,0,0,115,101,114,99,111,110,0,0,115,121,109,108,105,110,107,0,42,42,42,32,101,114,114,111,114,32,99,114,101,97,116,105,110,103,32,115,121,109,108,105,110,107,32,37,115,32,45,62,32,37,115,10,0,0,0,0,99,104,97,114,45,112,116,121,58,32,37,115,10,0,0,0,102,105,108,101,0,0,0,0,102,108,117,115,104,0,0,0,45,0,0,0,0,0,0,0,119,98,0,0,0,0,0,0,230,41,1,0,14,17,1,0,52,248,0,0,102,223,0,0,150,198,0,0,0,0,0,0,150,151,154,155,157,158,159,166,167,171,172,173,174,175,178,179,180,181,182,183,185,186,187,188,189,190,191,203,205,206,207,211,214,215,217,218,219,220,221,222,223,229,230,231,233,234,235,236,237,238,239,242,243,244,245,246,247,249,250,251,252,253,254,255,103,99,114,58,32,100,97,116,97,32,99,114,99,32,101,114,114,111,114,32,40,37,117,47,37,117,47,37,117,41,10,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,1,255,255,2,3,255,4,5,6,255,255,255,255,255,255,7,8,255,255,255,9,10,11,12,13,255,255,14,15,16,17,18,19,255,20,21,22,23,24,25,26,255,255,255,255,255,255,255,255,255,255,255,27,255,28,29,30,255,255,255,31,255,255,32,33,255,34,35,36,37,38,39,40,255,255,255,255,255,41,42,43,255,44,45,46,47,48,49,50,255,255,51,52,53,54,55,56,255,57,58,59,60,61,62,63,114,98,0,0,0,0,0,0,119,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,46,112,98,105,116,0,0,0,46,112,114,105,0,0,0,0,46,116,99], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+45644);
/* memory initializer */ allocate([112,114,105,58,32,99,114,99,32,101,114,114,111,114,10,0,112,114,105,58,32,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,110,117,109,98,101,114,32,40,37,108,117,41,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+48560);
/* memory initializer */ allocate([112,114,105,58,32,99,114,99,32,101,114,114,111,114,10,0,112,114,105,58,32,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,110,117,109,98,101,114,32,40,37,117,41,10,0,0,0,0,0,0,0,46,97,110,97,0,0,0,0,46,99,112,50,0,0,0,0,46,105,109,97,103,101,0,0,46,105,109,97,0,0,0,0,46,105,109,100,0,0,0,0,46,105,109,103,0,0,0,0,46,109,115,97,0,0,0,0,46,112,102,100,99,0,0,0,46,112,115,105,0,0,0,0,46,114,97,119,0,0,0,0,46,115,116,0,0,0,0,0,46,115,116,120,0,0,0,0,46,116,99,0,0,0,0,0,46,116,100,48,0,0,0,0,46,120,100,102,0,0,0,0,114,98,0,0,0,0,0,0,119,98,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,112,50,58,32,37,117,47,37,117,47,37,117,58,32,115,101,99,116,111,114,32,100,97,116,97,32,116,111,111,32,98,105,103,32,40,37,117,41,10,0,0,0,0,0,0,0,0,99,112,50,58,32,37,117,47,37,117,47,37,117,58,0,0,32,45,0,0,0,0,0,0,32,37,48,50,88,0,0,0,83,79,70,84,87,65,82,69,32,80,73,82,65,84,69,83,99,112,50,58,32,110,111,116,32,97,32,67,80,50,32,102,105,108,101,10,0,0,0,0,120,195,0,0,136,195,0,0,152,195,0,0,168,195,0,0,184,195,0,0,0,0,0,0,99,112,50,58,32,119,97,114,110,105,110,103,58,32,117,110,107,110,111,119,110,32,67,80,50,32,118,101,114,115,105,111,110,10,0,0,0,0,0,0,82,101,108,101,97,115,101,32,51,46,48,50,36,48,0,0,82,101,108,101,97,115,101,32,51,46,48,55,36,48,0,0,82,101,108,101,97,115,101,32,52,46,48,48,36,48,0,0,82,101,108,101,97,115,101,32,53,46,48,49,36,48,0,0,82,101,108,101,97,115,101,32,54,46,48,10,36,48,0,0,6,78,111,110,97,109,101,0,100,99,52,50,58,32,100,97,116,97,32,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,0,0,0,0,0,100,99,52,50,58,32,116,97,103,32,99,104,101,99,107,115,117,109,32,101,114,114,111,114,10,0,0,0,0,0,0,0,73,77,68,32,49,46,49,55,58,32,37,50,100,47,37,50,100,47,37,52,100,32,37,48,50,100,58,37,48,50,100,58,37,48,50,100,0,0,0,0,112,102,100,99,58,32,119,97,114,110,105,110,103,58,32,108,111,97,100,105,110,103,32,100,101,112,114,101,99,97,116,101,100,32,118,101,114,115,105,111,110,32,48,32,102,105,108,101,10,0,0,0,0,0,0,0,112,102,100,99,58,32,119,97,114,110,105,110,103,58,32,108,111,97,100,105,110,103,32,100,101,112,114,101,99,97,116,101,100,32,118,101,114,115,105,111,110,32,49,32,102,105,108,101,10,0,0,0,0,0,0,0,112,102,100,99,58,32,119,97,114,110,105,110,103,58,32,108,111,97,100,105,110,103,32,100,101,112,114,101,99,97,116,101,100,32,118,101,114,115,105,111,110,32,50,32,102,105,108,101,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,112,102,100,99,58,32,99,114,99,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,112,102,100,99,58,32,111,114,112,104,97,110,101,100,32,97,108,116,101,114,110,97,116,101,32,115,101,99,116,111,114,10,0,0,0,0,0,0,0,0,112,102,100,99,58,32,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,40,37,108,117,41,10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+49648);
/* memory initializer */ allocate([112,115,105,58,32,99,114,99,32,101,114,114,111,114,10,0,112,115,105,58,32,111,114,112,104,97,110,101,100,32,97,108,116,101,114,110,97,116,101,32,115,101,99,116,111,114,10,0,112,115,105,58,32,117,110,107,110,111,119,110,32,118,101,114,115,105,111,110,32,40,37,108,117,41,10,0,0,0,0,0,0,128,2,0,40,0,0,0,1,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,208,2,0,40,0,0,0,1,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,0,5,0,40,0,0,0,2,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,160,5,0,40,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,0,10,0,80,0,0,0,2,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,64,11,0,80,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,128,12,0,80,0,0,0,2,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,192,18,0,80,0,0,0,2,0,0,0,15,0,0,0,0,2,0,0,2,128,0,0,0,128,22,0,80,0,0,0,2,0,0,0,18,0,0,0,0,2,0,0,2,128,0,0,0,0,45,0,80,0,0,0,2,0,0,0,36,0,0,0,0,2,0,0,2,128,0,0,0,64,19,0,77,0,0,0,2,0,0,0,8,0,0,0,0,4,0,0,2,128,0,0,0,233,3,0,77,0,0,0,1,0,0,0,26,0,0,0,128,0,0,0,1,128,0,0,0,210,7,0,77,0,0,0,2,0,0,0,26,0,0,0,128,0,0,0,1,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,80,0,0,0,1,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,160,5,0,80,0,0,0,1,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,178,5,0,81,0,0,0,1,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,196,5,0,82,0,0,0,1,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,214,5,0,83,0,0,0,1,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,64,6,0,80,0,0,0,1,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,84,6,0,81,0,0,0,1,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,104,6,0,82,0,0,0,1,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,124,6,0,83,0,0,0,1,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,224,6,0,80,0,0,0,1,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,246,6,0,81,0,0,0,1,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,12,7,0,82,0,0,0,1,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,34,7,0,83,0,0,0,1,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,0,10,0,80,0,0,0,2,0,0,0,8,0,0,0,0,2,0,0,2,0,0,0,0,64,11,0,80,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,100,11,0,81,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,136,11,0,82,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,172,11,0,83,0,0,0,2,0,0,0,9,0,0,0,0,2,0,0,2,0,0,0,0,128,12,0,80,0,0,0,2,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,168,12,0,81,0,0,0,2,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,208,12,0,82,0,0,0,2,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,248,12,0,83,0,0,0,2,0,0,0,10,0,0,0,0,2,0,0,2,0,0,0,0,192,13,0,80,0,0,0,2,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,236,13,0,81,0,0,0,2,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,24,14,0,82,0,0,0,2,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,68,14,0,83,0,0,0,2,0,0,0,11,0,0,0,0,2,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,116,120,58,32,98,97,100,32,109,97,103,105,99,10,0,115,116,120,58,32,114,101,97,100,32,101,114,114,111,114,32,40,116,114,97,99,107,32,104,101,97,100,101,114,41,10,0,115,116,120,58,32,114,101,97,100,32,101,114,114,111,114,32,40,115,101,99,116,111,114,32,104,101,97,100,101,114,41,10,0,0,0,0,0,0,0,0,37,117,47,37,117,47,37,117,10,0,0,0,0,0,0,0,115,116,120,58,32,114,101,97,100,32,101,114,114,111,114,32,40,115,101,99,116,111,114,32,100,97,116,97,41,10,0,0,116,99,58,32,117,110,107,110,111,119,110,32,109,97,114,107,32,48,120,37,48,50,120,32,40,37,115,44,32,99,61,37,117,44,32,104,61,37,117,44,32,98,105,116,61,37,108,117,47,37,108,117,41,10,0,0,102,109,0,0,0,0,0,0,109,102,109,0,0,0,0,0,116,100,48,58,32,97,100,118,97,110,99,101,100,32,99,111,109,112,114,101,115,115,105,111,110,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,116,100,48,58,32,104,101,97,100,101,114,32,99,114,99,32,40,37,48,52,88,32,37,48,52,88,41,10,0,0,0,0,116,100,48,58,32,116,114,97,99,107,32,99,114,99,32,40,37,48,50,88,32,37,48,52,88,41,10,0,0,0,0,0,116,100,48,58,32,99,114,99,32,101,114,114,111,114,32,97,116,32,115,101,99,116,111,114,32,37,117,47,37,117,47,37,117,32,40,110,111,32,100,97,116,97,41,10,0,0,0,0,116,100,48,58,32,122,101,114,111,32,100,97,116,97,32,108,101,110,103,116,104,32,40,37,117,47,37,117,47,37,117,41,10,0,0,0,0,0,0,0,116,100,48,58,32,117,110,107,110,111,119,110,32,99,111,109,112,114,101,115,115,105,111,110,32,40,37,117,47,37,117,47,37,117,32,37,117,41,10,0,116,100,48,58,32,115,101,99,116,111,114,32,99,114,99,32,111,118,101,114,32,104,101,97,100,101,114,43,100,97,116,97,10,0,0,0,0,0,0,0,116,100,48,58,32,99,114,99,32,101,114,114,111,114,32,97,116,32,115,101,99,116,111,114,32,37,117,47,37,117,47,37,117,32,40,37,48,50,88,32,37,48,52,88,32,37,48,52,88,41,10,0,0,0,0,0,116,100,48,58,32,100,114,111,112,112,105,110,103,32,112,104,97,110,116,111,109,32,115,101,99,116,111,114,32,37,117,47,37,117,47,37,117,10,0,0,116,100,48,58,32,114,101,97,100,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,116,100,48,58,32,99,111,109,109,101,110,116,32,99,114,99,32,40,37,48,52,88,32,37,48,52,88,41,10,0,0,0,80,0,0,0,0,92,0,0,38,0,0,0,24,212,0,0,8,0,0,0,72,213,0,0,0,1,2,0,0,24,0,0,0,138,2,0,0,18,0,0,0,129,2,0,0,0,0,0,0,139,2,0,0,20,0,0,0,130,2,0,0,2,0,0,0,2,2,0,0,26,0,0,0,131,2,0,0,4,0,0,0,3,2,0,0,28,0,0,0,132,2,0,0,6,0,0,0,4,2,0,0,30,0,0,0,133,2,0,0,8,0,0,0,5,2,0,0,32,0,0,0,134,2,0,0,10,0,0,0,6,2,0,0,34,0,0,0,135,2,0,0,12,0,0,0,7,2,0,0,36,0,0,0,136,2,0,0,14,0,0,0,8,2,0,0,38,0,0,0,137,2,0,0,16,0,0,1,144,2,0,0,84,0,0,1,135,2,0,0,56,0,0,1,145,2,0,0,86,0,0,1,136,2,0,0,58,0,0,1,146,2,0,0,88,0,0,1,137,2,0,0,60,0,0,1,147,2,0,0,90,0,0,1,138,2,0,0,62,0,0,1,129,2,0,0,22,0,0,1,139,2,0,0,64,0,0,1,130,2,0,0,46,0,0,1,140,2,0,0,66,0,0,1,131,2,0,0,48,0,0,1,141,2,0,0,68,0,0,1,132,2,0,0,50,0,0,1,142,2,0,0,70,0,0,1,133,2,0,0,52,0,0,1,143,2,0,0,72,0,0,1,134,2,0,0,54,0,0,0,131,3,0,0,0,0,0,0,130,2,0,0,44,0,0,0,132,4,0,0,4,0,0,0,134,6,0,0,48,0,0,1,132,4,0,0,80,0,0,1,130,2,0,0,46,0,0,1,131,3,0,0,88,0,0,1,134,6,0,0,12,0,0,192,213,0,0,6,0,0,0,200,213,0,0,6,0,0,0,208,213,0,0,7,0,0,0,0,0,0,0,0,0,0,0,119,97,118,102,105,108,116,101,114,0,0,0,0,0,0,0,108,111,119,112,97,115,115,0,110,117,108,108,0,0,0,0,119,97,118,0,0,0,0,0,115,100,108,0,0,0,0,0,115,110,100,45,115,100,108,58,32,101,114,114,111,114,32,105,110,105,116,105,97,108,105,122,105,110,103,32,97,117,100,105,111,32,115,117,98,115,121,115,116,101,109,32,40,37,115,41,10,0,0,0,0,0,0,0,115,110,100,45,115,100,108,58,32,101,114,114,111,114,32,111,112,101,110,105,110,103,32,111,117,116,112,117,116,32,40,37,115,41,10,0,0,0,0,0,119,97,118,0,0,0,0,0,119,98,0,0,0,0,0,0,49,0,0,0,0,0,0,0,116,114,117,101,0,0,0,0,121,101,115,0,0,0,0,0,48,0,0,0,0,0,0,0,102,97,108,115,101,0,0,0,110,111,0,0,0,0,0,0,37,52,117,32,32,0,0,0,108,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,99,0,0,0,0,0,0,0,98,58,32,117,110,107,110,111,119,110,32,99,111,109,109,97,110,100,0,0,0,0,0,0,120,0,0,0,0,0,0,0,101,120,112,101,99,116,105,110,103,32,97,100,100,114,101,115,115,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,101,120,112,101,99,116,105,110,103,32,111,102,102,115,101,116,0,0,0,0,0,0,0,0,101,120,112,101,99,116,105,110,103,32,101,120,112,114,101,115,115,105,111,110,0,0,0,0,69,32,32,34,37,115,34,10,0,0,0,0,0,0,0,0,83,32,32,37,48,52,88,58,37,48,52,108,88,32,32,37,48,52,88,32,32,37,48,52,88,10,0,0,0,0,0,0,65,32,32,37,48,56,108,88,32,32,37,48,52,88,32,32,37,48,52,88,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,42,42,32,37,115,32,91,37,115,93,10,0,0,0,0,105,100,101,110,116,105,102,105,101,114,32,116,111,111,32,108,111,110,103,0,0,0,0,0,115,116,114,105,110,103,32,116,111,111,32,108,111,110,103,0,115,121,110,116,97,120,32,101,114,114,111,114,0,0,0,0,43,61,0,0,0,0,0,0,45,61,0,0,0,0,0,0,42,61,0,0,0,0,0,0,47,61,0,0,0,0,0,0,60,60,61,0,0,0,0,0,62,62,61,0,0,0,0,0,124,61,0,0,0,0,0,0,38,61,0,0,0,0,0,0,94,61,0,0,0,0,0,0,124,124,0,0,0,0,0,0,38,38,0,0,0,0,0,0,61,61,0,0,0,0,0,0,33,61,0,0,0,0,0,0,60,61,0,0,0,0,0,0,62,61,0,0,0,0,0,0,60,60,60,0,0,0,0,0,62,62,62,0,0,0,0,0,60,60,0,0,0,0,0,0,62,62,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,115,10,10,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,111,112,116,105,111,110,32,40,37,115,41,10,0,0,0,0,0,0,0,0,37,115,58,32,109,105,115,115,105,110,103,32,111,112,116,105,111,110,32,97,114,103,117,109,101,110,116,32,40,37,115,41,10,0,0,0,0,0,0,0,37,115,58,32,117,110,107,110,111,119,110,32,111,112,116,105,111,110,32,40,45,37,99,41,10,0,0,0,0,0,0,0,37,115,58,32,109,105,115,115,105,110,103,32,111,112,116,105,111,110,32,97,114,103,117,109,101,110,116,32,40,45,37,99,41,10,0,0,0,0,0,0,32,32,45,37,99,0,0,0,44,32,0,0,0,0,0,0,32,32,0,0,0,0,0,0,45,45,37,115,0,0,0,0,32,37,115,0,0,0,0,0,99,111,119,0,0,0,0,0,68,73,83,75,58,0,0,0,42,42,42,32,99,111,119,32,102,97,105,108,101,100,32,40,100,114,105,118,101,61,37,117,32,102,105,108,101,61,37,115,41,10,0,0,0,0,0,0,100,114,105,118,101,61,37,117,32,116,121,112,101,61,99,111,119,32,102,105,108,101,61,37,115,10,0,0,0,0,0,0,100,114,105,118,101,0,0,0,116,121,112,101,0,0,0,0,97,117,116,111,0,0,0,0,111,102,102,115,101,116,0,0,99,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,98,108,111,99,107,115,0,0,115,105,122,101,0,0,0,0,115,105,122,101,107,0,0,0,115,105,122,101,109,0,0,0,115,105,122,101,103,0,0,0,114,101,97,100,111,110,108,121,0,0,0,0,0,0,0,0,111,112,116,105,111,110,97,108,0,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,114,98,0,0,0,0,0,0,114,97,109,0,0,0,0,0,105,109,97,103,101,0,0,0,100,111,115,101,109,117,0,0,112,99,101,0,0,0,0,0,113,101,100,0,0,0,0,0,112,97,114,116,105,116,105,111,110,0,0,0,0,0,0,0,97,110,97,100,105,115,107,0,99,112,50,0,0,0,0,0,100,99,52,50,0,0,0,0,105,109,97,103,101,100,105,115,107,0,0,0,0,0,0,0,105,109,100,0,0,0,0,0,112,102,100,99,0,0,0,0,112,102,100,99,45,97,117,116,111,0,0,0,0,0,0,0,112,115,105,0,0,0,0,0,116,101,108,101,100,105,115,107,0,0,0,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,48,120,37,48,50,120,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,0,100,114,105,118,101,61,37,117,32,116,121,112,101,61,37,115,32,98,108,111,99,107,115,61,37,108,117,32,99,104,115,61,37,108,117,47,37,108,117,47,37,108,117,32,37,115,32,102,105,108,101,61,37,115,10,0,114,111,0,0,0,0,0,0,114,119,0,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,100,114,105,118,101,32,48,120,37,48,50,120,32,102,97,105,108,101,100,32,40,99,111,119,41,10,0,0,100,105,115,107,0,0,0,0,118,105,115,105,98,108,101,95,99,0,0,0,0,0,0,0,118,105,115,105,98,108,101,95,104,0,0,0,0,0,0,0,118,105,115,105,98,108,101,95,115,0,0,0,0,0,0,0,100,114,105,118,101,61,37,117,32,118,99,104,115,61,37,108,117,47,37,108,117,47,37,108,117,10,0,0,0,0,0,0,98,108,111,99,107,95,115,116,97,114,116,0,0,0,0,0,98,108,111,99,107,95,99,111,117,110,116,0,0,0,0,0,114,97,109,0,0,0,0,0,102,105,108,101,0,0,0,0,97,100,100,114,101,115,115,0,98,97,115,101,0,0,0,0,115,105,122,101,109,0,0,0,115,105,122,101,107,0,0,0,115,105,122,101,0,0,0,0,100,101,102,97,117,108,116,0,82,65,77,58,0,0,0,0,97,100,100,114,61,48,120,37,48,56,108,120,32,115,105,122,101,61,37,108,117,32,102,105,108,101,61,37,115,10,0,0,60,110,111,110,101,62,0,0,42,42,42,32,109,101,109,111,114,121,32,98,108,111,99,107,32,99,114,101,97,116,105,111,110,32,102,97,105,108,101,100,10,0,0,0,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,114,97,109,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,114,111,109,0,0,0,0,0,82,79,77,58,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,114,111,109,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,116,101,114,109,105,110,97,108,0,0,0,0,0,0,0,0,100,114,105,118,101,114,0,0,110,117,108,108,0,0,0,0,101,115,99,97,112,101,0,0,97,115,112,101,99,116,95,120,0,0,0,0,0,0,0,0,97,115,112,101,99,116,95,121,0,0,0,0,0,0,0,0,109,105,110,95,119,0,0,0,109,105,110,95,104,0,0,0,115,99,97,108,101,0,0,0,109,111,117,115,101,95,109,117,108,95,120,0,0,0,0,0,109,111,117,115,101,95,100,105,118,95,120,0,0,0,0,0,109,111,117,115,101,95,109,117,108,95,121,0,0,0,0,0,109,111,117,115,101,95,100,105,118,95,121,0,0,0,0,0,84,69,82,77,58,0,0,0,100,114,105,118,101,114,61,37,115,32,69,83,67,61,37,115,32,97,115,112,101,99,116,61,37,117,47,37,117,32,109,105,110,95,115,105,122,101,61,37,117,42,37,117,32,115,99,97,108,101,61,37,117,32,109,111,117,115,101,61,91,37,117,47,37,117,32,37,117,47,37,117,93,10,0,0,0,0,0,0,69,83,67,0,0,0,0,0,120,49,49,0,0,0,0,0,42,42,42,32,116,101,114,109,105,110,97,108,32,100,114,105,118,101,114,32,39,120,49,49,39,32,110,111,116,32,115,117,112,112,111,114,116,101,100,10,0,0,0,0,0,0,0,0,115,100,108,0,0,0,0,0,42,42,42,32,115,101,116,116,105,110,103,32,117,112,32,115,100,108,32,116,101,114,109,105,110,97,108,32,102,97,105,108,101,100,10,0,0,0,0,0,42,42,42,32,115,101,116,116,105,110,103,32,117,112,32,110,117,108,108,32,116,101,114,109,105,110,97,108,32,102,97,105,108,101,100,10,0,0,0,0,42,42,42,32,117,110,107,110,111,119,110,32,116,101,114,109,105,110,97,108,32,100,114,105,118,101,114,58,32,37,115,10,0,0,0,0,0,0,0,0,42,42,42,32,110,111,32,116,101,114,109,105,110,97,108,32,102,111,117,110,100,10,0,0,2,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,114,98,0,0,0,0,0,0,76,111,97,100,58,0,0,0,102,105,108,101,61,37,115,32,102,111,114,109,97,116,61,105,104,101,120,10,0,0,0,0,102,105,108,101,61,37,115,32,102,111,114,109,97,116,61,115,114,101,99,10,0,0,0,0,102,105,108,101,61,37,115,32,102,111,114,109,97,116,61,98,105,110,97,114,121,32,97,100,100,114,61,48,120,37,48,56,108,120,10,0,0,0,0,0,97,117,116,111,0,0,0,0,105,104,101,120,0,0,0,0,105,104,120,0,0,0,0,0,115,114,101,99,0,0,0,0,98,105,110,0,0,0,0,0,98,105,110,97,114,121,0,0,108,111,97,100,0,0,0,0,102,111,114,109,97,116,0,0,102,105,108,101,0,0,0,0,97,100,100,114,101,115,115,0,98,97,115,101,0,0,0,0,42,42,42,32,108,111,97,100,105,110,103,32,102,97,105,108,101,100,32,40,37,115,41,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,45,57,115,32,0,0,0,88,225,0,0,144,226,0,0,160,226,0,0,96,225,0,0,176,226,0,0,200,226,0,0,104,225,0,0,224,226,0,0,248,226,0,0,112,225,0,0,152,225,0,0,16,227,0,0,72,225,0,0,32,227,0,0,56,227,0,0,120,225,0,0,80,227,0,0,96,227,0,0,128,225,0,0,152,225,0,0,136,227,0,0,80,225,0,0,144,227,0,0,168,227,0,0,136,225,0,0,192,227,0,0,208,227,0,0,144,225,0,0,232,227,0,0,248,227,0,0,160,225,0,0,168,225,0,0,176,225,0,0,208,225,0,0,152,225,0,0,216,225,0,0,240,225,0,0,248,225,0,0,16,226,0,0,64,226,0,0,72,226,0,0,96,226,0,0,108,111,97,100,0,0,0,0,115,97,118,101,0,0,0,0,100,0,0,0,0,0,0,0,101,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,109,0,0,0,0,0,0,0,113,0,0,0,0,0,0,0,118,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,99,0,0,0,0,0,0,91,105,110,100,101,120,93,0,99,108,101,97,114,32,97,32,98,114,101,97,107,112,111,105,110,116,32,111,114,32,97,108,108,0,0,0,0,0,0,0,98,108,0,0,0,0,0,0,108,105,115,116,32,98,114,101,97,107,112,111,105,110,116,115,0,0,0,0,0,0,0,0,98,115,0,0,0,0,0,0,97,100,100,114,32,91,112,97,115,115,32,91,114,101,115,101,116,93,93,0,0,0,0,0,115,101,116,32,97,110,32,97,100,100,114,101,115,115,32,98,114,101,97,107,112,111,105,110,116,32,91,112,97,115,115,61,49,32,114,101,115,101,116,61,48,93,0,0,0,0,0,0,98,115,120,0,0,0,0,0,101,120,112,114,32,91,112,97,115,115,32,91,114,101,115,101,116,93,93,0,0,0,0,0,115,101,116,32,97,110,32,101,120,112,114,101,115,115,105,111,110,32,98,114,101,97,107,112,111,105,110,116,32,91,112,97,115,115,61,49,32,114,101,115,101,116,61,48,93,0,0,0,91,97,100,100,114,32,91,99,110,116,93,93,0,0,0,0,100,117,109,112,32,109,101,109,111,114,121,0,0,0,0,0,97,100,100,114,32,91,118,97,108,124,115,116,114,105,110,103,46,46,46,93,0,0,0,0,101,110,116,101,114,32,98,121,116,101,115,32,105,110,116,111,32,109,101,109,111,114,121,0,97,100,100,114,32,99,110,116,32,91,118,97,108,46,46,46,93,0,0,0,0,0,0,0,102,105,110,100,32,98,121,116,101,115,32,105,110,32,109,101,109,111,114,121,0,0,0,0,112,114,105,110,116,32,104,101,108,112,0,0,0,0,0,0,110,97,109,101,32,91,102,109,116,93,32,91,97,32,91,110,93,93,0,0,0,0,0,0,114,101,97,100,32,97,32,102,105,108,101,32,105,110,116,111,32,109,101,109,111,114,121,0,109,115,103,32,91,118,97,108,93,0,0,0,0,0,0,0,115,101,110,100,32,97,32,109,101,115,115,97,103,101,32,116,111,32,116,104,101,32,101,109,117,108,97,116,111,114,32,99,111,114,101,0,0,0,0,0,113,117,105,116,0,0,0,0,110,97,109,101,32,91,102,109,116,93,32,91,97,32,110,46,46,46,93,0,0,0,0,0,119,114,105,116,101,32,109,101,109,111,114,121,32,116,111,32,97,32,102,105,108,101,0,0,91,101,120,112,114,46,46,46,93,0,0,0,0,0,0,0,101,118,97,108,117,97,116,101,32,101,120,112,114,101,115,115,105,111,110,115,0,0,0,0,115,114,99,32,100,115,116,32,99,110,116,0,0,0,0,0,99,111,112,121,32,109,101,109,111,114,121,0,0,0,0,0,116,114,117,101,0,0,0,0,102,97,108,115,101,0,0,0,32,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,112,97,116,104,0,0,0,0,0,0,0,0,0,0,0,0,112,97,114,115,101,32,101,114,114,111,114,32,98,101,102,111,114,101,0,0,0,0,0,0,114,98,0,0,0,0,0,0,60,110,111,110,101,62,0,0,37,115,58,37,108,117,58,32,37,115,0,0,0,0,0,0,58,32,0,0,0,0,0,0,60,101,111,102,62,0,0,0,60,110,108,62,0,0,0,0,115,101,99,116,105,111,110,0,123,0,0,0,0,0,0,0,125,0,0,0,0,0,0,0,63,61,0,0,0,0,0,0,61,0,0,0,0,0,0,0,105,102,0,0,0,0,0,0,105,110,99,108,117,100,101,0,63,0,0,0,0,0,0,0,99,97,110,39,116,32,111,112,101,110,32,105,110,99,108,117,100,101,32,102,105,108,101,58,0,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,101,108,115,101,0,0,0,0,114,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,58,0,0,0,0,0,0,0,124,124,0,0,0,0,0,0,38,38,0,0,0,0,0,0,124,0,0,0,0,0,0,0,94,94,0,0,0,0,0,0,94,0,0,0,0,0,0,0,38,0,0,0,0,0,0,0,61,61,0,0,0,0,0,0,33,61,0,0,0,0,0,0,60,61,0,0,0,0,0,0,62,61,0,0,0,0,0,0,60,0,0,0,0,0,0,0,62,0,0,0,0,0,0,0,60,60,0,0,0,0,0,0,62,62,0,0,0,0,0,0,43,0,0,0,0,0,0,0,45,0,0,0,0,0,0,0,37,108,117,0,0,0,0,0,42,0,0,0,0,0,0,0,47,0,0,0,0,0,0,0,37,0,0,0,0,0,0,0,126,0,0,0,0,0,0,0,33,0,0,0,0,0,0,0,40,0,0,0,0,0,0,0,41,0,0,0,0,0,0,0,100,101,102,105,110,101,100,0,116,114,117,101,0,0,0,0,102,97,108,115,101,0,0,0,48,120,0,0,0,0,0,0,48,98,0,0,0,0,0,0,114,43,98,0,0,0,0,0,119,43,98,0,0,0,0,0,99,111,109,109,105,116,0,0,114,98,0,0,0,0,0,0,114,43,98,0,0,0,0,0,114,98,0,0,0,0,0,0,1,0,0,0,216,234,0,0,2,0,0,0,224,234,0,0,3,0,0,0,232,234,0,0,4,0,0,0,240,234,0,0,5,0,0,0,248,234,0,0,6,0,0,0,0,235,0,0,7,0,0,0,8,235,0,0,8,0,0,0,16,235,0,0,9,0,0,0,24,235,0,0,10,0,0,0,32,235,0,0,11,0,0,0,40,235,0,0,12,0,0,0,48,235,0,0,13,0,0,0,56,235,0,0,14,0,0,0,64,235,0,0,14,0,0,0,80,235,0,0,15,0,0,0,88,235,0,0,15,0,0,0,104,235,0,0,16,0,0,0,112,235,0,0,17,0,0,0,120,235,0,0,17,0,0,0,136,235,0,0,18,0,0,0,144,235,0,0,19,0,0,0,152,235,0,0,20,0,0,0,160,235,0,0,21,0,0,0,168,235,0,0,22,0,0,0,176,235,0,0,23,0,0,0,184,235,0,0,24,0,0,0,192,235,0,0,25,0,0,0,200,235,0,0,26,0,0,0,208,235,0,0,27,0,0,0,216,235,0,0,28,0,0,0,224,235,0,0,28,0,0,0,232,235,0,0,29,0,0,0,240,235,0,0,29,0,0,0,248,235,0,0,30,0,0,0,0,236,0,0,31,0,0,0,16,236,0,0,32,0,0,0,24,236,0,0,33,0,0,0,32,236,0,0,34,0,0,0,40,236,0,0,35,0,0,0,48,236,0,0,36,0,0,0,56,236,0,0,37,0,0,0,64,236,0,0,38,0,0,0,72,236,0,0,39,0,0,0,80,236,0,0,40,0,0,0,88,236,0,0,41,0,0,0,96,236,0,0,42,0,0,0,104,236,0,0,42,0,0,0,120,236,0,0,43,0,0,0,128,236,0,0,43,0,0,0,144,236,0,0,44,0,0,0,152,236,0,0,45,0,0,0,160,236,0,0,46,0,0,0,176,236,0,0,47,0,0,0,184,236,0,0,48,0,0,0,192,236,0,0,49,0,0,0,200,236,0,0,50,0,0,0,208,236,0,0,51,0,0,0,216,236,0,0,52,0,0,0,224,236,0,0,53,0,0,0,232,236,0,0,54,0,0,0,240,236,0,0,55,0,0,0,248,236,0,0,55,0,0,0,8,237,0,0,56,0,0,0,16,237,0,0,56,0,0,0,24,237,0,0,56,0,0,0,40,237,0,0,57,0,0,0,48,237,0,0,57,0,0,0,64,237,0,0,58,0,0,0,72,237,0,0,58,0,0,0,88,237,0,0,59,0,0,0,96,237,0,0,59,0,0,0,104,237,0,0,60,0,0,0,112,237,0,0,61,0,0,0,120,237,0,0,62,0,0,0,128,237,0,0,63,0,0,0,136,237,0,0,64,0,0,0,144,237,0,0,66,0,0,0,152,237,0,0,65,0,0,0,160,237,0,0,67,0,0,0,168,237,0,0,67,0,0,0,176,237,0,0,68,0,0,0,184,237,0,0,68,0,0,0,192,237,0,0,69,0,0,0,200,237,0,0,69,0,0,0,208,237,0,0,71,0,0,0,216,237,0,0,71,0,0,0,232,237,0,0,73,0,0,0,240,237,0,0,73,0,0,0,0,238,0,0,72,0,0,0,8,238,0,0,72,0,0,0,24,238,0,0,72,0,0,0,40,238,0,0,74,0,0,0,56,238,0,0,75,0,0,0,64,238,0,0,75,0,0,0,72,238,0,0,76,0,0,0,80,238,0,0,77,0,0,0,88,238,0,0,78,0,0,0,104,238,0,0,79,0,0,0,120,238,0,0,79,0,0,0,136,238,0,0,79,0,0,0,152,238,0,0,80,0,0,0,168,238,0,0,81,0,0,0,176,238,0,0,82,0,0,0,192,238,0,0,83,0,0,0,200,238,0,0,84,0,0,0,216,238,0,0,85,0,0,0,224,238,0,0,86,0,0,0,240,238,0,0,87,0,0,0,248,238,0,0,88,0,0,0,0,239,0,0,89,0,0,0,8,239,0,0,90,0,0,0,16,239,0,0,91,0,0,0,24,239,0,0,92,0,0,0,32,239,0,0,93,0,0,0,40,239,0,0,94,0,0,0,48,239,0,0,95,0,0,0,56,239,0,0,96,0,0,0,64,239,0,0,97,0,0,0,80,239,0,0,98,0,0,0,88,239,0,0,99,0,0,0,104,239,0,0,100,0,0,0,112,239,0,0,101,0,0,0,120,239,0,0,102,0,0,0,128,239,0,0,103,0,0,0,136,239,0,0,104,0,0,0,144,239,0,0,105,0,0,0,160,239,0,0,106,0,0,0,168,239,0,0,107,0,0,0,176,239,0,0,108,0,0,0,184,239,0,0,109,0,0,0,192,239,0,0,110,0,0,0,200,239,0,0,111,0,0,0,208,239,0,0,112,0,0,0,216,239,0,0,113,0,0,0,224,239,0,0,114,0,0,0,232,239,0,0,115,0,0,0,240,239,0,0,116,0,0,0,248,239,0,0,117,0,0,0,0,240,0,0,118,0,0,0,8,240,0,0,119,0,0,0,16,240,0,0,120,0,0,0,24,240,0,0,121,0,0,0,32,240,0,0,122,0,0,0,40,240,0,0,123,0,0,0,48,240,0,0,124,0,0,0,56,240,0,0,0,0,0,0,0,0,0,0,69,83,67,0,0,0,0,0,70,49,0,0,0,0,0,0,70,50,0,0,0,0,0,0,70,51,0,0,0,0,0,0,70,52,0,0,0,0,0,0,70,53,0,0,0,0,0,0,70,54,0,0,0,0,0,0,70,55,0,0,0,0,0,0,70,56,0,0,0,0,0,0,70,57,0,0,0,0,0,0,70,49,48,0,0,0,0,0,70,49,49,0,0,0,0,0,70,49,50,0,0,0,0,0,80,114,105,110,116,83,99,114,101,101,110,0,0,0,0,0,80,114,116,83,99,110,0,0,83,99,114,111,108,108,76,111,99,107,0,0,0,0,0,0,83,99,114,76,107,0,0,0,80,97,117,115,101,0,0,0,66,97,99,107,113,117,111,116,101,0,0,0,0,0,0,0,96,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,50,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,53,0,0,0,0,0,0,0,54,0,0,0,0,0,0,0,55,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,57,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,77,105,110,117,115,0,0,0,45,0,0,0,0,0,0,0,69,113,117,97,108,0,0,0,61,0,0,0,0,0,0,0,66,97,99,107,115,112,97,99,101,0,0,0,0,0,0,0,84,97,98,0,0,0,0,0,113,0,0,0,0,0,0,0,119,0,0,0,0,0,0,0,101,0,0,0,0,0,0,0,114,0,0,0,0,0,0,0,116,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,117,0,0,0,0,0,0,0,73,0,0,0,0,0,0,0,111,0,0,0,0,0,0,0,112,0,0,0,0,0,0,0,76,101,102,116,66,114,97,99,107,101,116,0,0,0,0,0,91,0,0,0,0,0,0,0,82,105,103,104,116,66,114,97,99,107,101,116,0,0,0,0,93,0,0,0,0,0,0,0,82,101,116,117,114,110,0,0,67,97,112,115,76,111,99,107,0,0,0,0,0,0,0,0,97,0,0,0,0,0,0,0,115,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,102,0,0,0,0,0,0,0,103,0,0,0,0,0,0,0,104,0,0,0,0,0,0,0,106,0,0,0,0,0,0,0,107,0,0,0,0,0,0,0,108,0,0,0,0,0,0,0,83,101,109,105,99,111,108,111,110,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,81,117,111,116,101,0,0,0,65,112,111,115,116,114,111,112,104,101,0,0,0,0,0,0,39,0,0,0,0,0,0,0,66,97,99,107,115,108,97,115,104,0,0,0,0,0,0,0,92,0,0,0,0,0,0,0,83,104,105,102,116,76,101,102,116,0,0,0,0,0,0,0,83,104,105,102,116,0,0,0,76,101,115,115,0,0,0,0,60,0,0,0,0,0,0,0,122,0,0,0,0,0,0,0,120,0,0,0,0,0,0,0,99,0,0,0,0,0,0,0,118,0,0,0,0,0,0,0,98,0,0,0,0,0,0,0,110,0,0,0,0,0,0,0,109,0,0,0,0,0,0,0,67,111,109,109,97,0,0,0,44,0,0,0,0,0,0,0,80,101,114,105,111,100,0,0,46,0,0,0,0,0,0,0,83,108,97,115,104,0,0,0,47,0,0,0,0,0,0,0,67,116,114,108,76,101,102,116,0,0,0,0,0,0,0,0,67,116,114,108,0,0,0,0,77,101,116,97,76,101,102,116,0,0,0,0,0,0,0,0,77,101,116,97,0,0,0,0,83,117,112,101,114,76,101,102,116,0,0,0,0,0,0,0,83,116,97,114,116,76,101,102,116,0,0,0,0,0,0,0,87,105,110,100,111,119,115,76,101,102,116,0,0,0,0,0,77,111,100,101,0,0,0,0,65,108,116,76,101,102,116,0,65,108,116,0,0,0,0,0,83,112,97,99,101,0,0,0,65,108,116,82,105,103,104,116,0,0,0,0,0,0,0,0,77,101,116,97,82,105,103,104,116,0,0,0,0,0,0,0,83,117,112,101,114,82,105,103,104,116,0,0,0,0,0,0,83,116,97,114,116,82,105,103,104,116,0,0,0,0,0,0,87,105,110,100,111,119,115,82,105,103,104,116,0,0,0,0,77,101,110,117,0,0,0,0,67,116,114,108,82,105,103,104,116,0,0,0,0,0,0,0,78,117,109,76,111,99,107,0,75,80,95,83,108,97,115,104,0,0,0,0,0,0,0,0,75,80,95,83,116,97,114,0,75,80,95,77,105,110,117,115,0,0,0,0,0,0,0,0,75,80,95,55,0,0,0,0,75,80,95,56,0,0,0,0,75,80,95,57,0,0,0,0,75,80,95,80,108,117,115,0,75,80,95,52,0,0,0,0,75,80,95,53,0,0,0,0,75,80,95,54,0,0,0,0,75,80,95,49,0,0,0,0,75,80,95,50,0,0,0,0,75,80,95,51,0,0,0,0,75,80,95,69,110,116,101,114,0,0,0,0,0,0,0,0,75,80,95,48,0,0,0,0,75,80,95,80,101,114,105,111,100,0,0,0,0,0,0,0,73,110,115,101,114,116,0,0,72,111,109,101,0,0,0,0,80,97,103,101,85,112,0,0,68,101,108,101,116,101,0,0,69,110,100,0,0,0,0,0,80,97,103,101,68,111,119,110,0,0,0,0,0,0,0,0,85,112,0,0,0,0,0,0,76,101,102,116,0,0,0,0,68,111,119,110,0,0,0,0,82,105,103,104,116,0,0,0,69,120,116,114,97,49,0,0,69,120,116,114,97,50,0,0,69,120,116,114,97,51,0,0,69,120,116,114,97,52,0,0,69,120,116,114,97,53,0,0,69,120,116,114,97,54,0,0,69,120,116,114,97,55,0,0,69,120,116,114,97,56,0,0,69,120,116,114,97,57,0,0,69,120,116,114,97,49,48,0,69,120,116,114,97,49,49,0,69,120,116,114,97,49,50,0,69,120,116,114,97,49,51,0,69,120,116,114,97,49,52,0,69,120,116,114,97,49,53,0,69,120,116,114,97,49,54,0,112,99,101,37,48,52,117,46,112,112,109,0,0,0,0,0,119,98,0,0,0,0,0,0,80,54,10,37,117,32,37,117,10,37,117,10,0,0,0,0,116,101,114,109,46,101,115,99,97,112,101,0,0,0,0,0,116,101,114,109,46,115,99,114,101,101,110,115,104,111,116,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,0,0,0,0,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,0,48,0,0,0,0,0,0,0,101,109,117,46,101,120,105,116,0,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,0,0,0,50,0,0,0,0,0,0,0,51,0,0,0,0,0,0,0,52,0,0,0,0,0,0,0,53,0,0,0,0,0,0,0,54,0,0,0,0,0,0,0,55,0,0,0,0,0,0,0,56,0,0,0,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,46,116,111,103,103,108,101,0,0,116,101,114,109,46,103,114,97,98,0,0,0,0,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,101,109,117,46,112,97,117,115,101,46,116,111,103,103,108,101,0,0,0,0,0,0,0,0,101,109,117,46,114,101,115,101,116,0,0,0,0,0,0,0,101,109,117,46,99,112,117,46,115,112,101,101,100,46,115,116,101,112,0,0,0,0,0,0,45,49,0,0,0,0,0,0,43,49,0,0,0,0,0,0,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,98,111,114,100,101,114,0,0,114,101,112,111,114,116,95,107,101,121,115,0,0,0,0,0,107,101,121,109,97,112,0,0,27,0,0,0,1,0,0,0,58,4,0,0,2,0,0,0,59,4,0,0,3,0,0,0,60,4,0,0,4,0,0,0,61,4,0,0,5,0,0,0,62,4,0,0,6,0,0,0,63,4,0,0,7,0,0,0,64,4,0,0,8,0,0,0,65,4,0,0,9,0,0,0,66,4,0,0,10,0,0,0,67,4,0,0,11,0,0,0,68,4,0,0,12,0,0,0,69,4,0,0,13,0,0,0,70,4,0,0,14,0,0,0,71,4,0,0,15,0,0,0,72,4,0,0,16,0,0,0,96,0,0,0,17,0,0,0,49,0,0,0,18,0,0,0,50,0,0,0,19,0,0,0,51,0,0,0,20,0,0,0,52,0,0,0,21,0,0,0,53,0,0,0,22,0,0,0,54,0,0,0,23,0,0,0,55,0,0,0,24,0,0,0,56,0,0,0,25,0,0,0,57,0,0,0,26,0,0,0,48,0,0,0,27,0,0,0,45,0,0,0,28,0,0,0,61,0,0,0,29,0,0,0,187,0,0,0,29,0,0,0,8,0,0,0,30,0,0,0,9,0,0,0,31,0,0,0,113,0,0,0,32,0,0,0,119,0,0,0,33,0,0,0,101,0,0,0,34,0,0,0,114,0,0,0,35,0,0,0,116,0,0,0,36,0,0,0,121,0,0,0,37,0,0,0,117,0,0,0,38,0,0,0,105,0,0,0,39,0,0,0,111,0,0,0,40,0,0,0,112,0,0,0,41,0,0,0,91,0,0,0,42,0,0,0,93,0,0,0,43,0,0,0,13,0,0,0,44,0,0,0,57,4,0,0,45,0,0,0,97,0,0,0,46,0,0,0,115,0,0,0,47,0,0,0,100,0,0,0,48,0,0,0,102,0,0,0,49,0,0,0,103,0,0,0,50,0,0,0,104,0,0,0,51,0,0,0,106,0,0,0,52,0,0,0,107,0,0,0,53,0,0,0,108,0,0,0,54,0,0,0,59,0,0,0,55,0,0,0,186,0,0,0,55,0,0,0,39,0,0,0,56,0,0,0,92,0,0,0,57,0,0,0,220,0,0,0,57,0,0,0,225,4,0,0,58,0,0,0,60,0,0,0,59,0,0,0,122,0,0,0,60,0,0,0,120,0,0,0,61,0,0,0,99,0,0,0,62,0,0,0,118,0,0,0,63,0,0,0,98,0,0,0,64,0,0,0,110,0,0,0,66,0,0,0,109,0,0,0,65,0,0,0,44,0,0,0,67,0,0,0,46,0,0,0,68,0,0,0,47,0,0,0,69,0,0,0,229,4,0,0,70,0,0,0,224,4,0,0,71,0,0,0,227,4,0,0,73,0,0,0,227,4,0,0,72,0,0,0,226,4,0,0,75,0,0,0,1,5,0,0,74,0,0,0,32,0,0,0,76,0,0,0,230,4,0,0,77,0,0,0,231,4,0,0,78,0,0,0,231,4,0,0,79,0,0,0,118,4,0,0,80,0,0,0,228,4,0,0,81,0,0,0,83,4,0,0,82,0,0,0,84,4,0,0,83,0,0,0,85,4,0,0,84,0,0,0,86,4,0,0,85,0,0,0,95,4,0,0,86,0,0,0,96,4,0,0,87,0,0,0,97,4,0,0,88,0,0,0,87,4,0,0,89,0,0,0,92,4,0,0,90,0,0,0,93,4,0,0,91,0,0,0,94,4,0,0,92,0,0,0,89,4,0,0,93,0,0,0,90,4,0,0,94,0,0,0,91,4,0,0,95,0,0,0,88,4,0,0,96,0,0,0,98,4,0,0,97,0,0,0,99,4,0,0,98,0,0,0,73,4,0,0,99,0,0,0,74,4,0,0,100,0,0,0,75,4,0,0,101,0,0,0,127,0,0,0,102,0,0,0,77,4,0,0,103,0,0,0,78,4,0,0,104,0,0,0,82,4,0,0,105,0,0,0,80,4,0,0,106,0,0,0,81,4,0,0,107,0,0,0,79,4,0,0,108,0,0,0,0,0,0,0,0,0,0,0,101,109,117,46,101,120,105,116], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+52560);
/* memory initializer */ allocate([0,0,0,0,0,0,0,0,49,0,0,0,0,0,0,0,101,109,117,46,115,116,111,112,0,0,0,0,0,0,0,0,115,100,108,58,32,107,101,121,32,61,32,48,120,37,48,52,120,10,0,0,0,0,0,0,115,100,108,58,32,98,108,105,116,32,101,114,114,111,114,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,101,114,109,46,103,114,97,98,0,0,0,0,0,0,0,116,101,114,109,46,114,101,108,101,97,115,101,0,0,0,0,116,101,114,109,46,116,105,116,108,101,0,0,0,0,0,0,116,101,114,109,46,115,101,116,95,98,111,114,100,101,114,95,120,0,0,0,0,0,0,0,116,101,114,109,46,115,101,116,95,98,111,114,100,101,114,95,121,0,0,0,0,0,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,46,116,111,103,103,108,101,0,0,116,101,114,109,46,102,117,108,108,115,99,114,101,101,110,0,112,99,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+62800);




var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);

assert(tempDoublePtr % 8 == 0);

function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

}

function copyTempDouble(ptr) {

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];

  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];

  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];

  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];

}


   
  Module["_i64Subtract"] = _i64Subtract;

   
  Module["_i64Add"] = _i64Add;

  
  
  
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86};
  
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};
  
  
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value;
      return value;
    }
  
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var lastSlash = path.lastIndexOf('/');
        if (lastSlash === -1) return path;
        return path.substr(lastSlash+1);
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.join('/'));
      },join2:function (l, r) {
        return PATH.normalize(l + '/' + r);
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            continue;
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          if (stream.tty.output.length) {
            stream.tty.ops.put_char(stream.tty, 10);
          }
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }}};
  
  var MEMFS={ops_table:null,CONTENT_OWNING:1,CONTENT_FLEXIBLE:2,CONTENT_FIXED:3,mount:function (mount) {
        return MEMFS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createNode:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (!MEMFS.ops_table) {
          MEMFS.ops_table = {
            dir: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                lookup: MEMFS.node_ops.lookup,
                mknod: MEMFS.node_ops.mknod,
                rename: MEMFS.node_ops.rename,
                unlink: MEMFS.node_ops.unlink,
                rmdir: MEMFS.node_ops.rmdir,
                readdir: MEMFS.node_ops.readdir,
                symlink: MEMFS.node_ops.symlink
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek
              }
            },
            file: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek,
                read: MEMFS.stream_ops.read,
                write: MEMFS.stream_ops.write,
                allocate: MEMFS.stream_ops.allocate,
                mmap: MEMFS.stream_ops.mmap
              }
            },
            link: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                readlink: MEMFS.node_ops.readlink
              },
              stream: {}
            },
            chrdev: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: FS.chrdev_stream_ops
            },
          };
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = MEMFS.ops_table.dir.node;
          node.stream_ops = MEMFS.ops_table.dir.stream;
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = MEMFS.ops_table.file.node;
          node.stream_ops = MEMFS.ops_table.file.stream;
          node.contents = [];
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        } else if (FS.isLink(node.mode)) {
          node.node_ops = MEMFS.ops_table.link.node;
          node.stream_ops = MEMFS.ops_table.link.stream;
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = MEMFS.ops_table.chrdev.node;
          node.stream_ops = MEMFS.ops_table.chrdev.stream;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },ensureFlexible:function (node) {
        if (node.contentMode !== MEMFS.CONTENT_FLEXIBLE) {
          var contents = node.contents;
          node.contents = Array.prototype.slice.call(contents);
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        }
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.contents.length;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.ensureFlexible(node);
            var contents = node.contents;
            if (attr.size < contents.length) contents.length = attr.size;
            else while (attr.size > contents.length) contents.push(0);
          }
        },lookup:function (parent, name) {
          throw FS.genericErrors[ERRNO_CODES.ENOENT];
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.createNode(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
          old_node.parent = new_dir;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.createNode(parent, newname, 511 /* 0777 */ | 40960, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          var node = stream.node;
          node.timestamp = Date.now();
          var contents = node.contents;
          if (length && contents.length === 0 && position === 0 && buffer.subarray) {
            // just replace it with the new data
            if (canOwn && offset === 0) {
              node.contents = buffer; // this could be a subarray of Emscripten HEAP, or allocated from some other source.
              node.contentMode = (buffer.buffer === HEAP8.buffer) ? MEMFS.CONTENT_OWNING : MEMFS.CONTENT_FIXED;
            } else {
              node.contents = new Uint8Array(buffer.subarray(offset, offset+length));
              node.contentMode = MEMFS.CONTENT_FIXED;
            }
            return length;
          }
          MEMFS.ensureFlexible(node);
          var contents = node.contents;
          while (contents.length < position) contents.push(0);
          for (var i = 0; i < length; i++) {
            contents[position + i] = buffer[offset + i];
          }
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.contents.length;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          stream.ungotten = [];
          stream.position = position;
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.ensureFlexible(stream.node);
          var contents = stream.node.contents;
          var limit = offset + length;
          while (limit > contents.length) contents.push(0);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 2) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < contents.length) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  
  var IDBFS={dbs:{},indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function (mount) {
        // reuse all of the core MEMFS functionality
        return MEMFS.mount.apply(null, arguments);
      },syncfs:function (mount, populate, callback) {
        IDBFS.getLocalSet(mount, function(err, local) {
          if (err) return callback(err);
  
          IDBFS.getRemoteSet(mount, function(err, remote) {
            if (err) return callback(err);
  
            var src = populate ? remote : local;
            var dst = populate ? local : remote;
  
            IDBFS.reconcile(src, dst, callback);
          });
        });
      },getDB:function (name, callback) {
        // check the cache first
        var db = IDBFS.dbs[name];
        if (db) {
          return callback(null, db);
        }
  
        var req;
        try {
          req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
        } catch (e) {
          return callback(e);
        }
        req.onupgradeneeded = function(e) {
          var db = e.target.result;
          var transaction = e.target.transaction;
  
          var fileStore;
  
          if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
            fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME);
          } else {
            fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME);
          }
  
          fileStore.createIndex('timestamp', 'timestamp', { unique: false });
        };
        req.onsuccess = function() {
          db = req.result;
  
          // add to the cache
          IDBFS.dbs[name] = db;
          callback(null, db);
        };
        req.onerror = function() {
          callback(this.error);
        };
      },getLocalSet:function (mount, callback) {
        var entries = {};
  
        function isRealDir(p) {
          return p !== '.' && p !== '..';
        };
        function toAbsolute(root) {
          return function(p) {
            return PATH.join2(root, p);
          }
        };
  
        var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));
  
        while (check.length) {
          var path = check.pop();
          var stat;
  
          try {
            stat = FS.stat(path);
          } catch (e) {
            return callback(e);
          }
  
          if (FS.isDir(stat.mode)) {
            check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)));
          }
  
          entries[path] = { timestamp: stat.mtime };
        }
  
        return callback(null, { type: 'local', entries: entries });
      },getRemoteSet:function (mount, callback) {
        var entries = {};
  
        IDBFS.getDB(mount.mountpoint, function(err, db) {
          if (err) return callback(err);
  
          var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readonly');
          transaction.onerror = function() { callback(this.error); };
  
          var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
          var index = store.index('timestamp');
  
          index.openKeyCursor().onsuccess = function(event) {
            var cursor = event.target.result;
  
            if (!cursor) {
              return callback(null, { type: 'remote', db: db, entries: entries });
            }
  
            entries[cursor.primaryKey] = { timestamp: cursor.key };
  
            cursor.continue();
          };
        });
      },loadLocalEntry:function (path, callback) {
        var stat, node;
  
        try {
          var lookup = FS.lookupPath(path);
          node = lookup.node;
          stat = FS.stat(path);
        } catch (e) {
          return callback(e);
        }
  
        if (FS.isDir(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode });
        } else if (FS.isFile(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode, contents: node.contents });
        } else {
          return callback(new Error('node type not supported'));
        }
      },storeLocalEntry:function (path, entry, callback) {
        try {
          if (FS.isDir(entry.mode)) {
            FS.mkdir(path, entry.mode);
          } else if (FS.isFile(entry.mode)) {
            FS.writeFile(path, entry.contents, { encoding: 'binary', canOwn: true });
          } else {
            return callback(new Error('node type not supported'));
          }
  
          FS.utime(path, entry.timestamp, entry.timestamp);
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },removeLocalEntry:function (path, callback) {
        try {
          var lookup = FS.lookupPath(path);
          var stat = FS.stat(path);
  
          if (FS.isDir(stat.mode)) {
            FS.rmdir(path);
          } else if (FS.isFile(stat.mode)) {
            FS.unlink(path);
          }
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },loadRemoteEntry:function (store, path, callback) {
        var req = store.get(path);
        req.onsuccess = function(event) { callback(null, event.target.result); };
        req.onerror = function() { callback(this.error); };
      },storeRemoteEntry:function (store, path, entry, callback) {
        var req = store.put(entry, path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function() { callback(this.error); };
      },removeRemoteEntry:function (store, path, callback) {
        var req = store.delete(path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function() { callback(this.error); };
      },reconcile:function (src, dst, callback) {
        var total = 0;
  
        var create = [];
        Object.keys(src.entries).forEach(function (key) {
          var e = src.entries[key];
          var e2 = dst.entries[key];
          if (!e2 || e.timestamp > e2.timestamp) {
            create.push(key);
            total++;
          }
        });
  
        var remove = [];
        Object.keys(dst.entries).forEach(function (key) {
          var e = dst.entries[key];
          var e2 = src.entries[key];
          if (!e2) {
            remove.push(key);
            total++;
          }
        });
  
        if (!total) {
          return callback(null);
        }
  
        var errored = false;
        var completed = 0;
        var db = src.type === 'remote' ? src.db : dst.db;
        var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readwrite');
        var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= total) {
            return callback(null);
          }
        };
  
        transaction.onerror = function() { done(this.error); };
  
        // sort paths in ascending order so directory entries are created
        // before the files inside them
        create.sort().forEach(function (path) {
          if (dst.type === 'local') {
            IDBFS.loadRemoteEntry(store, path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeLocalEntry(path, entry, done);
            });
          } else {
            IDBFS.loadLocalEntry(path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeRemoteEntry(store, path, entry, done);
            });
          }
        });
  
        // sort paths in descending order so files are deleted before their
        // parent directories
        remove.sort().reverse().forEach(function(path) {
          if (dst.type === 'local') {
            IDBFS.removeLocalEntry(path, done);
          } else {
            IDBFS.removeRemoteEntry(store, path, done);
          }
        });
      }};
  
  var NODEFS={isWindows:false,staticInit:function () {
        NODEFS.isWindows = !!process.platform.match(/^win/);
      },mount:function (mount) {
        assert(ENVIRONMENT_IS_NODE);
        return NODEFS.createNode(null, '/', NODEFS.getMode(mount.opts.root), 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = NODEFS.node_ops;
        node.stream_ops = NODEFS.stream_ops;
        return node;
      },getMode:function (path) {
        var stat;
        try {
          stat = fs.lstatSync(path);
          if (NODEFS.isWindows) {
            // On Windows, directories return permission bits 'rw-rw-rw-', even though they have 'rwxrwxrwx', so 
            // propagate write bits to execute bits.
            stat.mode = stat.mode | ((stat.mode & 146) >> 1);
          }
        } catch (e) {
          if (!e.code) throw e;
          throw new FS.ErrnoError(ERRNO_CODES[e.code]);
        }
        return stat.mode;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },flagsToPermissionStringMap:{0:"r",1:"r+",2:"r+",64:"r",65:"r+",66:"r+",129:"rx+",193:"rx+",514:"w+",577:"w",578:"w+",705:"wx",706:"wx+",1024:"a",1025:"a",1026:"a+",1089:"a",1090:"a+",1153:"ax",1154:"ax+",1217:"ax",1218:"ax+",4096:"rs",4098:"rs+"},flagsToPermissionString:function (flags) {
        if (flags in NODEFS.flagsToPermissionStringMap) {
          return NODEFS.flagsToPermissionStringMap[flags];
        } else {
          return flags;
        }
      },node_ops:{getattr:function (node) {
          var path = NODEFS.realPath(node);
          var stat;
          try {
            stat = fs.lstatSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          // node.js v0.10.20 doesn't report blksize and blocks on Windows. Fake them with default blksize of 4096.
          // See http://support.microsoft.com/kb/140365
          if (NODEFS.isWindows && !stat.blksize) {
            stat.blksize = 4096;
          }
          if (NODEFS.isWindows && !stat.blocks) {
            stat.blocks = (stat.size+stat.blksize-1)/stat.blksize|0;
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = NODEFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              fs.chmodSync(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              fs.utimesSync(path, date, date);
            }
            if (attr.size !== undefined) {
              fs.truncateSync(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          var mode = NODEFS.getMode(path);
          return NODEFS.createNode(parent, name, mode);
        },mknod:function (parent, name, mode, dev) {
          var node = NODEFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = NODEFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              fs.mkdirSync(path, node.mode);
            } else {
              fs.writeFileSync(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = NODEFS.realPath(oldNode);
          var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
          try {
            fs.renameSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.unlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.rmdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(NODEFS.realPath(parent), newName);
          try {
            fs.symlinkSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = NODEFS.realPath(stream.node);
          try {
            if (FS.isFile(stream.node.mode)) {
              stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags));
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            if (FS.isFile(stream.node.mode) && stream.nfd) {
              fs.closeSync(stream.nfd);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(length);
          var res;
          try {
            res = fs.readSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          if (res > 0) {
            for (var i = 0; i < res; i++) {
              buffer[offset + i] = nbuffer[i];
            }
          }
          return res;
        },write:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
          var res;
          try {
            res = fs.writeSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return res;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = fs.fstatSync(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }
  
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
  
          stream.position = position;
          return position;
        }}};
  
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);
  
  function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      // we don't currently perform any user-space buffering of data
    }var FS={root:null,mounts:[],devices:[null],streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,trackingDelegate:{},tracking:{openFlags:{READ:1,WRITE:2}},ErrnoError:null,genericErrors:{},handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + stackTrace();
        return ___setErrNo(e.errno);
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.cwd(), path);
        opts = opts || {};
  
        var defaults = {
          follow_mount: true,
          recurse_count: 0
        };
        for (var key in defaults) {
          if (opts[key] === undefined) {
            opts[key] = defaults[key];
          }
        }
  
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
  
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
  
        // start at the root
        var current = FS.root;
        var current_path = '/';
  
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
  
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join2(current_path, parts[i]);
  
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            if (!islast || (islast && opts.follow_mount)) {
              current = current.mounted.root;
            }
          }
  
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
  
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
  
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            var mount = node.mount.mountpoint;
            if (!path) return mount;
            return mount[mount.length-1] !== '/' ? mount + '/' + path : mount + path;
          }
          path = path ? node.name + '/' + path : node.name;
          node = node.parent;
        }
      },hashName:function (parentid, name) {
        var hash = 0;
  
  
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.nameTable.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.nameTable[hash];
        FS.nameTable[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.nameTable[hash] === node) {
          FS.nameTable[hash] = node.name_next;
        } else {
          var current = FS.nameTable[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.nameTable[hash]; node; node = node.name_next) {
          var nodeName = node.name;
          if (node.parent.id === parent.id && nodeName === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        if (!FS.FSNode) {
          FS.FSNode = function(parent, name, mode, rdev) {
            if (!parent) {
              parent = this;  // root node sets parent to itself
            }
            this.parent = parent;
            this.mount = parent.mount;
            this.mounted = null;
            this.id = FS.nextInode++;
            this.name = name;
            this.mode = mode;
            this.node_ops = {};
            this.stream_ops = {};
            this.rdev = rdev;
          };
  
          FS.FSNode.prototype = {};
  
          // compatibility
          var readMode = 292 | 73;
          var writeMode = 146;
  
          // NOTE we must use Object.defineProperties instead of individual calls to
          // Object.defineProperty in order to make closure compiler happy
          Object.defineProperties(FS.FSNode.prototype, {
            read: {
              get: function() { return (this.mode & readMode) === readMode; },
              set: function(val) { val ? this.mode |= readMode : this.mode &= ~readMode; }
            },
            write: {
              get: function() { return (this.mode & writeMode) === writeMode; },
              set: function(val) { val ? this.mode |= writeMode : this.mode &= ~writeMode; }
            },
            isFolder: {
              get: function() { return FS.isDir(this.mode); },
            },
            isDevice: {
              get: function() { return FS.isChrdev(this.mode); },
            },
          });
        }
  
        var node = new FS.FSNode(parent, name, mode, rdev);
  
        FS.hashAddNode(node);
  
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return !!node.mounted;
      },isFile:function (mode) {
        return (mode & 61440) === 32768;
      },isDir:function (mode) {
        return (mode & 61440) === 16384;
      },isLink:function (mode) {
        return (mode & 61440) === 40960;
      },isChrdev:function (mode) {
        return (mode & 61440) === 8192;
      },isBlkdev:function (mode) {
        return (mode & 61440) === 24576;
      },isFIFO:function (mode) {
        return (mode & 61440) === 4096;
      },isSocket:function (mode) {
        return (mode & 49152) === 49152;
      },flagModes:{"r":0,"rs":1052672,"r+":2,"w":577,"wx":705,"xw":705,"w+":578,"wx+":706,"xw+":706,"a":1089,"ax":1217,"xa":1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 2097155;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 512)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        return FS.nodePermissions(dir, 'x');
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 2097155) !== 0 ||  // opening for write
              (flags & 512)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 0;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        if (!FS.FSStream) {
          FS.FSStream = function(){};
          FS.FSStream.prototype = {};
          // compatibility
          Object.defineProperties(FS.FSStream.prototype, {
            object: {
              get: function() { return this.node; },
              set: function(val) { this.node = val; }
            },
            isRead: {
              get: function() { return (this.flags & 2097155) !== 1; }
            },
            isWrite: {
              get: function() { return (this.flags & 2097155) !== 0; }
            },
            isAppend: {
              get: function() { return (this.flags & 1024); }
            }
          });
        }
        // clone it, so we can return an instance of FSStream
        var newStream = new FS.FSStream();
        for (var p in stream) {
          newStream[p] = stream[p];
        }
        stream = newStream;
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getStreamFromPtr:function (ptr) {
        return FS.streams[ptr - 1];
      },getPtrForStream:function (stream) {
        return stream ? stream.fd + 1 : 0;
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },getMounts:function (mount) {
        var mounts = [];
        var check = [mount];
  
        while (check.length) {
          var m = check.pop();
  
          mounts.push(m);
  
          check.push.apply(check, m.mounts);
        }
  
        return mounts;
      },syncfs:function (populate, callback) {
        if (typeof(populate) === 'function') {
          callback = populate;
          populate = false;
        }
  
        var mounts = FS.getMounts(FS.root.mount);
        var completed = 0;
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= mounts.length) {
            callback(null);
          }
        };
  
        // sync all mounts
        mounts.forEach(function (mount) {
          if (!mount.type.syncfs) {
            return done(null);
          }
          mount.type.syncfs(mount, populate, done);
        });
      },mount:function (type, opts, mountpoint) {
        var root = mountpoint === '/';
        var pseudo = !mountpoint;
        var node;
  
        if (root && FS.root) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        } else if (!root && !pseudo) {
          var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
          mountpoint = lookup.path;  // use the absolute path
          node = lookup.node;
  
          if (FS.isMountpoint(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
          }
  
          if (!FS.isDir(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
          }
        }
  
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          mounts: []
        };
  
        // create a root node for the fs
        var mountRoot = type.mount(mount);
        mountRoot.mount = mount;
        mount.root = mountRoot;
  
        if (root) {
          FS.root = mountRoot;
        } else if (node) {
          // set as a mountpoint
          node.mounted = mount;
  
          // add the new mount to the current mount's children
          if (node.mount) {
            node.mount.mounts.push(mount);
          }
        }
  
        return mountRoot;
      },unmount:function (mountpoint) {
        var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
        if (!FS.isMountpoint(lookup.node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
  
        // destroy the nodes for this mount, and all its child mounts
        var node = lookup.node;
        var mount = node.mounted;
        var mounts = FS.getMounts(mount);
  
        Object.keys(FS.nameTable).forEach(function (hash) {
          var current = FS.nameTable[hash];
  
          while (current) {
            var next = current.name_next;
  
            if (mounts.indexOf(current.mount) !== -1) {
              FS.destroyNode(current);
            }
  
            current = next;
          }
        });
  
        // no longer a mountpoint
        node.mounted = null;
  
        // remove this mount from the child mounts
        var idx = node.mount.mounts.indexOf(mount);
        assert(idx !== -1);
        node.mount.mounts.splice(idx, 1);
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode = mode !== undefined ? mode : 438 /* 0666 */;
        mode &= 4095;
        mode |= 32768;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode = mode !== undefined ? mode : 511 /* 0777 */;
        mode &= 511 | 512;
        mode |= 16384;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        if (typeof(dev) === 'undefined') {
          dev = mode;
          mode = 438 /* 0666 */;
        }
        mode |= 8192;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        try {
          if (FS.trackingDelegate['willMovePath']) {
            FS.trackingDelegate['willMovePath'](old_path, new_path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
        try {
          if (FS.trackingDelegate['onMovePath']) FS.trackingDelegate['onMovePath'](old_path, new_path);
        } catch(e) {
          console.log("FS.trackingDelegate['onMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readlink:function (path) {
        var lookup = FS.lookupPath(path);
        var link = lookup.node;
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 438 /* 0666 */ : mode;
        if ((flags & 64)) {
          mode = (mode & 4095) | 32768;
        } else {
          mode = 0;
        }
        var node;
        if (typeof path === 'object') {
          node = path;
        } else {
          path = PATH.normalize(path);
          try {
            var lookup = FS.lookupPath(path, {
              follow: !(flags & 131072)
            });
            node = lookup.node;
          } catch (e) {
            // ignore
          }
        }
        // perhaps we need to create the node
        if ((flags & 64)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 128)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~512;
        }
        // check permissions
        var err = FS.mayOpen(node, flags);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // do truncation if necessary
        if ((flags & 512)) {
          FS.truncate(node, 0);
        }
        // we've already handled these, don't pass down to the underlying vfs
        flags &= ~(128 | 512);
  
        // register the stream with the filesystem
        var stream = FS.createStream({
          node: node,
          path: FS.getPath(node),  // we want the absolute path to the node
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        if (Module['logReadFiles'] && !(flags & 1)) {
          if (!FS.readFiles) FS.readFiles = {};
          if (!(path in FS.readFiles)) {
            FS.readFiles[path] = 1;
            Module['printErr']('read file: ' + path);
          }
        }
        try {
          if (FS.trackingDelegate['onOpenFile']) {
            var trackingFlags = 0;
            if ((flags & 2097155) !== 1) {
              trackingFlags |= FS.tracking.openFlags.READ;
            }
            if ((flags & 2097155) !== 0) {
              trackingFlags |= FS.tracking.openFlags.WRITE;
            }
            FS.trackingDelegate['onOpenFile'](path, trackingFlags);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['onOpenFile']('"+path+"', flags) threw an exception: " + e.message);
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        return stream.stream_ops.llseek(stream, offset, whence);
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        if (stream.flags & 1024) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        try {
          if (stream.path && FS.trackingDelegate['onWriteToFile']) FS.trackingDelegate['onWriteToFile'](stream.path);
        } catch(e) {
          console.log("FS.trackingDelegate['onWriteToFile']('"+path+"') threw an exception: " + e.message);
        }
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      },readFile:function (path, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'r';
        opts.encoding = opts.encoding || 'binary';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var ret;
        var stream = FS.open(path, opts.flags);
        var stat = FS.stat(path);
        var length = stat.size;
        var buf = new Uint8Array(length);
        FS.read(stream, buf, 0, length, 0);
        if (opts.encoding === 'utf8') {
          ret = '';
          var utf8 = new Runtime.UTF8Processor();
          for (var i = 0; i < length; i++) {
            ret += utf8.processCChar(buf[i]);
          }
        } else if (opts.encoding === 'binary') {
          ret = buf;
        }
        FS.close(stream);
        return ret;
      },writeFile:function (path, data, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'w';
        opts.encoding = opts.encoding || 'utf8';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var stream = FS.open(path, opts.flags, opts.mode);
        if (opts.encoding === 'utf8') {
          var utf8 = new Runtime.UTF8Processor();
          var buf = new Uint8Array(utf8.processJSString(data));
          FS.write(stream, buf, 0, buf.length, 0, opts.canOwn);
        } else if (opts.encoding === 'binary') {
          FS.write(stream, data, 0, data.length, 0, opts.canOwn);
        }
        FS.close(stream);
      },cwd:function () {
        return FS.currentPath;
      },chdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        if (!FS.isDir(lookup.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        var err = FS.nodePermissions(lookup.node, 'x');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        FS.currentPath = lookup.path;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp');
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev');
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', FS.makedev(6, 0));
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm');
        FS.mkdir('/dev/shm/tmp');
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
  
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
  
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=FS.getPtrForStream(stdin);
        assert(stdin.fd === 0, 'invalid handle for stdin (' + stdin.fd + ')');
  
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=FS.getPtrForStream(stdout);
        assert(stdout.fd === 1, 'invalid handle for stdout (' + stdout.fd + ')');
  
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=FS.getPtrForStream(stderr);
        assert(stderr.fd === 2, 'invalid handle for stderr (' + stderr.fd + ')');
      },ensureErrnoError:function () {
        if (FS.ErrnoError) return;
        FS.ErrnoError = function ErrnoError(errno) {
          this.errno = errno;
          for (var key in ERRNO_CODES) {
            if (ERRNO_CODES[key] === errno) {
              this.code = key;
              break;
            }
          }
          this.message = ERRNO_MESSAGES[errno];
        };
        FS.ErrnoError.prototype = new Error();
        FS.ErrnoError.prototype.constructor = FS.ErrnoError;
        // Some errors may happen quite a bit, to avoid overhead we reuse them (and suffer a lack of stack info)
        [ERRNO_CODES.ENOENT].forEach(function(code) {
          FS.genericErrors[code] = new FS.ErrnoError(code);
          FS.genericErrors[code].stack = '<generic error, no stack>';
        });
      },staticInit:function () {
        FS.ensureErrnoError();
  
        FS.nameTable = new Array(4096);
  
        FS.mount(MEMFS, {}, '/');
  
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureErrnoError();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
  
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join2(parent, part);
          try {
            FS.mkdir(current);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(node, mode | 146);
          var stream = FS.open(node, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(node, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
        function LazyUint8Array() {
          this.lengthKnown = false;
          this.chunks = []; // Loaded chunks. Index is the chunk number
        }
        LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
          if (idx > this.length-1 || idx < 0) {
            return undefined;
          }
          var chunkOffset = idx % this.chunkSize;
          var chunkNum = Math.floor(idx / this.chunkSize);
          return this.getter(chunkNum)[chunkOffset];
        }
        LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
          this.getter = getter;
        }
        LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
            // Find length
            var xhr = new XMLHttpRequest();
            xhr.open('HEAD', url, false);
            xhr.send(null);
            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
            var datalength = Number(xhr.getResponseHeader("Content-length"));
            var header;
            var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
            var chunkSize = 1024*1024; // Chunk size in bytes
  
            if (!hasByteServing) chunkSize = datalength;
  
            // Function to get a range from the remote URL.
            var doXHR = (function(from, to) {
              if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
              if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
  
              // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
              var xhr = new XMLHttpRequest();
              xhr.open('GET', url, false);
              if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
  
              // Some hints to the browser that we want binary data.
              if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
              if (xhr.overrideMimeType) {
                xhr.overrideMimeType('text/plain; charset=x-user-defined');
              }
  
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              if (xhr.response !== undefined) {
                return new Uint8Array(xhr.response || []);
              } else {
                return intArrayFromString(xhr.responseText || '', true);
              }
            });
            var lazyArray = this;
            lazyArray.setDataGetter(function(chunkNum) {
              var start = chunkNum * chunkSize;
              var end = (chunkNum+1) * chunkSize - 1; // including this byte
              end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
              if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                lazyArray.chunks[chunkNum] = doXHR(start, end);
              }
              if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
              return lazyArray.chunks[chunkNum];
            });
  
            this._length = datalength;
            this._chunkSize = chunkSize;
            this.lengthKnown = true;
        }
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
  
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
  
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function forceLoadLazyFile() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function putRequest_onsuccess() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function putRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function getRequest_onsuccess() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function getRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      }};
  
  var Browser={mainLoop:{scheduler:null,method:"",shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
  
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
  
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function imagePlugin_canHandle(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function imagePlugin_handle(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function img_onload() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function img_onerror(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function audioPlugin_canHandle(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function audioPlugin_handle(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function audio_onerror(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
  
        // Canvas event setup
  
        var canvas = Module['canvas'];
        if (canvas) {
          // forced aspect ratio can be enabled by defining 'forcedAspectRatio' on Module
          // Module['forcedAspectRatio'] = 4 / 3;
          
          canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                      canvas['mozRequestPointerLock'] ||
                                      canvas['webkitRequestPointerLock'] ||
                                      canvas['msRequestPointerLock'] ||
                                      function(){};
          canvas.exitPointerLock = document['exitPointerLock'] ||
                                   document['mozExitPointerLock'] ||
                                   document['webkitExitPointerLock'] ||
                                   document['msExitPointerLock'] ||
                                   function(){}; // no-op if function does not exist
          canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
  
          function pointerLockChange() {
            Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                  document['mozPointerLockElement'] === canvas ||
                                  document['webkitPointerLockElement'] === canvas ||
                                  document['msPointerLockElement'] === canvas;
          }
  
          document.addEventListener('pointerlockchange', pointerLockChange, false);
          document.addEventListener('mozpointerlockchange', pointerLockChange, false);
          document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
          document.addEventListener('mspointerlockchange', pointerLockChange, false);
  
          if (Module['elementPointerLock']) {
            canvas.addEventListener("click", function(ev) {
              if (!Browser.pointerLock && canvas.requestPointerLock) {
                canvas.requestPointerLock();
                ev.preventDefault();
              }
            }, false);
          }
        }
      },createContext:function (canvas, useWebGL, setInModule, webGLContextAttributes) {
        var ctx;
        var errorInfo = '?';
        function onContextCreationError(event) {
          errorInfo = event.statusMessage || errorInfo;
        }
        try {
          if (useWebGL) {
            var contextAttributes = {
              antialias: false,
              alpha: false
            };
  
            if (webGLContextAttributes) {
              for (var attribute in webGLContextAttributes) {
                contextAttributes[attribute] = webGLContextAttributes[attribute];
              }
            }
  
  
            canvas.addEventListener('webglcontextcreationerror', onContextCreationError, false);
            try {
              ['experimental-webgl', 'webgl'].some(function(webglId) {
                return ctx = canvas.getContext(webglId, contextAttributes);
              });
            } finally {
              canvas.removeEventListener('webglcontextcreationerror', onContextCreationError, false);
            }
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas: ' + [errorInfo, e]);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
  
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          GLctx = Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
  
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          var canvasContainer = canvas.parentNode;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement'] ||
               document['msFullScreenElement'] || document['msFullscreenElement'] ||
               document['webkitCurrentFullScreenElement']) === canvasContainer) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'] ||
                                      document['msExitFullscreen'] ||
                                      document['exitFullscreen'] ||
                                      function() {};
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else {
            
            // remove the full screen specific parent of the canvas again to restore the HTML structure from before going full screen
            canvasContainer.parentNode.insertBefore(canvas, canvasContainer);
            canvasContainer.parentNode.removeChild(canvasContainer);
            
            if (Browser.resizeCanvas) Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
          Browser.updateCanvasDimensions(canvas);
        }
  
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
          document.addEventListener('MSFullscreenChange', fullScreenChange, false);
        }
  
        // create a new parent to ensure the canvas has no siblings. this allows browsers to optimize full screen performance when its parent is the full screen root
        var canvasContainer = document.createElement("div");
        canvas.parentNode.insertBefore(canvasContainer, canvas);
        canvasContainer.appendChild(canvas);
        
        // use parent of canvas as full screen root to allow aspect ratio correction (Firefox stretches the root to screen size)
        canvasContainer.requestFullScreen = canvasContainer['requestFullScreen'] ||
                                            canvasContainer['mozRequestFullScreen'] ||
                                            canvasContainer['msRequestFullscreen'] ||
                                           (canvasContainer['webkitRequestFullScreen'] ? function() { canvasContainer['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvasContainer.requestFullScreen();
      },requestAnimationFrame:function requestAnimationFrame(func) {
        if (typeof window === 'undefined') { // Provide fallback to setTimeout if window is undefined (e.g. in Node.js)
          setTimeout(func, 1000/60);
        } else {
          if (!window.requestAnimationFrame) {
            window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                           window['mozRequestAnimationFrame'] ||
                                           window['webkitRequestAnimationFrame'] ||
                                           window['msRequestAnimationFrame'] ||
                                           window['oRequestAnimationFrame'] ||
                                           window['setTimeout'];
          }
          window.requestAnimationFrame(func);
        }
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },getMouseWheelDelta:function (event) {
        return Math.max(-1, Math.min(1, event.type === 'DOMMouseScroll' ? event.detail : -event.wheelDelta));
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,touches:{},lastTouches:{},calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
  
          // Neither .scrollX or .pageXOffset are defined in a spec, but
          // we prefer .scrollX because it is currently in a spec draft.
          // (see: http://www.w3.org/TR/2013/WD-cssom-view-20131217/)
          var scrollX = ((typeof window.scrollX !== 'undefined') ? window.scrollX : window.pageXOffset);
          var scrollY = ((typeof window.scrollY !== 'undefined') ? window.scrollY : window.pageYOffset);
  
          if (event.type === 'touchstart' || event.type === 'touchend' || event.type === 'touchmove') {
            var touch = event.touch;
            if (touch === undefined) {
              return; // the "touch" property is only defined in SDL
  
            }
            var adjustedX = touch.pageX - (scrollX + rect.left);
            var adjustedY = touch.pageY - (scrollY + rect.top);
  
            adjustedX = adjustedX * (cw / rect.width);
            adjustedY = adjustedY * (ch / rect.height);
  
            var coords = { x: adjustedX, y: adjustedY };
            
            if (event.type === 'touchstart') {
              Browser.lastTouches[touch.identifier] = coords;
              Browser.touches[touch.identifier] = coords;
            } else if (event.type === 'touchend' || event.type === 'touchmove') {
              Browser.lastTouches[touch.identifier] = Browser.touches[touch.identifier];
              Browser.touches[touch.identifier] = { x: adjustedX, y: adjustedY };
            } 
            return;
          }
  
          var x = event.pageX - (scrollX + rect.left);
          var y = event.pageY - (scrollY + rect.top);
  
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
  
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function xhr_onload() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        Browser.updateCanvasDimensions(canvas, width, height);
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },updateCanvasDimensions:function (canvas, wNative, hNative) {
        if (wNative && hNative) {
          canvas.widthNative = wNative;
          canvas.heightNative = hNative;
        } else {
          wNative = canvas.widthNative;
          hNative = canvas.heightNative;
        }
        var w = wNative;
        var h = hNative;
        if (Module['forcedAspectRatio'] && Module['forcedAspectRatio'] > 0) {
          if (w/h < Module['forcedAspectRatio']) {
            w = Math.round(h * Module['forcedAspectRatio']);
          } else {
            h = Math.round(w / Module['forcedAspectRatio']);
          }
        }
        if (((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
             document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
             document['fullScreenElement'] || document['fullscreenElement'] ||
             document['msFullScreenElement'] || document['msFullscreenElement'] ||
             document['webkitCurrentFullScreenElement']) === canvas.parentNode) && (typeof screen != 'undefined')) {
           var factor = Math.min(screen.width / w, screen.height / h);
           w = Math.round(w * factor);
           h = Math.round(h * factor);
        }
        if (Browser.resizeCanvas) {
          if (canvas.width  != w) canvas.width  = w;
          if (canvas.height != h) canvas.height = h;
          if (typeof canvas.style != 'undefined') {
            canvas.style.removeProperty( "width");
            canvas.style.removeProperty("height");
          }
        } else {
          if (canvas.width  != wNative) canvas.width  = wNative;
          if (canvas.height != hNative) canvas.height = hNative;
          if (typeof canvas.style != 'undefined') {
            if (w != wNative || h != hNative) {
              canvas.style.setProperty( "width", w + "px", "important");
              canvas.style.setProperty("height", h + "px", "important");
            } else {
              canvas.style.removeProperty( "width");
              canvas.style.removeProperty("height");
            }
          }
        }
      }};
  
  function _SDL_GetTicks() {
      return Math.floor(Date.now() - SDL.startTime);
    }var SDL={defaults:{width:320,height:200,copyOnLock:true},version:null,surfaces:{},canvasPool:[],events:[],fonts:[null],audios:[null],rwops:[null],music:{audio:null,volume:1},mixerFrequency:22050,mixerFormat:32784,mixerNumChannels:2,mixerChunkSize:1024,channelMinimumNumber:0,GL:false,glAttributes:{0:3,1:3,2:2,3:0,4:0,5:1,6:16,7:0,8:0,9:0,10:0,11:0,12:0,13:0,14:0,15:1,16:0,17:0,18:0},keyboardState:null,keyboardMap:{},canRequestFullscreen:false,isRequestingFullscreen:false,textInput:false,startTime:null,initFlags:0,buttonState:0,modState:0,DOMButtons:[0,0,0],DOMEventToSDLEvent:{},TOUCH_DEFAULT_ID:0,keyCodes:{16:1249,17:1248,18:1250,20:1081,33:1099,34:1102,35:1101,36:1098,37:1104,38:1106,39:1103,40:1105,44:316,45:1097,46:127,91:1251,93:1125,96:1122,97:1113,98:1114,99:1115,100:1116,101:1117,102:1118,103:1119,104:1120,105:1121,106:1109,107:1111,109:1110,110:1123,111:1108,112:1082,113:1083,114:1084,115:1085,116:1086,117:1087,118:1088,119:1089,120:1090,121:1091,122:1092,123:1093,124:1128,125:1129,126:1130,127:1131,128:1132,129:1133,130:1134,131:1135,132:1136,133:1137,134:1138,135:1139,144:1107,160:94,161:33,162:34,163:35,164:36,165:37,166:38,167:95,168:40,169:41,170:42,171:43,172:124,173:45,174:123,175:125,176:126,181:127,182:129,183:128,188:44,190:46,191:47,192:96,219:91,220:92,221:93,222:39},scanCodes:{8:42,9:43,13:40,27:41,32:44,35:204,39:53,44:54,46:55,47:56,48:39,49:30,50:31,51:32,52:33,53:34,54:35,55:36,56:37,57:38,58:203,59:51,61:46,91:47,92:49,93:48,96:52,97:4,98:5,99:6,100:7,101:8,102:9,103:10,104:11,105:12,106:13,107:14,108:15,109:16,110:17,111:18,112:19,113:20,114:21,115:22,116:23,117:24,118:25,119:26,120:27,121:28,122:29,127:76,305:224,308:226,316:70},loadRect:function (rect) {
        return {
          x: HEAP32[((rect + 0)>>2)],
          y: HEAP32[((rect + 4)>>2)],
          w: HEAP32[((rect + 8)>>2)],
          h: HEAP32[((rect + 12)>>2)]
        };
      },loadColorToCSSRGB:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgb(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ')';
      },loadColorToCSSRGBA:function (color) {
        var rgba = HEAP32[((color)>>2)];
        return 'rgba(' + (rgba&255) + ',' + ((rgba >> 8)&255) + ',' + ((rgba >> 16)&255) + ',' + (((rgba >> 24)&255)/255) + ')';
      },translateColorToCSSRGBA:function (rgba) {
        return 'rgba(' + (rgba&0xff) + ',' + (rgba>>8 & 0xff) + ',' + (rgba>>16 & 0xff) + ',' + (rgba>>>24)/0xff + ')';
      },translateRGBAToCSSRGBA:function (r, g, b, a) {
        return 'rgba(' + (r&0xff) + ',' + (g&0xff) + ',' + (b&0xff) + ',' + (a&0xff)/255 + ')';
      },translateRGBAToColor:function (r, g, b, a) {
        return r | g << 8 | b << 16 | a << 24;
      },makeSurface:function (width, height, flags, usePageCanvas, source, rmask, gmask, bmask, amask) {
        flags = flags || 0;
        var is_SDL_HWSURFACE = flags & 0x00000001;
        var is_SDL_HWPALETTE = flags & 0x00200000;
        var is_SDL_OPENGL = flags & 0x04000000;
  
        var surf = _malloc(60);
        var pixelFormat = _malloc(44);
        //surface with SDL_HWPALETTE flag is 8bpp surface (1 byte)
        var bpp = is_SDL_HWPALETTE ? 1 : 4;
        var buffer = 0;
  
        // preemptively initialize this for software surfaces,
        // otherwise it will be lazily initialized inside of SDL_LockSurface
        if (!is_SDL_HWSURFACE && !is_SDL_OPENGL) {
          buffer = _malloc(width * height * 4);
        }
  
        HEAP32[((surf)>>2)]=flags;
        HEAP32[(((surf)+(4))>>2)]=pixelFormat;
        HEAP32[(((surf)+(8))>>2)]=width;
        HEAP32[(((surf)+(12))>>2)]=height;
        HEAP32[(((surf)+(16))>>2)]=width * bpp;  // assuming RGBA or indexed for now,
                                                                                          // since that is what ImageData gives us in browsers
        HEAP32[(((surf)+(20))>>2)]=buffer;
        HEAP32[(((surf)+(36))>>2)]=0;
        HEAP32[(((surf)+(56))>>2)]=1;
  
        HEAP32[((pixelFormat)>>2)]=0 /* XXX missing C define SDL_PIXELFORMAT_RGBA8888 */;
        HEAP32[(((pixelFormat)+(4))>>2)]=0;// TODO
        HEAP8[(((pixelFormat)+(8))>>0)]=bpp * 8;
        HEAP8[(((pixelFormat)+(9))>>0)]=bpp;
  
        HEAP32[(((pixelFormat)+(12))>>2)]=rmask || 0x000000ff;
        HEAP32[(((pixelFormat)+(16))>>2)]=gmask || 0x0000ff00;
        HEAP32[(((pixelFormat)+(20))>>2)]=bmask || 0x00ff0000;
        HEAP32[(((pixelFormat)+(24))>>2)]=amask || 0xff000000;
  
        // Decide if we want to use WebGL or not
        SDL.GL = SDL.GL || is_SDL_OPENGL;
        var canvas;
        if (!usePageCanvas) {
          if (SDL.canvasPool.length > 0) {
            canvas = SDL.canvasPool.pop();
          } else {
            canvas = document.createElement('canvas');
          }
          canvas.width = width;
          canvas.height = height;
        } else {
          canvas = Module['canvas'];
        }
  
        var webGLContextAttributes = {
          antialias: ((SDL.glAttributes[13 /*SDL_GL_MULTISAMPLEBUFFERS*/] != 0) && (SDL.glAttributes[14 /*SDL_GL_MULTISAMPLESAMPLES*/] > 1)),
          depth: (SDL.glAttributes[6 /*SDL_GL_DEPTH_SIZE*/] > 0),
          stencil: (SDL.glAttributes[7 /*SDL_GL_STENCIL_SIZE*/] > 0)
        };
        
        var ctx = Browser.createContext(canvas, is_SDL_OPENGL, usePageCanvas, webGLContextAttributes);
              
        SDL.surfaces[surf] = {
          width: width,
          height: height,
          canvas: canvas,
          ctx: ctx,
          surf: surf,
          buffer: buffer,
          pixelFormat: pixelFormat,
          alpha: 255,
          flags: flags,
          locked: 0,
          usePageCanvas: usePageCanvas,
          source: source,
  
          isFlagSet: function(flag) {
            return flags & flag;
          }
        };
  
        return surf;
      },copyIndexedColorData:function (surfData, rX, rY, rW, rH) {
        // HWPALETTE works with palette
        // setted by SDL_SetColors
        if (!surfData.colors) {
          return;
        }
        
        var fullWidth  = Module['canvas'].width;
        var fullHeight = Module['canvas'].height;
  
        var startX  = rX || 0;
        var startY  = rY || 0;
        var endX    = (rW || (fullWidth - startX)) + startX;
        var endY    = (rH || (fullHeight - startY)) + startY;
        
        var buffer  = surfData.buffer;
        var data    = surfData.image.data;
        var colors  = surfData.colors;
  
        for (var y = startY; y < endY; ++y) {
          var indexBase = y * fullWidth;
          var colorBase = indexBase * 4;
          for (var x = startX; x < endX; ++x) {
            // HWPALETTE have only 256 colors (not rgba)
            var index = HEAPU8[((buffer + indexBase + x)>>0)] * 3;
            var colorOffset = colorBase + x * 4;
  
            data[colorOffset   ] = colors[index   ];
            data[colorOffset +1] = colors[index +1];
            data[colorOffset +2] = colors[index +2];
            //unused: data[colorOffset +3] = color[index +3];
          }
        }
      },freeSurface:function (surf) {
        var refcountPointer = surf + 56;
        var refcount = HEAP32[((refcountPointer)>>2)];
        if (refcount > 1) {
          HEAP32[((refcountPointer)>>2)]=refcount - 1;
          return;
        }
  
        var info = SDL.surfaces[surf];
        if (!info) return; // surface has already been freed
        if (!info.usePageCanvas && info.canvas) SDL.canvasPool.push(info.canvas);
        if (info.buffer) _free(info.buffer);
        _free(info.pixelFormat);
        _free(surf);
        SDL.surfaces[surf] = null;
  
        if (surf === SDL.screen) {
          SDL.screen = null;
        }
      },downFingers:{},savedKeydown:null,receiveEvent:function (event) {
        switch(event.type) {
          case 'touchstart': case 'touchmove': {
            event.preventDefault();
  
            var touches = [];
            
            // Clear out any touchstart events that we've already processed
            if (event.type === 'touchstart') {
              for (var i = 0; i < event.touches.length; i++) {
                var touch = event.touches[i];
                if (SDL.downFingers[touch.identifier] != true) {
                  SDL.downFingers[touch.identifier] = true;
                  touches.push(touch);
                }
              }
            } else {
              touches = event.touches;
            }
            
            var firstTouch = touches[0];
            if (event.type == 'touchstart') {
              SDL.DOMButtons[0] = 1;
            }
            var mouseEventType;
            switch(event.type) {
              case 'touchstart': mouseEventType = 'mousedown'; break;
              case 'touchmove': mouseEventType = 'mousemove'; break;
            }
            var mouseEvent = {
              type: mouseEventType,
              button: 0,
              pageX: firstTouch.clientX,
              pageY: firstTouch.clientY
            };
            SDL.events.push(mouseEvent);
  
            for (var i = 0; i < touches.length; i++) {
              var touch = touches[i];
              SDL.events.push({
                type: event.type,
                touch: touch
              });
            };
            break;
          }
          case 'touchend': {
            event.preventDefault();
            
            // Remove the entry in the SDL.downFingers hash
            // because the finger is no longer down.
            for(var i = 0; i < event.changedTouches.length; i++) {
              var touch = event.changedTouches[i];
              if (SDL.downFingers[touch.identifier] === true) {
                delete SDL.downFingers[touch.identifier];
              }
            }
  
            var mouseEvent = {
              type: 'mouseup',
              button: 0,
              pageX: event.changedTouches[0].clientX,
              pageY: event.changedTouches[0].clientY
            };
            SDL.DOMButtons[0] = 0;
            SDL.events.push(mouseEvent);
            
            for (var i = 0; i < event.changedTouches.length; i++) {
              var touch = event.changedTouches[i];
              SDL.events.push({
                type: 'touchend',
                touch: touch
              });
            };
            break;
          }
          case 'mousemove':
            if (SDL.DOMButtons[0] === 1) {
              SDL.events.push({
                type: 'touchmove',
                touch: {
                  identifier: 0,
                  deviceID: -1,
                  pageX: event.pageX,
                  pageY: event.pageY
                }
              });
            }
            if (Browser.pointerLock) {
              // workaround for firefox bug 750111
              if ('mozMovementX' in event) {
                event['movementX'] = event['mozMovementX'];
                event['movementY'] = event['mozMovementY'];
              }
              // workaround for Firefox bug 782777
              if (event['movementX'] == 0 && event['movementY'] == 0) {
                // ignore a mousemove event if it doesn't contain any movement info
                // (without pointer lock, we infer movement from pageX/pageY, so this check is unnecessary)
                event.preventDefault();
                return;
              }
            }
            // fall through
          case 'keydown': case 'keyup': case 'keypress': case 'mousedown': case 'mouseup': case 'DOMMouseScroll': case 'mousewheel':
            // If we preventDefault on keydown events, the subsequent keypress events
            // won't fire. However, it's fine (and in some cases necessary) to
            // preventDefault for keys that don't generate a character. Otherwise,
            // preventDefault is the right thing to do in general.
            if (event.type !== 'keydown' || (!SDL.unicode && !SDL.textInput) || (event.keyCode === 8 /* backspace */ || event.keyCode === 9 /* tab */)) {
              event.preventDefault();
            }
  
            if (event.type == 'DOMMouseScroll' || event.type == 'mousewheel') {
              var button = Browser.getMouseWheelDelta(event) > 0 ? 4 : 3;
              var event2 = {
                type: 'mousedown',
                button: button,
                pageX: event.pageX,
                pageY: event.pageY
              };
              SDL.events.push(event2);
              event = {
                type: 'mouseup',
                button: button,
                pageX: event.pageX,
                pageY: event.pageY
              };
            } else if (event.type == 'mousedown') {
              SDL.DOMButtons[event.button] = 1;
              SDL.events.push({
                type: 'touchstart',
                touch: {
                  identifier: 0,
                  deviceID: -1,
                  pageX: event.pageX,
                  pageY: event.pageY
                }
              });
            } else if (event.type == 'mouseup') {
              // ignore extra ups, can happen if we leave the canvas while pressing down, then return,
              // since we add a mouseup in that case
              if (!SDL.DOMButtons[event.button]) {
                return;
              }
  
              SDL.events.push({
                type: 'touchend',
                touch: {
                  identifier: 0,
                  deviceID: -1,
                  pageX: event.pageX,
                  pageY: event.pageY
                }
              });
              SDL.DOMButtons[event.button] = 0;
            }
  
            // We can only request fullscreen as the result of user input.
            // Due to this limitation, we toggle a boolean on keydown which
            // SDL_WM_ToggleFullScreen will check and subsequently set another
            // flag indicating for us to request fullscreen on the following
            // keyup. This isn't perfect, but it enables SDL_WM_ToggleFullScreen
            // to work as the result of a keypress (which is an extremely
            // common use case).
            if (event.type === 'keydown' || event.type === 'mousedown') {
              SDL.canRequestFullscreen = true;
            } else if (event.type === 'keyup' || event.type === 'mouseup') {
              if (SDL.isRequestingFullscreen) {
                Module['requestFullScreen'](true, true);
                SDL.isRequestingFullscreen = false;
              }
              SDL.canRequestFullscreen = false;
            }
  
            // SDL expects a unicode character to be passed to its keydown events.
            // Unfortunately, the browser APIs only provide a charCode property on
            // keypress events, so we must backfill in keydown events with their
            // subsequent keypress event's charCode.
            if (event.type === 'keypress' && SDL.savedKeydown) {
              // charCode is read-only
              SDL.savedKeydown.keypressCharCode = event.charCode;
              SDL.savedKeydown = null;
            } else if (event.type === 'keydown') {
              SDL.savedKeydown = event;
            }
  
            // Don't push keypress events unless SDL_StartTextInput has been called.
            if (event.type !== 'keypress' || SDL.textInput) {
              SDL.events.push(event);
            }
            break;
          case 'mouseout':
            // Un-press all pressed mouse buttons, because we might miss the release outside of the canvas
            for (var i = 0; i < 3; i++) {
              if (SDL.DOMButtons[i]) {
                SDL.events.push({
                  type: 'mouseup',
                  button: i,
                  pageX: event.pageX,
                  pageY: event.pageY
                });
                SDL.DOMButtons[i] = 0;
              }
            }
            event.preventDefault();
            break;
          case 'blur':
          case 'visibilitychange': {
            // Un-press all pressed keys: TODO
            for (var code in SDL.keyboardMap) {
              SDL.events.push({
                type: 'keyup',
                keyCode: SDL.keyboardMap[code]
              });
            }
            event.preventDefault();
            break;
          }
          case 'unload':
            if (Browser.mainLoop.runner) {
              SDL.events.push(event);
              // Force-run a main event loop, since otherwise this event will never be caught!
              Browser.mainLoop.runner();
            }
            return;
          case 'resize':
            SDL.events.push(event);
            // manually triggered resize event doesn't have a preventDefault member
            if (event.preventDefault) {
              event.preventDefault();
            }
            break;
        }
        if (SDL.events.length >= 10000) {
          Module.printErr('SDL event queue full, dropping events');
          SDL.events = SDL.events.slice(0, 10000);
        }
        return;
      },handleEvent:function (event) {
        if (event.handled) return;
        event.handled = true;
  
        switch (event.type) {
          case 'touchstart': case 'touchend': case 'touchmove': {
            Browser.calculateMouseEvent(event);
            break;
          }
          case 'keydown': case 'keyup': {
            var down = event.type === 'keydown';
            var code = event.keyCode;
            if (code >= 65 && code <= 90) {
              code += 32; // make lowercase for SDL
            } else {
              code = SDL.keyCodes[event.keyCode] || event.keyCode;
            }
            HEAP8[(((SDL.keyboardState)+(code))>>0)]=down;
            // TODO: lmeta, rmeta, numlock, capslock, KMOD_MODE, KMOD_RESERVED
            SDL.modState = (HEAP8[(((SDL.keyboardState)+(1248))>>0)] ? 0x0040 | 0x0080 : 0) | // KMOD_LCTRL & KMOD_RCTRL
              (HEAP8[(((SDL.keyboardState)+(1249))>>0)] ? 0x0001 | 0x0002 : 0) | // KMOD_LSHIFT & KMOD_RSHIFT
              (HEAP8[(((SDL.keyboardState)+(1250))>>0)] ? 0x0100 | 0x0200 : 0); // KMOD_LALT & KMOD_RALT
  
            if (down) {
              SDL.keyboardMap[code] = event.keyCode; // save the DOM input, which we can use to unpress it during blur
            } else {
              delete SDL.keyboardMap[code];
            }
  
            break;
          }
          case 'mousedown': case 'mouseup':
            if (event.type == 'mousedown') {
              // SDL_BUTTON(x) is defined as (1 << ((x)-1)).  SDL buttons are 1-3,
              // and DOM buttons are 0-2, so this means that the below formula is
              // correct.
              SDL.buttonState |= 1 << event.button;
            } else if (event.type == 'mouseup') {
              SDL.buttonState &= ~(1 << event.button);
            }
            // fall through
          case 'mousemove': {
            Browser.calculateMouseEvent(event);
            break;
          }
        }
      },makeCEvent:function (event, ptr) {
        if (typeof event === 'number') {
          // This is a pointer to a native C event that was SDL_PushEvent'ed
          _memcpy(ptr, event, 28); // XXX
          return;
        }
  
        SDL.handleEvent(event);
  
        switch (event.type) {
          case 'keydown': case 'keyup': {
            var down = event.type === 'keydown';
            //Module.print('Received key event: ' + event.keyCode);
            var key = event.keyCode;
            if (key >= 65 && key <= 90) {
              key += 32; // make lowercase for SDL
            } else {
              key = SDL.keyCodes[event.keyCode] || event.keyCode;
            }
            var scan;
            if (key >= 1024) {
              scan = key - 1024;
            } else {
              scan = SDL.scanCodes[key] || key;
            }
  
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP8[(((ptr)+(8))>>0)]=down ? 1 : 0;
            HEAP8[(((ptr)+(9))>>0)]=0; // TODO
            HEAP32[(((ptr)+(12))>>2)]=scan;
            HEAP32[(((ptr)+(16))>>2)]=key;
            HEAP16[(((ptr)+(20))>>1)]=SDL.modState;
            // some non-character keys (e.g. backspace and tab) won't have keypressCharCode set, fill in with the keyCode.
            HEAP32[(((ptr)+(24))>>2)]=event.keypressCharCode || key;
  
            break;
          }
          case 'keypress': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            // Not filling in windowID for now
            var cStr = intArrayFromString(String.fromCharCode(event.charCode));
            for (var i = 0; i < cStr.length; ++i) {
              HEAP8[(((ptr)+(8 + i))>>0)]=cStr[i];
            }
            break;
          }
          case 'mousedown': case 'mouseup': case 'mousemove': {
            if (event.type != 'mousemove') {
              var down = event.type === 'mousedown';
              HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP32[(((ptr)+(4))>>2)]=0;
              HEAP32[(((ptr)+(8))>>2)]=0;
              HEAP32[(((ptr)+(12))>>2)]=0;
              HEAP8[(((ptr)+(16))>>0)]=event.button+1; // DOM buttons are 0-2, SDL 1-3
              HEAP8[(((ptr)+(17))>>0)]=down ? 1 : 0;
              HEAP32[(((ptr)+(20))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(24))>>2)]=Browser.mouseY;
            } else {
              HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
              HEAP32[(((ptr)+(4))>>2)]=0;
              HEAP32[(((ptr)+(8))>>2)]=0;
              HEAP32[(((ptr)+(12))>>2)]=0;
              HEAP32[(((ptr)+(16))>>2)]=SDL.buttonState;
              HEAP32[(((ptr)+(20))>>2)]=Browser.mouseX;
              HEAP32[(((ptr)+(24))>>2)]=Browser.mouseY;
              HEAP32[(((ptr)+(28))>>2)]=Browser.mouseMovementX;
              HEAP32[(((ptr)+(32))>>2)]=Browser.mouseMovementY;
            }
            break;
          }
          case 'touchstart': case 'touchend': case 'touchmove': {
            var touch = event.touch;
            if (!Browser.touches[touch.identifier]) break;
            var w = Module['canvas'].width;
            var h = Module['canvas'].height;
            var x = Browser.touches[touch.identifier].x / w;
            var y = Browser.touches[touch.identifier].y / h;
            var lx = Browser.lastTouches[touch.identifier].x / w;
            var ly = Browser.lastTouches[touch.identifier].y / h;
            var dx = x - lx;
            var dy = y - ly;
            if (touch['deviceID'] === undefined) touch.deviceID = SDL.TOUCH_DEFAULT_ID;
            if (dx === 0 && dy === 0 && event.type === 'touchmove') return; // don't send these if nothing happened
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=_SDL_GetTicks();
            (tempI64 = [touch.deviceID>>>0,(tempDouble=touch.deviceID,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)],HEAP32[(((ptr)+(8))>>2)]=tempI64[0],HEAP32[(((ptr)+(12))>>2)]=tempI64[1]);
            (tempI64 = [touch.identifier>>>0,(tempDouble=touch.identifier,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)],HEAP32[(((ptr)+(16))>>2)]=tempI64[0],HEAP32[(((ptr)+(20))>>2)]=tempI64[1]);
            HEAPF32[(((ptr)+(24))>>2)]=x;
            HEAPF32[(((ptr)+(28))>>2)]=y;
            HEAPF32[(((ptr)+(32))>>2)]=dx;
            HEAPF32[(((ptr)+(36))>>2)]=dy;
            if (touch.force !== undefined) {
              HEAPF32[(((ptr)+(40))>>2)]=touch.force;
            } else { // No pressure data, send a digital 0/1 pressure.
              HEAPF32[(((ptr)+(40))>>2)]=event.type == "touchend" ? 0 : 1;
            }
            break;
          }
          case 'unload': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            break;
          }
          case 'resize': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP32[(((ptr)+(4))>>2)]=event.w;
            HEAP32[(((ptr)+(8))>>2)]=event.h;
            break;
          }
          case 'joystick_button_up': case 'joystick_button_down': {
            var state = event.type === 'joystick_button_up' ? 0 : 1;
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP8[(((ptr)+(4))>>0)]=event.index;
            HEAP8[(((ptr)+(5))>>0)]=event.button;
            HEAP8[(((ptr)+(6))>>0)]=state;
            break;
          }
          case 'joystick_axis_motion': {
            HEAP32[((ptr)>>2)]=SDL.DOMEventToSDLEvent[event.type];
            HEAP8[(((ptr)+(4))>>0)]=event.index;
            HEAP8[(((ptr)+(5))>>0)]=event.axis;
            HEAP32[(((ptr)+(8))>>2)]=SDL.joystickAxisValueConversion(event.value);
            break;
          }
          default: throw 'Unhandled SDL event: ' + event.type;
        }
      },estimateTextWidth:function (fontData, text) {
        var h = fontData.size;
        var fontString = h + 'px ' + fontData.name;
        var tempCtx = SDL.ttfContext;
        tempCtx.save();
        tempCtx.font = fontString;
        var ret = tempCtx.measureText(text).width | 0;
        tempCtx.restore();
        return ret;
      },allocateChannels:function (num) { // called from Mix_AllocateChannels and init
        if (SDL.numChannels && SDL.numChannels >= num && num != 0) return;
        SDL.numChannels = num;
        SDL.channels = [];
        for (var i = 0; i < num; i++) {
          SDL.channels[i] = {
            audio: null,
            volume: 1.0
          };
        }
      },setGetVolume:function (info, volume) {
        if (!info) return 0;
        var ret = info.volume * 128; // MIX_MAX_VOLUME
        if (volume != -1) {
          info.volume = volume / 128;
          if (info.audio) info.audio.volume = info.volume;
        }
        return ret;
      },fillWebAudioBufferFromHeap:function (heapPtr, sizeSamplesPerChannel, dstAudioBuffer) {
        // The input audio data is interleaved across the channels, i.e. [L, R, L, R, L, R, ...] and is either 8-bit or 16-bit as
        // supported by the SDL API. The output audio wave data for Web Audio API must be in planar buffers of [-1,1]-normalized Float32 data,
        // so perform a buffer conversion for the data.
        var numChannels = SDL.audio.channels;
        for(var c = 0; c < numChannels; ++c) {
          var channelData = dstAudioBuffer['getChannelData'](c);
          if (channelData.length != sizeSamplesPerChannel) {
            throw 'Web Audio output buffer length mismatch! Destination size: ' + channelData.length + ' samples vs expected ' + sizeSamplesPerChannel + ' samples!';
          }
          if (SDL.audio.format == 0x8010 /*AUDIO_S16LSB*/) {
            for(var j = 0; j < sizeSamplesPerChannel; ++j) {
              channelData[j] = (HEAP16[(((heapPtr)+((j*numChannels + c)*2))>>1)]) / 0x8000;
            }
          } else if (SDL.audio.format == 0x0008 /*AUDIO_U8*/) {
            for(var j = 0; j < sizeSamplesPerChannel; ++j) {
              var v = (HEAP8[(((heapPtr)+(j*numChannels + c))>>0)]);
              channelData[j] = ((v >= 0) ? v-128 : v+128) /128;
            }
          }
        }
      },debugSurface:function (surfData) {
        console.log('dumping surface ' + [surfData.surf, surfData.source, surfData.width, surfData.height]);
        var image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
        var data = image.data;
        var num = Math.min(surfData.width, surfData.height);
        for (var i = 0; i < num; i++) {
          console.log('   diagonal ' + i + ':' + [data[i*surfData.width*4 + i*4 + 0], data[i*surfData.width*4 + i*4 + 1], data[i*surfData.width*4 + i*4 + 2], data[i*surfData.width*4 + i*4 + 3]]);
        }
      },joystickEventState:1,lastJoystickState:{},joystickNamePool:{},recordJoystickState:function (joystick, state) {
        // Standardize button state.
        var buttons = new Array(state.buttons.length);
        for (var i = 0; i < state.buttons.length; i++) {
          buttons[i] = SDL.getJoystickButtonState(state.buttons[i]);
        }
  
        SDL.lastJoystickState[joystick] = {
          buttons: buttons,
          axes: state.axes.slice(0),
          timestamp: state.timestamp,
          index: state.index,
          id: state.id
        };
      },getJoystickButtonState:function (button) {
        if (typeof button === 'object') {
          // Current gamepad API editor's draft (Firefox Nightly)
          // https://dvcs.w3.org/hg/gamepad/raw-file/default/gamepad.html#idl-def-GamepadButton
          return button.pressed;
        } else {
          // Current gamepad API working draft (Firefox / Chrome Stable)
          // http://www.w3.org/TR/2012/WD-gamepad-20120529/#gamepad-interface
          return button > 0;
        }
      },queryJoysticks:function () {
        for (var joystick in SDL.lastJoystickState) {
          var state = SDL.getGamepad(joystick - 1);
          var prevState = SDL.lastJoystickState[joystick];
          // Check only if the timestamp has differed.
          // NOTE: Timestamp is not available in Firefox.
          if (typeof state.timestamp !== 'number' || state.timestamp !== prevState.timestamp) {
            var i;
            for (i = 0; i < state.buttons.length; i++) {
              var buttonState = SDL.getJoystickButtonState(state.buttons[i]);
              // NOTE: The previous state already has a boolean representation of
              //       its button, so no need to standardize its button state here.
              if (buttonState !== prevState.buttons[i]) {
                // Insert button-press event.
                SDL.events.push({
                  type: buttonState ? 'joystick_button_down' : 'joystick_button_up',
                  joystick: joystick,
                  index: joystick - 1,
                  button: i
                });
              }
            }
            for (i = 0; i < state.axes.length; i++) {
              if (state.axes[i] !== prevState.axes[i]) {
                // Insert axes-change event.
                SDL.events.push({
                  type: 'joystick_axis_motion',
                  joystick: joystick,
                  index: joystick - 1,
                  axis: i,
                  value: state.axes[i]
                });
              }
            }
  
            SDL.recordJoystickState(joystick, state);
          }
        }
      },joystickAxisValueConversion:function (value) {
        // Ensures that 0 is 0, 1 is 32767, and -1 is 32768.
        return Math.ceil(((value+1) * 32767.5) - 32768);
      },getGamepads:function () {
        var fcn = navigator.getGamepads || navigator.webkitGamepads || navigator.mozGamepads || navigator.gamepads || navigator.webkitGetGamepads;
        if (fcn !== undefined) {
          // The function must be applied on the navigator object.
          return fcn.apply(navigator);
        } else {
          return [];
        }
      },getGamepad:function (deviceIndex) {
        var gamepads = SDL.getGamepads();
        if (gamepads.length > deviceIndex && deviceIndex >= 0) {
          return gamepads[deviceIndex];
        }
        return null;
      }};function _SDL_EventState() {}

  
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      var stream = FS.getStream(fildes);
      if (stream) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }
  
  function _fileno(stream) {
      // int fileno(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fileno.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) return -1;
      return stream.fd;
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      var fd = _fileno(stream);
      _fsync(fd);
      return _close(fd);
    }

  function _SDL_CreateRGBSurfaceFrom(pixels, width, height, depth, pitch, rmask, gmask, bmask, amask) {
      // TODO: Take into account depth and pitch parameters.
  
      var surface = SDL.makeSurface(width, height, 0, false, 'CreateRGBSurfaceFrom', rmask, gmask, bmask, amask);
  
      var surfaceData = SDL.surfaces[surface];
      var surfaceImageData = surfaceData.ctx.getImageData(0, 0, width, height);
      var surfacePixelData = surfaceImageData.data;
  
      // Fill pixel data to created surface.
      // Supports SDL_PIXELFORMAT_RGBA8888 and SDL_PIXELFORMAT_RGB888
      var channels = amask ? 4 : 3; // RGBA8888 or RGB888
      for (var pixelOffset = 0; pixelOffset < width*height; pixelOffset++) {
  
        surfacePixelData[pixelOffset*4] = HEAPU8[(((pixels)+(pixelOffset*channels))>>0)]; // R
        surfacePixelData[pixelOffset*4+1] = HEAPU8[(((pixels)+(pixelOffset*channels+1))>>0)]; // G
        surfacePixelData[pixelOffset*4+2] = HEAPU8[(((pixels)+(pixelOffset*channels+2))>>0)]; // B
        surfacePixelData[pixelOffset*4+3] = amask ? HEAPU8[(((pixels)+(pixelOffset*channels+3))>>0)] : 0xff; // A
      };
      
      surfaceData.ctx.putImageData(surfaceImageData, 0, 0);
  
      return surface;
    }

  
  
  function _isspace(chr) {
      return (chr == 32) || (chr >= 9 && chr <= 13);
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[((str)>>0)])) str++;
  
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[((str)>>0)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[((str)>>0)] == 43) {
        str++;
      }
  
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[((str)>>0)] == 48) {
          if (HEAP8[((str+1)>>0)] == 120 ||
              HEAP8[((str+1)>>0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[((str)>>0)] == 48) {
          if (HEAP8[((str+1)>>0)] == 120 ||
              HEAP8[((str+1)>>0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
  
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[((str)>>0)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
  
      // Apply sign.
      ret *= multiplier;
  
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str;
      }
  
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
  
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
  
      if (bits == 64) {
        return ((asm["setTempRet0"]((tempDouble=ret,(+(Math_abs(tempDouble))) >= (+1) ? (tempDouble > (+0) ? ((Math_min((+(Math_floor((tempDouble)/(+4294967296)))), (+4294967295)))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+4294967296))))))>>>0) : 0)),ret>>>0)|0);
      }
  
      return ret;
    }function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }

  
  
  
  
  
  
  function _mkport() { throw 'TODO' }var SOCKFS={mount:function (mount) {
        return FS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
  
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
  
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 49152, 0);
        node.sock = sock;
  
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
  
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
  
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
  
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
  
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              // runtimeConfig gets set to true if WebSocket runtime configuration is available.
              var runtimeConfig = (Module['websocket'] && ('object' === typeof Module['websocket']));
  
              // The default value is 'ws://' the replace is needed because the compiler replaces "//" comments with '#'
              // comments without checking context, so we'd end up with ws:#, the replace swaps the "#" for "//" again.
              var url = 'ws:#'.replace('#', '//');
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['url']) {
                  url = Module['websocket']['url']; // Fetch runtime WebSocket URL config.
                }
              }
  
              if (url === 'ws://' || url === 'wss://') { // Is the supplied URL config just a prefix, if so complete it.
                url = url + addr + ':' + port;
              }
  
              // Make the WebSocket subprotocol (Sec-WebSocket-Protocol) default to binary if no configuration is set.
              var subProtocols = 'binary'; // The default value is 'binary'
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['subprotocol']) {
                  subProtocols = Module['websocket']['subprotocol']; // Fetch runtime WebSocket subprotocol config.
                }
              }
  
              // The regex trims the string (removes spaces at the beginning and end, then splits the string by
              // <any space>,<any space> into an Array. Whitespace removal is important for Websockify and ws.
              subProtocols = subProtocols.replace(/^ +| +$/g,"").split(/ *, */);
  
              // The node ws library API for specifying optional subprotocol is slightly different than the browser's.
              var opts = ENVIRONMENT_IS_NODE ? {'protocol': subProtocols.toString()} : subProtocols;
  
              // If node we use the ws library.
              var WebSocket = ENVIRONMENT_IS_NODE ? require('ws') : window['WebSocket'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
  
  
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
  
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
  
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
  
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
  
          var handleOpen = function () {
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
  
          function handleMessage(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
  
  
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
  
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
          };
  
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('error', function() {
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onmessage = function peer_socket_onmessage(event) {
              handleMessage(event.data);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (64 | 1) : 0;
          }
  
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
  
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (64 | 1);
          }
  
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 4;
          }
  
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
  
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 21531:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODS.EOPNOTSUPP);
          }
  
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
  
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
  
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
  
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
  
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
  
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
  
              // push to queue for accept to pick up
              sock.pending.push(newsock);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
            }
          });
          sock.server.on('closed', function() {
            sock.server = null;
          });
          sock.server.on('error', function() {
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
  
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
  
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
  
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
  
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
  
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
  
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
  
  
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
  
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var fd = _fileno(stream);
      var bytesWritten = _write(fd, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  
  
   
  Module["_strlen"] = _strlen;
  
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = (HEAP32[((tempDoublePtr)>>2)]=HEAP32[(((varargs)+(argIndex))>>2)],HEAP32[(((tempDoublePtr)+(4))>>2)]=HEAP32[(((varargs)+((argIndex)+(4)))>>2)],(+(HEAPF64[(tempDoublePtr)>>3])));
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+4))>>2)]];
  
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Runtime.getNativeFieldSize(type);
        return ret;
      }
  
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[((textIndex)>>0)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)>>0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          var flagPadSign = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              case 32:
                flagPadSign = true;
                break;
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          }
  
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)>>0)];
            }
          }
  
          // Handle precision.
          var precisionSet = false, precision = -1;
          if (next == 46) {
            precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)>>0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)>>0)];
          }
          if (precision < 0) {
            precision = 6; // Standard default.
            precisionSet = false;
          }
  
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)>>0)];
  
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
  
              // Add sign if needed
              if (currArg >= 0) {
                if (flagAlwaysSigned) {
                  prefix = '+' + prefix;
                } else if (flagPadSign) {
                  prefix = ' ' + prefix;
                }
              }
  
              // Move sign to prefix so we zero-pad after the sign
              if (argText.charAt(0) == '-') {
                prefix = '-' + prefix;
                argText = argText.substr(1);
              }
  
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
  
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
  
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
  
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
  
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
  
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
  
                // Add sign.
                if (currArg >= 0) {
                  if (flagAlwaysSigned) {
                    argText = '+' + argText;
                  } else if (flagPadSign) {
                    argText = ' ' + argText;
                  }
                }
              }
  
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
  
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
  
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)>>0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length;
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[((i)>>0)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }

  function _unlockpt() {
  Module['printErr']('missing function: unlockpt'); abort(-1);
  }


  
  var ___DEFAULT_POLLMASK=5;function _poll(fds, nfds, timeout) {
      // int poll(struct pollfd fds[], nfds_t nfds, int timeout);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/poll.html
      var nonzero = 0;
      for (var i = 0; i < nfds; i++) {
        var pollfd = fds + 8 * i;
        var fd = HEAP32[((pollfd)>>2)];
        var events = HEAP16[(((pollfd)+(4))>>1)];
        var mask = 32;
        var stream = FS.getStream(fd);
        if (stream) {
          mask = ___DEFAULT_POLLMASK;
          if (stream.stream_ops.poll) {
            mask = stream.stream_ops.poll(stream);
          }
        }
        mask &= events | 8 | 16;
        if (mask) nonzero++;
        HEAP16[(((pollfd)+(6))>>1)]=mask;
      }
      return nonzero;
    }

  function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }

  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)>>0)]=chr;
      var fd = _fileno(stream);
      var ret = _write(fd, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }

  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 30: return PAGE_SIZE;
        case 132:
        case 133:
        case 12:
        case 137:
        case 138:
        case 15:
        case 235:
        case 16:
        case 17:
        case 18:
        case 19:
        case 20:
        case 149:
        case 13:
        case 10:
        case 236:
        case 153:
        case 9:
        case 21:
        case 22:
        case 159:
        case 154:
        case 14:
        case 77:
        case 78:
        case 139:
        case 80:
        case 81:
        case 79:
        case 82:
        case 68:
        case 67:
        case 164:
        case 11:
        case 29:
        case 47:
        case 48:
        case 95:
        case 52:
        case 51:
        case 46:
          return 200809;
        case 27:
        case 246:
        case 127:
        case 128:
        case 23:
        case 24:
        case 160:
        case 161:
        case 181:
        case 182:
        case 242:
        case 183:
        case 184:
        case 243:
        case 244:
        case 245:
        case 165:
        case 178:
        case 179:
        case 49:
        case 50:
        case 168:
        case 169:
        case 175:
        case 170:
        case 171:
        case 172:
        case 97:
        case 76:
        case 32:
        case 173:
        case 35:
          return -1;
        case 176:
        case 177:
        case 7:
        case 155:
        case 8:
        case 157:
        case 125:
        case 126:
        case 92:
        case 93:
        case 129:
        case 130:
        case 131:
        case 94:
        case 91:
          return 1;
        case 74:
        case 60:
        case 69:
        case 70:
        case 4:
          return 1024;
        case 31:
        case 42:
        case 72:
          return 32;
        case 87:
        case 26:
        case 33:
          return 2147483647;
        case 34:
        case 1:
          return 47839;
        case 38:
        case 36:
          return 99;
        case 43:
        case 37:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 28: return 32768;
        case 44: return 32767;
        case 75: return 16384;
        case 39: return 1000;
        case 89: return 700;
        case 71: return 256;
        case 40: return 255;
        case 2: return 100;
        case 180: return 64;
        case 25: return 20;
        case 5: return 16;
        case 6: return 6;
        case 73: return 4;
        case 84: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }

  function _SDL_PollEvent(ptr) {
      if (SDL.initFlags & 0x200 && SDL.joystickEventState) {
        // If SDL_INIT_JOYSTICK was supplied AND the joystick system is configured
        // to automatically query for events, query for joystick events.
        SDL.queryJoysticks();
      }
      if (SDL.events.length === 0) return 0;
      if (ptr) {
        SDL.makeCEvent(SDL.events.shift(), ptr);
      }
      return 1;
    }

  function _SDL_GetVideoInfo() {
      // %struct.SDL_VideoInfo = type { i32, i32, %struct.SDL_PixelFormat*, i32, i32 } - 5 fields of quantum size
      var ret = _malloc(5*Runtime.QUANTUM_SIZE);
      HEAP32[((ret+Runtime.QUANTUM_SIZE*0)>>2)]=0; // TODO
      HEAP32[((ret+Runtime.QUANTUM_SIZE*1)>>2)]=0; // TODO
      HEAP32[((ret+Runtime.QUANTUM_SIZE*2)>>2)]=0;
      HEAP32[((ret+Runtime.QUANTUM_SIZE*3)>>2)]=Module["canvas"].width;
      HEAP32[((ret+Runtime.QUANTUM_SIZE*4)>>2)]=Module["canvas"].height;
      return ret;
    }


  
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
        var start = window['performance']['now']();
        while (window['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[((rqtp)>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(4))>>2)];
      if (rmtp !== 0) {
        HEAP32[((rmtp)>>2)]=0;
        HEAP32[(((rmtp)+(4))>>2)]=0;
      }
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }

  function _SDL_Flip(surf) {
      // We actually do this in Unlock, since the screen surface has as its canvas
      // backing the page canvas element
    }

  function _ptsname() {
  Module['printErr']('missing function: ptsname'); abort(-1);
  }

  function _SDL_GetMouseState(x, y) {
      if (x) HEAP32[((x)>>2)]=Browser.mouseX;
      if (y) HEAP32[((y)>>2)]=Browser.mouseY;
      return SDL.buttonState;
    }

  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      var fd = _fileno(stream);
      return _write(fd, s, _strlen(s));
    }

  function _tcflush() {
  Module['printErr']('missing function: tcflush'); abort(-1);
  }

  function _SDL_InitSubSystem(flags) { return 0 }


  function _SDL_GetError() {
      if (!SDL.errorMessage) {
        SDL.errorMessage = allocate(intArrayFromString("unknown SDL-emscripten error"), 'i8', ALLOC_NORMAL);
      }
      return SDL.errorMessage;
    }

  function _emscripten_cancel_main_loop() {
      Browser.mainLoop.scheduler = null;
      Browser.mainLoop.shouldPause = true;
    }

  
  function _malloc(bytes) {
      /* Over-allocate to make sure it is byte-aligned by 8.
       * This will leak memory, but this is only the dummy
       * implementation (replaced by dlmalloc normally) so
       * not an issue.
       */
      var ptr = Runtime.dynamicAlloc(bytes + 8);
      return (ptr+8) & 0xFFFFFFF8;
    }
  Module["_malloc"] = _malloc;
  
  var ___tm_current=allocate(44, "i8", ALLOC_STATIC);
  
  
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);
  
  
  var _tzname=allocate(8, "i32*", ALLOC_STATIC);
  
  var _daylight=allocate(1, "i32*", ALLOC_STATIC);
  
  var _timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
  
      HEAP32[((_timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60;
  
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((_daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset());
  
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((_tzname)>>2)]=winterNamePtr;
      HEAP32[(((_tzname)+(4))>>2)]=summerNamePtr;
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getDay();
  
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(36))>>2)]=start.getTimezoneOffset() * 60;
  
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(32))>>2)]=dst;
  
      HEAP32[(((tmPtr)+(40))>>2)]=___tm_timezone;
  
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }

   
  Module["_bitshift64Lshr"] = _bitshift64Lshr;

  
  
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)>>0)]=streamObj.ungotten.pop();
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(streamObj.fd, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return Math.floor(bytesRead / size);
    }

  
  function _SDL_Init(initFlags) {
      SDL.startTime = Date.now();
      SDL.initFlags = initFlags;
  
      // capture all key events. we just keep down and up, but also capture press to prevent default actions
      if (!Module['doNotCaptureKeyboard']) {
        document.addEventListener("keydown", SDL.receiveEvent);
        document.addEventListener("keyup", SDL.receiveEvent);
        document.addEventListener("keypress", SDL.receiveEvent);
        window.addEventListener("blur", SDL.receiveEvent);
        document.addEventListener("visibilitychange", SDL.receiveEvent);
      }
  
      if (initFlags & 0x200) {
        // SDL_INIT_JOYSTICK
        // Firefox will not give us Joystick data unless we register this NOP
        // callback.
        // https://bugzilla.mozilla.org/show_bug.cgi?id=936104
        addEventListener("gamepadconnected", function() {});
      }
  
      window.addEventListener("unload", SDL.receiveEvent);
      SDL.keyboardState = _malloc(0x10000); // Our SDL needs 512, but 64K is safe for older SDLs
      _memset(SDL.keyboardState, 0, 0x10000);
      // Initialize this structure carefully for closure
      SDL.DOMEventToSDLEvent['keydown']    = 0x300  /* SDL_KEYDOWN */;
      SDL.DOMEventToSDLEvent['keyup']      = 0x301  /* SDL_KEYUP */;
      SDL.DOMEventToSDLEvent['keypress']   = 0x303  /* SDL_TEXTINPUT */;
      SDL.DOMEventToSDLEvent['mousedown']  = 0x401  /* SDL_MOUSEBUTTONDOWN */;
      SDL.DOMEventToSDLEvent['mouseup']    = 0x402  /* SDL_MOUSEBUTTONUP */;
      SDL.DOMEventToSDLEvent['mousemove']  = 0x400  /* SDL_MOUSEMOTION */;
      SDL.DOMEventToSDLEvent['touchstart'] = 0x700  /* SDL_FINGERDOWN */;
      SDL.DOMEventToSDLEvent['touchend']   = 0x701  /* SDL_FINGERUP */;
      SDL.DOMEventToSDLEvent['touchmove']  = 0x702  /* SDL_FINGERMOTION */;
      SDL.DOMEventToSDLEvent['unload']     = 0x100  /* SDL_QUIT */;
      SDL.DOMEventToSDLEvent['resize']     = 0x7001 /* SDL_VIDEORESIZE/SDL_EVENT_COMPAT2 */;
      // These are not technically DOM events; the HTML gamepad API is poll-based.
      // However, we define them here, as the rest of the SDL code assumes that
      // all SDL events originate as DOM events.
      SDL.DOMEventToSDLEvent['joystick_axis_motion'] = 0x600 /* SDL_JOYAXISMOTION */;
      SDL.DOMEventToSDLEvent['joystick_button_down'] = 0x603 /* SDL_JOYBUTTONDOWN */;
      SDL.DOMEventToSDLEvent['joystick_button_up'] = 0x604 /* SDL_JOYBUTTONUP */;
      return 0; // success
    }function _SDL_WasInit() {
      if (SDL.startTime === null) {
        _SDL_Init();
      }
      return 1;
    }


  function _SDL_WM_ToggleFullScreen(surf) {
      if (Browser.isFullScreen) {
        Module['canvas'].cancelFullScreen();
        return 1;
      } else {
        if (!SDL.canRequestFullscreen) {
          return 0;
        }
        SDL.isRequestingFullscreen = true;
        return 1;
      }
    }

  function _gettimeofday(ptr) {
      var now = Date.now();
      HEAP32[((ptr)>>2)]=Math.floor(now/1000); // seconds
      HEAP32[(((ptr)+(4))>>2)]=Math.floor((now-1000*Math.floor(now/1000))*1000); // microseconds
      return 0;
    }

  function _vfprintf(s, f, va_arg) {
      return _fprintf(s, f, HEAP32[((va_arg)>>2)]);
    }

  function _SDL_WM_SetCaption(title, icon) {
      title = title && Pointer_stringify(title);
      icon = icon && Pointer_stringify(icon);
    }

  
  function _emscripten_memcpy_big(dest, src, num) {
      HEAPU8.set(HEAPU8.subarray(src, src+num), dest);
      return dest;
    } 
  Module["_memcpy"] = _memcpy;


  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }

   
  Module["_bitshift64Shl"] = _bitshift64Shl;

  function _signal(sig, func) {
      // TODO
      return 0;
    }

  function ___errno_location() {
      return ___errno_state;
    }

  function _SDL_LockAudio() {}

  function _SDL_OpenAudio(desired, obtained) {
      try {
        SDL.audio = {
          freq: HEAPU32[((desired)>>2)],
          format: HEAPU16[(((desired)+(4))>>1)],
          channels: HEAPU8[(((desired)+(6))>>0)],
          samples: HEAPU16[(((desired)+(8))>>1)], // Samples in the CB buffer per single sound channel.
          callback: HEAPU32[(((desired)+(16))>>2)],
          userdata: HEAPU32[(((desired)+(20))>>2)],
          paused: true,
          timer: null
        };
        // The .silence field tells the constant sample value that corresponds to the safe un-skewed silence value for the wave data.
        if (SDL.audio.format == 0x0008 /*AUDIO_U8*/) {
          SDL.audio.silence = 128; // Audio ranges in [0, 255], so silence is half-way in between.
        } else if (SDL.audio.format == 0x8010 /*AUDIO_S16LSB*/) {
          SDL.audio.silence = 0; // Signed data in range [-32768, 32767], silence is 0.
        } else {
          throw 'Invalid SDL audio format ' + SDL.audio.format + '!';
        }
        // Round the desired audio frequency up to the next 'common' frequency value.
        // Web Audio API spec states 'An implementation must support sample-rates in at least the range 22050 to 96000.'
        if (SDL.audio.freq <= 0) {
          throw 'Unsupported sound frequency ' + SDL.audio.freq + '!';
        } else if (SDL.audio.freq <= 22050) {
          SDL.audio.freq = 22050; // Take it safe and clamp everything lower than 22kHz to that.
        } else if (SDL.audio.freq <= 32000) {
          SDL.audio.freq = 32000;
        } else if (SDL.audio.freq <= 44100) {
          SDL.audio.freq = 44100;
        } else if (SDL.audio.freq <= 48000) {
          SDL.audio.freq = 48000;
        } else if (SDL.audio.freq <= 96000) {
          SDL.audio.freq = 96000;
        } else {
          throw 'Unsupported sound frequency ' + SDL.audio.freq + '!';
        }
        if (SDL.audio.channels == 0) {
          SDL.audio.channels = 1; // In SDL both 0 and 1 mean mono.
        } else if (SDL.audio.channels < 0 || SDL.audio.channels > 32) {
          throw 'Unsupported number of audio channels for SDL audio: ' + SDL.audio.channels + '!';
        } else if (SDL.audio.channels != 1 && SDL.audio.channels != 2) { // Unsure what SDL audio spec supports. Web Audio spec supports up to 32 channels.
          console.log('Warning: Using untested number of audio channels ' + SDL.audio.channels);
        }
        if (SDL.audio.samples < 128 || SDL.audio.samples > 524288 /* arbitrary cap */) {
          throw 'Unsupported audio callback buffer size ' + SDL.audio.samples + '!';
        } else if ((SDL.audio.samples & (SDL.audio.samples-1)) != 0) {
          throw 'Audio callback buffer size ' + SDL.audio.samples + ' must be a power-of-two!';
        }
        
        var totalSamples = SDL.audio.samples*SDL.audio.channels;
        SDL.audio.bytesPerSample = (SDL.audio.format == 0x0008 /*AUDIO_U8*/ || SDL.audio.format == 0x8008 /*AUDIO_S8*/) ? 1 : 2;
        SDL.audio.bufferSize = totalSamples*SDL.audio.bytesPerSample;
        SDL.audio.buffer = _malloc(SDL.audio.bufferSize);
        
        // To account for jittering in frametimes, always have multiple audio buffers queued up for the audio output device.
        // This helps that we won't starve that easily if a frame takes long to complete.
        SDL.audio.numSimultaneouslyQueuedBuffers = Module['SDL_numSimultaneouslyQueuedBuffers'] || 3;
        
        // Create a callback function that will be routinely called to ask more audio data from the user application.
        SDL.audio.caller = function SDL_audio_caller() {
          if (!SDL.audio) {
            return;
          }
          Runtime.dynCall('viii', SDL.audio.callback, [SDL.audio.userdata, SDL.audio.buffer, SDL.audio.bufferSize]);
          SDL.audio.pushAudio(SDL.audio.buffer, SDL.audio.bufferSize);
        };
        
        SDL.audio.audioOutput = new Audio();
        // As a workaround use Mozilla Audio Data API on Firefox until it ships with Web Audio and sound quality issues are fixed.
        if (typeof(SDL.audio.audioOutput['mozSetup'])==='function') {
          SDL.audio.audioOutput['mozSetup'](SDL.audio.channels, SDL.audio.freq); // use string attributes on mozOutput for closure compiler
          SDL.audio.mozBuffer = new Float32Array(totalSamples);
          SDL.audio.nextPlayTime = 0;
          SDL.audio.pushAudio = function SDL_audio_pushAudio(ptr, size) {
            --SDL.audio.numAudioTimersPending;
            var mozBuffer = SDL.audio.mozBuffer;
            // The input audio data for SDL audio is either 8-bit or 16-bit interleaved across channels, output for Mozilla Audio Data API
            // needs to be Float32 interleaved, so perform a sample conversion.
            if (SDL.audio.format == 0x8010 /*AUDIO_S16LSB*/) {
              for (var i = 0; i < totalSamples; i++) {
                mozBuffer[i] = (HEAP16[(((ptr)+(i*2))>>1)]) / 0x8000;
              }
            } else if (SDL.audio.format == 0x0008 /*AUDIO_U8*/) {
              for (var i = 0; i < totalSamples; i++) {
                var v = (HEAP8[(((ptr)+(i))>>0)]);
                mozBuffer[i] = ((v >= 0) ? v-128 : v+128) /128;
              }
            }
            // Submit the audio data to audio device.
            SDL.audio.audioOutput['mozWriteAudio'](mozBuffer);
            
            // Compute when the next audio callback should be called.
            var curtime = Date.now() / 1000.0 - SDL.audio.startTime;
            var playtime = Math.max(curtime, SDL.audio.nextPlayTime);
            var buffer_duration = SDL.audio.samples / SDL.audio.freq;
            SDL.audio.nextPlayTime = playtime + buffer_duration;
            // Schedule the next audio callback call to occur when the current one finishes.
            SDL.audio.timer = Browser.safeSetTimeout(SDL.audio.caller, 1000.0 * (playtime-curtime));
            ++SDL.audio.numAudioTimersPending;
            // And also schedule extra buffers _now_ if we have too few in queue.
            if (SDL.audio.numAudioTimersPending < SDL.audio.numSimultaneouslyQueuedBuffers) {
              ++SDL.audio.numAudioTimersPending;
              Browser.safeSetTimeout(SDL.audio.caller, 1.0);
            }
          }
        } else {
          // Initialize Web Audio API if we haven't done so yet. Note: Only initialize Web Audio context ever once on the web page,
          // since initializing multiple times fails on Chrome saying 'audio resources have been exhausted'.
          if (!SDL.audioContext) {
            if (typeof(AudioContext) !== 'undefined') {
              SDL.audioContext = new AudioContext();
            } else if (typeof(webkitAudioContext) !== 'undefined') {
              SDL.audioContext = new webkitAudioContext();
            } else {
              throw 'Web Audio API is not available!';
            }
          }
          SDL.audio.soundSource = new Array(); // Use an array of sound sources as a ring buffer to queue blocks of synthesized audio to Web Audio API.
          SDL.audio.nextSoundSource = 0; // Index of the next sound buffer in the ring buffer queue to play.
          SDL.audio.nextPlayTime = 0; // Time in seconds when the next audio block is due to start.
          
          // The pushAudio function with a new audio buffer whenever there is new audio data to schedule to be played back on the device.
          SDL.audio.pushAudio=function(ptr,sizeBytes) {
            try {
              --SDL.audio.numAudioTimersPending;
              if (SDL.audio.paused) return;
  
              var sizeSamples = sizeBytes / SDL.audio.bytesPerSample; // How many samples fit in the callback buffer?
              var sizeSamplesPerChannel = sizeSamples / SDL.audio.channels; // How many samples per a single channel fit in the cb buffer?
              if (sizeSamplesPerChannel != SDL.audio.samples) {
                throw 'Received mismatching audio buffer size!';
              }
              // Allocate new sound buffer to be played.
              var source = SDL.audioContext['createBufferSource']();
              if (SDL.audio.soundSource[SDL.audio.nextSoundSource]) {
                SDL.audio.soundSource[SDL.audio.nextSoundSource]['disconnect'](); // Explicitly disconnect old source, since we know it shouldn't be running anymore.
              }
              SDL.audio.soundSource[SDL.audio.nextSoundSource] = source;
              var soundBuffer = SDL.audioContext['createBuffer'](SDL.audio.channels,sizeSamplesPerChannel,SDL.audio.freq);
              SDL.audio.soundSource[SDL.audio.nextSoundSource]['connect'](SDL.audioContext['destination']);
  
              SDL.fillWebAudioBufferFromHeap(ptr, sizeSamplesPerChannel, soundBuffer);
              // Workaround https://bugzilla.mozilla.org/show_bug.cgi?id=883675 by setting the buffer only after filling. The order is important here!
              source['buffer'] = soundBuffer;
              
              // Schedule the generated sample buffer to be played out at the correct time right after the previously scheduled
              // sample buffer has finished.
              var curtime = SDL.audioContext['currentTime'];
              var playtime = Math.max(curtime, SDL.audio.nextPlayTime);
              var ss = SDL.audio.soundSource[SDL.audio.nextSoundSource];
              if (typeof ss['start'] !== 'undefined') {
                ss['start'](playtime);
              } else if (typeof ss['noteOn'] !== 'undefined') {
                ss['noteOn'](playtime);
              }
              var buffer_duration = sizeSamplesPerChannel / SDL.audio.freq;
              SDL.audio.nextPlayTime = playtime + buffer_duration;
              // Timer will be scheduled before the buffer completed playing.
              // Extra buffers are needed to avoid disturbing playing buffer.
              SDL.audio.nextSoundSource = (SDL.audio.nextSoundSource + 1) % (SDL.audio.numSimultaneouslyQueuedBuffers + 2);
              var secsUntilNextCall = playtime-curtime;
              
              // Queue the next audio frame push to be performed when the previously queued buffer has finished playing.
              var preemptBufferFeedMSecs = 1000*buffer_duration/2.0;
              SDL.audio.timer = Browser.safeSetTimeout(SDL.audio.caller, Math.max(0.0, 1000.0*secsUntilNextCall-preemptBufferFeedMSecs));
              ++SDL.audio.numAudioTimersPending;
  
              // If we are risking starving, immediately queue extra buffers.
              if (SDL.audio.numAudioTimersPending < SDL.audio.numSimultaneouslyQueuedBuffers) {
                ++SDL.audio.numAudioTimersPending;
                Browser.safeSetTimeout(SDL.audio.caller, 1.0);
              }
            } catch(e) {
              console.log('Web Audio API error playing back audio: ' + e.toString());
            }
          }
        }
  
        if (obtained) {
          // Report back the initialized audio parameters.
          HEAP32[((obtained)>>2)]=SDL.audio.freq;
          HEAP16[(((obtained)+(4))>>1)]=SDL.audio.format;
          HEAP8[(((obtained)+(6))>>0)]=SDL.audio.channels;
          HEAP8[(((obtained)+(7))>>0)]=SDL.audio.silence;
          HEAP16[(((obtained)+(8))>>1)]=SDL.audio.samples;
          HEAP32[(((obtained)+(16))>>2)]=SDL.audio.callback;
          HEAP32[(((obtained)+(20))>>2)]=SDL.audio.userdata;
        }
        SDL.allocateChannels(32);
  
      } catch(e) {
        console.log('Initializing SDL audio threw an exception: "' + e.toString() + '"! Continuing without audio.');
        SDL.audio = null;
        SDL.allocateChannels(0);
        if (obtained) {
          HEAP32[((obtained)>>2)]=0;
          HEAP16[(((obtained)+(4))>>1)]=0;
          HEAP8[(((obtained)+(6))>>0)]=0;
          HEAP8[(((obtained)+(7))>>0)]=0;
          HEAP16[(((obtained)+(8))>>1)]=0;
          HEAP32[(((obtained)+(16))>>2)]=0;
          HEAP32[(((obtained)+(20))>>2)]=0;
        }
      }
      if (!SDL.audio) {
        return -1;
      }
      return 0;
    }

  function _SDL_UnlockAudio() {}

  function _SDL_EnableKeyRepeat(delay, interval) {
      // TODO
    }

  function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)>>0)];
      }
    }

  function _SDL_PauseAudio(pauseOn) {
      if (!SDL.audio) {
        return;
      }
      if (pauseOn) {
        if (SDL.audio.timer !== undefined) {
          clearTimeout(SDL.audio.timer);
          SDL.audio.numAudioTimersPending = 0;
          SDL.audio.timer = undefined;
        }
        if (SDL.audio.scriptProcessorNode !== undefined) {
          SDL.audio.scriptProcessorNode['disconnect']();
          SDL.audio.scriptProcessorNode = undefined;
        }
      } else if (!SDL.audio.timer && !SDL.audio.scriptProcessorNode) {
        // If we are using the same sampling frequency as the native sampling rate of the Web Audio graph is using, we can feed our buffers via
        // Web Audio ScriptProcessorNode, which is a pull-mode API that calls back to our code to get audio data.
        if (SDL.audioContext !== undefined && SDL.audio.freq == SDL.audioContext['sampleRate'] && typeof SDL.audioContext['createScriptProcessor'] !== 'undefined') {
          var sizeSamplesPerChannel = SDL.audio.bufferSize / SDL.audio.bytesPerSample / SDL.audio.channels; // How many samples per a single channel fit in the cb buffer?
          SDL.audio.scriptProcessorNode = SDL.audioContext['createScriptProcessor'](sizeSamplesPerChannel, 0, SDL.audio.channels);
          SDL.audio.scriptProcessorNode['onaudioprocess'] = function (e) {
            Runtime.dynCall('viii', SDL.audio.callback, [SDL.audio.userdata, SDL.audio.buffer, SDL.audio.bufferSize]);
            SDL.fillWebAudioBufferFromHeap(SDL.audio.buffer, sizeSamplesPerChannel, e['outputBuffer']);
          }
          SDL.audio.scriptProcessorNode['connect'](SDL.audioContext['destination']);
        } else { // If we are using a different sampling rate, must manually queue audio data to the graph via timers.
          // Start the audio playback timer callback loop.
          SDL.audio.numAudioTimersPending = 1;
          SDL.audio.timer = Browser.safeSetTimeout(SDL.audio.caller, 1);
          SDL.audio.startTime = Date.now() / 1000.0; // Only used for Mozilla Audio Data API. Not needed for Web Audio API.
        }
      }
      SDL.audio.paused = pauseOn;
    }

   
  Module["_memset"] = _memset;

   
  Module["_strcat"] = _strcat;

  function _atexit(func, arg) {
      __ATEXIT__.unshift({ func: func, arg: arg });
    }

  function _abort() {
      Module['abort']();
    }


  
  function _free() {
  }
  Module["_free"] = _free;function _SDL_CloseAudio() {
      if (SDL.audio) {
        try{
          for(var i = 0; i < SDL.audio.soundSource.length; ++i) {
            if (!(typeof(SDL.audio.soundSource[i]==='undefined'))) {
              SDL.audio.soundSource[i].stop(0);
            }
          }
        } catch(e) {}
        SDL.audio.soundSource = null;
        _SDL_PauseAudio(1);
        _free(SDL.audio.buffer);
        SDL.audio = null;
        SDL.allocateChannels(0);
      }
    }


  var _tan=Math_tan;


  function _SDL_SetVideoMode(width, height, depth, flags) {
      ['touchstart', 'touchend', 'touchmove', 'mousedown', 'mouseup', 'mousemove', 'DOMMouseScroll', 'mousewheel', 'mouseout'].forEach(function(event) {
        Module['canvas'].addEventListener(event, SDL.receiveEvent, true);
      });
  
      // (0,0) means 'use fullscreen' in native; in Emscripten, use the current canvas size.
      if (width == 0 && height == 0) {
        var canvas = Module['canvas'];
        width = canvas.width;
        height = canvas.height;
      }
  
      Browser.setCanvasSize(width, height, true);
      // Free the old surface first.
      if (SDL.screen) {
        SDL.freeSurface(SDL.screen);
        assert(!SDL.screen);
      }
      SDL.screen = SDL.makeSurface(width, height, flags, true, 'screen');
      if (!SDL.addedResizeListener) {
        SDL.addedResizeListener = true;
        Browser.resizeListeners.push(function(w, h) {
          SDL.receiveEvent({
            type: 'resize',
            w: w,
            h: h
          });
        });
      }
      return SDL.screen;
    }

  function _tcsetattr(fildes, optional_actions, termios_p) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/tcsetattr.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (!stream.tty) {
        ___setErrNo(ERRNO_CODES.ENOTTY);
        return -1;
      }
      return 0;
    }

  function _tcgetattr(fildes, termios_p) {
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/tcgetattr.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (!stream.tty) {
        ___setErrNo(ERRNO_CODES.ENOTTY);
        return -1;
      }
      return 0;
    }

  function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 512;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 1024;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var fd = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return fd === -1 ? 0 : FS.getPtrForStream(FS.getStream(fd));
    }

  function _posix_openpt() {
  Module['printErr']('missing function: posix_openpt'); abort(-1);
  }

  
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        return FS.llseek(stream, offset, whence);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var fd = _fileno(stream);
      var ret = _lseek(fd, offset, whence);
      if (ret == -1) {
        return -1;
      }
      stream = FS.getStreamFromPtr(stream);
      stream.eof = false;
      return 0;
    }


  function _grantpt() {
  Module['printErr']('missing function: grantpt'); abort(-1);
  }

  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (FS.isChrdev(stream.node.mode)) {
        ___setErrNo(ERRNO_CODES.ESPIPE);
        return -1;
      } else {
        return stream.position;
      }
    }

  
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }

  
  function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))>>0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))>>0)]=0;
      return result.length;
    }function _sprintf(s, format, varargs) {
      // int sprintf(char *restrict s, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      return _snprintf(s, undefined, format, varargs);
    }

  function _fcntl(fildes, cmd, varargs, dup2) {
      // int fcntl(int fildes, int cmd, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/fcntl.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      switch (cmd) {
        case 0:
          var arg = HEAP32[((varargs)>>2)];
          if (arg < 0) {
            ___setErrNo(ERRNO_CODES.EINVAL);
            return -1;
          }
          var newStream;
          try {
            newStream = FS.open(stream.path, stream.flags, 0, arg);
          } catch (e) {
            FS.handleFSError(e);
            return -1;
          }
          return newStream.fd;
        case 1:
        case 2:
          return 0;  // FD_CLOEXEC makes no sense for a single process.
        case 3:
          return stream.flags;
        case 4:
          var arg = HEAP32[((varargs)>>2)];
          stream.flags |= arg;
          return 0;
        case 12:
        case 12:
          var arg = HEAP32[((varargs)>>2)];
          var offset = 0;
          // We're always unlocked.
          HEAP16[(((arg)+(offset))>>1)]=2;
          return 0;
        case 13:
        case 14:
        case 13:
        case 14:
          // Pretend that the locking is successful.
          return 0;
        case 8:
        case 9:
          // These are for sockets. We don't have them fully implemented yet.
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        default:
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
      }
      // Should never be reached. Only to silence strict warnings.
      return -1;
    }

   
  Module["_tolower"] = _tolower;

  function _SDL_ShowCursor(toggle) {
      switch (toggle) {
        case 0: // SDL_DISABLE
          if (Browser.isFullScreen) { // only try to lock the pointer when in full screen mode
            Module['canvas'].requestPointerLock();
            return 0;
          } else { // else return SDL_ENABLE to indicate the failure
            return 1;
          }
          break;
        case 1: // SDL_ENABLE
          Module['canvas'].exitPointerLock();
          return 1;
          break;
        case -1: // SDL_QUERY
          return !Browser.pointerLock;
          break;
        default:
          console.log( "SDL_ShowCursor called with unknown toggle parameter value: " + toggle + "." );
          break;
      }
    }

  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop, arg) {
      Module['noExitRuntime'] = true;
  
      assert(!Browser.mainLoop.scheduler, 'there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one, if you want to');
  
      Browser.mainLoop.runner = function Browser_mainLoop_runner() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from non-main loop sources
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
  
        // Signal GL rendering layer that processing of a new frame is about to start. This helps it optimize
        // VBO double-buffering and reduce GPU stalls.
  
        if (Browser.mainLoop.method === 'timeout' && Module.ctx) {
          Module.printErr('Looks like you are rendering without using requestAnimationFrame for the main loop. You should use 0 for the frame rate in emscripten_set_main_loop in order to use requestAnimationFrame, as that can greatly improve your frame rates!');
          Browser.mainLoop.method = ''; // just warn once per call to set main loop
        }
  
        if (Module['preMainLoop']) {
          Module['preMainLoop']();
        }
  
        try {
          if (typeof arg !== 'undefined') {
            Runtime.dynCall('vi', func, [arg]);
          } else {
            Runtime.dynCall('v', func);
          }
        } catch (e) {
          if (e instanceof ExitStatus) {
            return;
          } else {
            if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
            throw e;
          }
        }
  
        if (Module['postMainLoop']) {
          Module['postMainLoop']();
        }
  
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from the main loop itself
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        Browser.mainLoop.scheduler();
      }
      if (fps && fps > 0) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          setTimeout(Browser.mainLoop.runner, 1000/fps); // doing this each time means that on exception, we stop
        };
        Browser.mainLoop.method = 'timeout';
      } else {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        };
        Browser.mainLoop.method = 'rAF';
      }
      Browser.mainLoop.scheduler();
  
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }

  
  function _gmtime_r(time, tmPtr) {
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getUTCSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getUTCMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getUTCHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getUTCDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getUTCMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getUTCFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getUTCDay();
      HEAP32[(((tmPtr)+(36))>>2)]=0;
      HEAP32[(((tmPtr)+(32))>>2)]=0;
      var start = new Date(date); // define date using UTC, start from Jan 01 00:00:00 UTC
      start.setUTCDate(1);
      start.setUTCMonth(0);
      start.setUTCHours(0);
      start.setUTCMinutes(0);
      start.setUTCSeconds(0);
      start.setUTCMilliseconds(0);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(40))>>2)]=___tm_timezone;
  
      return tmPtr;
    }function _gmtime(time) {
      return _gmtime_r(time, ___tm_current);
    }

  function _symlink(path1, path2) {
      // int symlink(const char *path1, const char *path2);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/symlink.html
      path1 = Pointer_stringify(path1);
      path2 = Pointer_stringify(path2);
      try {
        FS.symlink(path1, path2);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  
  function _truncate(path, length) {
      // int truncate(const char *path, off_t length);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/truncate.html
      // NOTE: The path argument may be a string, to simplify ftruncate().
      if (typeof path !== 'string') path = Pointer_stringify(path);
      try {
        FS.truncate(path, length);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _ftruncate(fildes, length) {
      // int ftruncate(int fildes, off_t length);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftruncate.html
      try {
        FS.ftruncate(fildes, length);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = Pointer_stringify(path);
      try {
        FS.unlink(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }


  
  function _SDL_LockSurface(surf) {
      var surfData = SDL.surfaces[surf];
  
      surfData.locked++;
      if (surfData.locked > 1) return 0;
  
      if (!surfData.buffer) {
        surfData.buffer = _malloc(surfData.width * surfData.height * 4);
        HEAP32[(((surf)+(20))>>2)]=surfData.buffer;
      }
  
      // Mark in C/C++-accessible SDL structure
      // SDL_Surface has the following fields: Uint32 flags, SDL_PixelFormat *format; int w, h; Uint16 pitch; void *pixels; ...
      // So we have fields all of the same size, and 5 of them before us.
      // TODO: Use macros like in library.js
      HEAP32[(((surf)+(20))>>2)]=surfData.buffer;
  
      if (surf == SDL.screen && Module.screenIsReadOnly && surfData.image) return 0;
  
      surfData.image = surfData.ctx.getImageData(0, 0, surfData.width, surfData.height);
      if (surf == SDL.screen) {
        var data = surfData.image.data;
        var num = data.length;
        for (var i = 0; i < num/4; i++) {
          data[i*4+3] = 255; // opacity, as canvases blend alpha
        }
      }
  
      if (SDL.defaults.copyOnLock) {
        // Copy pixel data to somewhere accessible to 'C/C++'
        if (surfData.isFlagSet(0x00200000 /* SDL_HWPALETTE */)) {
          // If this is neaded then
          // we should compact the data from 32bpp to 8bpp index.
          // I think best way to implement this is use
          // additional colorMap hash (color->index).
          // Something like this:
          //
          // var size = surfData.width * surfData.height;
          // var data = '';
          // for (var i = 0; i<size; i++) {
          //   var color = SDL.translateRGBAToColor(
          //     surfData.image.data[i*4   ], 
          //     surfData.image.data[i*4 +1], 
          //     surfData.image.data[i*4 +2], 
          //     255);
          //   var index = surfData.colorMap[color];
          //   HEAP8[(((surfData.buffer)+(i))>>0)]=index;
          // }
          throw 'CopyOnLock is not supported for SDL_LockSurface with SDL_HWPALETTE flag set' + new Error().stack;
        } else {
        HEAPU8.set(surfData.image.data, surfData.buffer);
        }
      }
  
      return 0;
    }function _SDL_UpperBlit(src, srcrect, dst, dstrect) {
      var srcData = SDL.surfaces[src];
      var dstData = SDL.surfaces[dst];
      var sr, dr;
      if (srcrect) {
        sr = SDL.loadRect(srcrect);
      } else {
        sr = { x: 0, y: 0, w: srcData.width, h: srcData.height };
      }
      if (dstrect) {
        dr = SDL.loadRect(dstrect);
      } else {
        dr = { x: 0, y: 0, w: -1, h: -1 };
      }
      var oldAlpha = dstData.ctx.globalAlpha;
      dstData.ctx.globalAlpha = srcData.alpha/255;
      dstData.ctx.drawImage(srcData.canvas, sr.x, sr.y, sr.w, sr.h, dr.x, dr.y, sr.w, sr.h);
      dstData.ctx.globalAlpha = oldAlpha;
      if (dst != SDL.screen) {
        // XXX As in IMG_Load, for compatibility we write out |pixels|
        Runtime.warnOnce('WARNING: copying canvas data to memory for compatibility');
        _SDL_LockSurface(dst);
        dstData.locked--; // The surface is not actually locked in this hack
      }
      return 0;
    }

   
  Module["_strcpy"] = _strcpy;

  function _SDL_FreeSurface(surf) {
      if (surf) SDL.freeSurface(surf);
    }

  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret;
      }
      return ret;
    }

  function _SDL_WM_GrabInput() {}



FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
if (ENVIRONMENT_IS_NODE) { var fs = require("fs"); NODEFS.staticInit(); }
Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function Module_pauseMainLoop() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function Module_resumeMainLoop() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function Module_getUserMedia() { Browser.getUserMedia() }
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);

staticSealed = true; // seal the static portion of memory

STACK_MAX = STACK_BASE + 5242880;

DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);

assert(DYNAMIC_BASE < TOTAL_MEMORY, "TOTAL_MEMORY not big enough for stack");

 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);

var Math_min = Math.min;
function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiiii(index,a1,a2,a3,a4,a5) {
  try {
    return Module["dynCall_iiiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm=(function(global,env,buffer){"use asm";var a=new global.Int8Array(buffer);var b=new global.Int16Array(buffer);var c=new global.Int32Array(buffer);var d=new global.Uint8Array(buffer);var e=new global.Uint16Array(buffer);var f=new global.Uint32Array(buffer);var g=new global.Float32Array(buffer);var h=new global.Float64Array(buffer);var i=env.STACKTOP|0;var j=env.STACK_MAX|0;var k=env.tempDoublePtr|0;var l=env.ABORT|0;var m=env.cttz_i8|0;var n=env.ctlz_i8|0;var o=env._stderr|0;var p=env._stdin|0;var q=env._stdout|0;var r=0;var s=0;var t=0;var u=0;var v=+env.NaN,w=+env.Infinity;var x=0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0.0;var G=0;var H=0;var I=0;var J=0;var K=0;var L=0;var M=0;var N=0;var O=0;var P=0;var Q=global.Math.floor;var R=global.Math.abs;var S=global.Math.sqrt;var T=global.Math.pow;var U=global.Math.cos;var V=global.Math.sin;var W=global.Math.tan;var X=global.Math.acos;var Y=global.Math.asin;var Z=global.Math.atan;var _=global.Math.atan2;var $=global.Math.exp;var aa=global.Math.log;var ba=global.Math.ceil;var ca=global.Math.imul;var da=env.abort;var ea=env.assert;var fa=env.asmPrintInt;var ga=env.asmPrintFloat;var ha=env.min;var ia=env.invoke_iiii;var ja=env.invoke_viiiii;var ka=env.invoke_vi;var la=env.invoke_vii;var ma=env.invoke_ii;var na=env.invoke_viii;var oa=env.invoke_v;var pa=env.invoke_iiiii;var qa=env.invoke_iii;var ra=env.invoke_iiiiii;var sa=env.invoke_viiii;var ta=env._fread;var ua=env._SDL_PauseAudio;var va=env._atexit;var wa=env._truncate;var xa=env._fsync;var ya=env._SDL_GetError;var za=env._signal;var Aa=env._sbrk;var Ba=env._SDL_OpenAudio;var Ca=env._SDL_FreeSurface;var Da=env._emscripten_memcpy_big;var Ea=env._tcgetattr;var Fa=env._sysconf;var Ga=env._close;var Ha=env._SDL_InitSubSystem;var Ia=env._posix_openpt;var Ja=env._puts;var Ka=env._write;var La=env._ftell;var Ma=env._gmtime_r;var Na=env._SDL_WM_SetCaption;var Oa=env._SDL_WasInit;var Pa=env._send;var Qa=env._SDL_CreateRGBSurfaceFrom;var Ra=env._SDL_GetTicks;var Sa=env._fcntl;var Ta=env._SDL_LockAudio;var Ua=env._SDL_LockSurface;var Va=env._strtol;var Wa=env.___setErrNo;var Xa=env._grantpt;var Ya=env._unlink;var Za=env._nanosleep;var _a=env._gmtime;var $a=env._printf;var ab=env._sprintf;var bb=env._poll;var cb=env._localtime;var db=env._read;var eb=env._SDL_SetVideoMode;var fb=env._fwrite;var gb=env._time;var hb=env._fprintf;var ib=env._gettimeofday;var jb=env._ptsname;var kb=env._exit;var lb=env._SDL_ShowCursor;var mb=env._lseek;var nb=env._vfprintf;var ob=env._pwrite;var pb=env._unlockpt;var qb=env._localtime_r;var rb=env._tzset;var sb=env._open;var tb=env._SDL_Init;var ub=env._SDL_WM_GrabInput;var vb=env._snprintf;var wb=env._ftruncate;var xb=env._fseek;var yb=env._SDL_GetMouseState;var zb=env._fclose;var Ab=env.__parseInt;var Bb=env._recv;var Cb=env._tan;var Db=env._symlink;var Eb=env._abort;var Fb=env._SDL_Flip;var Gb=env._isspace;var Hb=env._strtoul;var Ib=env._fopen;var Jb=env._SDL_UnlockAudio;var Kb=env._tcflush;var Lb=env._SDL_CloseAudio;var Mb=env._usleep;var Nb=env._fflush;var Ob=env._SDL_GetVideoInfo;var Pb=env.__reallyNegative;var Qb=env._SDL_PollEvent;var Rb=env._fileno;var Sb=env.__exit;var Tb=env._tcsetattr;var Ub=env._fputs;var Vb=env._SDL_EventState;var Wb=env._pread;var Xb=env._mkport;var Yb=env._emscripten_set_main_loop;var Zb=env.___errno_location;var _b=env._fgetc;var $b=env._fputc;var ac=env._emscripten_cancel_main_loop;var bc=env.__formatString;var cc=env._SDL_WM_ToggleFullScreen;var dc=env._SDL_UpperBlit;var ec=env._SDL_EnableKeyRepeat;var fc=0.0;
// EMSCRIPTEN_START_FUNCS
function Vg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37464>>0]|0;a[h+1>>0]=a[37465>>0]|0;a[h+2>>0]=a[37466>>0]|0;a[h+3>>0]=a[37467>>0]|0;a[h+4>>0]=a[37468>>0]|0;c[b+28>>2]=2;h=d[e+3>>0]|0;c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35352,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;kj(b,b+160|0,e,a[e+1>>0]&63,8);i=f;return}function Wg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37456>>0]|0;a[h+1>>0]=a[37457>>0]|0;a[h+2>>0]=a[37458>>0]|0;a[h+3>>0]=a[37459>>0]|0;a[h+4>>0]=a[37460>>0]|0;c[b+28>>2]=2;h=d[e+3>>0]|0;c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35352,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;kj(b,b+160|0,e,a[e+1>>0]&63,8);i=f;return}function Xg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37448>>0]|0;a[h+1>>0]=a[37449>>0]|0;a[h+2>>0]=a[37450>>0]|0;a[h+3>>0]=a[37451>>0]|0;a[h+4>>0]=a[37452>>0]|0;c[b+28>>2]=2;h=d[e+3>>0]|0;c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35352,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;kj(b,b+160|0,e,a[e+1>>0]&63,8);i=f;return}function Yg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37440>>0]|0;a[h+1>>0]=a[37441>>0]|0;a[h+2>>0]=a[37442>>0]|0;a[h+3>>0]=a[37443>>0]|0;a[h+4>>0]=a[37444>>0]|0;c[b+28>>2]=2;h=d[e+3>>0]|0;c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35352,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;kj(b,b+160|0,e,a[e+1>>0]&63,8);i=f;return}function Zg(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+16|0;h=g;j=(b[e+12>>1]&63)==60;k=e+32|0;a[k+0>>0]=a[37432>>0]|0;a[k+1>>0]=a[37433>>0]|0;a[k+2>>0]=a[37434>>0]|0;a[k+3>>0]=a[37435>>0]|0;a[k+4>>0]=a[37436>>0]|0;a[k+5>>0]=a[37437>>0]|0;a[k+6>>0]=a[37438>>0]|0;c[e+28>>2]=2;k=d[f+3>>0]|0;c[h>>2]=35704;c[h+4>>2]=k;ab(e+96|0,35352,h|0)|0;h=e+8|0;c[h>>2]=(c[h>>2]|0)+1;h=e+160|0;if(j){a[h>>0]=5391171;a[h+1>>0]=21059;a[h+2>>0]=82;a[h+3>>0]=0;i=g;return}else{kj(e,h,f,a[f+1>>0]&63,8);i=g;return}}function _g(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+16|0;h=g;j=(b[e+12>>1]&63)==60;k=e+32|0;a[k+0>>0]=a[37424>>0]|0;a[k+1>>0]=a[37425>>0]|0;a[k+2>>0]=a[37426>>0]|0;a[k+3>>0]=a[37427>>0]|0;a[k+4>>0]=a[37428>>0]|0;a[k+5>>0]=a[37429>>0]|0;a[k+6>>0]=a[37430>>0]|0;c[e+28>>2]=2;k=(d[f+2>>0]|0)<<8|(d[f+3>>0]|0);c[h>>2]=35704;c[h+4>>2]=k;ab(e+96|0,35256,h|0)|0;h=e+8|0;c[h>>2]=(c[h>>2]|0)+1;h=e+160|0;if(j){a[h+0>>0]=a[35392>>0]|0;a[h+1>>0]=a[35393>>0]|0;a[h+2>>0]=a[35394>>0]|0;c[e>>2]=c[e>>2]|1;i=g;return}else{kj(e,h,f,a[f+1>>0]&63,16);i=g;return}}function $g(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37416>>0]|0;a[h+1>>0]=a[37417>>0]|0;a[h+2>>0]=a[37418>>0]|0;a[h+3>>0]=a[37419>>0]|0;a[h+4>>0]=a[37420>>0]|0;a[h+5>>0]=a[37421>>0]|0;a[h+6>>0]=a[37422>>0]|0;c[b+28>>2]=2;h=(((d[e+2>>0]|0)<<8|(d[e+3>>0]|0))<<8|(d[e+4>>0]|0))<<8|(d[e+5>>0]|0);c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35360,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+2;kj(b,b+160|0,e,a[e+1>>0]&63,32);i=f;return}function ah(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37408>>0]|0;a[h+1>>0]=a[37409>>0]|0;a[h+2>>0]=a[37410>>0]|0;a[h+3>>0]=a[37411>>0]|0;a[h+4>>0]=a[37412>>0]|0;a[h+5>>0]=a[37413>>0]|0;a[h+6>>0]=a[37414>>0]|0;c[b+28>>2]=2;h=d[e+3>>0]|0;c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35352,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;kj(b,b+160|0,e,a[e+1>>0]&63,8);i=f;return}function bh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37400>>0]|0;a[h+1>>0]=a[37401>>0]|0;a[h+2>>0]=a[37402>>0]|0;a[h+3>>0]=a[37403>>0]|0;a[h+4>>0]=a[37404>>0]|0;a[h+5>>0]=a[37405>>0]|0;a[h+6>>0]=a[37406>>0]|0;c[b+28>>2]=2;h=(d[e+2>>0]|0)<<8|(d[e+3>>0]|0);c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35256,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;kj(b,b+160|0,e,a[e+1>>0]&63,16);i=f;return}function ch(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37392>>0]|0;a[h+1>>0]=a[37393>>0]|0;a[h+2>>0]=a[37394>>0]|0;a[h+3>>0]=a[37395>>0]|0;a[h+4>>0]=a[37396>>0]|0;a[h+5>>0]=a[37397>>0]|0;a[h+6>>0]=a[37398>>0]|0;c[b+28>>2]=2;h=(((d[e+2>>0]|0)<<8|(d[e+3>>0]|0))<<8|(d[e+4>>0]|0))<<8|(d[e+5>>0]|0);c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35360,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+2;kj(b,b+160|0,e,a[e+1>>0]&63,32);i=f;return}function dh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b+8|0;j=c[h>>2]|0;k=a[e+(j<<1)>>0]|0;c[h>>2]=j+1;j=(k&8)==0;k=b+32|0;a[k+0>>0]=a[37384>>0]|0;a[k+1>>0]=a[37385>>0]|0;a[k+2>>0]=a[37386>>0]|0;a[k+3>>0]=a[37387>>0]|0;a[k+4>>0]=a[37388>>0]|0;a[k+5>>0]=a[37389>>0]|0;a[k+6>>0]=a[37390>>0]|0;c[b+28>>2]=2;k=b+96|0;if(j){kj(b,k,e,a[e+1>>0]&63,8);j=d[e+2>>0]|0;c[g>>2]=(j&128|0)!=0?35288:35296;c[g+4>>2]=j>>>4&7;ab(b+160|0,35280,g|0)|0;l=c[b>>2]|0;m=l|64;c[b>>2]=m;i=f;return}else{j=d[e+2>>0]|0;c[g>>2]=(j&128|0)!=0?35288:35296;c[g+4>>2]=j>>>4&7;ab(k|0,35280,g|0)|0;kj(b,b+160|0,e,a[e+1>>0]&63,8);l=c[b>>2]|0;m=l|64;c[b>>2]=m;i=f;return}}function eh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b+8|0;j=c[h>>2]|0;k=a[e+(j<<1)>>0]|0;c[h>>2]=j+1;j=(k&8)==0;k=b+32|0;a[k+0>>0]=a[37376>>0]|0;a[k+1>>0]=a[37377>>0]|0;a[k+2>>0]=a[37378>>0]|0;a[k+3>>0]=a[37379>>0]|0;a[k+4>>0]=a[37380>>0]|0;a[k+5>>0]=a[37381>>0]|0;a[k+6>>0]=a[37382>>0]|0;c[b+28>>2]=2;k=b+96|0;if(j){kj(b,k,e,a[e+1>>0]&63,16);j=d[e+2>>0]|0;c[g>>2]=(j&128|0)!=0?35288:35296;c[g+4>>2]=j>>>4&7;ab(b+160|0,35280,g|0)|0;l=c[b>>2]|0;m=l|64;c[b>>2]=m;i=f;return}else{j=d[e+2>>0]|0;c[g>>2]=(j&128|0)!=0?35288:35296;c[g+4>>2]=j>>>4&7;ab(k|0,35280,g|0)|0;kj(b,b+160|0,e,a[e+1>>0]&63,16);l=c[b>>2]|0;m=l|64;c[b>>2]=m;i=f;return}}function fh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b+8|0;j=c[h>>2]|0;k=a[e+(j<<1)>>0]|0;c[h>>2]=j+1;j=(k&8)==0;k=b+32|0;a[k+0>>0]=a[37368>>0]|0;a[k+1>>0]=a[37369>>0]|0;a[k+2>>0]=a[37370>>0]|0;a[k+3>>0]=a[37371>>0]|0;a[k+4>>0]=a[37372>>0]|0;a[k+5>>0]=a[37373>>0]|0;a[k+6>>0]=a[37374>>0]|0;c[b+28>>2]=2;k=b+96|0;if(j){kj(b,k,e,a[e+1>>0]&63,32);j=d[e+2>>0]|0;c[g>>2]=(j&128|0)!=0?35288:35296;c[g+4>>2]=j>>>4&7;ab(b+160|0,35280,g|0)|0;l=c[b>>2]|0;m=l|64;c[b>>2]=m;i=f;return}else{j=d[e+2>>0]|0;c[g>>2]=(j&128|0)!=0?35288:35296;c[g+4>>2]=j>>>4&7;ab(k|0,35280,g|0)|0;kj(b,b+160|0,e,a[e+1>>0]&63,32);l=c[b>>2]|0;m=l|64;c[b>>2]=m;i=f;return}}function gh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f>>0]=5262666;a[f+1>>0]=20557;a[f+2>>0]=80;a[f+3>>0]=0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,0);c[b>>2]=c[b>>2]|2;i=e;return}function hh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=b+32|0;a[g+0>>0]=a[37360>>0]|0;a[g+1>>0]=a[37361>>0]|0;a[g+2>>0]=a[37362>>0]|0;a[g+3>>0]=a[37363>>0]|0;a[g+4>>0]=a[37364>>0]|0;a[g+5>>0]=a[37365>>0]|0;a[g+6>>0]=a[37366>>0]|0;c[b+28>>2]=2;g=e+1|0;kj(b,b+96|0,e,a[g>>0]&63,8);h=d[e>>0]|0;kj(b,b+160|0,e,(h<<8|(d[g>>0]|0))>>>3&56|h>>>1&7,8);i=f;return}function ih(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=b+32|0;a[g+0>>0]=a[37352>>0]|0;a[g+1>>0]=a[37353>>0]|0;a[g+2>>0]=a[37354>>0]|0;a[g+3>>0]=a[37355>>0]|0;a[g+4>>0]=a[37356>>0]|0;a[g+5>>0]=a[37357>>0]|0;a[g+6>>0]=a[37358>>0]|0;c[b+28>>2]=2;g=e+1|0;kj(b,b+96|0,e,a[g>>0]&63,32);h=d[e>>0]|0;kj(b,b+160|0,e,(h<<8|(d[g>>0]|0))>>>3&56|h>>>1&7,32);i=f;return}function jh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f;h=b+32|0;j=h;a[j>>0]=1163284301;a[j+1>>0]=4544079;a[j+2>>0]=17750;a[j+3>>0]=69;j=h+4|0;a[j>>0]=4992577;a[j+1>>0]=19502;a[j+2>>0]=76;a[j+3>>0]=0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,32);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35272,g|0)|0;i=f;return}function kh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=b+32|0;a[g+0>>0]=a[37248>>0]|0;a[g+1>>0]=a[37249>>0]|0;a[g+2>>0]=a[37250>>0]|0;a[g+3>>0]=a[37251>>0]|0;a[g+4>>0]=a[37252>>0]|0;a[g+5>>0]=a[37253>>0]|0;a[g+6>>0]=a[37254>>0]|0;c[b+28>>2]=2;g=e+1|0;kj(b,b+96|0,e,a[g>>0]&63,16);h=d[e>>0]|0;kj(b,b+160|0,e,(h<<8|(d[g>>0]|0))>>>3&56|h>>>1&7,16);i=f;return}function lh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f;h=b+32|0;j=h;a[j>>0]=1163284301;a[j+1>>0]=4544079;a[j+2>>0]=17750;a[j+3>>0]=69;j=h+4|0;a[j>>0]=5713473;a[j+1>>0]=22318;a[j+2>>0]=87;a[j+3>>0]=0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35272,g|0)|0;i=f;return}function mh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37344>>0]|0;a[f+1>>0]=a[37345>>0]|0;a[f+2>>0]=a[37346>>0]|0;a[f+3>>0]=a[37347>>0]|0;a[f+4>>0]=a[37348>>0]|0;a[f+5>>0]=a[37349>>0]|0;a[f+6>>0]=a[37350>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,8);c[b>>2]=c[b>>2]|32;i=e;return}function nh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37336>>0]|0;a[f+1>>0]=a[37337>>0]|0;a[f+2>>0]=a[37338>>0]|0;a[f+3>>0]=a[37339>>0]|0;a[f+4>>0]=a[37340>>0]|0;a[f+5>>0]=a[37341>>0]|0;a[f+6>>0]=a[37342>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);c[b>>2]=c[b>>2]|32;i=e;return}function oh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37328>>0]|0;a[f+1>>0]=a[37329>>0]|0;a[f+2>>0]=a[37330>>0]|0;a[f+3>>0]=a[37331>>0]|0;a[f+4>>0]=a[37332>>0]|0;a[f+5>>0]=a[37333>>0]|0;a[f+6>>0]=a[37334>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,32);c[b>>2]=c[b>>2]|32;i=e;return}function ph(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37248>>0]|0;a[f+1>>0]=a[37249>>0]|0;a[f+2>>0]=a[37250>>0]|0;a[f+3>>0]=a[37251>>0]|0;a[f+4>>0]=a[37252>>0]|0;a[f+5>>0]=a[37253>>0]|0;a[f+6>>0]=a[37254>>0]|0;c[b+28>>2]=2;f=b+96|0;a[f+0>>0]=a[35392>>0]|0;a[f+1>>0]=a[35393>>0]|0;a[f+2>>0]=a[35394>>0]|0;kj(b,b+160|0,d,a[d+1>>0]&63,16);i=e;return}function qh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h>>0]=4933699;a[h+1>>0]=19272;a[h+2>>0]=75;a[h+3>>0]=0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function rh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h>>0]=4277580;a[h+1>>0]=16709;a[h+2>>0]=65;a[h+3>>0]=0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,32);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35272,g|0)|0;i=f;return}function sh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37320>>0]|0;a[f+1>>0]=a[37321>>0]|0;a[f+2>>0]=a[37322>>0]|0;a[f+3>>0]=a[37323>>0]|0;a[f+4>>0]=a[37324>>0]|0;a[f+5>>0]=a[37325>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,8);i=e;return}function th(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37312>>0]|0;a[f+1>>0]=a[37313>>0]|0;a[f+2>>0]=a[37314>>0]|0;a[f+3>>0]=a[37315>>0]|0;a[f+4>>0]=a[37316>>0]|0;a[f+5>>0]=a[37317>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);i=e;return}function uh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37304>>0]|0;a[f+1>>0]=a[37305>>0]|0;a[f+2>>0]=a[37306>>0]|0;a[f+3>>0]=a[37307>>0]|0;a[f+4>>0]=a[37308>>0]|0;a[f+5>>0]=a[37309>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,32);i=e;return}function vh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37248>>0]|0;a[f+1>>0]=a[37249>>0]|0;a[f+2>>0]=a[37250>>0]|0;a[f+3>>0]=a[37251>>0]|0;a[f+4>>0]=a[37252>>0]|0;a[f+5>>0]=a[37253>>0]|0;a[f+6>>0]=a[37254>>0]|0;c[b+28>>2]=2;f=b+96|0;a[f>>0]=5391171;a[f+1>>0]=21059;a[f+2>>0]=82;a[f+3>>0]=0;kj(b,b+160|0,d,a[d+1>>0]&63,16);c[b>>2]=c[b>>2]|64;i=e;return}function wh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37296>>0]|0;a[f+1>>0]=a[37297>>0]|0;a[f+2>>0]=a[37298>>0]|0;a[f+3>>0]=a[37299>>0]|0;a[f+4>>0]=a[37300>>0]|0;a[f+5>>0]=a[37301>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,8);i=e;return}function xh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37288>>0]|0;a[f+1>>0]=a[37289>>0]|0;a[f+2>>0]=a[37290>>0]|0;a[f+3>>0]=a[37291>>0]|0;a[f+4>>0]=a[37292>>0]|0;a[f+5>>0]=a[37293>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);i=e;return}function yh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37280>>0]|0;a[f+1>>0]=a[37281>>0]|0;a[f+2>>0]=a[37282>>0]|0;a[f+3>>0]=a[37283>>0]|0;a[f+4>>0]=a[37284>>0]|0;a[f+5>>0]=a[37285>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,32);i=e;return}function zh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37248>>0]|0;a[f+1>>0]=a[37249>>0]|0;a[f+2>>0]=a[37250>>0]|0;a[f+3>>0]=a[37251>>0]|0;a[f+4>>0]=a[37252>>0]|0;a[f+5>>0]=a[37253>>0]|0;a[f+6>>0]=a[37254>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,d,a[d+1>>0]&63,16);d=b+160|0;a[d>>0]=5391171;a[d+1>>0]=21059;a[d+2>>0]=82;a[d+3>>0]=0;i=e;return}function Ah(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37272>>0]|0;a[f+1>>0]=a[37273>>0]|0;a[f+2>>0]=a[37274>>0]|0;a[f+3>>0]=a[37275>>0]|0;a[f+4>>0]=a[37276>>0]|0;a[f+5>>0]=a[37277>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,8);i=e;return}function Bh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37264>>0]|0;a[f+1>>0]=a[37265>>0]|0;a[f+2>>0]=a[37266>>0]|0;a[f+3>>0]=a[37267>>0]|0;a[f+4>>0]=a[37268>>0]|0;a[f+5>>0]=a[37269>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);i=e;return}function Ch(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37256>>0]|0;a[f+1>>0]=a[37257>>0]|0;a[f+2>>0]=a[37258>>0]|0;a[f+3>>0]=a[37259>>0]|0;a[f+4>>0]=a[37260>>0]|0;a[f+5>>0]=a[37261>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,32);i=e;return}function Dh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37248>>0]|0;a[f+1>>0]=a[37249>>0]|0;a[f+2>>0]=a[37250>>0]|0;a[f+3>>0]=a[37251>>0]|0;a[f+4>>0]=a[37252>>0]|0;a[f+5>>0]=a[37253>>0]|0;a[f+6>>0]=a[37254>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,d,a[d+1>>0]&63,16);d=b+160|0;a[d+0>>0]=a[35392>>0]|0;a[d+1>>0]=a[35393>>0]|0;a[d+2>>0]=a[35394>>0]|0;c[b>>2]=c[b>>2]|1;i=e;return}function Eh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37240>>0]|0;a[f+1>>0]=a[37241>>0]|0;a[f+2>>0]=a[37242>>0]|0;a[f+3>>0]=a[37243>>0]|0;a[f+4>>0]=a[37244>>0]|0;a[f+5>>0]=a[37245>>0]|0;a[f+6>>0]=a[37246>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,8);c[b>>2]=c[b>>2]|32;i=e;return}function Fh(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f;h=b[d+12>>1]|0;j=d+32|0;if((h&56)==0){a[j+0>>0]=a[37232>>0]|0;a[j+1>>0]=a[37233>>0]|0;a[j+2>>0]=a[37234>>0]|0;a[j+3>>0]=a[37235>>0]|0;a[j+4>>0]=a[37236>>0]|0;c[d+28>>2]=1;c[g>>2]=h&7;ab(d+96|0,35264,g|0)|0;i=f;return}else{a[j>>0]=4277584;a[j+1>>0]=16709;a[j+2>>0]=65;a[j+3>>0]=0;c[d+28>>2]=1;kj(d,d+96|0,e,a[e+1>>0]&63,32);i=f;return}}function Gh(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+16|0;g=f;h=e[b+12>>1]|0;j=h>>>3&7;if((j|0)==4){k=b+32|0;l=k;a[l>>0]=1163284301;a[l+1>>0]=4544079;a[l+2>>0]=17750;a[l+3>>0]=69;l=k+4|0;a[l>>0]=5713485;a[l+1>>0]=22318;a[l+2>>0]=87;a[l+3>>0]=0;c[b+28>>2]=2;jj(b,b+96|0,d,25,16);kj(b,b+160|0,d,a[d+1>>0]&63,16);i=f;return}else if((j|0)==0){j=b+32|0;a[j+0>>0]=a[37224>>0]|0;a[j+1>>0]=a[37225>>0]|0;a[j+2>>0]=a[37226>>0]|0;a[j+3>>0]=a[37227>>0]|0;a[j+4>>0]=a[37228>>0]|0;a[j+5>>0]=a[37229>>0]|0;c[b+28>>2]=1;c[g>>2]=h&7;ab(b+96|0,35264,g|0)|0;i=f;return}else{g=b+32|0;h=g;a[h>>0]=1163284301;a[h+1>>0]=4544079;a[h+2>>0]=17750;a[h+3>>0]=69;h=g+4|0;a[h>>0]=5713485;a[h+1>>0]=22318;a[h+2>>0]=87;a[h+3>>0]=0;c[b+28>>2]=2;jj(b,b+96|0,d,24,16);kj(b,b+160|0,d,a[d+1>>0]&63,16);i=f;return}}function Hh(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+16|0;g=f;h=e[b+12>>1]|0;j=h>>>3&7;if((j|0)==4){k=b+32|0;l=k;a[l>>0]=1163284301;a[l+1>>0]=4544079;a[l+2>>0]=17750;a[l+3>>0]=69;l=k+4|0;a[l>>0]=4992589;a[l+1>>0]=19502;a[l+2>>0]=76;a[l+3>>0]=0;c[b+28>>2]=2;jj(b,b+96|0,d,25,32);kj(b,b+160|0,d,a[d+1>>0]&63,32);i=f;return}else if((j|0)==0){j=b+32|0;a[j+0>>0]=a[37216>>0]|0;a[j+1>>0]=a[37217>>0]|0;a[j+2>>0]=a[37218>>0]|0;a[j+3>>0]=a[37219>>0]|0;a[j+4>>0]=a[37220>>0]|0;a[j+5>>0]=a[37221>>0]|0;c[b+28>>2]=1;c[g>>2]=h&7;ab(b+96|0,35264,g|0)|0;i=f;return}else{g=b+32|0;h=g;a[h>>0]=1163284301;a[h+1>>0]=4544079;a[h+2>>0]=17750;a[h+3>>0]=69;h=g+4|0;a[h>>0]=4992589;a[h+1>>0]=19502;a[h+2>>0]=76;a[h+3>>0]=0;c[b+28>>2]=2;jj(b,b+96|0,d,24,32);kj(b,b+160|0,d,a[d+1>>0]&63,32);i=f;return}}function Ih(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+16|0;h=g;j=b[e+12>>1]|0;k=e+32|0;if((j&56)==0){a[k+0>>0]=a[37208>>0]|0;a[k+1>>0]=a[37209>>0]|0;a[k+2>>0]=a[37210>>0]|0;a[k+3>>0]=a[37211>>0]|0;a[k+4>>0]=a[37212>>0]|0;a[k+5>>0]=a[37213>>0]|0;a[k+6>>0]=a[37214>>0]|0;c[e+28>>2]=1;c[h>>2]=j&7;ab(e+96|0,35264,h|0)|0;c[e>>2]=c[e>>2]|128;i=g;return}else{a[k>>0]=4277580;a[k+1>>0]=16709;a[k+2>>0]=65;a[k+3>>0]=0;c[e+28>>2]=2;kj(e,e+96|0,f,a[f+1>>0]&63,32);c[h>>2]=(d[f>>0]|0)>>>1&7;ab(e+160|0,35272,h|0)|0;i=g;return}}function Jh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37200>>0]|0;a[f+1>>0]=a[37201>>0]|0;a[f+2>>0]=a[37202>>0]|0;a[f+3>>0]=a[37203>>0]|0;a[f+4>>0]=a[37204>>0]|0;a[f+5>>0]=a[37205>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,8);i=e;return}function Kh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37192>>0]|0;a[f+1>>0]=a[37193>>0]|0;a[f+2>>0]=a[37194>>0]|0;a[f+3>>0]=a[37195>>0]|0;a[f+4>>0]=a[37196>>0]|0;a[f+5>>0]=a[37197>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);i=e;return}function Lh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[37184>>0]|0;a[f+1>>0]=a[37185>>0]|0;a[f+2>>0]=a[37186>>0]|0;a[f+3>>0]=a[37187>>0]|0;a[f+4>>0]=a[37188>>0]|0;a[f+5>>0]=a[37189>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,32);i=e;return}function Mh(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=d+32|0;if((b[d+12>>1]|0)==19196){h=g;j=h;a[j>>0]=1162628169;a[j+1>>0]=4541516;a[j+2>>0]=17740;a[j+3>>0]=69;j=h+4|0;a[j>>0]=4997447;a[j+1>>0]=19521;a[j+2>>0]=76;a[j+3>>0]=0;c[d+28>>2]=0;c[d>>2]=c[d>>2]|4;i=f;return}else{a[g>>0]=5456212;a[g+1>>0]=21313;a[g+2>>0]=83;a[g+3>>0]=0;c[d+28>>2]=1;kj(d,d+96|0,e,a[e+1>>0]&63,8);i=f;return}}function Nh(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;i=i+16|0;j=h;k=f+8|0;l=c[k>>2]|0;m=l<<1;n=(d[g+m>>0]|0)<<8;o=n|(d[g+(m|1)>>0]|0);c[k>>2]=l+1;l=f+14|0;b[l>>1]=o;o=(n&1024|0)==0;n=f+32|0;a[n+0>>0]=a[37176>>0]|0;a[n+1>>0]=a[37177>>0]|0;a[n+2>>0]=a[37178>>0]|0;a[n+3>>0]=a[37179>>0]|0;a[n+4>>0]=a[37180>>0]|0;a[n+5>>0]=a[37181>>0]|0;a[n+6>>0]=a[37182>>0]|0;c[f+28>>2]=2;kj(f,f+96|0,g,a[g+1>>0]&63,32);g=f+160|0;n=e[l>>1]|0;if(o){c[j>>2]=n>>>12&7;ab(g|0,35264,j|0)|0;p=c[f>>2]|0;q=p|128;c[f>>2]=q;i=h;return}else{c[j>>2]=n&7;c[j+4>>2]=n>>>12&7;ab(g|0,35408,j|0)|0;p=c[f>>2]|0;q=p|128;c[f>>2]=q;i=h;return}}function Oh(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;i=i+16|0;j=h;k=f+8|0;l=c[k>>2]|0;m=l<<1;n=(d[g+m>>0]|0)<<8;o=n|(d[g+(m|1)>>0]|0);c[k>>2]=l+1;l=f+14|0;b[l>>1]=o;o=f+32|0;if((n&1024|0)==0){a[o+0>>0]=a[37168>>0]|0;a[o+1>>0]=a[37169>>0]|0;a[o+2>>0]=a[37170>>0]|0;a[o+3>>0]=a[37171>>0]|0;a[o+4>>0]=a[37172>>0]|0;a[o+5>>0]=a[37173>>0]|0;a[o+6>>0]=a[37174>>0]|0;c[f+28>>2]=2;kj(f,f+96|0,g,a[g+1>>0]&63,32);n=e[l>>1]|0;c[j>>2]=n&7;c[j+4>>2]=n>>>12&7;ab(f+160|0,35408,j|0)|0;p=c[f>>2]|0;q=p|128;c[f>>2]=q;i=h;return}else{n=o;o=n;a[o>>0]=1431718212;a[o+1>>0]=5592649;a[o+2>>0]=21846;a[o+3>>0]=85;o=n+4|0;a[o>>0]=4992588;a[o+1>>0]=19502;a[o+2>>0]=76;a[o+3>>0]=0;c[f+28>>2]=2;kj(f,f+96|0,g,a[g+1>>0]&63,32);g=e[l>>1]|0;c[j>>2]=g&7;c[j+4>>2]=g>>>12&7;ab(f+160|0,35408,j|0)|0;p=c[f>>2]|0;q=p|128;c[f>>2]=q;i=h;return}}function Ph(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+16|0;h=g;j=e+32|0;if((b[e+12>>1]&56)==0){a[j+0>>0]=a[35848>>0]|0;a[j+1>>0]=a[35849>>0]|0;a[j+2>>0]=a[35850>>0]|0;c[e+28>>2]=1;k=(d[f>>0]|0)<<8|(d[f+1>>0]|0);c[h>>2]=35704;c[h+4>>2]=k;ab(e+96|0,35256,h|0)|0;i=g;return}else{h=j;j=h;a[j>>0]=1163284301;a[j+1>>0]=4544079;a[j+2>>0]=17750;a[j+3>>0]=69;j=h+4|0;a[j>>0]=5713485;a[j+1>>0]=22318;a[j+2>>0]=87;a[j+3>>0]=0;c[e+28>>2]=2;jj(e,e+160|0,f,24,16);kj(e,e+96|0,f,a[f+1>>0]&63,16);i=g;return}}function Qh(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+16|0;h=g;j=e+32|0;if((b[e+12>>1]&56)==0){a[j+0>>0]=a[35848>>0]|0;a[j+1>>0]=a[35849>>0]|0;a[j+2>>0]=a[35850>>0]|0;c[e+28>>2]=1;k=(d[f>>0]|0)<<8|(d[f+1>>0]|0);c[h>>2]=35704;c[h+4>>2]=k;ab(e+96|0,35256,h|0)|0;i=g;return}else{h=j;j=h;a[j>>0]=1163284301;a[j+1>>0]=4544079;a[j+2>>0]=17750;a[j+3>>0]=69;j=h+4|0;a[j>>0]=4992589;a[j+1>>0]=19502;a[j+2>>0]=76;a[j+3>>0]=0;c[e+28>>2]=2;jj(e,e+160|0,f,24,32);kj(e,e+96|0,f,a[f+1>>0]&63,32);i=g;return}}function Rh(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+16|0;h=g;j=b[e+12>>1]|0;k=j&65535;do{switch(j<<16>>16){case 20081:{l=e+32|0;a[l>>0]=5263182;a[l+1>>0]=20559;a[l+2>>0]=80;a[l+3>>0]=0;c[e+28>>2]=0;i=g;return};case 20082:{l=e+32|0;a[l+0>>0]=a[37112>>0]|0;a[l+1>>0]=a[37113>>0]|0;a[l+2>>0]=a[37114>>0]|0;a[l+3>>0]=a[37115>>0]|0;a[l+4>>0]=a[37116>>0]|0;c[e+28>>2]=1;l=(d[f+2>>0]|0)<<8|(d[f+3>>0]|0);c[h>>2]=35704;c[h+4>>2]=l;ab(e+96|0,35256,h|0)|0;l=e+8|0;c[l>>2]=(c[l>>2]|0)+1;c[e>>2]=c[e>>2]|1;i=g;return};case 20087:{l=e+32|0;a[l>>0]=5395538;a[l+1>>0]=21076;a[l+2>>0]=82;a[l+3>>0]=0;c[e+28>>2]=0;i=g;return};case 20091:{l=e+8|0;c[l>>2]=(c[l>>2]|0)+1;l=e+32|0;a[l+0>>0]=a[37128>>0]|0;a[l+1>>0]=a[37129>>0]|0;a[l+2>>0]=a[37130>>0]|0;a[l+3>>0]=a[37131>>0]|0;a[l+4>>0]=a[37132>>0]|0;a[l+5>>0]=a[37133>>0]|0;c[e+28>>2]=2;l=f+2|0;m=d[l>>0]|0;c[h>>2]=(m&128|0)!=0?35288:35296;c[h+4>>2]=m>>>4&7;ab(e+96|0,35280,h|0)|0;m=e+160|0;n=(d[l>>0]|0)<<8&3840|(d[f+3>>0]|0);if((n|0)==1){l=c[e>>2]|64;c[e>>2]=l;o=l;p=35432;q=24}else if((n|0)==2048){l=c[e>>2]|64;c[e>>2]=l;o=l;p=35400;q=24}else if((n|0)==2049){l=c[e>>2]|64;c[e>>2]=l;o=l;p=35440;q=24}else if((n|0)==0){l=c[e>>2]|64;c[e>>2]=l;o=l;p=35424;q=24}else{c[h>>2]=n;ab(m|0,35448,h|0)|0;n=c[e>>2]|64;c[e>>2]=n;r=e;s=n}if((q|0)==24){n=d[p>>0]|d[p+1>>0]<<8|d[p+2>>0]<<16|d[p+3>>0]<<24;a[m>>0]=n;a[m+1>>0]=n>>8;a[m+2>>0]=n>>16;a[m+3>>0]=n>>24;r=e;s=o}c[r>>2]=s|64;i=g;return};case 20090:{n=e+8|0;c[n>>2]=(c[n>>2]|0)+1;n=e+32|0;a[n+0>>0]=a[37128>>0]|0;a[n+1>>0]=a[37129>>0]|0;a[n+2>>0]=a[37130>>0]|0;a[n+3>>0]=a[37131>>0]|0;a[n+4>>0]=a[37132>>0]|0;a[n+5>>0]=a[37133>>0]|0;c[e+28>>2]=2;n=e+96|0;m=f+2|0;l=(d[m>>0]|0)<<8&3840|(d[f+3>>0]|0);if((l|0)==1){c[e>>2]=c[e>>2]|64;t=35432;q=16}else if((l|0)==0){c[e>>2]=c[e>>2]|64;t=35424;q=16}else if((l|0)==2049){c[e>>2]=c[e>>2]|64;t=35440;q=16}else if((l|0)==2048){c[e>>2]=c[e>>2]|64;t=35400;q=16}else{c[h>>2]=l;ab(n|0,35448,h|0)|0;c[e>>2]=c[e>>2]|64;u=e}if((q|0)==16){l=d[t>>0]|d[t+1>>0]<<8|d[t+2>>0]<<16|d[t+3>>0]<<24;a[n>>0]=l;a[n+1>>0]=l>>8;a[n+2>>0]=l>>16;a[n+3>>0]=l>>24;u=e}l=d[m>>0]|0;c[h>>2]=(l&128|0)!=0?35288:35296;c[h+4>>2]=l>>>4&7;ab(e+160|0,35280,h|0)|0;c[u>>2]=c[u>>2]|64;i=g;return};case 20084:{l=e+32|0;a[l>>0]=4478034;a[l+1>>0]=17492;a[l+2>>0]=68;a[l+3>>0]=0;c[e+28>>2]=1;l=(d[f+2>>0]|0)<<8|(d[f+3>>0]|0);c[h>>2]=35704;c[h+4>>2]=l;ab(e+96|0,35256,h|0)|0;l=e+8|0;c[l>>2]=(c[l>>2]|0)+1;c[e>>2]=c[e>>2]|80;i=g;return};case 20086:{l=e+32|0;a[l+0>>0]=a[37120>>0]|0;a[l+1>>0]=a[37121>>0]|0;a[l+2>>0]=a[37122>>0]|0;a[l+3>>0]=a[37123>>0]|0;a[l+4>>0]=a[37124>>0]|0;a[l+5>>0]=a[37125>>0]|0;c[e+28>>2]=0;c[e>>2]=c[e>>2]|32;i=g;return};case 20080:{l=e+32|0;a[l+0>>0]=a[37104>>0]|0;a[l+1>>0]=a[37105>>0]|0;a[l+2>>0]=a[37106>>0]|0;a[l+3>>0]=a[37107>>0]|0;a[l+4>>0]=a[37108>>0]|0;a[l+5>>0]=a[37109>>0]|0;c[e+28>>2]=0;c[e>>2]=c[e>>2]|1;i=g;return};case 20085:{l=e+32|0;a[l>>0]=5461074;a[l+1>>0]=21332;a[l+2>>0]=83;a[l+3>>0]=0;c[e+28>>2]=0;c[e>>2]=c[e>>2]|16;i=g;return};case 20083:{l=e+32|0;a[l>>0]=4543570;a[l+1>>0]=17748;a[l+2>>0]=69;a[l+3>>0]=0;c[e+28>>2]=0;c[e>>2]=c[e>>2]|9;i=g;return};default:{if((k&48|0)==0){l=e+32|0;a[l+0>>0]=a[37136>>0]|0;a[l+1>>0]=a[37137>>0]|0;a[l+2>>0]=a[37138>>0]|0;a[l+3>>0]=a[37139>>0]|0;a[l+4>>0]=a[37140>>0]|0;c[e+28>>2]=1;c[h>>2]=35704;c[h+4>>2]=k&15;ab(e+96|0,35352,h|0)|0;i=g;return}l=k&56;if((l|0)==16){m=e+32|0;a[m+0>>0]=a[37144>>0]|0;a[m+1>>0]=a[37145>>0]|0;a[m+2>>0]=a[37146>>0]|0;a[m+3>>0]=a[37147>>0]|0;a[m+4>>0]=a[37148>>0]|0;c[e+28>>2]=2;c[h>>2]=k&7;ab(e+96|0,35272,h|0)|0;m=(d[f+2>>0]|0)<<8|(d[f+3>>0]|0);c[h>>2]=35704;c[h+4>>2]=m;ab(e+160|0,35256,h|0)|0;m=e+8|0;c[m>>2]=(c[m>>2]|0)+1;i=g;return}else if((l|0)==24){m=e+32|0;a[m+0>>0]=a[37152>>0]|0;a[m+1>>0]=a[37153>>0]|0;a[m+2>>0]=a[37154>>0]|0;a[m+3>>0]=a[37155>>0]|0;a[m+4>>0]=a[37156>>0]|0;c[e+28>>2]=1;c[h>>2]=k&7;ab(e+96|0,35272,h|0)|0;i=g;return}else if((l|0)==40){m=e+32|0;a[m+0>>0]=a[37160>>0]|0;a[m+1>>0]=a[37161>>0]|0;a[m+2>>0]=a[37162>>0]|0;a[m+3>>0]=a[37163>>0]|0;a[m+4>>0]=a[37164>>0]|0;c[e+28>>2]=2;m=e+96|0;a[m>>0]=5264213;a[m+1>>0]=20563;a[m+2>>0]=80;a[m+3>>0]=0;c[h>>2]=k&7;ab(e+160|0,35272,h|0)|0;c[e>>2]=c[e>>2]|1;i=g;return}else if((l|0)==32){l=e+32|0;a[l+0>>0]=a[37160>>0]|0;a[l+1>>0]=a[37161>>0]|0;a[l+2>>0]=a[37162>>0]|0;a[l+3>>0]=a[37163>>0]|0;a[l+4>>0]=a[37164>>0]|0;c[e+28>>2]=2;c[h>>2]=k&7;ab(e+96|0,35272,h|0)|0;l=e+160|0;a[l>>0]=5264213;a[l+1>>0]=20563;a[l+2>>0]=80;a[l+3>>0]=0;c[e>>2]=c[e>>2]|1;i=g;return}else{l=e+32|0;a[l+0>>0]=a[35848>>0]|0;a[l+1>>0]=a[35849>>0]|0;a[l+2>>0]=a[35850>>0]|0;c[e+28>>2]=1;l=(d[f>>0]|0)<<8|(d[f+1>>0]|0);c[h>>2]=35704;c[h+4>>2]=l;ab(e+96|0,35256,h|0)|0;i=g;return}}}}while(0)}function Sh(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f>>0]=5395274;a[f+1>>0]=21075;a[f+2>>0]=82;a[f+3>>0]=0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,0);c[b>>2]=c[b>>2]|4;i=e;return}function Th(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37096>>0]|0;a[h+1>>0]=a[37097>>0]|0;a[h+2>>0]=a[37098>>0]|0;a[h+3>>0]=a[37099>>0]|0;a[h+4>>0]=a[37100>>0]|0;a[h+5>>0]=a[37101>>0]|0;a[h+6>>0]=a[37102>>0]|0;c[b+28>>2]=2;h=(d[e>>0]|0)>>>1&7;c[g>>2]=35704;c[g+4>>2]=(h|0)==0?8:h;ab(b+96|0,35376,g|0)|0;kj(b,b+160|0,e,a[e+1>>0]&63,8);i=f;return}function Uh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37088>>0]|0;a[h+1>>0]=a[37089>>0]|0;a[h+2>>0]=a[37090>>0]|0;a[h+3>>0]=a[37091>>0]|0;a[h+4>>0]=a[37092>>0]|0;a[h+5>>0]=a[37093>>0]|0;a[h+6>>0]=a[37094>>0]|0;c[b+28>>2]=2;h=(d[e>>0]|0)>>>1&7;c[g>>2]=35704;c[g+4>>2]=(h|0)==0?8:h;ab(b+96|0,35376,g|0)|0;kj(b,b+160|0,e,a[e+1>>0]&63,16);i=f;return}function Vh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37080>>0]|0;a[h+1>>0]=a[37081>>0]|0;a[h+2>>0]=a[37082>>0]|0;a[h+3>>0]=a[37083>>0]|0;a[h+4>>0]=a[37084>>0]|0;a[h+5>>0]=a[37085>>0]|0;a[h+6>>0]=a[37086>>0]|0;c[b+28>>2]=2;h=(d[e>>0]|0)>>>1&7;c[g>>2]=35704;c[g+4>>2]=(h|0)==0?8:h;ab(b+96|0,35376,g|0)|0;kj(b,b+160|0,e,a[e+1>>0]&63,32);i=f;return}function Wh(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;i=i+16|0;j=h;k=f+12|0;l=e[k>>1]|0;m=l>>>8&15;n=l&63;if(m>>>0>1){c[f>>2]=c[f>>2]|32}if((n|0)==58){Rz(f+32|0,c[36504+(m<<2)>>2]|0)|0;c[f+28>>2]=1;o=(d[g+2>>0]|0)<<8|(d[g+3>>0]|0);c[j>>2]=35704;c[j+4>>2]=o;ab(f+96|0,35256,j|0)|0;o=f+8|0;c[o>>2]=(c[o>>2]|0)+1;c[f>>2]=c[f>>2]|128;i=h;return}else if((n|0)==59){Rz(f+32|0,c[36504+(m<<2)>>2]|0)|0;c[f+28>>2]=1;o=(((d[g+2>>0]|0)<<8|(d[g+3>>0]|0))<<8|(d[g+4>>0]|0))<<8|(d[g+5>>0]|0);c[j>>2]=35704;c[j+4>>2]=o;ab(f+96|0,35360,j|0)|0;o=f+8|0;c[o>>2]=(c[o>>2]|0)+2;c[f>>2]=c[f>>2]|128;i=h;return}else if((n|0)==60){Rz(f+32|0,c[36504+(m<<2)>>2]|0)|0;c[f+28>>2]=0;c[f>>2]=c[f>>2]|128;i=h;return}else{if((l&56|0)==8){Rz(f+32|0,c[36568+(m<<2)>>2]|0)|0;c[f+28>>2]=2;c[j>>2]=b[k>>1]&7;ab(f+96|0,35264,j|0)|0;k=f+8|0;l=c[k>>2]|0;n=l<<1;o=(d[g+n>>0]|0)<<8;p=o|(d[g+(n|1)>>0]|0);c[k>>2]=l+1;l=(c[f+4>>2]|0)+2+((o&32768|0)!=0?p|-65536:p)|0;c[j>>2]=35704;c[j+4>>2]=l;ab(f+160|0,35384,j|0)|0;c[f>>2]=c[f>>2]|2;i=h;return}else{Rz(f+32|0,c[36632+(m<<2)>>2]|0)|0;c[f+28>>2]=1;kj(f,f+96|0,g,a[g+1>>0]&63,8);i=h;return}}}function Xh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36496>>0]|0;a[h+1>>0]=a[36497>>0]|0;a[h+2>>0]=a[36498>>0]|0;a[h+3>>0]=a[36499>>0]|0;a[h+4>>0]=a[36500>>0]|0;a[h+5>>0]=a[36501>>0]|0;a[h+6>>0]=a[36502>>0]|0;c[b+28>>2]=2;h=(d[e>>0]|0)>>>1&7;c[g>>2]=35704;c[g+4>>2]=(h|0)==0?8:h;ab(b+96|0,35376,g|0)|0;kj(b,b+160|0,e,a[e+1>>0]&63,8);i=f;return}function Yh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36488>>0]|0;a[h+1>>0]=a[36489>>0]|0;a[h+2>>0]=a[36490>>0]|0;a[h+3>>0]=a[36491>>0]|0;a[h+4>>0]=a[36492>>0]|0;a[h+5>>0]=a[36493>>0]|0;a[h+6>>0]=a[36494>>0]|0;c[b+28>>2]=2;h=(d[e>>0]|0)>>>1&7;c[g>>2]=35704;c[g+4>>2]=(h|0)==0?8:h;ab(b+96|0,35376,g|0)|0;kj(b,b+160|0,e,a[e+1>>0]&63,16);i=f;return}function Zh(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36480>>0]|0;a[h+1>>0]=a[36481>>0]|0;a[h+2>>0]=a[36482>>0]|0;a[h+3>>0]=a[36483>>0]|0;a[h+4>>0]=a[36484>>0]|0;a[h+5>>0]=a[36485>>0]|0;a[h+6>>0]=a[36486>>0]|0;c[b+28>>2]=2;h=(d[e>>0]|0)>>>1&7;c[g>>2]=35704;c[g+4>>2]=(h|0)==0?8:h;ab(b+96|0,35376,g|0)|0;kj(b,b+160|0,e,a[e+1>>0]&63,32);i=f;return}function _h(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+16|0;h=g;j=(e[b+12>>1]|0)>>>8&15;k=f+1|0;l=a[k>>0]|0;if(l<<24>>24==0){m=b+32|0;Rz(m|0,c[36280+(j<<2)>>2]|0)|0;c[b+28>>2]=1;n=b+8|0;o=c[n>>2]|0;p=o<<1;q=(d[f+p>>0]|0)<<8;r=q|(d[f+(p|1)>>0]|0);c[n>>2]=o+1;o=(c[b+4>>2]|0)+2+((q&32768|0)!=0?r|-65536:r)|0;c[h>>2]=35704;c[h+4>>2]=o;ab(b+96|0,35384,h|0)|0;o=b+(Kz(m|0)|0)+32|0;a[o+0>>0]=a[35536>>0]|0;a[o+1>>0]=a[35537>>0]|0;a[o+2>>0]=a[35538>>0]|0;s=(j|0)==1;t=c[b>>2]|0;u=s?4:2;v=t|u;w=j>>>0>1;x=v|32;y=w?x:v;c[b>>2]=y;i=g;return}o=b+32|0;Rz(o|0,c[36280+(j<<2)>>2]|0)|0;c[b+28>>2]=1;m=b+96|0;if(l<<24>>24==-1){l=b+8|0;r=c[l>>2]|0;q=r<<1;n=(((d[f+q>>0]|0)<<8|(d[f+(q|1)>>0]|0))<<8|(d[f+(q+2)>>0]|0))<<8|(d[f+(q+3)>>0]|0);c[l>>2]=r+2;r=(c[b+4>>2]|0)+2+n|0;c[h>>2]=35704;c[h+4>>2]=r;ab(m|0,35384,h|0)|0;r=b+(Kz(o|0)|0)+32|0;a[r+0>>0]=a[35528>>0]|0;a[r+1>>0]=a[35529>>0]|0;a[r+2>>0]=a[35530>>0]|0;c[b>>2]=c[b>>2]|128;s=(j|0)==1;t=c[b>>2]|0;u=s?4:2;v=t|u;w=j>>>0>1;x=v|32;y=w?x:v;c[b>>2]=y;i=g;return}else{r=d[k>>0]|0;k=(c[b+4>>2]|0)+2+((r&128|0)!=0?r|-256:r)|0;c[h>>2]=35704;c[h+4>>2]=k;ab(m|0,35384,h|0)|0;h=b+(Kz(o|0)|0)+32|0;a[h+0>>0]=a[36344>>0]|0;a[h+1>>0]=a[36345>>0]|0;a[h+2>>0]=a[36346>>0]|0;s=(j|0)==1;t=c[b>>2]|0;u=s?4:2;v=t|u;w=j>>>0>1;x=v|32;y=w?x:v;c[b>>2]=y;i=g;return}}function $h(b,f){b=b|0;f=f|0;var g=0,h=0,j=0;g=i;i=i+16|0;h=g;j=b+32|0;a[j+0>>0]=a[36272>>0]|0;a[j+1>>0]=a[36273>>0]|0;a[j+2>>0]=a[36274>>0]|0;a[j+3>>0]=a[36275>>0]|0;a[j+4>>0]=a[36276>>0]|0;a[j+5>>0]=a[36277>>0]|0;c[b+28>>2]=2;j=e[b+12>>1]|0;c[h>>2]=35704;c[h+4>>2]=(j&128|0)!=0?j|-256:j&255;ab(b+96|0,35360,h|0)|0;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+160|0,35264,h|0)|0;i=g;return}function ai(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36256>>0]|0;a[h+1>>0]=a[36257>>0]|0;a[h+2>>0]=a[36258>>0]|0;a[h+3>>0]=a[36259>>0]|0;a[h+4>>0]=a[36260>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,8);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function bi(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36240>>0]|0;a[h+1>>0]=a[36241>>0]|0;a[h+2>>0]=a[36242>>0]|0;a[h+3>>0]=a[36243>>0]|0;a[h+4>>0]=a[36244>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function ci(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36232>>0]|0;a[h+1>>0]=a[36233>>0]|0;a[h+2>>0]=a[36234>>0]|0;a[h+3>>0]=a[36235>>0]|0;a[h+4>>0]=a[36236>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,32);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function di(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36264>>0]|0;a[h+1>>0]=a[36265>>0]|0;a[h+2>>0]=a[36266>>0]|0;a[h+3>>0]=a[36267>>0]|0;a[h+4>>0]=a[36268>>0]|0;a[h+5>>0]=a[36269>>0]|0;a[h+6>>0]=a[36270>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function ei(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+16|0;h=g;j=b+12|0;k=e[j>>1]|0;l=k>>>3&7;if((l|0)==1){m=b+32|0;a[m+0>>0]=a[36248>>0]|0;a[m+1>>0]=a[36249>>0]|0;a[m+2>>0]=a[36250>>0]|0;a[m+3>>0]=a[36251>>0]|0;a[m+4>>0]=a[36252>>0]|0;a[m+5>>0]=a[36253>>0]|0;a[m+6>>0]=a[36254>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35312,h|0)|0;c[h>>2]=(e[j>>1]|0)>>>9&7;ab(b+160|0,35312,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else if((l|0)==0){l=b+32|0;a[l+0>>0]=a[36248>>0]|0;a[l+1>>0]=a[36249>>0]|0;a[l+2>>0]=a[36250>>0]|0;a[l+3>>0]=a[36251>>0]|0;a[l+4>>0]=a[36252>>0]|0;a[l+5>>0]=a[36253>>0]|0;a[l+6>>0]=a[36254>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35264,h|0)|0;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+160|0,35264,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else{k=b+32|0;a[k+0>>0]=a[36256>>0]|0;a[k+1>>0]=a[36257>>0]|0;a[k+2>>0]=a[36258>>0]|0;a[k+3>>0]=a[36259>>0]|0;a[k+4>>0]=a[36260>>0]|0;c[b+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+96|0,35264,h|0)|0;kj(b,b+160|0,f,a[f+1>>0]&63,8);i=g;return}}function fi(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+16|0;h=g;j=e+32|0;if((b[e+12>>1]&48)>>>0<16){a[j+0>>0]=a[35848>>0]|0;a[j+1>>0]=a[35849>>0]|0;a[j+2>>0]=a[35850>>0]|0;c[e+28>>2]=1;k=(d[f>>0]|0)<<8|(d[f+1>>0]|0);c[h>>2]=35704;c[h+4>>2]=k;ab(e+96|0,35256,h|0)|0;i=g;return}else{a[j+0>>0]=a[36240>>0]|0;a[j+1>>0]=a[36241>>0]|0;a[j+2>>0]=a[36242>>0]|0;a[j+3>>0]=a[36243>>0]|0;a[j+4>>0]=a[36244>>0]|0;c[e+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(e+96|0,35264,h|0)|0;kj(e,e+160|0,f,a[f+1>>0]&63,16);i=g;return}}function gi(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+16|0;h=g;j=e+32|0;if((b[e+12>>1]&48)>>>0<16){a[j+0>>0]=a[35848>>0]|0;a[j+1>>0]=a[35849>>0]|0;a[j+2>>0]=a[35850>>0]|0;c[e+28>>2]=1;k=(d[f>>0]|0)<<8|(d[f+1>>0]|0);c[h>>2]=35704;c[h+4>>2]=k;ab(e+96|0,35256,h|0)|0;i=g;return}else{a[j+0>>0]=a[36232>>0]|0;a[j+1>>0]=a[36233>>0]|0;a[j+2>>0]=a[36234>>0]|0;a[j+3>>0]=a[36235>>0]|0;a[j+4>>0]=a[36236>>0]|0;c[e+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(e+96|0,35264,h|0)|0;kj(e,e+160|0,f,a[f+1>>0]&63,32);i=g;return}}function hi(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36224>>0]|0;a[h+1>>0]=a[36225>>0]|0;a[h+2>>0]=a[36226>>0]|0;a[h+3>>0]=a[36227>>0]|0;a[h+4>>0]=a[36228>>0]|0;a[h+5>>0]=a[36229>>0]|0;a[h+6>>0]=a[36230>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function ii(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36208>>0]|0;a[h+1>>0]=a[36209>>0]|0;a[h+2>>0]=a[36210>>0]|0;a[h+3>>0]=a[36211>>0]|0;a[h+4>>0]=a[36212>>0]|0;a[h+5>>0]=a[36213>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,8);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function ji(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36192>>0]|0;a[h+1>>0]=a[36193>>0]|0;a[h+2>>0]=a[36194>>0]|0;a[h+3>>0]=a[36195>>0]|0;a[h+4>>0]=a[36196>>0]|0;a[h+5>>0]=a[36197>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function ki(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36176>>0]|0;a[h+1>>0]=a[36177>>0]|0;a[h+2>>0]=a[36178>>0]|0;a[h+3>>0]=a[36179>>0]|0;a[h+4>>0]=a[36180>>0]|0;a[h+5>>0]=a[36181>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,32);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function li(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36216>>0]|0;a[h+1>>0]=a[36217>>0]|0;a[h+2>>0]=a[36218>>0]|0;a[h+3>>0]=a[36219>>0]|0;a[h+4>>0]=a[36220>>0]|0;a[h+5>>0]=a[36221>>0]|0;a[h+6>>0]=a[36222>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35272,g|0)|0;i=f;return}function mi(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+16|0;h=g;j=b+12|0;k=e[j>>1]|0;l=k>>>3&7;if((l|0)==0){m=b+32|0;a[m+0>>0]=a[36200>>0]|0;a[m+1>>0]=a[36201>>0]|0;a[m+2>>0]=a[36202>>0]|0;a[m+3>>0]=a[36203>>0]|0;a[m+4>>0]=a[36204>>0]|0;a[m+5>>0]=a[36205>>0]|0;a[m+6>>0]=a[36206>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35264,h|0)|0;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+160|0,35264,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else if((l|0)==1){l=b+32|0;a[l+0>>0]=a[36200>>0]|0;a[l+1>>0]=a[36201>>0]|0;a[l+2>>0]=a[36202>>0]|0;a[l+3>>0]=a[36203>>0]|0;a[l+4>>0]=a[36204>>0]|0;a[l+5>>0]=a[36205>>0]|0;a[l+6>>0]=a[36206>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35312,h|0)|0;c[h>>2]=(e[j>>1]|0)>>>9&7;ab(b+160|0,35312,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else{j=b+32|0;a[j+0>>0]=a[36208>>0]|0;a[j+1>>0]=a[36209>>0]|0;a[j+2>>0]=a[36210>>0]|0;a[j+3>>0]=a[36211>>0]|0;a[j+4>>0]=a[36212>>0]|0;a[j+5>>0]=a[36213>>0]|0;c[b+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+96|0,35264,h|0)|0;kj(b,b+160|0,f,a[f+1>>0]&63,8);i=g;return}}function ni(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+16|0;h=g;j=b+12|0;k=e[j>>1]|0;l=k>>>3&7;if((l|0)==1){m=b+32|0;a[m+0>>0]=a[36184>>0]|0;a[m+1>>0]=a[36185>>0]|0;a[m+2>>0]=a[36186>>0]|0;a[m+3>>0]=a[36187>>0]|0;a[m+4>>0]=a[36188>>0]|0;a[m+5>>0]=a[36189>>0]|0;a[m+6>>0]=a[36190>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35312,h|0)|0;c[h>>2]=(e[j>>1]|0)>>>9&7;ab(b+160|0,35312,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else if((l|0)==0){l=b+32|0;a[l+0>>0]=a[36184>>0]|0;a[l+1>>0]=a[36185>>0]|0;a[l+2>>0]=a[36186>>0]|0;a[l+3>>0]=a[36187>>0]|0;a[l+4>>0]=a[36188>>0]|0;a[l+5>>0]=a[36189>>0]|0;a[l+6>>0]=a[36190>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35264,h|0)|0;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+160|0,35264,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else{k=b+32|0;a[k+0>>0]=a[36192>>0]|0;a[k+1>>0]=a[36193>>0]|0;a[k+2>>0]=a[36194>>0]|0;a[k+3>>0]=a[36195>>0]|0;a[k+4>>0]=a[36196>>0]|0;a[k+5>>0]=a[36197>>0]|0;c[b+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+96|0,35264,h|0)|0;kj(b,b+160|0,f,a[f+1>>0]&63,16);i=g;return}}function oi(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+16|0;h=g;j=b+12|0;k=e[j>>1]|0;l=k>>>3&7;if((l|0)==0){m=b+32|0;a[m+0>>0]=a[36168>>0]|0;a[m+1>>0]=a[36169>>0]|0;a[m+2>>0]=a[36170>>0]|0;a[m+3>>0]=a[36171>>0]|0;a[m+4>>0]=a[36172>>0]|0;a[m+5>>0]=a[36173>>0]|0;a[m+6>>0]=a[36174>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35264,h|0)|0;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+160|0,35264,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else if((l|0)==1){l=b+32|0;a[l+0>>0]=a[36168>>0]|0;a[l+1>>0]=a[36169>>0]|0;a[l+2>>0]=a[36170>>0]|0;a[l+3>>0]=a[36171>>0]|0;a[l+4>>0]=a[36172>>0]|0;a[l+5>>0]=a[36173>>0]|0;a[l+6>>0]=a[36174>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35312,h|0)|0;c[h>>2]=(e[j>>1]|0)>>>9&7;ab(b+160|0,35312,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else{j=b+32|0;a[j+0>>0]=a[36176>>0]|0;a[j+1>>0]=a[36177>>0]|0;a[j+2>>0]=a[36178>>0]|0;a[j+3>>0]=a[36179>>0]|0;a[j+4>>0]=a[36180>>0]|0;a[j+5>>0]=a[36181>>0]|0;c[b+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+96|0,35264,h|0)|0;kj(b,b+160|0,f,a[f+1>>0]&63,32);i=g;return}}function pi(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36160>>0]|0;a[h+1>>0]=a[36161>>0]|0;a[h+2>>0]=a[36162>>0]|0;a[h+3>>0]=a[36163>>0]|0;a[h+4>>0]=a[36164>>0]|0;a[h+5>>0]=a[36165>>0]|0;a[h+6>>0]=a[36166>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,32);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35272,g|0)|0;i=f;return}function qi(a,b){a=a|0;b=b|0;var d=0,f=0;b=i;i=i+32|0;d=b;f=b+8|0;c[d>>2]=e[a+12>>1]|0;ab(f|0,35240,d|0)|0;Rz(a+32|0,f|0)|0;c[a+28>>2]=0;c[a>>2]=c[a>>2]|4;i=b;return}function ri(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36152>>0]|0;a[h+1>>0]=a[36153>>0]|0;a[h+2>>0]=a[36154>>0]|0;a[h+3>>0]=a[36155>>0]|0;a[h+4>>0]=a[36156>>0]|0;a[h+5>>0]=a[36157>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,8);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function si(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36144>>0]|0;a[h+1>>0]=a[36145>>0]|0;a[h+2>>0]=a[36146>>0]|0;a[h+3>>0]=a[36147>>0]|0;a[h+4>>0]=a[36148>>0]|0;a[h+5>>0]=a[36149>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function ti(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36136>>0]|0;a[h+1>>0]=a[36137>>0]|0;a[h+2>>0]=a[36138>>0]|0;a[h+3>>0]=a[36139>>0]|0;a[h+4>>0]=a[36140>>0]|0;a[h+5>>0]=a[36141>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,32);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function ui(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36128>>0]|0;a[h+1>>0]=a[36129>>0]|0;a[h+2>>0]=a[36130>>0]|0;a[h+3>>0]=a[36131>>0]|0;a[h+4>>0]=a[36132>>0]|0;a[h+5>>0]=a[36133>>0]|0;a[h+6>>0]=a[36134>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35272,g|0)|0;i=f;return}function vi(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;i=i+16|0;j=h;k=f+12|0;l=b[k>>1]|0;m=f+32|0;if((l&56)==8){a[m+0>>0]=a[36112>>0]|0;a[m+1>>0]=a[36113>>0]|0;a[m+2>>0]=a[36114>>0]|0;a[m+3>>0]=a[36115>>0]|0;a[m+4>>0]=a[36116>>0]|0;a[m+5>>0]=a[36117>>0]|0;a[m+6>>0]=a[36118>>0]|0;c[f+28>>2]=2;c[j>>2]=l&7;ab(f+96|0,35304,j|0)|0;c[j>>2]=(e[k>>1]|0)>>>9&7;ab(f+160|0,35304,j|0)|0;i=h;return}else{a[m+0>>0]=a[36120>>0]|0;a[m+1>>0]=a[36121>>0]|0;a[m+2>>0]=a[36122>>0]|0;a[m+3>>0]=a[36123>>0]|0;a[m+4>>0]=a[36124>>0]|0;a[m+5>>0]=a[36125>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;kj(f,f+160|0,g,a[g+1>>0]&63,8);i=h;return}}function wi(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;i=i+16|0;j=h;k=f+12|0;l=b[k>>1]|0;m=f+32|0;if((l&56)==8){a[m+0>>0]=a[36096>>0]|0;a[m+1>>0]=a[36097>>0]|0;a[m+2>>0]=a[36098>>0]|0;a[m+3>>0]=a[36099>>0]|0;a[m+4>>0]=a[36100>>0]|0;a[m+5>>0]=a[36101>>0]|0;a[m+6>>0]=a[36102>>0]|0;c[f+28>>2]=2;c[j>>2]=l&7;ab(f+96|0,35304,j|0)|0;c[j>>2]=(e[k>>1]|0)>>>9&7;ab(f+160|0,35304,j|0)|0;i=h;return}else{a[m+0>>0]=a[36104>>0]|0;a[m+1>>0]=a[36105>>0]|0;a[m+2>>0]=a[36106>>0]|0;a[m+3>>0]=a[36107>>0]|0;a[m+4>>0]=a[36108>>0]|0;a[m+5>>0]=a[36109>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;kj(f,f+160|0,g,a[g+1>>0]&63,16);i=h;return}}function xi(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;i=i+16|0;j=h;k=f+12|0;l=b[k>>1]|0;m=f+32|0;if((l&56)==8){a[m+0>>0]=a[36080>>0]|0;a[m+1>>0]=a[36081>>0]|0;a[m+2>>0]=a[36082>>0]|0;a[m+3>>0]=a[36083>>0]|0;a[m+4>>0]=a[36084>>0]|0;a[m+5>>0]=a[36085>>0]|0;a[m+6>>0]=a[36086>>0]|0;c[f+28>>2]=2;c[j>>2]=l&7;ab(f+96|0,35304,j|0)|0;c[j>>2]=(e[k>>1]|0)>>>9&7;ab(f+160|0,35304,j|0)|0;i=h;return}else{a[m+0>>0]=a[36088>>0]|0;a[m+1>>0]=a[36089>>0]|0;a[m+2>>0]=a[36090>>0]|0;a[m+3>>0]=a[36091>>0]|0;a[m+4>>0]=a[36092>>0]|0;a[m+5>>0]=a[36093>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;kj(f,f+160|0,g,a[g+1>>0]&63,32);i=h;return}}function yi(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36072>>0]|0;a[h+1>>0]=a[36073>>0]|0;a[h+2>>0]=a[36074>>0]|0;a[h+3>>0]=a[36075>>0]|0;a[h+4>>0]=a[36076>>0]|0;a[h+5>>0]=a[36077>>0]|0;a[h+6>>0]=a[36078>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,32);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35272,g|0)|0;i=f;return}function zi(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36056>>0]|0;a[h+1>>0]=a[36057>>0]|0;a[h+2>>0]=a[36058>>0]|0;a[h+3>>0]=a[36059>>0]|0;a[h+4>>0]=a[36060>>0]|0;a[h+5>>0]=a[36061>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,8);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function Ai(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36040>>0]|0;a[h+1>>0]=a[36041>>0]|0;a[h+2>>0]=a[36042>>0]|0;a[h+3>>0]=a[36043>>0]|0;a[h+4>>0]=a[36044>>0]|0;a[h+5>>0]=a[36045>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function Bi(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36032>>0]|0;a[h+1>>0]=a[36033>>0]|0;a[h+2>>0]=a[36034>>0]|0;a[h+3>>0]=a[36035>>0]|0;a[h+4>>0]=a[36036>>0]|0;a[h+5>>0]=a[36037>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,32);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function Ci(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36064>>0]|0;a[h+1>>0]=a[36065>>0]|0;a[h+2>>0]=a[36066>>0]|0;a[h+3>>0]=a[36067>>0]|0;a[h+4>>0]=a[36068>>0]|0;a[h+5>>0]=a[36069>>0]|0;a[h+6>>0]=a[36070>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function Di(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+16|0;h=g;j=b+12|0;k=e[j>>1]|0;l=k>>>3&7;if((l|0)==0){m=b+32|0;a[m+0>>0]=a[36048>>0]|0;a[m+1>>0]=a[36049>>0]|0;a[m+2>>0]=a[36050>>0]|0;a[m+3>>0]=a[36051>>0]|0;a[m+4>>0]=a[36052>>0]|0;a[m+5>>0]=a[36053>>0]|0;a[m+6>>0]=a[36054>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35264,h|0)|0;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+160|0,35264,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else if((l|0)==1){l=b+32|0;a[l+0>>0]=a[36048>>0]|0;a[l+1>>0]=a[36049>>0]|0;a[l+2>>0]=a[36050>>0]|0;a[l+3>>0]=a[36051>>0]|0;a[l+4>>0]=a[36052>>0]|0;a[l+5>>0]=a[36053>>0]|0;a[l+6>>0]=a[36054>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35312,h|0)|0;c[h>>2]=(e[j>>1]|0)>>>9&7;ab(b+160|0,35312,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else{j=b+32|0;a[j+0>>0]=a[36056>>0]|0;a[j+1>>0]=a[36057>>0]|0;a[j+2>>0]=a[36058>>0]|0;a[j+3>>0]=a[36059>>0]|0;a[j+4>>0]=a[36060>>0]|0;a[j+5>>0]=a[36061>>0]|0;c[b+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+96|0,35264,h|0)|0;kj(b,b+160|0,f,a[f+1>>0]&63,8);i=g;return}}function Ei(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;i=i+16|0;j=h;k=f+12|0;l=(e[k>>1]|0)>>>3&7;if((l|0)==0){m=f+32|0;a[m>>0]=4675653;a[m+1>>0]=18264;a[m+2>>0]=71;a[m+3>>0]=0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return}else if((l|0)==1){l=f+32|0;a[l>>0]=4675653;a[l+1>>0]=18264;a[l+2>>0]=71;a[l+3>>0]=0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35272,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35272,j|0)|0;i=h;return}else{k=f+32|0;a[k+0>>0]=a[36040>>0]|0;a[k+1>>0]=a[36041>>0]|0;a[k+2>>0]=a[36042>>0]|0;a[k+3>>0]=a[36043>>0]|0;a[k+4>>0]=a[36044>>0]|0;a[k+5>>0]=a[36045>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;kj(f,f+160|0,g,a[g+1>>0]&63,16);i=h;return}}function Fi(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;i=i+16|0;j=h;k=f+12|0;l=(e[k>>1]|0)>>>3&7;if((l|0)==0){m=f+32|0;a[m+0>>0]=a[35848>>0]|0;a[m+1>>0]=a[35849>>0]|0;a[m+2>>0]=a[35850>>0]|0;c[f+28>>2]=1;m=(d[g>>0]|0)<<8|(d[g+1>>0]|0);c[j>>2]=35704;c[j+4>>2]=m;ab(f+96|0,35256,j|0)|0;i=h;return}else if((l|0)==1){l=f+32|0;a[l>>0]=4675653;a[l+1>>0]=18264;a[l+2>>0]=71;a[l+3>>0]=0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35272,j|0)|0;i=h;return}else{k=f+32|0;a[k+0>>0]=a[36032>>0]|0;a[k+1>>0]=a[36033>>0]|0;a[k+2>>0]=a[36034>>0]|0;a[k+3>>0]=a[36035>>0]|0;a[k+4>>0]=a[36036>>0]|0;a[k+5>>0]=a[36037>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;kj(f,f+160|0,g,a[g+1>>0]&63,32);i=h;return}}function Gi(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36024>>0]|0;a[h+1>>0]=a[36025>>0]|0;a[h+2>>0]=a[36026>>0]|0;a[h+3>>0]=a[36027>>0]|0;a[h+4>>0]=a[36028>>0]|0;a[h+5>>0]=a[36029>>0]|0;a[h+6>>0]=a[36030>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function Hi(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36008>>0]|0;a[h+1>>0]=a[36009>>0]|0;a[h+2>>0]=a[36010>>0]|0;a[h+3>>0]=a[36011>>0]|0;a[h+4>>0]=a[36012>>0]|0;a[h+5>>0]=a[36013>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,8);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function Ii(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[35992>>0]|0;a[h+1>>0]=a[35993>>0]|0;a[h+2>>0]=a[35994>>0]|0;a[h+3>>0]=a[35995>>0]|0;a[h+4>>0]=a[35996>>0]|0;a[h+5>>0]=a[35997>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function Ji(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[35976>>0]|0;a[h+1>>0]=a[35977>>0]|0;a[h+2>>0]=a[35978>>0]|0;a[h+3>>0]=a[35979>>0]|0;a[h+4>>0]=a[35980>>0]|0;a[h+5>>0]=a[35981>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,32);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35264,g|0)|0;i=f;return}function Ki(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[36016>>0]|0;a[h+1>>0]=a[36017>>0]|0;a[h+2>>0]=a[36018>>0]|0;a[h+3>>0]=a[36019>>0]|0;a[h+4>>0]=a[36020>>0]|0;a[h+5>>0]=a[36021>>0]|0;a[h+6>>0]=a[36022>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35272,g|0)|0;i=f;return}function Li(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+16|0;h=g;j=b+12|0;k=e[j>>1]|0;l=k>>>3&7;if((l|0)==0){m=b+32|0;a[m+0>>0]=a[36e3>>0]|0;a[m+1>>0]=a[36001>>0]|0;a[m+2>>0]=a[36002>>0]|0;a[m+3>>0]=a[36003>>0]|0;a[m+4>>0]=a[36004>>0]|0;a[m+5>>0]=a[36005>>0]|0;a[m+6>>0]=a[36006>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35264,h|0)|0;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+160|0,35264,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else if((l|0)==1){l=b+32|0;a[l+0>>0]=a[36e3>>0]|0;a[l+1>>0]=a[36001>>0]|0;a[l+2>>0]=a[36002>>0]|0;a[l+3>>0]=a[36003>>0]|0;a[l+4>>0]=a[36004>>0]|0;a[l+5>>0]=a[36005>>0]|0;a[l+6>>0]=a[36006>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35312,h|0)|0;c[h>>2]=(e[j>>1]|0)>>>9&7;ab(b+160|0,35312,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else{j=b+32|0;a[j+0>>0]=a[36008>>0]|0;a[j+1>>0]=a[36009>>0]|0;a[j+2>>0]=a[36010>>0]|0;a[j+3>>0]=a[36011>>0]|0;a[j+4>>0]=a[36012>>0]|0;a[j+5>>0]=a[36013>>0]|0;c[b+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+96|0,35264,h|0)|0;kj(b,b+160|0,f,a[f+1>>0]&63,8);i=g;return}}function Mi(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+16|0;h=g;j=b+12|0;k=e[j>>1]|0;l=k>>>3&7;if((l|0)==0){m=b+32|0;a[m+0>>0]=a[35984>>0]|0;a[m+1>>0]=a[35985>>0]|0;a[m+2>>0]=a[35986>>0]|0;a[m+3>>0]=a[35987>>0]|0;a[m+4>>0]=a[35988>>0]|0;a[m+5>>0]=a[35989>>0]|0;a[m+6>>0]=a[35990>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35264,h|0)|0;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+160|0,35264,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else if((l|0)==1){l=b+32|0;a[l+0>>0]=a[35984>>0]|0;a[l+1>>0]=a[35985>>0]|0;a[l+2>>0]=a[35986>>0]|0;a[l+3>>0]=a[35987>>0]|0;a[l+4>>0]=a[35988>>0]|0;a[l+5>>0]=a[35989>>0]|0;a[l+6>>0]=a[35990>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35312,h|0)|0;c[h>>2]=(e[j>>1]|0)>>>9&7;ab(b+160|0,35312,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else{j=b+32|0;a[j+0>>0]=a[35992>>0]|0;a[j+1>>0]=a[35993>>0]|0;a[j+2>>0]=a[35994>>0]|0;a[j+3>>0]=a[35995>>0]|0;a[j+4>>0]=a[35996>>0]|0;a[j+5>>0]=a[35997>>0]|0;c[b+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+96|0,35264,h|0)|0;kj(b,b+160|0,f,a[f+1>>0]&63,16);i=g;return}}function Ni(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;i=i+16|0;h=g;j=b+12|0;k=e[j>>1]|0;l=k>>>3&7;if((l|0)==0){m=b+32|0;a[m+0>>0]=a[35968>>0]|0;a[m+1>>0]=a[35969>>0]|0;a[m+2>>0]=a[35970>>0]|0;a[m+3>>0]=a[35971>>0]|0;a[m+4>>0]=a[35972>>0]|0;a[m+5>>0]=a[35973>>0]|0;a[m+6>>0]=a[35974>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35264,h|0)|0;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+160|0,35264,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else if((l|0)==1){l=b+32|0;a[l+0>>0]=a[35968>>0]|0;a[l+1>>0]=a[35969>>0]|0;a[l+2>>0]=a[35970>>0]|0;a[l+3>>0]=a[35971>>0]|0;a[l+4>>0]=a[35972>>0]|0;a[l+5>>0]=a[35973>>0]|0;a[l+6>>0]=a[35974>>0]|0;c[b+28>>2]=2;c[h>>2]=k&7;ab(b+96|0,35312,h|0)|0;c[h>>2]=(e[j>>1]|0)>>>9&7;ab(b+160|0,35312,h|0)|0;c[b>>2]=c[b>>2]|32;i=g;return}else{j=b+32|0;a[j+0>>0]=a[35976>>0]|0;a[j+1>>0]=a[35977>>0]|0;a[j+2>>0]=a[35978>>0]|0;a[j+3>>0]=a[35979>>0]|0;a[j+4>>0]=a[35980>>0]|0;a[j+5>>0]=a[35981>>0]|0;c[b+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(b+96|0,35264,h|0)|0;kj(b,b+160|0,f,a[f+1>>0]&63,32);i=g;return}}function Oi(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[35960>>0]|0;a[h+1>>0]=a[35961>>0]|0;a[h+2>>0]=a[35962>>0]|0;a[h+3>>0]=a[35963>>0]|0;a[h+4>>0]=a[35964>>0]|0;a[h+5>>0]=a[35965>>0]|0;a[h+6>>0]=a[35966>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,32);c[g>>2]=(d[e>>0]|0)>>>1&7;ab(b+160|0,35272,g|0)|0;i=f;return}function Pi(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;i=i+16|0;j=h;k=f+12|0;switch((e[k>>1]|0)>>>3&7|0){case 7:{l=f+32|0;a[l+0>>0]=a[35952>>0]|0;a[l+1>>0]=a[35953>>0]|0;a[l+2>>0]=a[35954>>0]|0;a[l+3>>0]=a[35955>>0]|0;a[l+4>>0]=a[35956>>0]|0;a[l+5>>0]=a[35957>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 5:{l=f+32|0;a[l+0>>0]=a[35936>>0]|0;a[l+1>>0]=a[35937>>0]|0;a[l+2>>0]=a[35938>>0]|0;a[l+3>>0]=a[35939>>0]|0;a[l+4>>0]=a[35940>>0]|0;a[l+5>>0]=a[35941>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 2:{l=f+32|0;a[l+0>>0]=a[35944>>0]|0;a[l+1>>0]=a[35945>>0]|0;a[l+2>>0]=a[35946>>0]|0;a[l+3>>0]=a[35947>>0]|0;a[l+4>>0]=a[35948>>0]|0;a[l+5>>0]=a[35949>>0]|0;a[l+6>>0]=a[35950>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;c[f>>2]=c[f>>2]|32;i=h;return};case 3:{l=f+32|0;a[l+0>>0]=a[35952>>0]|0;a[l+1>>0]=a[35953>>0]|0;a[l+2>>0]=a[35954>>0]|0;a[l+3>>0]=a[35955>>0]|0;a[l+4>>0]=a[35956>>0]|0;a[l+5>>0]=a[35957>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 0:{l=f+32|0;a[l+0>>0]=a[35928>>0]|0;a[l+1>>0]=a[35929>>0]|0;a[l+2>>0]=a[35930>>0]|0;a[l+3>>0]=a[35931>>0]|0;a[l+4>>0]=a[35932>>0]|0;a[l+5>>0]=a[35933>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 1:{l=f+32|0;a[l+0>>0]=a[35936>>0]|0;a[l+1>>0]=a[35937>>0]|0;a[l+2>>0]=a[35938>>0]|0;a[l+3>>0]=a[35939>>0]|0;a[l+4>>0]=a[35940>>0]|0;a[l+5>>0]=a[35941>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 4:{l=f+32|0;a[l+0>>0]=a[35928>>0]|0;a[l+1>>0]=a[35929>>0]|0;a[l+2>>0]=a[35930>>0]|0;a[l+3>>0]=a[35931>>0]|0;a[l+4>>0]=a[35932>>0]|0;a[l+5>>0]=a[35933>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 6:{l=f+32|0;a[l+0>>0]=a[35944>>0]|0;a[l+1>>0]=a[35945>>0]|0;a[l+2>>0]=a[35946>>0]|0;a[l+3>>0]=a[35947>>0]|0;a[l+4>>0]=a[35948>>0]|0;a[l+5>>0]=a[35949>>0]|0;a[l+6>>0]=a[35950>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;c[f>>2]=c[f>>2]|32;i=h;return};default:{k=f+32|0;a[k+0>>0]=a[35848>>0]|0;a[k+1>>0]=a[35849>>0]|0;a[k+2>>0]=a[35850>>0]|0;c[f+28>>2]=1;k=(d[g>>0]|0)<<8|(d[g+1>>0]|0);c[j>>2]=35704;c[j+4>>2]=k;ab(f+96|0,35256,j|0)|0;i=h;return}}}function Qi(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;i=i+16|0;j=h;k=f+12|0;switch((e[k>>1]|0)>>>3&7|0){case 4:{l=f+32|0;a[l+0>>0]=a[35888>>0]|0;a[l+1>>0]=a[35889>>0]|0;a[l+2>>0]=a[35890>>0]|0;a[l+3>>0]=a[35891>>0]|0;a[l+4>>0]=a[35892>>0]|0;a[l+5>>0]=a[35893>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 0:{l=f+32|0;a[l+0>>0]=a[35888>>0]|0;a[l+1>>0]=a[35889>>0]|0;a[l+2>>0]=a[35890>>0]|0;a[l+3>>0]=a[35891>>0]|0;a[l+4>>0]=a[35892>>0]|0;a[l+5>>0]=a[35893>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 2:{l=f+32|0;a[l+0>>0]=a[35784>>0]|0;a[l+1>>0]=a[35785>>0]|0;a[l+2>>0]=a[35786>>0]|0;a[l+3>>0]=a[35787>>0]|0;a[l+4>>0]=a[35788>>0]|0;a[l+5>>0]=a[35789>>0]|0;a[l+6>>0]=a[35790>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;c[f>>2]=c[f>>2]|32;i=h;return};case 1:{l=f+32|0;a[l+0>>0]=a[35800>>0]|0;a[l+1>>0]=a[35801>>0]|0;a[l+2>>0]=a[35802>>0]|0;a[l+3>>0]=a[35803>>0]|0;a[l+4>>0]=a[35804>>0]|0;a[l+5>>0]=a[35805>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 5:{l=f+32|0;a[l+0>>0]=a[35800>>0]|0;a[l+1>>0]=a[35801>>0]|0;a[l+2>>0]=a[35802>>0]|0;a[l+3>>0]=a[35803>>0]|0;a[l+4>>0]=a[35804>>0]|0;a[l+5>>0]=a[35805>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 7:{l=f+32|0;a[l+0>>0]=a[35768>>0]|0;a[l+1>>0]=a[35769>>0]|0;a[l+2>>0]=a[35770>>0]|0;a[l+3>>0]=a[35771>>0]|0;a[l+4>>0]=a[35772>>0]|0;a[l+5>>0]=a[35773>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 6:{l=f+32|0;a[l+0>>0]=a[35784>>0]|0;a[l+1>>0]=a[35785>>0]|0;a[l+2>>0]=a[35786>>0]|0;a[l+3>>0]=a[35787>>0]|0;a[l+4>>0]=a[35788>>0]|0;a[l+5>>0]=a[35789>>0]|0;a[l+6>>0]=a[35790>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;c[f>>2]=c[f>>2]|32;i=h;return};case 3:{l=f+32|0;a[l+0>>0]=a[35768>>0]|0;a[l+1>>0]=a[35769>>0]|0;a[l+2>>0]=a[35770>>0]|0;a[l+3>>0]=a[35771>>0]|0;a[l+4>>0]=a[35772>>0]|0;a[l+5>>0]=a[35773>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};default:{k=f+32|0;a[k+0>>0]=a[35848>>0]|0;a[k+1>>0]=a[35849>>0]|0;a[k+2>>0]=a[35850>>0]|0;c[f+28>>2]=1;k=(d[g>>0]|0)<<8|(d[g+1>>0]|0);c[j>>2]=35704;c[j+4>>2]=k;ab(f+96|0,35256,j|0)|0;i=h;return}}}function Ri(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;i=i+16|0;j=h;k=f+12|0;switch((e[k>>1]|0)>>>3&7|0){case 7:{l=f+32|0;a[l+0>>0]=a[35920>>0]|0;a[l+1>>0]=a[35921>>0]|0;a[l+2>>0]=a[35922>>0]|0;a[l+3>>0]=a[35923>>0]|0;a[l+4>>0]=a[35924>>0]|0;a[l+5>>0]=a[35925>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 4:{l=f+32|0;a[l+0>>0]=a[35896>>0]|0;a[l+1>>0]=a[35897>>0]|0;a[l+2>>0]=a[35898>>0]|0;a[l+3>>0]=a[35899>>0]|0;a[l+4>>0]=a[35900>>0]|0;a[l+5>>0]=a[35901>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 0:{l=f+32|0;a[l+0>>0]=a[35896>>0]|0;a[l+1>>0]=a[35897>>0]|0;a[l+2>>0]=a[35898>>0]|0;a[l+3>>0]=a[35899>>0]|0;a[l+4>>0]=a[35900>>0]|0;a[l+5>>0]=a[35901>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 1:{l=f+32|0;a[l+0>>0]=a[35904>>0]|0;a[l+1>>0]=a[35905>>0]|0;a[l+2>>0]=a[35906>>0]|0;a[l+3>>0]=a[35907>>0]|0;a[l+4>>0]=a[35908>>0]|0;a[l+5>>0]=a[35909>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 3:{l=f+32|0;a[l+0>>0]=a[35920>>0]|0;a[l+1>>0]=a[35921>>0]|0;a[l+2>>0]=a[35922>>0]|0;a[l+3>>0]=a[35923>>0]|0;a[l+4>>0]=a[35924>>0]|0;a[l+5>>0]=a[35925>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 5:{l=f+32|0;a[l+0>>0]=a[35904>>0]|0;a[l+1>>0]=a[35905>>0]|0;a[l+2>>0]=a[35906>>0]|0;a[l+3>>0]=a[35907>>0]|0;a[l+4>>0]=a[35908>>0]|0;a[l+5>>0]=a[35909>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 2:{l=f+32|0;a[l+0>>0]=a[35912>>0]|0;a[l+1>>0]=a[35913>>0]|0;a[l+2>>0]=a[35914>>0]|0;a[l+3>>0]=a[35915>>0]|0;a[l+4>>0]=a[35916>>0]|0;a[l+5>>0]=a[35917>>0]|0;a[l+6>>0]=a[35918>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;c[f>>2]=c[f>>2]|32;i=h;return};case 6:{l=f+32|0;a[l+0>>0]=a[35912>>0]|0;a[l+1>>0]=a[35913>>0]|0;a[l+2>>0]=a[35914>>0]|0;a[l+3>>0]=a[35915>>0]|0;a[l+4>>0]=a[35916>>0]|0;a[l+5>>0]=a[35917>>0]|0;a[l+6>>0]=a[35918>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;c[f>>2]=c[f>>2]|32;i=h;return};default:{k=f+32|0;a[k+0>>0]=a[35848>>0]|0;a[k+1>>0]=a[35849>>0]|0;a[k+2>>0]=a[35850>>0]|0;c[f+28>>2]=1;k=(d[g>>0]|0)<<8|(d[g+1>>0]|0);c[j>>2]=35704;c[j+4>>2]=k;ab(f+96|0,35256,j|0)|0;i=h;return}}}function Si(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[35888>>0]|0;a[f+1>>0]=a[35889>>0]|0;a[f+2>>0]=a[35890>>0]|0;a[f+3>>0]=a[35891>>0]|0;a[f+4>>0]=a[35892>>0]|0;a[f+5>>0]=a[35893>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);i=e;return}function Ti(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;i=i+16|0;j=h;k=f+12|0;switch((e[k>>1]|0)>>>3&7|0){case 1:{l=f+32|0;a[l+0>>0]=a[35864>>0]|0;a[l+1>>0]=a[35865>>0]|0;a[l+2>>0]=a[35866>>0]|0;a[l+3>>0]=a[35867>>0]|0;a[l+4>>0]=a[35868>>0]|0;a[l+5>>0]=a[35869>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 2:{l=f+32|0;a[l+0>>0]=a[35872>>0]|0;a[l+1>>0]=a[35873>>0]|0;a[l+2>>0]=a[35874>>0]|0;a[l+3>>0]=a[35875>>0]|0;a[l+4>>0]=a[35876>>0]|0;a[l+5>>0]=a[35877>>0]|0;a[l+6>>0]=a[35878>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;c[f>>2]=c[f>>2]|32;i=h;return};case 3:{l=f+32|0;a[l+0>>0]=a[35880>>0]|0;a[l+1>>0]=a[35881>>0]|0;a[l+2>>0]=a[35882>>0]|0;a[l+3>>0]=a[35883>>0]|0;a[l+4>>0]=a[35884>>0]|0;a[l+5>>0]=a[35885>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 5:{l=f+32|0;a[l+0>>0]=a[35864>>0]|0;a[l+1>>0]=a[35865>>0]|0;a[l+2>>0]=a[35866>>0]|0;a[l+3>>0]=a[35867>>0]|0;a[l+4>>0]=a[35868>>0]|0;a[l+5>>0]=a[35869>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 0:{l=f+32|0;a[l+0>>0]=a[35856>>0]|0;a[l+1>>0]=a[35857>>0]|0;a[l+2>>0]=a[35858>>0]|0;a[l+3>>0]=a[35859>>0]|0;a[l+4>>0]=a[35860>>0]|0;a[l+5>>0]=a[35861>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 6:{l=f+32|0;a[l+0>>0]=a[35872>>0]|0;a[l+1>>0]=a[35873>>0]|0;a[l+2>>0]=a[35874>>0]|0;a[l+3>>0]=a[35875>>0]|0;a[l+4>>0]=a[35876>>0]|0;a[l+5>>0]=a[35877>>0]|0;a[l+6>>0]=a[35878>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;c[f>>2]=c[f>>2]|32;i=h;return};case 4:{l=f+32|0;a[l+0>>0]=a[35856>>0]|0;a[l+1>>0]=a[35857>>0]|0;a[l+2>>0]=a[35858>>0]|0;a[l+3>>0]=a[35859>>0]|0;a[l+4>>0]=a[35860>>0]|0;a[l+5>>0]=a[35861>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 7:{l=f+32|0;a[l+0>>0]=a[35880>>0]|0;a[l+1>>0]=a[35881>>0]|0;a[l+2>>0]=a[35882>>0]|0;a[l+3>>0]=a[35883>>0]|0;a[l+4>>0]=a[35884>>0]|0;a[l+5>>0]=a[35885>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};default:{k=f+32|0;a[k+0>>0]=a[35848>>0]|0;a[k+1>>0]=a[35849>>0]|0;a[k+2>>0]=a[35850>>0]|0;c[f+28>>2]=1;k=(d[g>>0]|0)<<8|(d[g+1>>0]|0);c[j>>2]=35704;c[j+4>>2]=k;ab(f+96|0,35256,j|0)|0;i=h;return}}}function Ui(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;i=i+16|0;j=h;k=f+12|0;switch((e[k>>1]|0)>>>3&7|0){case 7:{l=f+32|0;a[l+0>>0]=a[35760>>0]|0;a[l+1>>0]=a[35761>>0]|0;a[l+2>>0]=a[35762>>0]|0;a[l+3>>0]=a[35763>>0]|0;a[l+4>>0]=a[35764>>0]|0;a[l+5>>0]=a[35765>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 1:{l=f+32|0;a[l+0>>0]=a[35792>>0]|0;a[l+1>>0]=a[35793>>0]|0;a[l+2>>0]=a[35794>>0]|0;a[l+3>>0]=a[35795>>0]|0;a[l+4>>0]=a[35796>>0]|0;a[l+5>>0]=a[35797>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 6:{l=f+32|0;a[l+0>>0]=a[35776>>0]|0;a[l+1>>0]=a[35777>>0]|0;a[l+2>>0]=a[35778>>0]|0;a[l+3>>0]=a[35779>>0]|0;a[l+4>>0]=a[35780>>0]|0;a[l+5>>0]=a[35781>>0]|0;a[l+6>>0]=a[35782>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;c[f>>2]=c[f>>2]|32;i=h;return};case 5:{l=f+32|0;a[l+0>>0]=a[35792>>0]|0;a[l+1>>0]=a[35793>>0]|0;a[l+2>>0]=a[35794>>0]|0;a[l+3>>0]=a[35795>>0]|0;a[l+4>>0]=a[35796>>0]|0;a[l+5>>0]=a[35797>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 0:{l=f+32|0;a[l+0>>0]=a[35808>>0]|0;a[l+1>>0]=a[35809>>0]|0;a[l+2>>0]=a[35810>>0]|0;a[l+3>>0]=a[35811>>0]|0;a[l+4>>0]=a[35812>>0]|0;a[l+5>>0]=a[35813>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 2:{l=f+32|0;a[l+0>>0]=a[35776>>0]|0;a[l+1>>0]=a[35777>>0]|0;a[l+2>>0]=a[35778>>0]|0;a[l+3>>0]=a[35779>>0]|0;a[l+4>>0]=a[35780>>0]|0;a[l+5>>0]=a[35781>>0]|0;a[l+6>>0]=a[35782>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;c[f>>2]=c[f>>2]|32;i=h;return};case 3:{l=f+32|0;a[l+0>>0]=a[35760>>0]|0;a[l+1>>0]=a[35761>>0]|0;a[l+2>>0]=a[35762>>0]|0;a[l+3>>0]=a[35763>>0]|0;a[l+4>>0]=a[35764>>0]|0;a[l+5>>0]=a[35765>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 4:{l=f+32|0;a[l+0>>0]=a[35808>>0]|0;a[l+1>>0]=a[35809>>0]|0;a[l+2>>0]=a[35810>>0]|0;a[l+3>>0]=a[35811>>0]|0;a[l+4>>0]=a[35812>>0]|0;a[l+5>>0]=a[35813>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};default:{k=f+32|0;a[k+0>>0]=a[35848>>0]|0;a[k+1>>0]=a[35849>>0]|0;a[k+2>>0]=a[35850>>0]|0;c[f+28>>2]=1;k=(d[g>>0]|0)<<8|(d[g+1>>0]|0);c[j>>2]=35704;c[j+4>>2]=k;ab(f+96|0,35256,j|0)|0;i=h;return}}}function Vi(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0;h=i;i=i+16|0;j=h;k=f+12|0;switch((e[k>>1]|0)>>>3&7|0){case 2:{l=f+32|0;a[l+0>>0]=a[35832>>0]|0;a[l+1>>0]=a[35833>>0]|0;a[l+2>>0]=a[35834>>0]|0;a[l+3>>0]=a[35835>>0]|0;a[l+4>>0]=a[35836>>0]|0;a[l+5>>0]=a[35837>>0]|0;a[l+6>>0]=a[35838>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;c[f>>2]=c[f>>2]|32;i=h;return};case 1:{l=f+32|0;a[l+0>>0]=a[35824>>0]|0;a[l+1>>0]=a[35825>>0]|0;a[l+2>>0]=a[35826>>0]|0;a[l+3>>0]=a[35827>>0]|0;a[l+4>>0]=a[35828>>0]|0;a[l+5>>0]=a[35829>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 4:{l=f+32|0;a[l+0>>0]=a[35816>>0]|0;a[l+1>>0]=a[35817>>0]|0;a[l+2>>0]=a[35818>>0]|0;a[l+3>>0]=a[35819>>0]|0;a[l+4>>0]=a[35820>>0]|0;a[l+5>>0]=a[35821>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 6:{l=f+32|0;a[l+0>>0]=a[35832>>0]|0;a[l+1>>0]=a[35833>>0]|0;a[l+2>>0]=a[35834>>0]|0;a[l+3>>0]=a[35835>>0]|0;a[l+4>>0]=a[35836>>0]|0;a[l+5>>0]=a[35837>>0]|0;a[l+6>>0]=a[35838>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;c[f>>2]=c[f>>2]|32;i=h;return};case 0:{l=f+32|0;a[l+0>>0]=a[35816>>0]|0;a[l+1>>0]=a[35817>>0]|0;a[l+2>>0]=a[35818>>0]|0;a[l+3>>0]=a[35819>>0]|0;a[l+4>>0]=a[35820>>0]|0;a[l+5>>0]=a[35821>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 5:{l=f+32|0;a[l+0>>0]=a[35824>>0]|0;a[l+1>>0]=a[35825>>0]|0;a[l+2>>0]=a[35826>>0]|0;a[l+3>>0]=a[35827>>0]|0;a[l+4>>0]=a[35828>>0]|0;a[l+5>>0]=a[35829>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 7:{l=f+32|0;a[l+0>>0]=a[35840>>0]|0;a[l+1>>0]=a[35841>>0]|0;a[l+2>>0]=a[35842>>0]|0;a[l+3>>0]=a[35843>>0]|0;a[l+4>>0]=a[35844>>0]|0;a[l+5>>0]=a[35845>>0]|0;c[f+28>>2]=2;c[j>>2]=(d[g>>0]|0)>>>1&7;ab(f+96|0,35264,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};case 3:{l=f+32|0;a[l+0>>0]=a[35840>>0]|0;a[l+1>>0]=a[35841>>0]|0;a[l+2>>0]=a[35842>>0]|0;a[l+3>>0]=a[35843>>0]|0;a[l+4>>0]=a[35844>>0]|0;a[l+5>>0]=a[35845>>0]|0;c[f+28>>2]=2;l=(d[g>>0]|0)>>>1&7;c[j>>2]=35704;c[j+4>>2]=(l|0)==0?8:l;ab(f+96|0,35376,j|0)|0;c[j>>2]=b[k>>1]&7;ab(f+160|0,35264,j|0)|0;i=h;return};default:{k=f+32|0;a[k+0>>0]=a[35848>>0]|0;a[k+1>>0]=a[35849>>0]|0;a[k+2>>0]=a[35850>>0]|0;c[f+28>>2]=1;k=(d[g>>0]|0)<<8|(d[g+1>>0]|0);c[j>>2]=35704;c[j+4>>2]=k;ab(f+96|0,35256,j|0)|0;i=h;return}}}function Wi(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[35808>>0]|0;a[f+1>>0]=a[35809>>0]|0;a[f+2>>0]=a[35810>>0]|0;a[f+3>>0]=a[35811>>0]|0;a[f+4>>0]=a[35812>>0]|0;a[f+5>>0]=a[35813>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);i=e;return}function Xi(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[35800>>0]|0;a[f+1>>0]=a[35801>>0]|0;a[f+2>>0]=a[35802>>0]|0;a[f+3>>0]=a[35803>>0]|0;a[f+4>>0]=a[35804>>0]|0;a[f+5>>0]=a[35805>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);i=e;return}function Yi(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[35792>>0]|0;a[f+1>>0]=a[35793>>0]|0;a[f+2>>0]=a[35794>>0]|0;a[f+3>>0]=a[35795>>0]|0;a[f+4>>0]=a[35796>>0]|0;a[f+5>>0]=a[35797>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);i=e;return}function Zi(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[35784>>0]|0;a[f+1>>0]=a[35785>>0]|0;a[f+2>>0]=a[35786>>0]|0;a[f+3>>0]=a[35787>>0]|0;a[f+4>>0]=a[35788>>0]|0;a[f+5>>0]=a[35789>>0]|0;a[f+6>>0]=a[35790>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);c[b>>2]=c[b>>2]|32;i=e;return}function _i(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[35776>>0]|0;a[f+1>>0]=a[35777>>0]|0;a[f+2>>0]=a[35778>>0]|0;a[f+3>>0]=a[35779>>0]|0;a[f+4>>0]=a[35780>>0]|0;a[f+5>>0]=a[35781>>0]|0;a[f+6>>0]=a[35782>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);c[b>>2]=c[b>>2]|32;i=e;return}function $i(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[35768>>0]|0;a[f+1>>0]=a[35769>>0]|0;a[f+2>>0]=a[35770>>0]|0;a[f+3>>0]=a[35771>>0]|0;a[f+4>>0]=a[35772>>0]|0;a[f+5>>0]=a[35773>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);i=e;return}function aj(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[35760>>0]|0;a[f+1>>0]=a[35761>>0]|0;a[f+2>>0]=a[35762>>0]|0;a[f+3>>0]=a[35763>>0]|0;a[f+4>>0]=a[35764>>0]|0;a[f+5>>0]=a[35765>>0]|0;c[b+28>>2]=1;kj(b,b+96|0,d,a[d+1>>0]&63,16);i=e;return}function bj(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[35752>>0]|0;a[f+1>>0]=a[35753>>0]|0;a[f+2>>0]=a[35754>>0]|0;a[f+3>>0]=a[35755>>0]|0;a[f+4>>0]=a[35756>>0]|0;a[f+5>>0]=a[35757>>0]|0;c[b+28>>2]=1;jj(b,b+96|0,d,33,8);i=e;return}function cj(b,d){b=b|0;d=d|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[35744>>0]|0;a[h+1>>0]=a[35745>>0]|0;a[h+2>>0]=a[35746>>0]|0;a[h+3>>0]=a[35747>>0]|0;a[h+4>>0]=a[35748>>0]|0;a[h+5>>0]=a[35749>>0]|0;a[h+6>>0]=a[35750>>0]|0;c[b+28>>2]=2;jj(b,b+96|0,d,33,8);c[g>>2]=(e[b+14>>1]|0)>>>12&7;ab(b+160|0,35264,g|0)|0;i=f;return}function dj(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[35736>>0]|0;a[f+1>>0]=a[35737>>0]|0;a[f+2>>0]=a[35738>>0]|0;a[f+3>>0]=a[35739>>0]|0;a[f+4>>0]=a[35740>>0]|0;a[f+5>>0]=a[35741>>0]|0;c[b+28>>2]=1;jj(b,b+96|0,d,33,8);i=e;return}function ej(b,d){b=b|0;d=d|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[35728>>0]|0;a[h+1>>0]=a[35729>>0]|0;a[h+2>>0]=a[35730>>0]|0;a[h+3>>0]=a[35731>>0]|0;a[h+4>>0]=a[35732>>0]|0;a[h+5>>0]=a[35733>>0]|0;a[h+6>>0]=a[35734>>0]|0;c[b+28>>2]=2;jj(b,b+96|0,d,33,8);c[g>>2]=(e[b+14>>1]|0)>>>12&7;ab(b+160|0,35264,g|0)|0;i=f;return}function fj(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[35720>>0]|0;a[f+1>>0]=a[35721>>0]|0;a[f+2>>0]=a[35722>>0]|0;a[f+3>>0]=a[35723>>0]|0;a[f+4>>0]=a[35724>>0]|0;a[f+5>>0]=a[35725>>0]|0;c[b+28>>2]=1;jj(b,b+96|0,d,33,8);i=e;return}function gj(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=b+32|0;a[f+0>>0]=a[35712>>0]|0;a[f+1>>0]=a[35713>>0]|0;a[f+2>>0]=a[35714>>0]|0;a[f+3>>0]=a[35715>>0]|0;a[f+4>>0]=a[35716>>0]|0;a[f+5>>0]=a[35717>>0]|0;c[b+28>>2]=1;jj(b,b+96|0,d,33,8);i=e;return}function hj(b,d){b=b|0;d=d|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[35248>>0]|0;a[h+1>>0]=a[35249>>0]|0;a[h+2>>0]=a[35250>>0]|0;a[h+3>>0]=a[35251>>0]|0;a[h+4>>0]=a[35252>>0]|0;a[h+5>>0]=a[35253>>0]|0;c[b+28>>2]=2;c[g>>2]=(e[b+14>>1]|0)>>>12&7;ab(b+96|0,35264,g|0)|0;jj(b,b+160|0,d,33,8);i=f;return}function ij(a,b){a=a|0;b=b|0;var d=0,f=0;b=i;i=i+32|0;d=b;f=b+8|0;c[d>>2]=e[a+12>>1]|0;ab(f|0,35240,d|0)|0;Rz(a+32|0,f|0)|0;c[a+28>>2]=0;c[a>>2]=c[a>>2]|4;i=b;return}function jj(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;l=i;i=i+16|0;m=l;do{switch(j|0){case 8:{c[m>>2]=(d[h>>0]|0)>>>1&7;ab(g|0,35272,m|0)|0;i=l;return};case 13:{c[m>>2]=(e[f+12>>1]|0)>>>9&7;ab(g|0,35312,m|0)|0;i=l;return};case 3:{kj(f,g,h,a[h+1>>0]&63,k);i=l;return};case 20:{n=e[f+12>>1]|0;c[m>>2]=35704;c[m+4>>2]=(n&128|0)!=0?n|-256:n&255;ab(g|0,35360,m|0)|0;i=l;return};case 0:{a[g>>0]=0;i=l;return};case 22:{n=f+8|0;o=c[n>>2]|0;p=o<<1;q=(d[h+p>>0]|0)<<8;r=q|(d[h+(p|1)>>0]|0);c[n>>2]=o+1;o=(c[f+4>>2]|0)+2+((q&32768|0)!=0?r|-65536:r)|0;c[m>>2]=35704;c[m+4>>2]=o;ab(g|0,35384,m|0)|0;i=l;return};case 11:{c[m>>2]=(e[f+12>>1]|0)>>>9&7;ab(g|0,35304,m|0)|0;i=l;return};case 24:{o=(d[h+2>>0]|0)<<8|(d[h+3>>0]|0);c[m>>2]=1;a[g>>0]=0;r=0;q=0;n=0;while(1){if((r|0)!=8|(n|0)==0){s=n}else{lj(g,q,n,m);s=0}p=(s|0)==0;if((1<<r&o|0)==0){if(p){t=q;u=0}else{lj(g,q,s,m);t=q;u=0}}else{t=p?r:q;u=s+1|0}r=r+1|0;if((r|0)==16){break}else{q=t;n=u}}if((u|0)!=0){lj(g,t,u,m)}n=f+8|0;c[n>>2]=(c[n>>2]|0)+1;i=l;return};case 23:{n=f+8|0;q=c[n>>2]|0;r=q<<1;o=(((d[h+r>>0]|0)<<8|(d[h+(r|1)>>0]|0))<<8|(d[h+(r+2)>>0]|0))<<8|(d[h+(r+3)>>0]|0);c[n>>2]=q+2;q=(c[f+4>>2]|0)+2+o|0;c[m>>2]=35704;c[m+4>>2]=q;ab(g|0,35384,m|0)|0;i=l;return};case 28:{a[g>>0]=5264213;a[g+1>>0]=20563;a[g+2>>0]=80;a[g+3>>0]=0;i=l;return};case 27:{a[g+0>>0]=a[35392>>0]|0;a[g+1>>0]=a[35393>>0]|0;a[g+2>>0]=a[35394>>0]|0;i=l;return};case 26:{a[g>>0]=5391171;a[g+1>>0]=21059;a[g+2>>0]=82;a[g+3>>0]=0;i=l;return};case 5:{c[m>>2]=b[f+12>>1]&7;ab(g|0,35264,m|0)|0;i=l;return};case 21:{q=d[h+1>>0]|0;o=(c[f+4>>2]|0)+2+((q&128|0)!=0?q|-256:q)|0;c[m>>2]=35704;c[m+4>>2]=o;ab(g|0,35384,m|0)|0;i=l;return};case 9:{o=d[h+2>>0]|0;c[m>>2]=(o&128|0)!=0?35288:35296;c[m+4>>2]=o>>>4&7;ab(g|0,35280,m|0)|0;i=l;return};case 2:{o=(d[h+2>>0]|0)<<8|(d[h+3>>0]|0);c[m>>2]=35704;c[m+4>>2]=o;ab(g|0,35256,m|0)|0;i=l;return};case 4:{o=d[h>>0]|0;kj(f,g,h,(o<<8|(d[h+1>>0]|0))>>>3&56|o>>>1&7,k);i=l;return};case 10:{c[m>>2]=b[f+12>>1]&7;ab(g|0,35304,m|0)|0;i=l;return};case 30:{o=e[f+14>>1]|0;c[m>>2]=o&7;c[m+4>>2]=o>>>12&7;ab(g|0,35408,m|0)|0;i=l;return};case 31:{o=e[f+14>>1]|0;c[m>>2]=o&7;c[m+4>>2]=o>>>12&7;ab(g|0,35408,m|0)|0;i=l;return};case 34:case 32:{c[m>>2]=(e[f+14>>1]|0)>>>12&7;ab(g|0,35264,m|0)|0;i=l;return};case 33:{o=f+8|0;q=c[o>>2]|0;n=q<<1;r=(d[h+n>>0]|0)<<8|(d[h+(n|1)>>0]|0);n=q+1|0;c[o>>2]=n;b[f+(n<<1)+12>>1]=r;kj(f,g,h,a[h+1>>0]&63,8);r=Kz(g|0)|0;a[g+r>>0]=32;n=r+2|0;o=g+n|0;a[g+(r+1)>>0]=123;r=f+14|0;q=e[r>>1]|0;p=q>>>6;if((q&2048|0)==0){c[m>>2]=p&31;ab(o|0,35416,m|0)|0}else{c[m>>2]=p&7;ab(o|0,35264,m|0)|0}p=(Kz(o|0)|0)+n|0;n=p+1|0;o=g+n|0;a[g+p>>0]=58;p=e[r>>1]|0;r=p&31;q=(r|0)==0?32:r;if((p&32|0)==0){c[m>>2]=q;ab(o|0,35416,m|0)|0}else{c[m>>2]=q&7;ab(o|0,35264,m|0)|0}q=g+((Kz(o|0)|0)+n)|0;a[q>>0]=125;a[q+1>>0]=0;i=l;return};case 16:{q=(d[h+2>>0]|0)<<8|(d[h+3>>0]|0);c[m>>2]=35704;c[m+4>>2]=q;ab(g|0,35256,m|0)|0;q=f+8|0;c[q>>2]=(c[q>>2]|0)+1;i=l;return};case 25:{q=a[h+2>>0]|0;n=q&255;o=d[h+3>>0]|0;c[m>>2]=1;a[g>>0]=0;p=((((((((((((((n<<8|o)<<1|o&1)<<2&252|o&2|o>>>2&1)<<1&510|o>>>3&1)<<1&1022|o>>>4&1)<<1&2046|o>>>5&1)<<1&4094|o>>>6&1)<<1&8190|o>>>7)<<1&16382|n&1)<<2|n&2|n>>>2&1)<<1&4094|n>>>3&1)<<1&8190|n>>>4&1)<<1&16382|n>>>5&1)<<1&32766|(q&255)>>>6&1)<<1|n>>>7;n=0;q=0;o=0;while(1){if((n|0)!=8|(o|0)==0){v=o}else{lj(g,q,o,m);v=0}r=(v|0)==0;if((p&1<<n|0)==0){if(r){w=q;x=0}else{lj(g,q,v,m);w=q;x=0}}else{w=r?n:q;x=v+1|0}n=n+1|0;if((n|0)==16){break}else{q=w;o=x}}if((x|0)!=0){lj(g,w,x,m)}o=f+8|0;c[o>>2]=(c[o>>2]|0)+1;i=l;return};case 14:{o=(d[h+2>>0]|0)<<8;q=o|(d[h+3>>0]|0);n=(o&32768|0)!=0;o=b[f+12>>1]&7;c[m>>2]=n?35336:35344;c[m+4>>2]=35704;c[m+8>>2]=(n?0-q|0:q)&65535;c[m+12>>2]=o;ab(g|0,35320,m|0)|0;o=f+8|0;c[o>>2]=(c[o>>2]|0)+1;i=l;return};case 29:{o=(d[h+2>>0]|0)<<8&3840|(d[h+3>>0]|0);if((o|0)==0){c[f>>2]=c[f>>2]|64;y=35424}else if((o|0)==1){c[f>>2]=c[f>>2]|64;y=35432}else if((o|0)==2048){c[f>>2]=c[f>>2]|64;y=35400}else if((o|0)==2049){c[f>>2]=c[f>>2]|64;y=35440}else{c[m>>2]=o;ab(g|0,35448,m|0)|0;c[f>>2]=c[f>>2]|64;i=l;return}o=d[y>>0]|d[y+1>>0]<<8|d[y+2>>0]<<16|d[y+3>>0]<<24;a[g>>0]=o;a[g+1>>0]=o>>8;a[g+2>>0]=o>>16;a[g+3>>0]=o>>24;i=l;return};case 1:{o=(d[h>>0]|0)<<8|(d[h+1>>0]|0);c[m>>2]=35704;c[m+4>>2]=o;ab(g|0,35256,m|0)|0;i=l;return};case 12:{c[m>>2]=b[f+12>>1]&7;ab(g|0,35312,m|0)|0;i=l;return};case 18:{o=(d[h>>0]|0)>>>1&7;c[m>>2]=35704;c[m+4>>2]=(o|0)==0?8:o;ab(g|0,35376,m|0)|0;i=l;return};case 15:{o=d[h+3>>0]|0;c[m>>2]=35704;c[m+4>>2]=o;ab(g|0,35352,m|0)|0;o=f+8|0;c[o>>2]=(c[o>>2]|0)+1;i=l;return};case 6:{c[m>>2]=(d[h>>0]|0)>>>1&7;ab(g|0,35264,m|0)|0;i=l;return};case 19:{o=b[f+12>>1]&15;c[m>>2]=35704;c[m+4>>2]=o;ab(g|0,35352,m|0)|0;i=l;return};case 17:{o=(((d[h+2>>0]|0)<<8|(d[h+3>>0]|0))<<8|(d[h+4>>0]|0))<<8|(d[h+5>>0]|0);c[m>>2]=35704;c[m+4>>2]=o;ab(g|0,35360,m|0)|0;o=f+8|0;c[o>>2]=(c[o>>2]|0)+2;i=l;return};case 7:{c[m>>2]=b[f+12>>1]&7;ab(g|0,35272,m|0)|0;i=l;return};default:{a[g>>0]=0;i=l;return}}}while(0)}function kj(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;i=i+32|0;j=h;switch(f>>>3&7|0){case 2:{c[j>>2]=f&7;ab(b|0,35488,j|0)|0;i=h;return};case 1:{c[j>>2]=f&7;ab(b|0,35272,j|0)|0;i=h;return};case 4:{c[j>>2]=f&7;ab(b|0,35312,j|0)|0;i=h;return};case 0:{c[j>>2]=f&7;ab(b|0,35264,j|0)|0;i=h;return};case 7:{switch(f&7|0){case 0:{k=a+8|0;l=c[k>>2]|0;m=l<<1;n=(d[e+m>>0]|0)<<8;o=n|(d[e+(m|1)>>0]|0);c[k>>2]=l+1;l=(n&32768|0)!=0;c[j>>2]=l?35336:35344;c[j+4>>2]=35704;c[j+8>>2]=(l?0-o|0:o)&65535;ab(b|0,35544,j|0)|0;i=h;return};case 1:{o=a+8|0;l=c[o>>2]|0;n=l<<1;k=(d[e+n>>0]|0)<<8|(d[e+(n|1)>>0]|0);n=l+1|0;c[o>>2]=n;m=n<<1;n=(d[e+m>>0]|0)<<8|(d[e+(m|1)>>0]|0);c[o>>2]=l+2;c[j>>2]=35704;c[j+4>>2]=n|k<<16;ab(b|0,35384,j|0)|0;i=h;return};case 2:{k=a+8|0;n=c[k>>2]|0;l=n<<1;o=(d[e+l>>0]|0)<<8;m=o|(d[e+(l|1)>>0]|0);c[k>>2]=n+1;n=(c[a+4>>2]|0)+2+((o&32768|0)!=0?m|-65536:m)|0;c[j>>2]=35704;c[j+4>>2]=n;ab(b|0,35560,j|0)|0;i=h;return};case 3:{n=a+8|0;m=c[n>>2]|0;o=m<<1;k=d[e+o>>0]|0;l=k<<8;p=d[e+(o|1)>>0]|0;c[n>>2]=m+1;if((l&256|0)!=0){mj(a,b,e);i=h;return}m=(p&128|0)!=0;c[j>>2]=m?35336:35344;c[j+4>>2]=35704;c[j+8>>2]=(m?0-p|0:p)&255;c[j+12>>2]=(l&32768|0)!=0?35288:35296;c[j+16>>2]=k>>>4&7;c[j+20>>2]=(l&2048|0)!=0?35528:35536;c[j+24>>2]=1<<(k>>>1&3);ab(b|0,35576,j|0)|0;if((l&1536|0)==0){i=h;return}c[a>>2]=c[a>>2]|128;i=h;return};case 4:{if((g|0)==8){l=a+8|0;k=c[l>>2]|0;p=d[e+(k<<1|1)>>0]|0;c[l>>2]=k+1;c[j>>2]=35704;c[j+4>>2]=p;ab(b|0,35352,j|0)|0;i=h;return}else if((g|0)==16){p=a+8|0;k=c[p>>2]|0;l=k<<1;m=(d[e+l>>0]|0)<<8|(d[e+(l|1)>>0]|0);c[p>>2]=k+1;c[j>>2]=35704;c[j+4>>2]=m;ab(b|0,35256,j|0)|0;i=h;return}else if((g|0)==32){g=a+8|0;m=c[g>>2]|0;k=m<<1;p=(d[e+k>>0]|0)<<8|(d[e+(k|1)>>0]|0);k=m+1|0;c[g>>2]=k;l=k<<1;k=(d[e+l>>0]|0)<<8|(d[e+(l|1)>>0]|0);c[g>>2]=m+2;c[j>>2]=35704;c[j+4>>2]=k|p<<16;ab(b|0,35360,j|0)|0;i=h;return}else{i=h;return}break};default:{c[j>>2]=f&63;ab(b|0,35600,j|0)|0;i=h;return}}break};case 6:{p=a+8|0;k=c[p>>2]|0;m=k<<1;g=d[e+m>>0]|0;l=g<<8;n=d[e+(m|1)>>0]|0;c[p>>2]=k+1;if((l&256|0)!=0){mj(a,b,e);i=h;return}k=(n&128|0)!=0;c[j>>2]=k?35336:35344;c[j+4>>2]=35704;c[j+8>>2]=(k?0-n|0:n)&255;c[j+12>>2]=f&7;c[j+16>>2]=(l&32768|0)!=0?35288:35296;c[j+20>>2]=g>>>4&7;c[j+24>>2]=(l&2048|0)!=0?35528:35536;c[j+28>>2]=1<<(g>>>1&3);ab(b|0,35496,j|0)|0;if((l&1536|0)==0){i=h;return}c[a>>2]=c[a>>2]|128;i=h;return};case 5:{l=a+8|0;a=c[l>>2]|0;g=a<<1;n=(d[e+g>>0]|0)<<8;k=n|(d[e+(g|1)>>0]|0);c[l>>2]=a+1;a=(n&32768|0)!=0;c[j>>2]=a?35336:35344;c[j+4>>2]=35704;c[j+8>>2]=(a?0-k|0:k)&65535;c[j+12>>2]=f&7;ab(b|0,35320,j|0)|0;i=h;return};case 3:{c[j>>2]=f&7;ab(b|0,35304,j|0)|0;i=h;return};default:{c[j>>2]=f&63;ab(b|0,35600,j|0)|0;i=h;return}}}function lj(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;i=i+48|0;h=g;j=g+16|0;k=d>>>0<8;l=k?d:d+ -8|0;d=k?35296:35288;if((c[f>>2]|0)==0){k=b+(Kz(b|0)|0)|0;a[k>>0]=47;a[k+1>>0]=0}if(e>>>0>2){c[h>>2]=d;c[h+4>>2]=l;c[h+8>>2]=d;c[h+12>>2]=e+ -1+l;ab(j|0,35456,h|0)|0;Pz(b|0,j|0)|0;c[f>>2]=0;i=g;return}if((e|0)==2){c[h>>2]=d;c[h+4>>2]=l;c[h+8>>2]=d;c[h+12>>2]=l+1;ab(j|0,35472,h|0)|0;Pz(b|0,j|0)|0;c[f>>2]=0;i=g;return}else{c[h>>2]=d;c[h+4>>2]=l;ab(j|0,35280,h|0)|0;Pz(b|0,j|0)|0;c[f>>2]=0;i=g;return}}function mj(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;j=i;i=i+112|0;k=j;l=j+72|0;m=j+56|0;n=j+40|0;o=j+24|0;p=j+88|0;q=e[f+14>>1]|0;r=(q&64|0)==0;do{if((q&128|0)==0){s=e[f+12>>1]|0;if((s&56|0)==56){a[l+0>>0]=a[35616>>0]|0;a[l+1>>0]=a[35617>>0]|0;a[l+2>>0]=a[35618>>0]|0;break}else{c[k>>2]=s&7;ab(l|0,35272,k|0)|0;break}}else{b[l>>1]=45}}while(0);if(r){c[k>>2]=(q&32768|0)!=0?35288:35296;c[k+4>>2]=q>>>12&7;c[k+8>>2]=(q&2048|0)!=0?35528:35536;ab(m|0,35624,k|0)|0}else{b[m>>1]=45}r=q>>>9&3;if((r|0)==0){a[p>>0]=0}else{c[k>>2]=1<<r;ab(p|0,35632,k|0)|0}r=q>>>4&3;if((r|0)==1|(r|0)==0){b[n>>1]=45}else if((r|0)==2){s=f+8|0;t=c[s>>2]|0;u=t<<1;v=(d[h+u>>0]|0)<<8;w=v|(d[h+(u|1)>>0]|0);c[s>>2]=t+1;t=(v&32768|0)!=0;if(t){x=0-w&65535}else{x=w}c[k>>2]=t?35336:35344;c[k+4>>2]=35704;c[k+8>>2]=x;ab(n|0,35544,k|0)|0}else if((r|0)==3){r=f+8|0;x=c[r>>2]|0;t=x<<1;w=(d[h+t>>0]|0)<<8|(d[h+(t|1)>>0]|0);t=x+1|0;c[r>>2]=t;v=t<<1;t=(d[h+v>>0]|0)<<8|(d[h+(v|1)>>0]|0);c[r>>2]=x+2;x=t|w<<16;w=(x|0)<0;c[k>>2]=w?35336:35344;c[k+4>>2]=35704;c[k+8>>2]=w?0-x|0:x;ab(n|0,35640,k|0)|0}x=q&3;if((x|0)==1|(x|0)==0){b[o>>1]=45}else if((x|0)==2){w=f+8|0;t=c[w>>2]|0;r=t<<1;v=(d[h+r>>0]|0)<<8;s=v|(d[h+(r|1)>>0]|0);c[w>>2]=t+1;t=(v&32768|0)!=0;if(t){y=0-s&65535}else{y=s}c[k>>2]=t?35336:35344;c[k+4>>2]=35704;c[k+8>>2]=y;ab(o|0,35544,k|0)|0}else if((x|0)==3){x=f+8|0;y=c[x>>2]|0;t=y<<1;s=(d[h+t>>0]|0)<<8|(d[h+(t|1)>>0]|0);t=y+1|0;c[x>>2]=t;v=t<<1;t=(d[h+v>>0]|0)<<8|(d[h+(v|1)>>0]|0);c[x>>2]=y+2;y=t|s<<16;s=(y|0)<0;c[k>>2]=s?35336:35344;c[k+4>>2]=35704;c[k+8>>2]=s?0-y|0:y;ab(o|0,35640,k|0)|0}if((q&4|0)==0){c[k>>2]=l;c[k+4>>2]=n;c[k+8>>2]=m;c[k+12>>2]=p;c[k+16>>2]=o;ab(g|0,35680,k|0)|0;z=c[f>>2]|0;A=z|128;c[f>>2]=A;i=j;return}else{c[k>>2]=l;c[k+4>>2]=n;c[k+8>>2]=m;c[k+12>>2]=p;c[k+16>>2]=o;ab(g|0,35656,k|0)|0;z=c[f>>2]|0;A=z|128;c[f>>2]=A;i=j;return}}function nj(){var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=yz(4528)|0;if((e|0)==0){f=0;i=d;return f|0}g=e+52|0;h=e+334|0;j=e+0|0;k=j+48|0;do{c[j>>2]=0;j=j+4|0}while((j|0)<(k|0));b[e+48>>1]=0;j=g+0|0;k=j+36|0;do{c[j>>2]=0;j=j+4|0}while((j|0)<(k|0));a[h>>0]=1;a[e+335>>0]=2;c[e+364>>2]=0;a[e+368>>0]=0;c[e+372>>2]=1;c[e+376>>2]=0;c[e+380>>2]=0;c[e+384>>2]=0;c[e+388>>2]=37616;c[e+392>>2]=0;c[e+396>>2]=0;ak(e);b[e+166>>1]=8192;g=e+148|0;j=e+88|0;k=j+64|0;do{c[j>>2]=0;j=j+4|0}while((j|0)<(k|0));if((a[h>>0]|0)==0){c[g>>2]=0;c[e+172>>2]=0}else{c[e+168>>2]=0;c[g>>2]=0}c[e+152>>2]=0;Oz(e+176|0,0,156)|0;f=e;i=d;return f|0}function oj(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[a+4>>2]=b;c[a+8>>2]=d;c[a+12>>2]=e;c[a+16>>2]=f;c[a+20>>2]=g;c[a+24>>2]=h;c[a+28>>2]=i;return}function pj(a,b,d){a=a|0;b=b|0;d=d|0;c[a+32>>2]=b;c[a+36>>2]=(b|0)==0?0:d;return}function qj(a,b,d){a=a|0;b=b|0;d=d|0;c[a+40>>2]=b;c[a+44>>2]=d;return}function rj(a,b,d){a=a|0;b=b|0;d=d|0;c[a+60>>2]=b;c[a+64>>2]=d;return}function sj(a,b){a=a|0;b=b|0;var d=0;d=c[a>>2]|0;c[a>>2]=(b|0)==0?d|1:d&-2;return}function tj(a){a=a|0;var b=0;b=i;c[a>>2]=0;ak(a);i=b;return}function uj(a){a=a|0;var b=0;b=i;c[a>>2]=2;ak(a);i=b;return}function vj(a){a=a|0;var b=0;b=i;c[a>>2]=7;dn(a);i=b;return}function wj(a){a=a|0;return c[a+392>>2]|0}function xj(a){a=a|0;return c[a+396>>2]|0}function yj(a){a=a|0;return c[a+372>>2]|0}function zj(b,c){b=b|0;c=c|0;a[b+335>>0]=c&3;return}function Aj(a){a=a|0;return c[a+376>>2]|0}function Bj(a){a=a|0;return c[a+384>>2]|0}function Cj(a){a=a|0;return c[a+388>>2]|0}function Dj(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;if(b>>>0>31){e=0;i=d;return e|0}e=c[a+(((c[a+196>>2]|0)-b&31)<<2)+200>>2]|0;i=d;return e|0}function Ej(a){a=a|0;return b[a+328>>1]|0}function Fj(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=i;k=(a[g>>0]|0)==37?g+1|0:g;if((Fz(k,37624)|0)==0){c[h>>2]=c[f+152>>2];l=0;i=j;return l|0}if((Fz(k,37632)|0)==0){c[h>>2]=c[f+((c[f+196>>2]&31)<<2)+200>>2];l=0;i=j;return l|0}g=a[k>>0]|0;if(g<<24>>24==111){if((a[k+1>>0]|0)==112){m=a[k+2>>0]|0;if((m+ -48<<24>>24&255)<10){n=k;o=m;p=0;while(1){p=(p*10|0)+ -48+(o<<24>>24)|0;o=a[n+3>>0]|0;if(!((o+ -48<<24>>24&255)<10)){break}else{n=n+1|0}}q=o;r=p<<1}else{q=m;r=0}if(!(q<<24>>24==0)){l=1;i=j;return l|0}q=(c[f+152>>2]|0)+r&16777215;r=q+1|0;if(r>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;s=(d[m+q>>0]<<8|d[m+r>>0])&65535}else{s=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}c[h>>2]=s&65535;l=0;i=j;return l|0}}if((Fz(k,37640)|0)==0){c[h>>2]=e[f+166>>1]|0;l=0;i=j;return l|0}if((Fz(k,37648)|0)==0){c[h>>2]=c[f+148>>2];l=0;i=j;return l|0}if((Fz(k,37656)|0)==0){c[h>>2]=b[f+166>>1]&255;l=0;i=j;return l|0}if((Fz(k,37664)|0)==0){c[h>>2]=c[((a[f+334>>0]|0)==0?f+148|0:f+168|0)>>2];l=0;i=j;return l|0}if((Fz(k,37672)|0)==0){c[h>>2]=c[((a[f+334>>0]|0)==0?f+172|0:f+148|0)>>2];l=0;i=j;return l|0}if(g<<24>>24==65|g<<24>>24==97){t=97}else if(g<<24>>24==68|g<<24>>24==100){t=100}else{l=1;i=j;return l|0}g=k+1|0;s=a[g>>0]|0;if((s+ -48<<24>>24&255)<10){q=g;r=s;s=0;while(1){s=(s*10|0)+ -48+(r<<24>>24)|0;u=q+1|0;r=a[u>>0]|0;if(!((r+ -48<<24>>24&255)<10)){break}else{q=u}}v=q;w=u;x=s&7}else{v=k;w=g;x=0}if((t|0)==97){y=f+(x<<2)+120|0}else{y=f+(x<<2)+88|0}x=c[y>>2]|0;c[h>>2]=x;y=a[w>>0]|0;if(y<<24>>24==46){switch(a[v+2>>0]|0){case 66:case 98:{c[h>>2]=x&255;break};case 87:case 119:{c[h>>2]=x&65535;break};case 76:case 108:{break};default:{l=1;i=j;return l|0}}z=a[v+3>>0]|0}else{z=y}l=z<<24>>24!=0|0;i=j;return l|0}function Gj(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;h=(a[e>>0]|0)==37?e+1|0:e;if((Fz(h,37624)|0)==0){Hj(d,f);j=0;i=g;return j|0}if((Fz(h,37640)|0)==0){e=d+166|0;if(!(((b[e>>1]^f&65535)&8192)==0)){k=f&8192;l=d+334|0;m=d+148|0;n=c[m>>2]|0;if((a[l>>0]|0)==0){o=d+168|0;c[o>>2]=n;p=o;q=d+172|0}else{o=d+172|0;c[o>>2]=n;p=d+168|0;q=o}c[m>>2]=c[((k|0)!=0?q:p)>>2];a[l>>0]=k>>>13}b[e>>1]=f&42783;j=0;i=g;return j|0}if((Fz(h,37648)|0)==0){c[d+148>>2]=f;j=0;i=g;return j|0}if((Fz(h,37656)|0)==0){e=d+166|0;b[e>>1]=b[e>>1]&65280|f&255;j=0;i=g;return j|0}if((Fz(h,37664)|0)==0){if((a[d+334>>0]|0)==0){c[d+148>>2]=f;j=0;i=g;return j|0}else{c[d+168>>2]=f;j=0;i=g;return j|0}}if((Fz(h,37672)|0)==0){if((a[d+334>>0]|0)==0){c[d+172>>2]=f;j=0;i=g;return j|0}else{c[d+148>>2]=f;j=0;i=g;return j|0}}e=a[h>>0]|0;if(e<<24>>24==68|e<<24>>24==100){r=100}else if(e<<24>>24==65|e<<24>>24==97){r=97}else{j=1;i=g;return j|0}e=h+1|0;k=a[e>>0]|0;if((k+ -48<<24>>24&255)<10){l=e;e=k;p=0;while(1){p=(p*10|0)+ -48+(e<<24>>24)|0;q=l+1|0;e=a[q>>0]|0;if(!((e+ -48<<24>>24&255)<10)){break}else{l=q}}s=l;t=e;u=p&7}else{s=h;t=k;u=0}if(t<<24>>24==46){switch(a[s+2>>0]|0){case 87:case 119:{v=65535;break};case 76:case 108:{v=-1;break};case 66:case 98:{v=255;break};default:{j=1;i=g;return j|0}}w=a[s+3>>0]|0;x=v}else{w=t;x=-1}if(!(w<<24>>24==0)){j=1;i=g;return j|0}if((r|0)==97){r=d+(u<<2)+120|0;c[r>>2]=c[r>>2]&~x|x&f;j=0;i=g;return j|0}else{r=d+(u<<2)+88|0;c[r>>2]=c[r>>2]&~x|x&f;j=0;i=g;return j|0}return 0}function Hj(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=e+156|0;c[h>>2]=f;do{if((f&1|0)==0){j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=f&16777215;l=k+1|0;if(l>>>0<(c[e+36>>2]|0)>>>0){m=c[e+32>>2]|0;n=(d[m+k>>0]<<8|d[m+l>>0])&65535}else{n=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=n;if((a[e+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;j=e+152|0;c[j>>2]=(c[j>>2]|0)+2;break}else{Kj(e);break}}else{Mj(e,f,0,0)}}while(0);n=c[h>>2]|0;if((n&1|0)!=0){Mj(e,n,0,0);o=e+152|0;c[o>>2]=f;i=g;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=n&16777215;n=k+1|0;if(n>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;p=(d[l+k>>0]<<8|d[l+n>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=p;if((a[e+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=e+152|0;c[h>>2]=(c[h>>2]|0)+2;o=e+152|0;c[o>>2]=f;i=g;return}else{Kj(e);o=e+152|0;c[o>>2]=f;i=g;return}}function Ij(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;g=d+166|0;h=e&65535;if(((b[g>>1]^e)&8192)==0){j=h&42783;k=j&65535;b[g>>1]=k;i=f;return}e=h&8192;l=d+334|0;m=d+148|0;n=c[m>>2]|0;if((a[l>>0]|0)==0){o=d+168|0;c[o>>2]=n;p=o;q=d+172|0}else{o=d+172|0;c[o>>2]=n;p=d+168|0;q=o}c[m>>2]=c[((e|0)!=0?q:p)>>2];a[l>>0]=e>>>13;j=h&42783;k=j&65535;b[g>>1]=k;i=f;return}function Jj(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=e+376|0;c[g>>2]=(c[g>>2]|0)+1;g=e+152|0;c[e+380>>2]=c[g>>2];c[e+384>>2]=0;c[e+388>>2]=37680;h=e+166|0;if((b[h>>1]&8192)==0){j=e+334|0;k=e+148|0;l=c[k>>2]|0;if((a[j>>0]|0)==0){c[e+168>>2]=l;m=c[e+172>>2]|0}else{c[e+172>>2]=l;m=l}c[k>>2]=m;a[j>>0]=1}b[h>>1]=9984;h=e+36|0;j=c[h>>2]|0;if(j>>>0>3){m=c[e+32>>2]|0;n=((d[m>>0]<<8|d[m+1>>0])<<8|d[m+2>>0])<<8|d[m+3>>0];o=j}else{j=oc[c[e+16>>2]&31](c[e+4>>2]|0,0)|0;n=j;o=c[h>>2]|0}c[e+148>>2]=n;if(o>>>0>7){o=c[e+32>>2]|0;p=((d[o+4>>0]<<8|d[o+5>>0])<<8|d[o+6>>0])<<8|d[o+7>>0]}else{p=oc[c[e+16>>2]&31](c[e+4>>2]|0,4)|0}o=e+156|0;c[o>>2]=p;do{if((p&1|0)==0){n=e+164|0;b[e+162>>1]=b[n>>1]|0;j=p&16777215;m=j+1|0;if(m>>>0<(c[h>>2]|0)>>>0){k=c[e+32>>2]|0;q=(d[k+j>>0]<<8|d[k+m>>0])&65535}else{q=oc[c[e+12>>2]&31](c[e+4>>2]|0,j)|0}b[n>>1]=q;if((a[e+336>>0]|0)==0){c[o>>2]=(c[o>>2]|0)+2;c[g>>2]=(c[g>>2]|0)+2;break}else{Kj(e);break}}else{Mj(e,p,0,0)}}while(0);p=c[o>>2]|0;if((p&1|0)!=0){Mj(e,p,0,0);r=c[o>>2]|0;s=r+ -4|0;c[g>>2]=s;t=e+372|0;u=c[t>>2]|0;v=u+64|0;c[t>>2]=v;i=f;return}q=e+164|0;b[e+162>>1]=b[q>>1]|0;n=p&16777215;p=n+1|0;if(p>>>0<(c[h>>2]|0)>>>0){h=c[e+32>>2]|0;w=(d[h+n>>0]<<8|d[h+p>>0])&65535}else{w=oc[c[e+12>>2]&31](c[e+4>>2]|0,n)|0}b[q>>1]=w;if((a[e+336>>0]|0)==0){c[o>>2]=(c[o>>2]|0)+2;c[g>>2]=(c[g>>2]|0)+2;r=c[o>>2]|0;s=r+ -4|0;c[g>>2]=s;t=e+372|0;u=c[t>>2]|0;v=u+64|0;c[t>>2]=v;i=f;return}else{Kj(e);r=c[o>>2]|0;s=r+ -4|0;c[g>>2]=s;t=e+372|0;u=c[t>>2]|0;v=u+64|0;c[t>>2]=v;i=f;return}}function Kj(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;a[b+336>>0]=0;Lj(b,2,0,37688);e=b+148|0;f=c[e>>2]|0;g=f+ -4|0;h=g&16777215;j=h+3|0;k=b+36|0;if(j>>>0<(c[k>>2]|0)>>>0){l=b+32|0;a[(c[l>>2]|0)+h>>0]=0;a[(c[l>>2]|0)+(h+1)>>0]=0;a[(c[l>>2]|0)+(h+2)>>0]=0;a[(c[l>>2]|0)+j>>0]=0}else{lc[c[b+28>>2]&31](c[b+4>>2]|0,h,0)}c[e>>2]=g;g=f+ -8|0;f=g&16777215;h=f+3|0;if(h>>>0<(c[k>>2]|0)>>>0){k=b+32|0;a[(c[k>>2]|0)+f>>0]=0;a[(c[k>>2]|0)+(f+1)>>0]=0;a[(c[k>>2]|0)+(f+2)>>0]=0;a[(c[k>>2]|0)+h>>0]=0;c[e>>2]=g;m=b+372|0;n=c[m>>2]|0;o=n+62|0;c[m>>2]=o;i=d;return}else{lc[c[b+28>>2]&31](c[b+4>>2]|0,f,0);c[e>>2]=g;m=b+372|0;n=c[m>>2]|0;o=n+62|0;c[m>>2]=o;i=d;return}}function Lj(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;j=i;k=f&255;f=e+376|0;c[f>>2]=(c[f>>2]|0)+1;f=e+152|0;c[e+380>>2]=c[f>>2];c[e+384>>2]=k;c[e+388>>2]=h;h=c[e+80>>2]|0;if((h|0)!=0){jc[h&255](c[e+68>>2]|0,k)}if((k|0)!=7&(k+ -32|0)>>>0>15){b[e+332>>1]=0}h=e+166|0;l=b[h>>1]|0;m=l&1823|8192;if((l&8192)==0){n=e+334|0;o=e+148|0;p=c[o>>2]|0;if((a[n>>0]|0)==0){c[e+168>>2]=p;q=c[e+172>>2]|0}else{c[e+172>>2]=p;q=p}c[o>>2]=q;a[n>>0]=1}b[h>>1]=m;if((c[e>>2]&2|0)==0){r=e+36|0;s=c[e+148>>2]|0}else{m=k<<2;h=(g<<12|m)&65535;g=e+148|0;n=(c[g>>2]|0)+ -2|0;q=n&16777215;o=q+1|0;p=e+36|0;if(o>>>0<(c[p>>2]|0)>>>0){t=e+32|0;a[(c[t>>2]|0)+q>>0]=(h&65535)>>>8;a[(c[t>>2]|0)+o>>0]=m}else{lc[c[e+24>>2]&31](c[e+4>>2]|0,q,h)}c[g>>2]=n;r=p;s=n}n=c[f>>2]|0;p=e+148|0;g=s+ -4|0;h=g&16777215;q=h+3|0;if(q>>>0<(c[r>>2]|0)>>>0){m=e+32|0;a[(c[m>>2]|0)+h>>0]=n>>>24;a[(c[m>>2]|0)+(h+1)>>0]=n>>>16;a[(c[m>>2]|0)+(h+2)>>0]=n>>>8;a[(c[m>>2]|0)+q>>0]=n}else{lc[c[e+28>>2]&31](c[e+4>>2]|0,h,n)}c[p>>2]=g;g=s+ -6|0;s=g&16777215;n=s+1|0;if(n>>>0<(c[r>>2]|0)>>>0){h=e+32|0;a[(c[h>>2]|0)+s>>0]=(l&65535)>>>8;a[(c[h>>2]|0)+n>>0]=l}else{lc[c[e+24>>2]&31](c[e+4>>2]|0,s,l)}c[p>>2]=g;g=(c[e+176>>2]|0)+(k<<2)&16777215;k=g+3|0;if(k>>>0<(c[r>>2]|0)>>>0){p=c[e+32>>2]|0;u=((d[p+g>>0]<<8|d[p+(g+1)>>0])<<8|d[p+(g+2)>>0])<<8|d[p+k>>0]}else{u=oc[c[e+16>>2]&31](c[e+4>>2]|0,g)|0}g=e+156|0;c[g>>2]=u;do{if((u&1|0)==0){k=e+164|0;b[e+162>>1]=b[k>>1]|0;p=u&16777215;l=p+1|0;if(l>>>0<(c[r>>2]|0)>>>0){s=c[e+32>>2]|0;v=(d[s+p>>0]<<8|d[s+l>>0])&65535}else{v=oc[c[e+12>>2]&31](c[e+4>>2]|0,p)|0}b[k>>1]=v;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;c[f>>2]=(c[f>>2]|0)+2;break}else{Kj(e);break}}else{Mj(e,u,0,0)}}while(0);v=c[g>>2]|0;if((v&1|0)!=0){Mj(e,v,0,0);c[f>>2]=u;i=j;return}k=e+164|0;b[e+162>>1]=b[k>>1]|0;p=v&16777215;v=p+1|0;if(v>>>0<(c[r>>2]|0)>>>0){r=c[e+32>>2]|0;w=(d[r+p>>0]<<8|d[r+v>>0])&65535}else{w=oc[c[e+12>>2]&31](c[e+4>>2]|0,p)|0}b[k>>1]=w;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;c[f>>2]=(c[f>>2]|0)+2;c[f>>2]=u;i=j;return}else{Kj(e);c[f>>2]=u;i=j;return}}function Mj(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;Lj(d,3,8,37696);j=b[d+160>>1]|0;k=d+148|0;l=c[k>>2]|0;m=l+ -2|0;n=m&16777215;o=n+1|0;p=d+36|0;if(o>>>0<(c[p>>2]|0)>>>0){q=d+32|0;a[(c[q>>2]|0)+n>>0]=(j&65535)>>>8;a[(c[q>>2]|0)+o>>0]=j}else{lc[c[d+24>>2]&31](c[d+4>>2]|0,n,j)}c[k>>2]=m;m=l+ -6|0;j=m&16777215;n=j+3|0;if(n>>>0<(c[p>>2]|0)>>>0){o=d+32|0;a[(c[o>>2]|0)+j>>0]=e>>>24;a[(c[o>>2]|0)+(j+1)>>0]=e>>>16;a[(c[o>>2]|0)+(j+2)>>0]=e>>>8;a[(c[o>>2]|0)+n>>0]=e}else{lc[c[d+28>>2]&31](c[d+4>>2]|0,j,e)}c[k>>2]=m;m=(g|0)==0?16:0;if((f|0)==0){r=m}else{r=(m&65535|8)&65535}m=l+ -8|0;l=m&16777215;f=l+1|0;if(f>>>0<(c[p>>2]|0)>>>0){p=d+32|0;a[(c[p>>2]|0)+l>>0]=(r&65535)>>>8;a[(c[p>>2]|0)+f>>0]=r;c[k>>2]=m;s=d+372|0;t=c[s>>2]|0;u=t+64|0;c[s>>2]=u;i=h;return}else{lc[c[d+24>>2]&31](c[d+4>>2]|0,l,r);c[k>>2]=m;s=d+372|0;t=c[s>>2]|0;u=t+64|0;c[s>>2]=u;i=h;return}}function Nj(a){a=a|0;var b=0,d=0;b=i;d=c[a+76>>2]|0;if((d|0)!=0){jc[d&255](c[a+68>>2]|0,e[a+160>>1]|0)}Lj(a,4,0,37704);d=a+372|0;c[d>>2]=(c[d>>2]|0)+62;i=b;return}function Oj(a){a=a|0;var b=0,d=0;b=i;Lj(a,5,0,37712);d=a+372|0;c[d>>2]=(c[d>>2]|0)+66;i=b;return}function Pj(a){a=a|0;var b=0,d=0;b=i;Lj(a,6,0,37720);d=a+372|0;c[d>>2]=(c[d>>2]|0)+68;i=b;return}function Qj(a){a=a|0;var b=0,d=0;b=i;Lj(a,7,0,37728);d=a+372|0;c[d>>2]=(c[d>>2]|0)+68;i=b;return}function Rj(a){a=a|0;var b=0,d=0;b=i;Lj(a,8,0,37736);d=a+372|0;c[d>>2]=(c[d>>2]|0)+62;i=b;return}function Sj(a){a=a|0;var b=0,d=0;b=i;Lj(a,10,0,37752);d=a+372|0;c[d>>2]=(c[d>>2]|0)+62;i=b;return}function Tj(a){a=a|0;var b=0,d=0;b=i;Lj(a,11,0,37760);d=a+372|0;c[d>>2]=(c[d>>2]|0)+62;i=b;return}function Uj(a){a=a|0;var b=0,d=0;b=i;Lj(a,14,0,37768);d=a+372|0;c[d>>2]=(c[d>>2]|0)+62;i=b;return}function Vj(a,b){a=a|0;b=b|0;var d=0;d=i;Lj(a,b+32|0,0,37784);b=a+372|0;c[b>>2]=(c[b>>2]|0)+62;i=d;return}function Wj(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;if((d|0)!=0){f=b+335|0;a[f>>0]=a[f>>0]&254;if((d|0)==7){if((c[b+364>>2]|0)!=7){a[b+368>>0]=1}}}c[b+364>>2]=d;i=e;return}function Xj(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;f=d+48|0;if((a[f>>0]|0)!=0){i=e;return}a[f>>0]=1;g=d+44|0;h=c[g>>2]|0;if((h|0)!=0){jc[h&255](c[d+40>>2]|0,1)}h=d+166|0;j=d+334|0;k=a[j>>0]|0;if((b[h>>1]&8192)==0){l=d+148|0;m=c[l>>2]|0;if(k<<24>>24==0){c[d+168>>2]=m}else{c[d+172>>2]=m}a[j>>0]=1;b[h>>1]=8192;n=d+88|0;o=n+60|0;do{c[n>>2]=0;n=n+4|0}while((n|0)<(o|0));c[l>>2]=0;p=l;q=10}else{l=d+148|0;j=k<<24>>24==0;b[h>>1]=8192;n=d+88|0;o=n+60|0;do{c[n>>2]=0;n=n+4|0}while((n|0)<(o|0));c[l>>2]=0;if(j){c[l>>2]=0;c[d+172>>2]=0}else{p=l;q=10}}if((q|0)==10){c[d+168>>2]=0;c[p>>2]=0}p=d+176|0;a[d+335>>0]=0;a[d+336>>0]=0;c[p+0>>2]=0;c[p+4>>2]=0;c[p+8>>2]=0;c[p+12>>2]=0;Jj(d);if((a[f>>0]|0)==0){i=e;return}a[f>>0]=0;f=c[g>>2]|0;if((f|0)==0){i=e;return}jc[f&255](c[d+40>>2]|0,0);i=e;return}function Yj(d){d=d|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=c[d+152>>2]|0;h=d+196|0;j=(c[h>>2]|0)+1|0;c[h>>2]=j;c[d+((j&31)<<2)+200>>2]=g;a[d+336>>0]=0;g=d+166|0;j=d+332|0;b[j>>1]=b[g>>1]|0;h=b[d+162>>1]|0;b[d+160>>1]=h;ic[c[d+400+((h&65535)>>>6<<2)>>2]&511](d);h=d+392|0;c[h>>2]=(c[h>>2]|0)+1;if((b[j>>1]|0)<0){Lj(d,9,0,37744);j=d+372|0;c[j>>2]=(c[j>>2]|0)+62}j=d+368|0;if((a[j>>0]|0)!=0){Lj(d,31,0,37776);b[g>>1]=e[g>>1]|1792;h=d+372|0;c[h>>2]=(c[h>>2]|0)+62;a[j>>0]=0;i=f;return}j=c[d+364>>2]|0;if((j|0)==0){i=f;return}if(!(((e[g>>1]|0)>>>8&7)>>>0<j>>>0)){i=f;return}h=c[d+56>>2]|0;if((h|0)!=0){k=oc[h&31](c[d+52>>2]|0,j)|0;if(k>>>0<256){Lj(d,k,0,37792);b[g>>1]=b[g>>1]&63743|j<<8&1792;k=d+372|0;c[k>>2]=(c[k>>2]|0)+62;i=f;return}}Lj(d,j+24|0,0,37776);b[g>>1]=b[g>>1]&63743|j<<8&1792;j=d+372|0;c[j>>2]=(c[j>>2]|0)+62;i=f;return}function Zj(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0;e=i;i=i+16|0;f=e;g=b+372|0;h=b+396|0;j=b+335|0;k=d;d=c[g>>2]|0;while(1){if(k>>>0<d>>>0){l=k;m=d;break}n=k-d|0;c[h>>2]=(c[h>>2]|0)+d;c[g>>2]=0;if((a[j>>0]|0)!=0){p=7;break}Yj(b);q=c[g>>2]|0;if((q|0)==0){p=5;break}else{k=n;d=q}}if((p|0)==5){d=c[o>>2]|0;c[f>>2]=c[b+152>>2];hb(d|0,37800,f|0)|0;Nb(d|0)|0;l=n;m=c[g>>2]|0}else if((p|0)==7){i=e;return}c[h>>2]=(c[h>>2]|0)+l;c[g>>2]=m-l;i=e;return}function _j(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=h;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;n=f+336|0;if((a[n>>0]|0)!=0){Kj(f);i=h;return}k=(c[j>>2]|0)+2|0;c[j>>2]=k;p=f+152|0;r=(c[p>>2]|0)+2|0;c[p>>2]=r;s=e[m>>1]|0;t=(s&32768|0)!=0?s|-65536:s;if((g|0)!=0){g=f+372|0;c[g>>2]=(c[g>>2]|0)+12;if((k&1|0)!=0){Mj(f,k,0,0);i=h;return}b[m>>1]=q;q=k&16777215;k=q+1|0;if(k>>>0<(c[o>>2]|0)>>>0){g=c[f+32>>2]|0;b[l>>1]=d[g+q>>0]<<8|d[g+k>>0]}else{k=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0;q=(a[n>>0]|0)==0;b[l>>1]=k;if(!q){Kj(f);i=h;return}}c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;i=h;return}q=f+((b[f+160>>1]&7)<<2)+88|0;k=c[q>>2]|0;g=k+65535&65535;c[q>>2]=g|k&-65536;k=f+372|0;q=c[k>>2]|0;if((g|0)==65535){c[k>>2]=q+14;g=c[j>>2]|0;if((g&1|0)!=0){Mj(f,g,0,0);i=h;return}b[m>>1]=b[l>>1]|0;s=g&16777215;g=s+1|0;if(g>>>0<(c[o>>2]|0)>>>0){u=c[f+32>>2]|0;v=(d[u+s>>0]<<8|d[u+g>>0])&65535}else{v=oc[c[f+12>>2]&31](c[f+4>>2]|0,s)|0}b[l>>1]=v;if((a[n>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;i=h;return}else{Kj(f);i=h;return}}c[k>>2]=q+10;q=t+r|0;c[j>>2]=q;if((q&1|0)!=0){Mj(f,q,0,0);i=h;return}b[m>>1]=b[l>>1]|0;r=q&16777215;q=r+1|0;if(q>>>0<(c[o>>2]|0)>>>0){t=c[f+32>>2]|0;w=(d[t+r>>0]<<8|d[t+q>>0])&65535}else{w=oc[c[f+12>>2]&31](c[f+4>>2]|0,r)|0}b[l>>1]=w;if((a[n>>0]|0)!=0){Kj(f);i=h;return}r=(c[j>>2]|0)+2|0;c[j>>2]=r;c[p>>2]=(c[p>>2]|0)+2;if((r&1|0)!=0){Mj(f,r,0,0);i=h;return}b[m>>1]=w;w=r&16777215;r=w+1|0;if(r>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;b[l>>1]=d[o+w>>0]<<8|d[o+r>>0]}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,w)|0;w=(a[n>>0]|0)==0;b[l>>1]=r;if(!w){Kj(f);i=h;return}}f=c[j>>2]|0;c[j>>2]=f+2;c[p>>2]=f+ -2;i=h;return}function $j(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=e+372|0;c[h>>2]=(c[h>>2]|0)+4;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,509,8)|0)!=0){i=g;return}if((Mo(e,((f|0)!=0)<<31>>31)|0)!=0){i=g;return}f=e+156|0;h=c[f>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=g;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[f>>2]=(c[f>>2]|0)+2;f=e+152|0;c[f>>2]=(c[f>>2]|0)+2;i=g;return}else{Kj(e);i=g;return}}function ak(a){a=a|0;var b=0,d=0,e=0;b=i;d=0;do{e=c[37832+(d<<2)>>2]|0;c[a+(d<<2)+400>>2]=(e|0)==0?235:e;d=d+1|0}while((d|0)!=1024);c[a+4496>>2]=235;c[a+4500>>2]=40;c[a+4504>>2]=40;c[a+4508>>2]=40;c[a+4512>>2]=40;c[a+4516>>2]=40;c[a+4520>>2]=40;c[a+4524>>2]=40;i=b;return}function bk(a){a=a|0;var b=0,d=0;b=i;Nj(a);d=a+372|0;c[d>>2]=(c[d>>2]|0)+2;i=b;return}function ck(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;h=f+160|0;j=b[h>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,2020,32)|0)!=0){i=g;return}if((c[f+340>>2]|0)!=2){Nj(f);i=g;return}j=f+372|0;c[j>>2]=(c[j>>2]|0)+4;c[f+(((e[h>>1]|0)>>>9&7)<<2)+120>>2]=c[f+344>>2];h=f+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[k>>1]=n;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function dk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+16|0;g=f;h=e+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;l=e+162|0;b[l>>1]=b[k>>1]|0;m=j&16777215;j=m+1|0;n=e+36|0;if(j>>>0<(c[n>>2]|0)>>>0){o=c[e+32>>2]|0;p=(d[o+m>>0]<<8|d[o+j>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[k>>1]=p;m=e+336|0;if((a[m>>0]|0)!=0){Kj(e);i=f;return}j=(c[h>>2]|0)+2|0;c[h>>2]=j;o=e+152|0;c[o>>2]=(c[o>>2]|0)+2;q=b[l>>1]|0;r=b[e+160>>1]&63;if((r|0)==60){s=e+372|0;c[s>>2]=(c[s>>2]|0)+20;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}b[l>>1]=p;p=j&16777215;j=p+1|0;if(j>>>0<(c[n>>2]|0)>>>0){s=c[e+32>>2]|0;b[k>>1]=d[s+p>>0]<<8|d[s+j>>0]}else{j=oc[c[e+12>>2]&31](c[e+4>>2]|0,p)|0;p=(a[m>>0]|0)==0;b[k>>1]=j;if(!p){Kj(e);i=f;return}}c[h>>2]=(c[h>>2]|0)+2;c[o>>2]=(c[o>>2]|0)+2;p=e+166|0;j=b[p>>1]|0;b[p>>1]=(j|q)&31|j&65280;i=f;return}if((nc[c[46024+(r<<2)>>2]&63](e,r,509,8)|0)!=0){i=f;return}if((Jo(e,g)|0)!=0){i=f;return}r=(d[g>>0]|q&65535)&255;q=e+372|0;c[q>>2]=(c[q>>2]|0)+8;bo(e,15,r);q=c[h>>2]|0;if((q&1|0)!=0){Mj(e,q,0,0);i=f;return}b[l>>1]=b[k>>1]|0;l=q&16777215;q=l+1|0;if(q>>>0<(c[n>>2]|0)>>>0){n=c[e+32>>2]|0;t=(d[n+l>>0]<<8|d[n+q>>0])&65535}else{t=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=t;if((a[m>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;c[o>>2]=(c[o>>2]|0)+2;Mo(e,r)|0;i=f;return}else{Kj(e);i=f;return}}function ek(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+16|0;g=f;h=e+160|0;if((b[h>>1]&63)==60){if((a[e+334>>0]|0)==0){Rj(e);i=f;return}j=e+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(e,k,0,0);i=f;return}l=e+164|0;m=e+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=e+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[e+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[e+12>>2]&31](c[e+4>>2]|0,n)|0}b[l>>1]=q;n=e+336|0;if((a[n>>0]|0)!=0){Kj(e);i=f;return}k=(c[j>>2]|0)+2|0;c[j>>2]=k;p=e+152|0;r=(c[p>>2]|0)+2|0;c[p>>2]=r;s=b[m>>1]|0;t=e+372|0;c[t>>2]=(c[t>>2]|0)+20;if((k&1|0)!=0){Mj(e,k,0,0);i=f;return}b[m>>1]=q;q=k&16777215;m=q+1|0;do{if(m>>>0<(c[o>>2]|0)>>>0){t=c[e+32>>2]|0;b[l>>1]=d[t+q>>0]<<8|d[t+m>>0];u=k;v=r}else{t=oc[c[e+12>>2]&31](c[e+4>>2]|0,q)|0;w=(a[n>>0]|0)==0;b[l>>1]=t;if(w){u=c[j>>2]|0;v=c[p>>2]|0;break}Kj(e);i=f;return}}while(0);c[j>>2]=u+2;c[p>>2]=v+2;Ij(e,(b[e+166>>1]|s)&65535&42783);i=f;return}s=e+156|0;v=c[s>>2]|0;if((v&1|0)!=0){Mj(e,v,0,0);i=f;return}p=e+164|0;u=e+162|0;b[u>>1]=b[p>>1]|0;j=v&16777215;v=j+1|0;l=e+36|0;if(v>>>0<(c[l>>2]|0)>>>0){n=c[e+32>>2]|0;x=(d[n+j>>0]<<8|d[n+v>>0])&65535}else{x=oc[c[e+12>>2]&31](c[e+4>>2]|0,j)|0}b[p>>1]=x;x=e+336|0;if((a[x>>0]|0)!=0){Kj(e);i=f;return}c[s>>2]=(c[s>>2]|0)+2;j=e+152|0;c[j>>2]=(c[j>>2]|0)+2;v=b[u>>1]|0;n=b[h>>1]&63;if((nc[c[46024+(n<<2)>>2]&63](e,n,509,16)|0)!=0){i=f;return}if((Ko(e,g)|0)!=0){i=f;return}n=b[g>>1]|v;v=e+372|0;c[v>>2]=(c[v>>2]|0)+8;co(e,15,n);v=c[s>>2]|0;if((v&1|0)!=0){Mj(e,v,0,0);i=f;return}b[u>>1]=b[p>>1]|0;u=v&16777215;v=u+1|0;if(v>>>0<(c[l>>2]|0)>>>0){l=c[e+32>>2]|0;y=(d[l+u>>0]<<8|d[l+v>>0])&65535}else{y=oc[c[e+12>>2]&31](c[e+4>>2]|0,u)|0}b[p>>1]=y;if((a[x>>0]|0)==0){c[s>>2]=(c[s>>2]|0)+2;c[j>>2]=(c[j>>2]|0)+2;No(e,n)|0;i=f;return}else{Kj(e);i=f;return}}function fk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g;j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;n=f+336|0;if((a[n>>0]|0)!=0){Kj(f);i=g;return}k=(c[j>>2]|0)+2|0;c[j>>2]=k;p=f+152|0;c[p>>2]=(c[p>>2]|0)+2;r=b[m>>1]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}b[m>>1]=q;q=k&16777215;k=q+1|0;if(k>>>0<(c[o>>2]|0)>>>0){s=c[f+32>>2]|0;b[l>>1]=d[s+q>>0]<<8|d[s+k>>0]}else{k=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0;q=(a[n>>0]|0)==0;b[l>>1]=k;if(!q){Kj(f);i=g;return}}c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;q=e[m>>1]|(r&65535)<<16;r=b[f+160>>1]&63;if((nc[c[46024+(r<<2)>>2]&63](f,r,509,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}r=q|c[h>>2];h=f+372|0;c[h>>2]=(c[h>>2]|0)+16;eo(f,15,r);h=c[j>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}b[m>>1]=b[l>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;t=(d[o+m>>0]<<8|d[o+h>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=t;if((a[n>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;Oo(f,r)|0;i=g;return}else{Kj(f);i=g;return}}function gk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;i=i+16|0;h=g;j=f+160|0;k=e[j>>1]|0;l=k&56;if((l|0)==8){m=f+156|0;n=c[m>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);i=g;return}o=f+164|0;p=f+162|0;b[p>>1]=b[o>>1]|0;q=n&16777215;n=q+1|0;r=f+36|0;if(n>>>0<(c[r>>2]|0)>>>0){s=c[f+32>>2]|0;t=(d[s+q>>0]<<8|d[s+n>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[o>>1]=t;t=f+336|0;if((a[t>>0]|0)!=0){Kj(f);i=g;return}c[m>>2]=(c[m>>2]|0)+2;q=f+152|0;c[q>>2]=(c[q>>2]|0)+2;n=e[p>>1]|0;s=((n&32768|0)!=0?n|-65536:n)+(c[f+((b[j>>1]&7)<<2)+120>>2]|0)|0;n=s&16777215;u=c[r>>2]|0;if(n>>>0<u>>>0){v=a[(c[f+32>>2]|0)+n>>0]|0;w=u}else{u=oc[c[f+8>>2]&31](c[f+4>>2]|0,n)|0;v=u;w=c[r>>2]|0}u=s+2&16777215;if(u>>>0<w>>>0){x=a[(c[f+32>>2]|0)+u>>0]|0}else{x=oc[c[f+8>>2]&31](c[f+4>>2]|0,u)|0}u=f+372|0;c[u>>2]=(c[u>>2]|0)+16;u=f+(((e[j>>1]|0)>>>9&7)<<2)+88|0;c[u>>2]=x&255|(v&255)<<8|c[u>>2]&-65536;u=c[m>>2]|0;if((u&1|0)!=0){Mj(f,u,0,0);i=g;return}b[p>>1]=b[o>>1]|0;p=u&16777215;u=p+1|0;if(u>>>0<(c[r>>2]|0)>>>0){r=c[f+32>>2]|0;y=(d[r+p>>0]<<8|d[r+u>>0])&65535}else{y=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=y;if((a[t>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;c[q>>2]=(c[q>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else if((l|0)==0){l=c[f+((k&7)<<2)+88>>2]|0;q=1<<(c[f+((k>>>9&7)<<2)+88>>2]&31);m=f+372|0;c[m>>2]=(c[m>>2]|0)+6;m=f+166|0;t=e[m>>1]|0;b[m>>1]=(q&l|0)==0?t|4:t&65531;t=f+156|0;l=c[t>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}q=f+164|0;b[f+162>>1]=b[q>>1]|0;m=l&16777215;l=m+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){y=c[f+32>>2]|0;z=(d[y+m>>0]<<8|d[y+l>>0])&65535}else{z=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[q>>1]=z;if((a[f+336>>0]|0)==0){c[t>>2]=(c[t>>2]|0)+2;t=f+152|0;c[t>>2]=(c[t>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else{t=k&63;if((nc[c[46024+(t<<2)>>2]&63](f,t,4092,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}t=1<<(c[f+(((e[j>>1]|0)>>>9&7)<<2)+88>>2]&7);j=f+372|0;c[j>>2]=(c[j>>2]|0)+4;j=f+166|0;k=e[j>>1]|0;b[j>>1]=(t&d[h>>0]|0)==0?k|4:k&65531;k=f+156|0;h=c[k>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}t=f+164|0;b[f+162>>1]=b[t>>1]|0;j=h&16777215;h=j+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){z=c[f+32>>2]|0;A=(d[z+j>>0]<<8|d[z+h>>0])&65535}else{A=oc[c[f+12>>2]&31](c[f+4>>2]|0,j)|0}b[t>>1]=A;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}}function hk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+16|0;h=g;j=f+160|0;k=e[j>>1]|0;l=k>>>3&7;if((l|0)==1){m=f+156|0;n=c[m>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);i=g;return}o=f+164|0;p=f+162|0;b[p>>1]=b[o>>1]|0;q=n&16777215;n=q+1|0;r=f+36|0;if(n>>>0<(c[r>>2]|0)>>>0){s=c[f+32>>2]|0;t=(d[s+q>>0]<<8|d[s+n>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[o>>1]=t;t=f+336|0;if((a[t>>0]|0)!=0){Kj(f);i=g;return}c[m>>2]=(c[m>>2]|0)+2;q=f+152|0;c[q>>2]=(c[q>>2]|0)+2;n=e[p>>1]|0;s=((n&32768|0)!=0?n|-65536:n)+(c[f+((b[j>>1]&7)<<2)+120>>2]|0)|0;n=s&16777215;u=c[r>>2]|0;if(n>>>0<u>>>0){v=a[(c[f+32>>2]|0)+n>>0]|0;w=u}else{u=oc[c[f+8>>2]&31](c[f+4>>2]|0,n)|0;v=u;w=c[r>>2]|0}u=s+2&16777215;if(u>>>0<w>>>0){x=a[(c[f+32>>2]|0)+u>>0]|0;y=w}else{w=oc[c[f+8>>2]&31](c[f+4>>2]|0,u)|0;x=w;y=c[r>>2]|0}w=s+4&16777215;if(w>>>0<y>>>0){z=a[(c[f+32>>2]|0)+w>>0]|0;A=y}else{y=oc[c[f+8>>2]&31](c[f+4>>2]|0,w)|0;z=y;A=c[r>>2]|0}y=s+6&16777215;if(y>>>0<A>>>0){B=a[(c[f+32>>2]|0)+y>>0]|0}else{B=oc[c[f+8>>2]&31](c[f+4>>2]|0,y)|0}y=f+372|0;c[y>>2]=(c[y>>2]|0)+24;c[f+(((e[j>>1]|0)>>>9&7)<<2)+88>>2]=B&255|(z&255|(x&255|(v&255)<<8)<<8)<<8;v=c[m>>2]|0;if((v&1|0)!=0){Mj(f,v,0,0);i=g;return}b[p>>1]=b[o>>1]|0;p=v&16777215;v=p+1|0;if(v>>>0<(c[r>>2]|0)>>>0){r=c[f+32>>2]|0;C=(d[r+p>>0]<<8|d[r+v>>0])&65535}else{C=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=C;if((a[t>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;c[q>>2]=(c[q>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else if((l|0)==0){l=f+((k&7)<<2)+88|0;q=c[l>>2]|0;m=1<<(c[f+((k>>>9&7)<<2)+88>>2]&31);t=f+372|0;c[t>>2]=(c[t>>2]|0)+8;c[l>>2]=m^q;l=f+166|0;t=e[l>>1]|0;b[l>>1]=(m&q|0)==0?t|4:t&65531;t=f+156|0;q=c[t>>2]|0;if((q&1|0)!=0){Mj(f,q,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;l=q&16777215;q=l+1|0;if(q>>>0<(c[f+36>>2]|0)>>>0){C=c[f+32>>2]|0;D=(d[C+l>>0]<<8|d[C+q>>0])&65535}else{D=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[m>>1]=D;if((a[f+336>>0]|0)==0){c[t>>2]=(c[t>>2]|0)+2;t=f+152|0;c[t>>2]=(c[t>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else{t=k&63;if((nc[c[46024+(t<<2)>>2]&63](f,t,508,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}t=1<<(c[f+(((e[j>>1]|0)>>>9&7)<<2)+88>>2]&7);j=d[h>>0]|0;h=f+372|0;c[h>>2]=(c[h>>2]|0)+8;h=f+166|0;k=e[h>>1]|0;b[h>>1]=(t&j|0)==0?k|4:k&65531;k=f+156|0;h=c[k>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}D=f+164|0;b[f+162>>1]=b[D>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){l=c[f+32>>2]|0;E=(d[l+m>>0]<<8|d[l+h>>0])&65535}else{E=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[D>>1]=E;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;Mo(f,(j^t)&255)|0;i=g;return}else{Kj(f);i=g;return}}}function ik(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+16|0;h=g;j=f+160|0;k=e[j>>1]|0;l=k>>>3&7;if((l|0)==1){m=f+156|0;n=c[m>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);i=g;return}o=f+164|0;p=f+162|0;b[p>>1]=b[o>>1]|0;q=n&16777215;n=q+1|0;r=f+36|0;if(n>>>0<(c[r>>2]|0)>>>0){s=c[f+32>>2]|0;t=(d[s+q>>0]<<8|d[s+n>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[o>>1]=t;t=f+336|0;if((a[t>>0]|0)!=0){Kj(f);i=g;return}c[m>>2]=(c[m>>2]|0)+2;q=f+152|0;c[q>>2]=(c[q>>2]|0)+2;n=e[j>>1]|0;s=e[p>>1]|0;u=((s&32768|0)!=0?s|-65536:s)+(c[f+((n&7)<<2)+120>>2]|0)|0;s=c[f+((n>>>9&7)<<2)+88>>2]|0;n=s>>>8&255;v=u&16777215;if(v>>>0<(c[r>>2]|0)>>>0){a[(c[f+32>>2]|0)+v>>0]=n}else{lc[c[f+20>>2]&31](c[f+4>>2]|0,v,n)}n=s&255;s=u+2&16777215;if(s>>>0<(c[r>>2]|0)>>>0){a[(c[f+32>>2]|0)+s>>0]=n}else{lc[c[f+20>>2]&31](c[f+4>>2]|0,s,n)}n=f+372|0;c[n>>2]=(c[n>>2]|0)+16;n=c[m>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);i=g;return}b[p>>1]=b[o>>1]|0;p=n&16777215;n=p+1|0;if(n>>>0<(c[r>>2]|0)>>>0){r=c[f+32>>2]|0;w=(d[r+p>>0]<<8|d[r+n>>0])&65535}else{w=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=w;if((a[t>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;c[q>>2]=(c[q>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else if((l|0)==0){l=f+((k&7)<<2)+88|0;q=c[l>>2]|0;m=1<<(c[f+((k>>>9&7)<<2)+88>>2]&31);t=f+372|0;c[t>>2]=(c[t>>2]|0)+10;t=f+166|0;w=e[t>>1]|0;b[t>>1]=(m&q|0)==0?w|4:w&65531;c[l>>2]=q&~m;m=f+156|0;q=c[m>>2]|0;if((q&1|0)!=0){Mj(f,q,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;w=q&16777215;q=w+1|0;if(q>>>0<(c[f+36>>2]|0)>>>0){t=c[f+32>>2]|0;x=(d[t+w>>0]<<8|d[t+q>>0])&65535}else{x=oc[c[f+12>>2]&31](c[f+4>>2]|0,w)|0}b[l>>1]=x;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else{m=k&63;if((nc[c[46024+(m<<2)>>2]&63](f,m,508,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}m=1<<(c[f+(((e[j>>1]|0)>>>9&7)<<2)+88>>2]&7);j=d[h>>0]|0;h=f+372|0;c[h>>2]=(c[h>>2]|0)+8;h=f+166|0;k=e[h>>1]|0;b[h>>1]=(m&j|0)==0?k|4:k&65531;k=f+156|0;h=c[k>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}x=f+164|0;b[f+162>>1]=b[x>>1]|0;l=h&16777215;h=l+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){w=c[f+32>>2]|0;y=(d[w+l>>0]<<8|d[w+h>>0])&65535}else{y=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[x>>1]=y;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;Mo(f,(m^255)&j&255)|0;i=g;return}else{Kj(f);i=g;return}}}function jk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;i=i+16|0;h=g;j=f+160|0;k=e[j>>1]|0;l=k>>>3&7;if((l|0)==1){m=f+156|0;n=c[m>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);i=g;return}o=f+164|0;p=f+162|0;b[p>>1]=b[o>>1]|0;q=n&16777215;n=q+1|0;r=f+36|0;if(n>>>0<(c[r>>2]|0)>>>0){s=c[f+32>>2]|0;t=(d[s+q>>0]<<8|d[s+n>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[o>>1]=t;t=f+336|0;if((a[t>>0]|0)!=0){Kj(f);i=g;return}c[m>>2]=(c[m>>2]|0)+2;q=f+152|0;c[q>>2]=(c[q>>2]|0)+2;n=e[j>>1]|0;s=e[p>>1]|0;u=((s&32768|0)!=0?s|-65536:s)+(c[f+((n&7)<<2)+120>>2]|0)|0;s=c[f+((n>>>9&7)<<2)+88>>2]|0;n=s>>>24&255;v=u&16777215;if(v>>>0<(c[r>>2]|0)>>>0){a[(c[f+32>>2]|0)+v>>0]=n}else{lc[c[f+20>>2]&31](c[f+4>>2]|0,v,n)}n=s>>>16&255;v=u+2&16777215;if(v>>>0<(c[r>>2]|0)>>>0){a[(c[f+32>>2]|0)+v>>0]=n}else{lc[c[f+20>>2]&31](c[f+4>>2]|0,v,n)}n=s>>>8&255;v=u+4&16777215;if(v>>>0<(c[r>>2]|0)>>>0){a[(c[f+32>>2]|0)+v>>0]=n}else{lc[c[f+20>>2]&31](c[f+4>>2]|0,v,n)}n=s&255;s=u+6&16777215;if(s>>>0<(c[r>>2]|0)>>>0){a[(c[f+32>>2]|0)+s>>0]=n}else{lc[c[f+20>>2]&31](c[f+4>>2]|0,s,n)}n=f+372|0;c[n>>2]=(c[n>>2]|0)+24;n=c[m>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);i=g;return}b[p>>1]=b[o>>1]|0;p=n&16777215;n=p+1|0;if(n>>>0<(c[r>>2]|0)>>>0){r=c[f+32>>2]|0;w=(d[r+p>>0]<<8|d[r+n>>0])&65535}else{w=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=w;if((a[t>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;c[q>>2]=(c[q>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else if((l|0)==0){l=f+((k&7)<<2)+88|0;q=c[l>>2]|0;m=1<<(c[f+((k>>>9&7)<<2)+88>>2]&31);t=f+372|0;c[t>>2]=(c[t>>2]|0)+8;t=f+166|0;w=e[t>>1]|0;b[t>>1]=(m&q|0)==0?w|4:w&65531;c[l>>2]=m|q;q=f+156|0;m=c[q>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;w=m&16777215;m=w+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){t=c[f+32>>2]|0;x=(d[t+w>>0]<<8|d[t+m>>0])&65535}else{x=oc[c[f+12>>2]&31](c[f+4>>2]|0,w)|0}b[l>>1]=x;if((a[f+336>>0]|0)==0){c[q>>2]=(c[q>>2]|0)+2;q=f+152|0;c[q>>2]=(c[q>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else{q=k&63;if((nc[c[46024+(q<<2)>>2]&63](f,q,508,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}q=1<<(c[f+(((e[j>>1]|0)>>>9&7)<<2)+88>>2]&7);j=d[h>>0]|0;h=f+372|0;c[h>>2]=(c[h>>2]|0)+8;h=f+166|0;k=e[h>>1]|0;b[h>>1]=(q&j|0)==0?k|4:k&65531;k=f+156|0;h=c[k>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}x=f+164|0;b[f+162>>1]=b[x>>1]|0;l=h&16777215;h=l+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){w=c[f+32>>2]|0;y=(d[w+l>>0]<<8|d[w+h>>0])&65535}else{y=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[x>>1]=y;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;Mo(f,(j|q)&255)|0;i=g;return}else{Kj(f);i=g;return}}}function kk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+16|0;g=f;h=e+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;l=e+162|0;b[l>>1]=b[k>>1]|0;m=j&16777215;j=m+1|0;n=e+36|0;if(j>>>0<(c[n>>2]|0)>>>0){o=c[e+32>>2]|0;p=(d[o+m>>0]<<8|d[o+j>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[k>>1]=p;m=e+336|0;if((a[m>>0]|0)!=0){Kj(e);i=f;return}j=(c[h>>2]|0)+2|0;c[h>>2]=j;o=e+152|0;c[o>>2]=(c[o>>2]|0)+2;q=b[l>>1]|0;r=b[e+160>>1]&63;if((r|0)==60){s=e+372|0;c[s>>2]=(c[s>>2]|0)+20;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}b[l>>1]=p;p=j&16777215;j=p+1|0;if(j>>>0<(c[n>>2]|0)>>>0){s=c[e+32>>2]|0;b[k>>1]=d[s+p>>0]<<8|d[s+j>>0]}else{j=oc[c[e+12>>2]&31](c[e+4>>2]|0,p)|0;p=(a[m>>0]|0)==0;b[k>>1]=j;if(!p){Kj(e);i=f;return}}c[h>>2]=(c[h>>2]|0)+2;c[o>>2]=(c[o>>2]|0)+2;p=e+166|0;j=b[p>>1]|0;b[p>>1]=j&q&31|j&65280;i=f;return}if((nc[c[46024+(r<<2)>>2]&63](e,r,509,8)|0)!=0){i=f;return}if((Jo(e,g)|0)!=0){i=f;return}r=d[g>>0]&(q&65535)&255;q=e+372|0;c[q>>2]=(c[q>>2]|0)+8;bo(e,15,r);q=c[h>>2]|0;if((q&1|0)!=0){Mj(e,q,0,0);i=f;return}b[l>>1]=b[k>>1]|0;l=q&16777215;q=l+1|0;if(q>>>0<(c[n>>2]|0)>>>0){n=c[e+32>>2]|0;t=(d[n+l>>0]<<8|d[n+q>>0])&65535}else{t=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=t;if((a[m>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;c[o>>2]=(c[o>>2]|0)+2;Mo(e,r)|0;i=f;return}else{Kj(e);i=f;return}}function lk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+16|0;g=f;h=e+160|0;if((b[h>>1]&63)==60){if((a[e+334>>0]|0)==0){Rj(e);i=f;return}j=e+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(e,k,0,0);i=f;return}l=e+164|0;m=e+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=e+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[e+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[e+12>>2]&31](c[e+4>>2]|0,n)|0}b[l>>1]=q;n=e+336|0;if((a[n>>0]|0)!=0){Kj(e);i=f;return}k=(c[j>>2]|0)+2|0;c[j>>2]=k;p=e+152|0;r=(c[p>>2]|0)+2|0;c[p>>2]=r;s=b[m>>1]|0;t=e+372|0;c[t>>2]=(c[t>>2]|0)+20;if((k&1|0)!=0){Mj(e,k,0,0);i=f;return}b[m>>1]=q;q=k&16777215;m=q+1|0;do{if(m>>>0<(c[o>>2]|0)>>>0){t=c[e+32>>2]|0;b[l>>1]=d[t+q>>0]<<8|d[t+m>>0];u=k;v=r}else{t=oc[c[e+12>>2]&31](c[e+4>>2]|0,q)|0;w=(a[n>>0]|0)==0;b[l>>1]=t;if(w){u=c[j>>2]|0;v=c[p>>2]|0;break}Kj(e);i=f;return}}while(0);c[j>>2]=u+2;c[p>>2]=v+2;Ij(e,b[e+166>>1]&s);i=f;return}s=e+156|0;v=c[s>>2]|0;if((v&1|0)!=0){Mj(e,v,0,0);i=f;return}p=e+164|0;u=e+162|0;b[u>>1]=b[p>>1]|0;j=v&16777215;v=j+1|0;l=e+36|0;if(v>>>0<(c[l>>2]|0)>>>0){n=c[e+32>>2]|0;x=(d[n+j>>0]<<8|d[n+v>>0])&65535}else{x=oc[c[e+12>>2]&31](c[e+4>>2]|0,j)|0}b[p>>1]=x;x=e+336|0;if((a[x>>0]|0)!=0){Kj(e);i=f;return}c[s>>2]=(c[s>>2]|0)+2;j=e+152|0;c[j>>2]=(c[j>>2]|0)+2;v=b[u>>1]|0;n=b[h>>1]&63;if((nc[c[46024+(n<<2)>>2]&63](e,n,509,16)|0)!=0){i=f;return}if((Ko(e,g)|0)!=0){i=f;return}n=b[g>>1]&v;v=e+372|0;c[v>>2]=(c[v>>2]|0)+8;co(e,15,n);v=c[s>>2]|0;if((v&1|0)!=0){Mj(e,v,0,0);i=f;return}b[u>>1]=b[p>>1]|0;u=v&16777215;v=u+1|0;if(v>>>0<(c[l>>2]|0)>>>0){l=c[e+32>>2]|0;y=(d[l+u>>0]<<8|d[l+v>>0])&65535}else{y=oc[c[e+12>>2]&31](c[e+4>>2]|0,u)|0}b[p>>1]=y;if((a[x>>0]|0)==0){c[s>>2]=(c[s>>2]|0)+2;c[j>>2]=(c[j>>2]|0)+2;No(e,n)|0;i=f;return}else{Kj(e);i=f;return}}function mk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g;j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;n=f+336|0;if((a[n>>0]|0)!=0){Kj(f);i=g;return}k=(c[j>>2]|0)+2|0;c[j>>2]=k;p=f+152|0;c[p>>2]=(c[p>>2]|0)+2;r=b[m>>1]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}b[m>>1]=q;q=k&16777215;k=q+1|0;if(k>>>0<(c[o>>2]|0)>>>0){s=c[f+32>>2]|0;b[l>>1]=d[s+q>>0]<<8|d[s+k>>0]}else{k=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0;q=(a[n>>0]|0)==0;b[l>>1]=k;if(!q){Kj(f);i=g;return}}c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;q=e[m>>1]|(r&65535)<<16;r=b[f+160>>1]&63;if((nc[c[46024+(r<<2)>>2]&63](f,r,509,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}r=c[h>>2]&q;q=f+372|0;c[q>>2]=(c[q>>2]|0)+16;eo(f,15,r);q=c[j>>2]|0;if((q&1|0)!=0){Mj(f,q,0,0);i=g;return}b[m>>1]=b[l>>1]|0;m=q&16777215;q=m+1|0;if(q>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;t=(d[o+m>>0]<<8|d[o+q>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=t;if((a[n>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;Oo(f,r)|0;i=g;return}else{Kj(f);i=g;return}}function nk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+16|0;g=f;h=e+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;l=e+162|0;b[l>>1]=b[k>>1]|0;m=j&16777215;j=m+1|0;n=e+36|0;if(j>>>0<(c[n>>2]|0)>>>0){o=c[e+32>>2]|0;p=(d[o+m>>0]<<8|d[o+j>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[k>>1]=p;p=e+336|0;if((a[p>>0]|0)!=0){Kj(e);i=f;return}c[h>>2]=(c[h>>2]|0)+2;m=e+152|0;c[m>>2]=(c[m>>2]|0)+2;j=b[l>>1]|0;o=b[e+160>>1]&63;if((nc[c[46024+(o<<2)>>2]&63](e,o,509,8)|0)!=0){i=f;return}if((Jo(e,g)|0)!=0){i=f;return}o=a[g>>0]|0;g=(o&255)-(j&65535)&255;q=e+372|0;c[q>>2]=(c[q>>2]|0)+8;oo(e,g,j&255,o);o=c[h>>2]|0;if((o&1|0)!=0){Mj(e,o,0,0);i=f;return}b[l>>1]=b[k>>1]|0;l=o&16777215;o=l+1|0;if(o>>>0<(c[n>>2]|0)>>>0){n=c[e+32>>2]|0;r=(d[n+l>>0]<<8|d[n+o>>0])&65535}else{r=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=r;if((a[p>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;c[m>>2]=(c[m>>2]|0)+2;Mo(e,g)|0;i=f;return}else{Kj(e);i=f;return}}function ok(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+16|0;g=f;h=e+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;l=e+162|0;b[l>>1]=b[k>>1]|0;m=j&16777215;j=m+1|0;n=e+36|0;if(j>>>0<(c[n>>2]|0)>>>0){o=c[e+32>>2]|0;p=(d[o+m>>0]<<8|d[o+j>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[k>>1]=p;p=e+336|0;if((a[p>>0]|0)!=0){Kj(e);i=f;return}c[h>>2]=(c[h>>2]|0)+2;m=e+152|0;c[m>>2]=(c[m>>2]|0)+2;j=b[l>>1]|0;o=b[e+160>>1]&63;if((nc[c[46024+(o<<2)>>2]&63](e,o,509,16)|0)!=0){i=f;return}if((Ko(e,g)|0)!=0){i=f;return}o=b[g>>1]|0;g=(o&65535)-(j&65535)&65535;q=e+372|0;c[q>>2]=(c[q>>2]|0)+8;po(e,g,j,o);o=c[h>>2]|0;if((o&1|0)!=0){Mj(e,o,0,0);i=f;return}b[l>>1]=b[k>>1]|0;l=o&16777215;o=l+1|0;if(o>>>0<(c[n>>2]|0)>>>0){n=c[e+32>>2]|0;r=(d[n+l>>0]<<8|d[n+o>>0])&65535}else{r=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=r;if((a[p>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;c[m>>2]=(c[m>>2]|0)+2;No(e,g)|0;i=f;return}else{Kj(e);i=f;return}}function pk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g;j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;n=f+336|0;if((a[n>>0]|0)!=0){Kj(f);i=g;return}k=(c[j>>2]|0)+2|0;c[j>>2]=k;p=f+152|0;c[p>>2]=(c[p>>2]|0)+2;r=b[m>>1]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}b[m>>1]=q;q=k&16777215;k=q+1|0;if(k>>>0<(c[o>>2]|0)>>>0){s=c[f+32>>2]|0;b[l>>1]=d[s+q>>0]<<8|d[s+k>>0]}else{k=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0;q=(a[n>>0]|0)==0;b[l>>1]=k;if(!q){Kj(f);i=g;return}}c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;q=e[m>>1]|(r&65535)<<16;r=b[f+160>>1]&63;if((nc[c[46024+(r<<2)>>2]&63](f,r,509,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}r=c[h>>2]|0;h=r-q|0;k=f+372|0;c[k>>2]=(c[k>>2]|0)+16;qo(f,h,q,r);r=c[j>>2]|0;if((r&1|0)!=0){Mj(f,r,0,0);i=g;return}b[m>>1]=b[l>>1]|0;m=r&16777215;r=m+1|0;if(r>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;t=(d[o+m>>0]<<8|d[o+r>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=t;if((a[n>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;Oo(f,h)|0;i=g;return}else{Kj(f);i=g;return}}function qk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+16|0;g=f;h=e+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;l=e+162|0;b[l>>1]=b[k>>1]|0;m=j&16777215;j=m+1|0;n=e+36|0;if(j>>>0<(c[n>>2]|0)>>>0){o=c[e+32>>2]|0;p=(d[o+m>>0]<<8|d[o+j>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[k>>1]=p;p=e+336|0;if((a[p>>0]|0)!=0){Kj(e);i=f;return}c[h>>2]=(c[h>>2]|0)+2;m=e+152|0;c[m>>2]=(c[m>>2]|0)+2;j=b[l>>1]|0;o=b[e+160>>1]&63;if((nc[c[46024+(o<<2)>>2]&63](e,o,509,8)|0)!=0){i=f;return}if((Jo(e,g)|0)!=0){i=f;return}o=a[g>>0]|0;g=(o&255)+(j&65535)&255;q=e+372|0;c[q>>2]=(c[q>>2]|0)+8;fo(e,g,j&255,o);o=c[h>>2]|0;if((o&1|0)!=0){Mj(e,o,0,0);i=f;return}b[l>>1]=b[k>>1]|0;l=o&16777215;o=l+1|0;if(o>>>0<(c[n>>2]|0)>>>0){n=c[e+32>>2]|0;r=(d[n+l>>0]<<8|d[n+o>>0])&65535}else{r=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=r;if((a[p>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;c[m>>2]=(c[m>>2]|0)+2;Mo(e,g)|0;i=f;return}else{Kj(e);i=f;return}}function rk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+16|0;g=f;h=e+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;l=e+162|0;b[l>>1]=b[k>>1]|0;m=j&16777215;j=m+1|0;n=e+36|0;if(j>>>0<(c[n>>2]|0)>>>0){o=c[e+32>>2]|0;p=(d[o+m>>0]<<8|d[o+j>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[k>>1]=p;p=e+336|0;if((a[p>>0]|0)!=0){Kj(e);i=f;return}c[h>>2]=(c[h>>2]|0)+2;m=e+152|0;c[m>>2]=(c[m>>2]|0)+2;j=b[l>>1]|0;o=b[e+160>>1]&63;if((nc[c[46024+(o<<2)>>2]&63](e,o,509,16)|0)!=0){i=f;return}if((Ko(e,g)|0)!=0){i=f;return}o=b[g>>1]|0;g=(o&65535)+(j&65535)&65535;q=e+372|0;c[q>>2]=(c[q>>2]|0)+8;go(e,g,j,o);o=c[h>>2]|0;if((o&1|0)!=0){Mj(e,o,0,0);i=f;return}b[l>>1]=b[k>>1]|0;l=o&16777215;o=l+1|0;if(o>>>0<(c[n>>2]|0)>>>0){n=c[e+32>>2]|0;r=(d[n+l>>0]<<8|d[n+o>>0])&65535}else{r=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=r;if((a[p>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;c[m>>2]=(c[m>>2]|0)+2;No(e,g)|0;i=f;return}else{Kj(e);i=f;return}}function sk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g;j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;n=f+336|0;if((a[n>>0]|0)!=0){Kj(f);i=g;return}k=(c[j>>2]|0)+2|0;c[j>>2]=k;p=f+152|0;c[p>>2]=(c[p>>2]|0)+2;r=b[m>>1]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}b[m>>1]=q;q=k&16777215;k=q+1|0;if(k>>>0<(c[o>>2]|0)>>>0){s=c[f+32>>2]|0;b[l>>1]=d[s+q>>0]<<8|d[s+k>>0]}else{k=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0;q=(a[n>>0]|0)==0;b[l>>1]=k;if(!q){Kj(f);i=g;return}}c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;q=e[m>>1]|(r&65535)<<16;r=b[f+160>>1]&63;if((nc[c[46024+(r<<2)>>2]&63](f,r,509,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}r=c[h>>2]|0;h=r+q|0;k=f+372|0;c[k>>2]=(c[k>>2]|0)+16;ho(f,h,q,r);r=c[j>>2]|0;if((r&1|0)!=0){Mj(f,r,0,0);i=g;return}b[m>>1]=b[l>>1]|0;m=r&16777215;r=m+1|0;if(r>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;t=(d[o+m>>0]<<8|d[o+r>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=t;if((a[n>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;Oo(f,h)|0;i=g;return}else{Kj(f);i=g;return}}function tk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+16|0;h=g;j=f+160|0;k=f+156|0;l=c[k>>2]|0;m=(l&1|0)==0;if((b[j>>1]&56)==0){if(!m){Mj(f,l,0,0);i=g;return}n=f+164|0;o=f+162|0;b[o>>1]=b[n>>1]|0;p=l&16777215;q=p+1|0;r=f+36|0;if(q>>>0<(c[r>>2]|0)>>>0){s=c[f+32>>2]|0;t=(d[s+p>>0]<<8|d[s+q>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[n>>1]=t;p=f+336|0;if((a[p>>0]|0)!=0){Kj(f);i=g;return}q=(c[k>>2]|0)+2|0;c[k>>2]=q;s=f+152|0;u=(c[s>>2]|0)+2|0;c[s>>2]=u;v=1<<(b[o>>1]&31)&c[f+((b[j>>1]&7)<<2)+88>>2];w=f+372|0;c[w>>2]=(c[w>>2]|0)+10;w=f+166|0;x=e[w>>1]|0;b[w>>1]=(v|0)==0?x|4:x&65531;if((q&1|0)!=0){Mj(f,q,0,0);i=g;return}b[o>>1]=t;t=q&16777215;o=t+1|0;do{if(o>>>0<(c[r>>2]|0)>>>0){x=c[f+32>>2]|0;b[n>>1]=d[x+t>>0]<<8|d[x+o>>0];y=q;z=u}else{x=oc[c[f+12>>2]&31](c[f+4>>2]|0,t)|0;v=(a[p>>0]|0)==0;b[n>>1]=x;if(v){y=c[k>>2]|0;z=c[s>>2]|0;break}Kj(f);i=g;return}}while(0);c[k>>2]=y+2;c[s>>2]=z+2;i=g;return}if(!m){Mj(f,l,0,0);i=g;return}m=f+164|0;z=f+162|0;b[z>>1]=b[m>>1]|0;s=l&16777215;l=s+1|0;y=f+36|0;if(l>>>0<(c[y>>2]|0)>>>0){n=c[f+32>>2]|0;A=(d[n+s>>0]<<8|d[n+l>>0])&65535}else{A=oc[c[f+12>>2]&31](c[f+4>>2]|0,s)|0}b[m>>1]=A;A=f+336|0;if((a[A>>0]|0)!=0){Kj(f);i=g;return}c[k>>2]=(c[k>>2]|0)+2;s=f+152|0;c[s>>2]=(c[s>>2]|0)+2;l=e[z>>1]|0;n=b[j>>1]&63;if((nc[c[46024+(n<<2)>>2]&63](f,n,2044,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}n=d[h>>0]&1<<(l&7);l=f+372|0;c[l>>2]=(c[l>>2]|0)+8;l=f+166|0;h=e[l>>1]|0;b[l>>1]=(n|0)==0?h|4:h&65531;h=c[k>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}b[z>>1]=b[m>>1]|0;z=h&16777215;h=z+1|0;if(h>>>0<(c[y>>2]|0)>>>0){y=c[f+32>>2]|0;B=(d[y+z>>0]<<8|d[y+h>>0])&65535}else{B=oc[c[f+12>>2]&31](c[f+4>>2]|0,z)|0}b[m>>1]=B;if((a[A>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;c[s>>2]=(c[s>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function uk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+16|0;h=g;j=f+160|0;k=f+156|0;l=c[k>>2]|0;m=(l&1|0)==0;if((b[j>>1]&56)==0){if(!m){Mj(f,l,0,0);i=g;return}n=f+164|0;o=f+162|0;b[o>>1]=b[n>>1]|0;p=l&16777215;q=p+1|0;r=f+36|0;if(q>>>0<(c[r>>2]|0)>>>0){s=c[f+32>>2]|0;t=(d[s+p>>0]<<8|d[s+q>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[n>>1]=t;p=f+336|0;if((a[p>>0]|0)!=0){Kj(f);i=g;return}q=(c[k>>2]|0)+2|0;c[k>>2]=q;s=f+152|0;u=(c[s>>2]|0)+2|0;c[s>>2]=u;v=f+((b[j>>1]&7)<<2)+88|0;w=c[v>>2]|0;x=1<<(b[o>>1]&31);y=x^w;z=f+372|0;c[z>>2]=(c[z>>2]|0)+12;z=f+166|0;A=e[z>>1]|0;b[z>>1]=(x&w|0)==0?A|4:A&65531;if((q&1|0)!=0){Mj(f,q,0,0);i=g;return}b[o>>1]=t;t=q&16777215;o=t+1|0;do{if(o>>>0<(c[r>>2]|0)>>>0){A=c[f+32>>2]|0;b[n>>1]=d[A+t>>0]<<8|d[A+o>>0];B=q;C=u}else{A=oc[c[f+12>>2]&31](c[f+4>>2]|0,t)|0;w=(a[p>>0]|0)==0;b[n>>1]=A;if(w){B=c[k>>2]|0;C=c[s>>2]|0;break}Kj(f);i=g;return}}while(0);c[k>>2]=B+2;c[s>>2]=C+2;c[v>>2]=y;i=g;return}if(!m){Mj(f,l,0,0);i=g;return}m=f+164|0;y=f+162|0;b[y>>1]=b[m>>1]|0;v=l&16777215;l=v+1|0;C=f+36|0;if(l>>>0<(c[C>>2]|0)>>>0){s=c[f+32>>2]|0;D=(d[s+v>>0]<<8|d[s+l>>0])&65535}else{D=oc[c[f+12>>2]&31](c[f+4>>2]|0,v)|0}b[m>>1]=D;D=f+336|0;if((a[D>>0]|0)!=0){Kj(f);i=g;return}c[k>>2]=(c[k>>2]|0)+2;v=f+152|0;c[v>>2]=(c[v>>2]|0)+2;l=b[y>>1]&7;s=b[j>>1]&63;if((nc[c[46024+(s<<2)>>2]&63](f,s,508,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}s=1<<l;l=d[h>>0]|0;h=f+372|0;c[h>>2]=(c[h>>2]|0)+12;h=f+166|0;j=e[h>>1]|0;b[h>>1]=(s&l|0)==0?j|4:j&65531;j=c[k>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}b[y>>1]=b[m>>1]|0;y=j&16777215;j=y+1|0;if(j>>>0<(c[C>>2]|0)>>>0){C=c[f+32>>2]|0;E=(d[C+y>>0]<<8|d[C+j>>0])&65535}else{E=oc[c[f+12>>2]&31](c[f+4>>2]|0,y)|0}b[m>>1]=E;if((a[D>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;c[v>>2]=(c[v>>2]|0)+2;Mo(f,(l^s)&255)|0;i=g;return}else{Kj(f);i=g;return}}function vk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+16|0;h=g;j=f+160|0;k=f+156|0;l=c[k>>2]|0;m=(l&1|0)==0;if((b[j>>1]&56)==0){if(!m){Mj(f,l,0,0);i=g;return}n=f+164|0;o=f+162|0;b[o>>1]=b[n>>1]|0;p=l&16777215;q=p+1|0;r=f+36|0;if(q>>>0<(c[r>>2]|0)>>>0){s=c[f+32>>2]|0;t=(d[s+p>>0]<<8|d[s+q>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[n>>1]=t;p=f+336|0;if((a[p>>0]|0)!=0){Kj(f);i=g;return}q=(c[k>>2]|0)+2|0;c[k>>2]=q;s=f+152|0;u=(c[s>>2]|0)+2|0;c[s>>2]=u;v=f+((b[j>>1]&7)<<2)+88|0;w=c[v>>2]|0;x=1<<(b[o>>1]&31);y=w&~x;z=f+372|0;c[z>>2]=(c[z>>2]|0)+14;z=f+166|0;A=e[z>>1]|0;b[z>>1]=(x&w|0)==0?A|4:A&65531;if((q&1|0)!=0){Mj(f,q,0,0);i=g;return}b[o>>1]=t;t=q&16777215;o=t+1|0;do{if(o>>>0<(c[r>>2]|0)>>>0){A=c[f+32>>2]|0;b[n>>1]=d[A+t>>0]<<8|d[A+o>>0];B=q;C=u}else{A=oc[c[f+12>>2]&31](c[f+4>>2]|0,t)|0;w=(a[p>>0]|0)==0;b[n>>1]=A;if(w){B=c[k>>2]|0;C=c[s>>2]|0;break}Kj(f);i=g;return}}while(0);c[k>>2]=B+2;c[s>>2]=C+2;c[v>>2]=y;i=g;return}if(!m){Mj(f,l,0,0);i=g;return}m=f+164|0;y=f+162|0;b[y>>1]=b[m>>1]|0;v=l&16777215;l=v+1|0;C=f+36|0;if(l>>>0<(c[C>>2]|0)>>>0){s=c[f+32>>2]|0;D=(d[s+v>>0]<<8|d[s+l>>0])&65535}else{D=oc[c[f+12>>2]&31](c[f+4>>2]|0,v)|0}b[m>>1]=D;D=f+336|0;if((a[D>>0]|0)!=0){Kj(f);i=g;return}c[k>>2]=(c[k>>2]|0)+2;v=f+152|0;c[v>>2]=(c[v>>2]|0)+2;l=b[y>>1]&7;s=b[j>>1]&63;if((nc[c[46024+(s<<2)>>2]&63](f,s,508,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}s=1<<l;l=d[h>>0]|0;h=f+372|0;c[h>>2]=(c[h>>2]|0)+12;h=f+166|0;j=e[h>>1]|0;b[h>>1]=(s&l|0)==0?j|4:j&65531;j=c[k>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}b[y>>1]=b[m>>1]|0;y=j&16777215;j=y+1|0;if(j>>>0<(c[C>>2]|0)>>>0){C=c[f+32>>2]|0;E=(d[C+y>>0]<<8|d[C+j>>0])&65535}else{E=oc[c[f+12>>2]&31](c[f+4>>2]|0,y)|0}b[m>>1]=E;if((a[D>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;c[v>>2]=(c[v>>2]|0)+2;Mo(f,l&(s^255)&255)|0;i=g;return}else{Kj(f);i=g;return}}function wk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;g=i;i=i+16|0;h=g;j=f+160|0;k=f+156|0;l=c[k>>2]|0;m=(l&1|0)==0;if((b[j>>1]&56)==0){if(!m){Mj(f,l,0,0);i=g;return}n=f+164|0;o=f+162|0;b[o>>1]=b[n>>1]|0;p=l&16777215;q=p+1|0;r=f+36|0;if(q>>>0<(c[r>>2]|0)>>>0){s=c[f+32>>2]|0;t=(d[s+p>>0]<<8|d[s+q>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[n>>1]=t;p=f+336|0;if((a[p>>0]|0)!=0){Kj(f);i=g;return}q=(c[k>>2]|0)+2|0;c[k>>2]=q;s=f+152|0;u=(c[s>>2]|0)+2|0;c[s>>2]=u;v=f+((b[j>>1]&7)<<2)+88|0;w=c[v>>2]|0;x=1<<(b[o>>1]&31);y=x|w;z=f+372|0;c[z>>2]=(c[z>>2]|0)+12;z=f+166|0;A=e[z>>1]|0;b[z>>1]=(x&w|0)==0?A|4:A&65531;if((q&1|0)!=0){Mj(f,q,0,0);i=g;return}b[o>>1]=t;t=q&16777215;o=t+1|0;do{if(o>>>0<(c[r>>2]|0)>>>0){A=c[f+32>>2]|0;b[n>>1]=d[A+t>>0]<<8|d[A+o>>0];B=q;C=u}else{A=oc[c[f+12>>2]&31](c[f+4>>2]|0,t)|0;w=(a[p>>0]|0)==0;b[n>>1]=A;if(w){B=c[k>>2]|0;C=c[s>>2]|0;break}Kj(f);i=g;return}}while(0);c[k>>2]=B+2;c[s>>2]=C+2;c[v>>2]=y;i=g;return}if(!m){Mj(f,l,0,0);i=g;return}m=f+164|0;y=f+162|0;b[y>>1]=b[m>>1]|0;v=l&16777215;l=v+1|0;C=f+36|0;if(l>>>0<(c[C>>2]|0)>>>0){s=c[f+32>>2]|0;D=(d[s+v>>0]<<8|d[s+l>>0])&65535}else{D=oc[c[f+12>>2]&31](c[f+4>>2]|0,v)|0}b[m>>1]=D;D=f+336|0;if((a[D>>0]|0)!=0){Kj(f);i=g;return}c[k>>2]=(c[k>>2]|0)+2;v=f+152|0;c[v>>2]=(c[v>>2]|0)+2;l=b[y>>1]&7;s=b[j>>1]&63;if((nc[c[46024+(s<<2)>>2]&63](f,s,508,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}s=1<<l;l=d[h>>0]|0;h=f+372|0;c[h>>2]=(c[h>>2]|0)+12;h=f+166|0;j=e[h>>1]|0;b[h>>1]=(s&l|0)==0?j|4:j&65531;j=c[k>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}b[y>>1]=b[m>>1]|0;y=j&16777215;j=y+1|0;if(j>>>0<(c[C>>2]|0)>>>0){C=c[f+32>>2]|0;E=(d[C+y>>0]<<8|d[C+j>>0])&65535}else{E=oc[c[f+12>>2]&31](c[f+4>>2]|0,y)|0}b[m>>1]=E;if((a[D>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;c[v>>2]=(c[v>>2]|0)+2;Mo(f,(l|s)&255)|0;i=g;return}else{Kj(f);i=g;return}}function xk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+16|0;g=f;h=e+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;l=e+162|0;b[l>>1]=b[k>>1]|0;m=j&16777215;j=m+1|0;n=e+36|0;if(j>>>0<(c[n>>2]|0)>>>0){o=c[e+32>>2]|0;p=(d[o+m>>0]<<8|d[o+j>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[k>>1]=p;m=e+336|0;if((a[m>>0]|0)!=0){Kj(e);i=f;return}j=(c[h>>2]|0)+2|0;c[h>>2]=j;o=e+152|0;c[o>>2]=(c[o>>2]|0)+2;q=b[l>>1]|0;r=b[e+160>>1]&63;if((r|0)==60){s=e+372|0;c[s>>2]=(c[s>>2]|0)+20;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}b[l>>1]=p;p=j&16777215;j=p+1|0;if(j>>>0<(c[n>>2]|0)>>>0){s=c[e+32>>2]|0;b[k>>1]=d[s+p>>0]<<8|d[s+j>>0]}else{j=oc[c[e+12>>2]&31](c[e+4>>2]|0,p)|0;p=(a[m>>0]|0)==0;b[k>>1]=j;if(!p){Kj(e);i=f;return}}c[h>>2]=(c[h>>2]|0)+2;c[o>>2]=(c[o>>2]|0)+2;p=e+166|0;j=b[p>>1]|0;b[p>>1]=(j^q)&31|j&65280;i=f;return}if((nc[c[46024+(r<<2)>>2]&63](e,r,509,8)|0)!=0){i=f;return}if((Jo(e,g)|0)!=0){i=f;return}r=(d[g>>0]^q&65535)&255;q=e+372|0;c[q>>2]=(c[q>>2]|0)+8;bo(e,15,r);q=c[h>>2]|0;if((q&1|0)!=0){Mj(e,q,0,0);i=f;return}b[l>>1]=b[k>>1]|0;l=q&16777215;q=l+1|0;if(q>>>0<(c[n>>2]|0)>>>0){n=c[e+32>>2]|0;t=(d[n+l>>0]<<8|d[n+q>>0])&65535}else{t=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=t;if((a[m>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;c[o>>2]=(c[o>>2]|0)+2;Mo(e,r)|0;i=f;return}else{Kj(e);i=f;return}}function yk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+16|0;g=f;h=e+160|0;if((b[h>>1]&63)==60){if((a[e+334>>0]|0)==0){Rj(e);i=f;return}j=e+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(e,k,0,0);i=f;return}l=e+164|0;m=e+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=e+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[e+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[e+12>>2]&31](c[e+4>>2]|0,n)|0}b[l>>1]=q;n=e+336|0;if((a[n>>0]|0)!=0){Kj(e);i=f;return}k=(c[j>>2]|0)+2|0;c[j>>2]=k;p=e+152|0;r=(c[p>>2]|0)+2|0;c[p>>2]=r;s=b[m>>1]|0;t=e+372|0;c[t>>2]=(c[t>>2]|0)+20;if((k&1|0)!=0){Mj(e,k,0,0);i=f;return}b[m>>1]=q;q=k&16777215;m=q+1|0;do{if(m>>>0<(c[o>>2]|0)>>>0){t=c[e+32>>2]|0;b[l>>1]=d[t+q>>0]<<8|d[t+m>>0];u=k;v=r}else{t=oc[c[e+12>>2]&31](c[e+4>>2]|0,q)|0;w=(a[n>>0]|0)==0;b[l>>1]=t;if(w){u=c[j>>2]|0;v=c[p>>2]|0;break}Kj(e);i=f;return}}while(0);c[j>>2]=u+2;c[p>>2]=v+2;Ij(e,(b[e+166>>1]^s)&65535&42783);i=f;return}s=e+156|0;v=c[s>>2]|0;if((v&1|0)!=0){Mj(e,v,0,0);i=f;return}p=e+164|0;u=e+162|0;b[u>>1]=b[p>>1]|0;j=v&16777215;v=j+1|0;l=e+36|0;if(v>>>0<(c[l>>2]|0)>>>0){n=c[e+32>>2]|0;x=(d[n+j>>0]<<8|d[n+v>>0])&65535}else{x=oc[c[e+12>>2]&31](c[e+4>>2]|0,j)|0}b[p>>1]=x;x=e+336|0;if((a[x>>0]|0)!=0){Kj(e);i=f;return}c[s>>2]=(c[s>>2]|0)+2;j=e+152|0;c[j>>2]=(c[j>>2]|0)+2;v=b[u>>1]|0;n=b[h>>1]&63;if((nc[c[46024+(n<<2)>>2]&63](e,n,509,16)|0)!=0){i=f;return}if((Ko(e,g)|0)!=0){i=f;return}n=b[g>>1]^v;co(e,15,n);v=e+372|0;c[v>>2]=(c[v>>2]|0)+8;v=c[s>>2]|0;if((v&1|0)!=0){Mj(e,v,0,0);i=f;return}b[u>>1]=b[p>>1]|0;u=v&16777215;v=u+1|0;if(v>>>0<(c[l>>2]|0)>>>0){l=c[e+32>>2]|0;y=(d[l+u>>0]<<8|d[l+v>>0])&65535}else{y=oc[c[e+12>>2]&31](c[e+4>>2]|0,u)|0}b[p>>1]=y;if((a[x>>0]|0)==0){c[s>>2]=(c[s>>2]|0)+2;c[j>>2]=(c[j>>2]|0)+2;No(e,n)|0;i=f;return}else{Kj(e);i=f;return}}function zk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g;j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;n=f+336|0;if((a[n>>0]|0)!=0){Kj(f);i=g;return}k=(c[j>>2]|0)+2|0;c[j>>2]=k;p=f+152|0;c[p>>2]=(c[p>>2]|0)+2;r=b[m>>1]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}b[m>>1]=q;q=k&16777215;k=q+1|0;if(k>>>0<(c[o>>2]|0)>>>0){s=c[f+32>>2]|0;b[l>>1]=d[s+q>>0]<<8|d[s+k>>0]}else{k=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0;q=(a[n>>0]|0)==0;b[l>>1]=k;if(!q){Kj(f);i=g;return}}c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;q=e[m>>1]|(r&65535)<<16;r=b[f+160>>1]&63;if((nc[c[46024+(r<<2)>>2]&63](f,r,509,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}r=c[h>>2]^q;q=f+372|0;c[q>>2]=(c[q>>2]|0)+12;eo(f,15,r);q=c[j>>2]|0;if((q&1|0)!=0){Mj(f,q,0,0);i=g;return}b[m>>1]=b[l>>1]|0;m=q&16777215;q=m+1|0;if(q>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;t=(d[o+m>>0]<<8|d[o+q>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=t;if((a[n>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;Oo(f,r)|0;i=g;return}else{Kj(f);i=g;return}}function Ak(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+16|0;g=f;h=e+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;l=e+162|0;b[l>>1]=b[k>>1]|0;m=j&16777215;j=m+1|0;n=e+36|0;if(j>>>0<(c[n>>2]|0)>>>0){o=c[e+32>>2]|0;p=(d[o+m>>0]<<8|d[o+j>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[k>>1]=p;p=e+336|0;if((a[p>>0]|0)!=0){Kj(e);i=f;return}c[h>>2]=(c[h>>2]|0)+2;m=e+152|0;c[m>>2]=(c[m>>2]|0)+2;j=b[l>>1]|0;o=b[e+160>>1]&63;if((nc[c[46024+(o<<2)>>2]&63](e,o,2045,8)|0)!=0){i=f;return}if((Jo(e,g)|0)!=0){i=f;return}o=e+372|0;c[o>>2]=(c[o>>2]|0)+8;o=a[g>>0]|0;lo(e,(o&255)-(j&65535)&255,j&255,o);o=c[h>>2]|0;if((o&1|0)!=0){Mj(e,o,0,0);i=f;return}b[l>>1]=b[k>>1]|0;l=o&16777215;o=l+1|0;if(o>>>0<(c[n>>2]|0)>>>0){n=c[e+32>>2]|0;q=(d[n+l>>0]<<8|d[n+o>>0])&65535}else{q=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=q;if((a[p>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;c[m>>2]=(c[m>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function Bk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+16|0;g=f;h=e+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;l=e+162|0;b[l>>1]=b[k>>1]|0;m=j&16777215;j=m+1|0;n=e+36|0;if(j>>>0<(c[n>>2]|0)>>>0){o=c[e+32>>2]|0;p=(d[o+m>>0]<<8|d[o+j>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[k>>1]=p;p=e+336|0;if((a[p>>0]|0)!=0){Kj(e);i=f;return}c[h>>2]=(c[h>>2]|0)+2;m=e+152|0;c[m>>2]=(c[m>>2]|0)+2;j=b[l>>1]|0;o=b[e+160>>1]&63;if((nc[c[46024+(o<<2)>>2]&63](e,o,2045,16)|0)!=0){i=f;return}if((Ko(e,g)|0)!=0){i=f;return}o=e+372|0;c[o>>2]=(c[o>>2]|0)+8;o=b[g>>1]|0;mo(e,(o&65535)-(j&65535)&65535,j,o);o=c[h>>2]|0;if((o&1|0)!=0){Mj(e,o,0,0);i=f;return}b[l>>1]=b[k>>1]|0;l=o&16777215;o=l+1|0;if(o>>>0<(c[n>>2]|0)>>>0){n=c[e+32>>2]|0;q=(d[n+l>>0]<<8|d[n+o>>0])&65535}else{q=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=q;if((a[p>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;c[m>>2]=(c[m>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function Ck(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g;j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;n=f+336|0;if((a[n>>0]|0)!=0){Kj(f);i=g;return}k=(c[j>>2]|0)+2|0;c[j>>2]=k;p=f+152|0;c[p>>2]=(c[p>>2]|0)+2;r=b[m>>1]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}b[m>>1]=q;q=k&16777215;k=q+1|0;if(k>>>0<(c[o>>2]|0)>>>0){s=c[f+32>>2]|0;b[l>>1]=d[s+q>>0]<<8|d[s+k>>0]}else{k=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0;q=(a[n>>0]|0)==0;b[l>>1]=k;if(!q){Kj(f);i=g;return}}c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;q=e[m>>1]|(r&65535)<<16;r=b[f+160>>1]&63;if((nc[c[46024+(r<<2)>>2]&63](f,r,2045,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}r=f+372|0;c[r>>2]=(c[r>>2]|0)+12;r=c[h>>2]|0;no(f,r-q|0,q,r);r=c[j>>2]|0;if((r&1|0)!=0){Mj(f,r,0,0);i=g;return}b[m>>1]=b[l>>1]|0;m=r&16777215;r=m+1|0;if(r>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;t=(d[o+m>>0]<<8|d[o+r>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=t;if((a[n>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function Dk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+16|0;h=g;if((c[f>>2]&2|0)==0){Nj(f);j=f+372|0;c[j>>2]=(c[j>>2]|0)+2;i=g;return}j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;q=f+336|0;if((a[q>>0]|0)!=0){Kj(f);i=g;return}c[j>>2]=(c[j>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;k=f+160|0;p=e[m>>1]|0;r=p>>>12;do{if((p&2048|0)==0){s=b[k>>1]&63;if((nc[c[46024+(s<<2)>>2]&63](f,s,508,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}s=r&7;t=a[h>>0]|0;if((r&8|0)==0){u=f+(s<<2)+88|0;c[u>>2]=c[u>>2]&-256|t&255;break}else{u=t&255;c[f+(s<<2)+120>>2]=(u&128|0)!=0?u|-256:u;break}}else{u=r&7;if((r&8|0)==0){v=c[f+(u<<2)+88>>2]|0}else{v=c[f+(u<<2)+120>>2]&255}a[h>>0]=v;u=b[k>>1]&63;if((nc[c[46024+(u<<2)>>2]&63](f,u,508,8)|0)!=0){i=g;return}if((Mo(f,a[h>>0]|0)|0)!=0){i=g;return}}}while(0);h=f+372|0;c[h>>2]=(c[h>>2]|0)+4;h=c[j>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}b[m>>1]=b[l>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;w=(d[o+m>>0]<<8|d[o+h>>0])&65535}else{w=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=w;if((a[q>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[n>>2]=(c[n>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function Ek(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+16|0;h=g;if((c[f>>2]&2|0)==0){Nj(f);j=f+372|0;c[j>>2]=(c[j>>2]|0)+2;i=g;return}j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;q=f+336|0;if((a[q>>0]|0)!=0){Kj(f);i=g;return}c[j>>2]=(c[j>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;k=f+160|0;p=e[m>>1]|0;r=p>>>12;do{if((p&2048|0)==0){s=b[k>>1]&63;if((nc[c[46024+(s<<2)>>2]&63](f,s,508,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}s=r&7;t=b[h>>1]|0;if((r&8|0)==0){u=f+(s<<2)+88|0;c[u>>2]=c[u>>2]&-65536|t&65535;break}else{u=t&65535;c[f+(s<<2)+120>>2]=(u&32768|0)==0?u:u|-65536;break}}else{u=r&7;if((r&8|0)==0){v=c[f+(u<<2)+88>>2]|0}else{v=c[f+(u<<2)+120>>2]&65535}b[h>>1]=v;u=b[k>>1]&63;if((nc[c[46024+(u<<2)>>2]&63](f,u,508,16)|0)!=0){i=g;return}if((No(f,b[h>>1]|0)|0)!=0){i=g;return}}}while(0);h=f+372|0;c[h>>2]=(c[h>>2]|0)+4;h=c[j>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}b[m>>1]=b[l>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;w=(d[o+m>>0]<<8|d[o+h>>0])&65535}else{w=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=w;if((a[q>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[n>>2]=(c[n>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function Fk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+16|0;h=g;if((c[f>>2]&2|0)==0){Nj(f);j=f+372|0;c[j>>2]=(c[j>>2]|0)+2;i=g;return}j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;q=f+336|0;if((a[q>>0]|0)!=0){Kj(f);i=g;return}c[j>>2]=(c[j>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;k=f+160|0;p=e[m>>1]|0;r=p>>>12;do{if((p&2048|0)==0){s=b[k>>1]&63;if((nc[c[46024+(s<<2)>>2]&63](f,s,508,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}s=r&7;t=c[h>>2]|0;if((r&8|0)==0){c[f+(s<<2)+88>>2]=t;break}else{c[f+(s<<2)+120>>2]=t;break}}else{t=r&7;if((r&8|0)==0){u=f+(t<<2)+88|0}else{u=f+(t<<2)+120|0}c[h>>2]=c[u>>2];t=b[k>>1]&63;if((nc[c[46024+(t<<2)>>2]&63](f,t,508,32)|0)!=0){i=g;return}if((Oo(f,c[h>>2]|0)|0)!=0){i=g;return}}}while(0);h=f+372|0;c[h>>2]=(c[h>>2]|0)+4;h=c[j>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}b[m>>1]=b[l>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;v=(d[o+m>>0]<<8|d[o+h>>0])&65535}else{v=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=v;if((a[q>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[n>>2]=(c[n>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function Gk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=f+160|0;k=b[j>>1]&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}k=e[j>>1]|0;j=k>>>3&56|k>>>9&7;if((nc[c[46024+(j<<2)>>2]&63](f,j,509,8)|0)!=0){i=g;return}if((Mo(f,a[h>>0]|0)|0)!=0){i=g;return}j=f+372|0;c[j>>2]=(c[j>>2]|0)+4;bo(f,15,a[h>>0]|0);h=f+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[k>>1]=n;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function Hk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=f+160|0;k=b[j>>1]&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}k=e[j>>1]|0;j=k>>>3&56|k>>>9&7;if((nc[c[46024+(j<<2)>>2]&63](f,j,509,32)|0)!=0){i=g;return}if((Oo(f,c[h>>2]|0)|0)!=0){i=g;return}j=f+372|0;c[j>>2]=(c[j>>2]|0)+4;eo(f,15,c[h>>2]|0);h=f+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[k>>1]=n;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function Ik(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=f+160|0;k=b[j>>1]&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}c[f+(((e[j>>1]|0)>>>9&7)<<2)+120>>2]=c[h>>2];h=f+372|0;c[h>>2]=(c[h>>2]|0)+4;h=f+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[k>>1]=n;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function Jk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=f+160|0;k=b[j>>1]&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=e[j>>1]|0;j=k>>>3&56|k>>>9&7;if((nc[c[46024+(j<<2)>>2]&63](f,j,509,16)|0)!=0){i=g;return}if((No(f,b[h>>1]|0)|0)!=0){i=g;return}j=f+372|0;c[j>>2]=(c[j>>2]|0)+4;co(f,15,b[h>>1]|0);h=f+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[k>>1]=n;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}



function lw(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+16|0;g=f;h=c[b>>2]|0;if((mw(b,d,e)|0)==0){j=0;i=f;return j|0}a:while(1){k=c[b>>2]|0;while(1){l=a[b+k+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}k=k+1|0}c[b>>2]=k;l=55344;m=60;n=k;while(1){if(!((a[b+n+4>>0]|0)==m<<24>>24)){o=k;p=9;break}q=n+1|0;r=l+1|0;s=a[r>>0]|0;if(s<<24>>24==0){p=8;break}else{l=r;m=s;n=q}}do{if((p|0)==8){p=0;c[b>>2]=q;t=1}else if((p|0)==9){while(1){p=0;n=a[b+o+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}o=o+1|0;p=9}c[b>>2]=o;if((a[b+o+4>>0]|0)==60){c[b>>2]=o+1;t=2;break}else{u=o}while(1){n=a[b+u+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}u=u+1|0}c[b>>2]=u;n=55352;m=62;l=u;while(1){if(!((a[b+l+4>>0]|0)==m<<24>>24)){v=u;break}w=l+1|0;k=n+1|0;s=a[k>>0]|0;if(s<<24>>24==0){p=18;break}else{n=k;m=s;l=w}}if((p|0)==18){p=0;c[b>>2]=w;t=3;break}while(1){l=a[b+v+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}v=v+1|0}c[b>>2]=v;if((a[b+v+4>>0]|0)!=62){j=1;p=30;break a}c[b>>2]=v+1;t=4}}while(0);if((mw(b,g,e)|0)==0){break}if((t|0)==1){c[d>>2]=(c[d>>2]|0)>>>0<=(c[g>>2]|0)>>>0;continue}else if((t|0)==2){c[d>>2]=(c[d>>2]|0)>>>0<(c[g>>2]|0)>>>0;continue}else if((t|0)==3){c[d>>2]=(c[d>>2]|0)>>>0>=(c[g>>2]|0)>>>0;continue}else if((t|0)==4){c[d>>2]=(c[d>>2]|0)>>>0>(c[g>>2]|0)>>>0;continue}else{continue}}if((p|0)==30){i=f;return j|0}c[b>>2]=h;j=0;i=f;return j|0}function mw(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+16|0;g=f+8|0;h=f+4|0;j=f;k=c[b>>2]|0;if((nw(b,d,e)|0)==0){l=0;i=f;return l|0}while(1){m=c[b>>2]|0;while(1){n=a[b+m+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}m=m+1|0}c[b>>2]=m;if((a[b+m+4>>0]|0)==43){o=m;p=1}else{q=m;while(1){n=a[b+q+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}q=q+1|0}c[b>>2]=q;if((a[b+q+4>>0]|0)==45){o=q;p=2}else{break}}c[b>>2]=o+1;if((nw(b,g,e)|0)==0){r=11;break}m=c[g>>2]|0;c[d>>2]=(c[d>>2]|0)+((p|0)==1?m:0-m|0)}if((r|0)==11){c[b>>2]=k;l=0;i=f;return l|0}p=q;a:while(1){q=a[b+p+4>>0]|0;if(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13){p=p+1|0;continue}c[b>>2]=p;q=55360;g=60;o=p;while(1){if(!((a[b+o+4>>0]|0)==g<<24>>24)){s=p;r=19;break}t=o+1|0;m=q+1|0;n=a[m>>0]|0;if(n<<24>>24==0){r=18;break}else{q=m;g=n;o=t}}do{if((r|0)==18){r=0;c[b>>2]=t;u=t;v=1}else if((r|0)==19){while(1){r=0;o=a[b+s+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}s=s+1|0;r=19}c[b>>2]=s;o=55368;g=62;q=s;while(1){if(!((a[b+q+4>>0]|0)==g<<24>>24)){w=s;break}x=q+1|0;n=o+1|0;m=a[n>>0]|0;if(m<<24>>24==0){r=24;break}else{o=n;g=m;q=x}}if((r|0)==24){r=0;c[b>>2]=x;u=x;v=2;break}while(1){q=a[b+w+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}w=w+1|0}c[b>>2]=w;q=55376;g=60;o=w;while(1){if(!((a[b+o+4>>0]|0)==g<<24>>24)){y=w;break}z=o+1|0;m=q+1|0;n=a[m>>0]|0;if(n<<24>>24==0){r=30;break}else{q=m;g=n;o=z}}if((r|0)==30){r=0;c[b>>2]=z;u=z;v=3;break}while(1){o=a[b+y+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}y=y+1|0}c[b>>2]=y;o=55384;g=62;q=y;do{if(!((a[b+q+4>>0]|0)==g<<24>>24)){l=1;r=54;break a}q=q+1|0;o=o+1|0;g=a[o>>0]|0}while(!(g<<24>>24==0));c[b>>2]=q;u=q;v=4}}while(0);if((nw(b,j,e)|0)==0){break}while(1){g=c[b>>2]|0;while(1){o=a[b+g+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}g=g+1|0}c[b>>2]=g;if((a[b+g+4>>0]|0)==43){A=g;B=1}else{C=g;while(1){q=a[b+C+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}C=C+1|0}c[b>>2]=C;if((a[b+C+4>>0]|0)==45){A=C;B=2}else{break}}c[b>>2]=A+1;if((nw(b,h,e)|0)==0){r=46;break a}g=c[h>>2]|0;c[j>>2]=(c[j>>2]|0)+((B|0)==1?g:0-g|0)}g=c[j>>2]&31;c[j>>2]=g;if((v|0)==1){q=c[d>>2]|0;c[d>>2]=q<<g|q>>>(32-g|0);p=C;continue}else if((v|0)==2){q=c[d>>2]|0;c[d>>2]=q>>>g|q<<32-g;p=C;continue}else if((v|0)==3){c[d>>2]=c[d>>2]<<g;p=C;continue}else if((v|0)==4){c[d>>2]=(c[d>>2]|0)>>>g;p=C;continue}else{p=C;continue}}if((r|0)==46){c[b>>2]=u}else if((r|0)==54){i=f;return l|0}c[b>>2]=k;l=0;i=f;return l|0}function nw(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+16|0;g=f;h=c[b>>2]|0;if((ow(b,d,e)|0)==0){j=0;i=f;return j|0}a:while(1){k=c[b>>2]|0;while(1){l=a[b+k+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}k=k+1|0}c[b>>2]=k;do{if((a[b+k+4>>0]|0)==42){c[b>>2]=k+1;m=1}else{l=k;while(1){n=a[b+l+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}l=l+1|0}c[b>>2]=l;if((a[b+l+4>>0]|0)==47){c[b>>2]=l+1;m=2;break}else{o=l}while(1){n=a[b+o+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}o=o+1|0}c[b>>2]=o;if((a[b+o+4>>0]|0)!=37){j=1;p=26;break a}c[b>>2]=o+1;m=3}}while(0);if((ow(b,g,e)|0)==0){break}if((m|0)==1){c[d>>2]=ca(c[g>>2]|0,c[d>>2]|0)|0;continue}k=c[g>>2]|0;l=(k|0)!=0;if((m|0)==2){if(l){c[d>>2]=((c[d>>2]|0)>>>0)/(k>>>0)|0;continue}else{c[d>>2]=-1;continue}}else{if(l){c[d>>2]=((c[d>>2]|0)>>>0)%(k>>>0)|0;continue}else{c[d>>2]=0;continue}}}if((p|0)==26){i=f;return j|0}c[b>>2]=h;j=0;i=f;return j|0}function ow(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=i;i=i+272|0;g=f;h=f+8|0;j=c[b>>2]|0;k=j;while(1){l=a[b+k+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}k=k+1|0}c[b>>2]=k;do{if((a[b+k+4>>0]|0)==33){l=k+1|0;c[b>>2]=l;m=l;n=1}else{l=k;while(1){o=a[b+l+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}l=l+1|0}c[b>>2]=l;if((a[b+l+4>>0]|0)==126){o=l+1|0;c[b>>2]=o;m=o;n=2;break}else{p=l}while(1){o=a[b+p+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}p=p+1|0}c[b>>2]=p;if((a[b+p+4>>0]|0)==43){l=p+1|0;c[b>>2]=l;m=l;n=3;break}else{q=p}while(1){l=a[b+q+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}q=q+1|0}c[b>>2]=q;if((a[b+q+4>>0]|0)==45){l=q+1|0;c[b>>2]=l;m=l;n=4}else{m=q;n=0}}}while(0);q=m;while(1){m=a[b+q+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}q=q+1|0}c[b>>2]=q;m=q;while(1){r=b+m+4|0;p=a[r>>0]|0;if(!(p<<24>>24==10|p<<24>>24==9|p<<24>>24==32|p<<24>>24==13)){break}m=m+1|0}c[b>>2]=m;p=a[r>>0]|0;if(((p<<24>>24)+ -36|0)>>>0<2){a[h>>0]=p;s=h+1|0;t=m+1|0;u=1}else{s=h;t=m;u=0}while(1){m=a[b+t+4>>0]|0;if(m<<24>>24==0){v=30;break}if(!((m+ -48<<24>>24&255)<10|(m+ -97<<24>>24&255)<26|(m+ -65<<24>>24&255)<26|m<<24>>24==95)){v=30;break}a[s>>0]=m;m=u+1|0;if(m>>>0<256){s=s+1|0;t=t+1|0;u=m}else{v=29;break}}a:do{if((v|0)==29){m=b+(c[b>>2]|0)+4|0;c[g>>2]=55184;c[g+4>>2]=m;pw(55168,g);w=c[b>>2]|0;v=59}else if((v|0)==30){a[s>>0]=0;c[b>>2]=t;if((u|0)==0){w=t;v=59}else{m=a[h>>0]|0;p=(m+ -36<<24>>24&255)<2;if(!p){c[b>>2]=q;r=q;while(1){x=b+r+4|0;k=a[x>>0]|0;if(!(k<<24>>24==10|k<<24>>24==9|k<<24>>24==32|k<<24>>24==13)){break}r=r+1|0}c[b>>2]=r;k=a[x>>0]|0;if(!(k<<24>>24==0)){l=k;o=k<<24>>24;k=0;y=r;z=0;b:while(1){do{if((l+ -48<<24>>24&255)<10){A=o+ -48|0}else{if((l+ -97<<24>>24&255)<6){A=o+ -87|0;break}if(!((l+ -65<<24>>24&255)<6)){B=k;C=y;D=z;break b}A=o+ -55|0}}while(0);if(!(A>>>0<e>>>0)){B=k;C=y;D=z;break}E=A+(ca(z,e)|0)|0;F=k+1|0;G=y+1|0;H=a[b+G+4>>0]|0;if(H<<24>>24==0){B=F;C=G;D=E;break}else{l=H;o=H<<24>>24;k=F;y=G;z=E}}if((B|0)!=0){c[b>>2]=C;c[d>>2]=D;if(!(C>>>0<t>>>0)){break}}}c[b>>2]=t}z=p?h+1|0:h;if(m<<24>>24==36){v=53}else{y=c[13780]|0;if((y|0)==0){I=m}else{if((gc[y&63](c[13782]|0,z,d)|0)==0){break}I=a[h>>0]|0}if(!(I<<24>>24==37)){v=53}}c:do{if((v|0)==53){y=c[13784]|0;if((y|0)!=0){k=c[13786]|0;o=0;while(1){l=o+1|0;if((Fz(c[k+(o<<3)>>2]|0,z)|0)==0){break}if(l>>>0<y>>>0){o=l}else{break c}}c[d>>2]=c[k+(o<<3)+4>>2];break a}}}while(0);c[b>>2]=q;w=q;v=59}}}while(0);do{if((v|0)==59){while(1){v=0;I=a[b+w+4>>0]|0;if(!(I<<24>>24==10|I<<24>>24==9|I<<24>>24==32|I<<24>>24==13)){break}w=w+1|0;v=59}c[b>>2]=w;if((a[b+w+4>>0]|0)==40){c[b>>2]=w+1;if((gw(b,d,e)|0)!=0){I=c[b>>2]|0;while(1){h=a[b+I+4>>0]|0;if(!(h<<24>>24==10|h<<24>>24==9|h<<24>>24==32|h<<24>>24==13)){break}I=I+1|0}c[b>>2]=I;if((a[b+I+4>>0]|0)==41){c[b>>2]=I+1;break}}c[b>>2]=q}else{h=w;while(1){J=b+h+4|0;t=a[J>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}h=h+1|0}c[b>>2]=h;I=a[J>>0]|0;if(!(I<<24>>24==0)){t=I;C=I<<24>>24;I=0;D=h;B=0;d:while(1){do{if((t+ -48<<24>>24&255)<10){K=C+ -48|0}else{if((t+ -97<<24>>24&255)<6){K=C+ -87|0;break}if(!((t+ -65<<24>>24&255)<6)){L=I;M=D;N=B;break d}K=C+ -55|0}}while(0);if(!(K>>>0<e>>>0)){L=I;M=D;N=B;break}o=K+(ca(B,e)|0)|0;k=I+1|0;A=D+1|0;x=a[b+A+4>>0]|0;if(x<<24>>24==0){L=k;M=A;N=o;break}else{t=x;C=x<<24>>24;I=k;D=A;B=o}}if((L|0)!=0){c[b>>2]=M;c[d>>2]=N;break}}}c[b>>2]=j;O=0;i=f;return O|0}}while(0);if((n|0)==1){c[d>>2]=(c[d>>2]|0)==0;O=1;i=f;return O|0}else if((n|0)==2){c[d>>2]=~c[d>>2];O=1;i=f;return O|0}else if((n|0)==4){c[d>>2]=0-(c[d>>2]|0);O=1;i=f;return O|0}else{O=1;i=f;return O|0}return 0}function pw(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;i=i+16|0;e=d;if((c[13852]|0)==0){c[13852]=c[q>>2]}c[e>>2]=b;nb(c[13852]|0,a|0,e|0)|0;Nb(c[13852]|0)|0;b=c[13848]|0;if((b|0)==0){i=d;return}nb(b|0,a|0,e|0)|0;Nb(c[13848]|0)|0;i=d;return}function qw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;d=Kz(a|0)|0;e=c[13852]|0;if((e|0)==0){f=c[q>>2]|0;c[13852]=f;g=f}else{g=e}$b(45,g|0)|0;Nb(c[13852]|0)|0;g=c[13848]|0;if((g|0)!=0){$b(45,g|0)|0;Nb(c[13848]|0)|0}g=c[13852]|0;if((g|0)==0){e=c[q>>2]|0;c[13852]=e;h=e}else{h=g}Ub(a|0,h|0)|0;Nb(c[13852]|0)|0;h=c[13848]|0;if((h|0)!=0){Ub(a|0,h|0)|0;Nb(c[13848]|0)|0}h=d+1|0;d=c[13852]|0;a=(d|0)==0;if(h>>>0<78){g=c[q>>2]|0;e=a;f=d;j=h;while(1){if(e){c[13852]=g;k=g}else{k=f}$b(45,k|0)|0;Nb(c[13852]|0)|0;h=c[13848]|0;if((h|0)!=0){$b(45,h|0)|0;Nb(c[13848]|0)|0}h=j+1|0;l=c[13852]|0;m=(l|0)==0;if((h|0)==78){n=l;o=m;break}else{e=m;f=l;j=h}}}else{n=d;o=a}if(o){o=c[q>>2]|0;c[13852]=o;p=o}else{p=n}$b(10,p|0)|0;Nb(c[13852]|0)|0;p=c[13848]|0;if((p|0)==0){i=b;return}$b(10,p|0)|0;Nb(c[13848]|0)|0;i=b;return}function rw(a,b){a=a|0;b=b|0;c[13850]=a;c[13852]=b;return}function sw(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;f=i;i=i+32|0;g=f;h=f+4|0;j=b[e>>1]|0;do{if(j<<16>>16<0){k=2}else{l=e+16|0;m=b[l>>1]|0;if(m<<16>>16>-1){n=l;l=m;m=1;do{o=m+ -1|0;p=e+(o<<4)|0;r=l<<16>>16;if(l<<16>>16<256){s=Qz(r|0)|0}else{s=r}r=b[p>>1]|0;t=r<<16>>16;if(r<<16>>16<256){u=Qz(t|0)|0}else{u=t}if((s|0)<(u|0)){v=b[n>>1]|0;w=12}else{if((s|0)<=(u|0)){t=b[n>>1]|0;if(t<<16>>16>(b[p>>1]|0)){v=t;w=12}}}if((w|0)==12){w=0;t=e+(m<<4)+2|0;b[h+0>>1]=b[t+0>>1]|0;b[h+2>>1]=b[t+2>>1]|0;b[h+4>>1]=b[t+4>>1]|0;b[h+6>>1]=b[t+6>>1]|0;b[h+8>>1]=b[t+8>>1]|0;b[h+10>>1]=b[t+10>>1]|0;b[h+12>>1]=b[t+12>>1]|0;c[n+0>>2]=c[p+0>>2];c[n+4>>2]=c[p+4>>2];c[n+8>>2]=c[p+8>>2];c[n+12>>2]=c[p+12>>2];a:do{if((o|0)==0){x=e}else{p=v<<16>>16;b:do{if(v<<16>>16<256){t=o;while(1){r=t+ -1|0;y=Qz(p|0)|0;z=e+(r<<4)|0;A=b[z>>1]|0;B=A<<16>>16;if(A<<16>>16<256){C=Qz(B|0)|0}else{C=B}if((y|0)<(C|0)){D=e+(t<<4)|0}else{if((y|0)>(C|0)){E=t;break b}y=b[z>>1]|0;if(v<<16>>16<y<<16>>16){E=t;break b}z=e+(t<<4)|0;if(v<<16>>16>y<<16>>16){D=z}else{x=z;break a}}z=e+(r<<4)|0;c[D+0>>2]=c[z+0>>2];c[D+4>>2]=c[z+4>>2];c[D+8>>2]=c[z+8>>2];c[D+12>>2]=c[z+12>>2];if((r|0)==0){x=e;break a}else{t=r}}}else{t=o;while(1){r=t+ -1|0;z=e+(r<<4)|0;y=b[z>>1]|0;B=y<<16>>16;if(y<<16>>16<256){F=Qz(B|0)|0}else{F=B}if((p|0)<(F|0)){G=e+(t<<4)|0}else{if((p|0)>(F|0)){E=t;break b}B=b[z>>1]|0;if(v<<16>>16<B<<16>>16){E=t;break b}z=e+(t<<4)|0;if(v<<16>>16>B<<16>>16){G=z}else{x=z;break a}}z=e+(r<<4)|0;c[G+0>>2]=c[z+0>>2];c[G+4>>2]=c[z+4>>2];c[G+8>>2]=c[z+8>>2];c[G+12>>2]=c[z+12>>2];if((r|0)==0){x=e;break a}else{t=r}}}}while(0);x=e+(E<<4)|0}}while(0);b[x>>1]=v;o=x+2|0;b[o+0>>1]=b[h+0>>1]|0;b[o+2>>1]=b[h+2>>1]|0;b[o+4>>1]=b[h+4>>1]|0;b[o+6>>1]=b[h+6>>1]|0;b[o+8>>1]=b[h+8>>1]|0;b[o+10>>1]=b[h+10>>1]|0;b[o+12>>1]=b[h+12>>1]|0}m=m+1|0;n=e+(m<<4)|0;l=b[n>>1]|0}while(l<<16>>16>-1);l=b[e>>1]|0;if(l<<16>>16>-1){H=l;I=0;J=0}else{k=2;break}}else{H=j;I=0;J=0}do{if((c[e+(I<<4)+12>>2]|0)==0){K=0}else{l=c[e+(I<<4)+4>>2]|0;if(H<<16>>16<256){L=(l|0)==0?2:4}else{L=0}if((l|0)==0){M=L}else{M=L+2+(Kz(l|0)|0)|0}l=c[e+(I<<4)+8>>2]|0;if((l|0)==0){K=M}else{K=M+1+(Kz(l|0)|0)|0}}J=K>>>0>J>>>0?K:J;I=I+1|0;H=b[e+(I<<4)>>1]|0}while(H<<16>>16>-1);k=J+2|0}}while(0);if((a|0)!=0){c[g>>2]=a;$a(55416,g|0)|0}if((d|0)!=0){Ja(d|0)|0}d=b[e>>1]|0;if(!(d<<16>>16>-1)){i=f;return}a=c[q>>2]|0;J=e;e=d;do{if(e<<16>>16<256){c[g>>2]=e<<16>>16;$a(55600,g|0)|0;d=J+4|0;if((c[d>>2]|0)==0){N=d;O=2}else{$a(55608,g|0)|0;N=d;O=4}}else{$a(55616,g|0)|0;N=J+4|0;O=0}d=c[N>>2]|0;if((d|0)==0){P=O}else{c[g>>2]=d;$a(55624,g|0)|0;P=O+2+(Kz(c[N>>2]|0)|0)|0}d=J+8|0;H=c[d>>2]|0;if((H|0)==0){Q=P}else{c[g>>2]=H;$a(55632,g|0)|0;Q=P+1+(Kz(c[d>>2]|0)|0)|0}if(Q>>>0<k>>>0){d=Q;do{$b(32,a|0)|0;d=d+1|0}while((d|0)!=(k|0))}Ja(c[J+12>>2]|0)|0;J=J+16|0;e=b[J>>1]|0}while(e<<16>>16>-1);i=f;return}function tw(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;j=i;i=i+16|0;k=j;if((d|0)==0&(f|0)==0){c[13858]=-1;l=0;i=j;return l|0}if((c[13858]|0)<0){c[13856]=0;c[13858]=0;c[13860]=1;c[13862]=0;m=0}else{m=(c[13856]|0)!=0}if(m|(h|0)==0){m=c[13860]|0;if((m|0)>=(d|0)){l=-1;i=j;return l|0}c[13858]=m;c[13860]=m+1;c[g>>2]=f+(m<<2);l=0;i=j;return l|0}m=c[13862]|0;if((m|0)==0){n=11}else{p=a[m>>0]|0;if(p<<24>>24==0){n=11}else{q=p}}a:do{if((n|0)==11){p=c[13860]|0;if((p|0)>=(d|0)){l=-1;i=j;return l|0}c[13858]=p;m=p+1|0;c[13860]=m;r=f+(p<<2)|0;s=c[r>>2]|0;c[13862]=s;do{if((a[s>>0]|0)==45){t=s+1|0;u=a[t>>0]|0;if(u<<24>>24==0){break}else if(!(u<<24>>24==45)){c[13862]=t;q=a[t>>0]|0;break a}t=s+2|0;if((a[t>>0]|0)==0){c[13856]=1;if((m|0)>=(d|0)){l=-1;i=j;return l|0}c[13858]=m;c[13860]=p+2;c[g>>2]=f+(m<<2);l=0;i=j;return l|0}u=b[h>>1]|0;b:do{if(u<<16>>16>-1){v=h;w=u;while(1){x=v+16|0;if((Fz(c[v+4>>2]|0,t)|0)==0){break}y=b[x>>1]|0;if(y<<16>>16>-1){v=x;w=y}else{break b}}if((v|0)!=0){y=(e[v+2>>1]|0)+m|0;if((y|0)>(d|0)){x=c[o>>2]|0;c[k>>2]=c[f>>2];c[k+4>>2]=s;hb(x|0,55488,k|0)|0;l=-3;i=j;return l|0}else{c[g>>2]=f+(m<<2);c[13860]=y;c[13862]=0;l=w<<16>>16;i=j;return l|0}}}}while(0);t=c[o>>2]|0;c[k>>2]=c[f>>2];c[k+4>>2]=s;hb(t|0,55456,k|0)|0;l=-2;i=j;return l|0}}while(0);c[g>>2]=r;c[13862]=0;l=0;i=j;return l|0}}while(0);n=q<<24>>24;q=b[h>>1]|0;c:do{if(q<<16>>16>-1){s=h;m=q;while(1){p=s+16|0;if((m<<16>>16|0)==(n|0)){break}m=b[p>>1]|0;if(!(m<<16>>16>-1)){break c}else{s=p}}if((s|0)!=0){m=c[13860]|0;r=(e[s+2>>1]|0)+m|0;if((r|0)>(d|0)){p=c[o>>2]|0;c[k>>2]=c[f>>2];c[k+4>>2]=n;hb(p|0,55560,k|0)|0;l=-3;i=j;return l|0}else{c[g>>2]=f+(m<<2);c[13860]=r;c[13862]=(c[13862]|0)+1;l=n;i=j;return l|0}}}}while(0);g=c[o>>2]|0;c[k>>2]=c[f>>2];c[k+4>>2]=n;hb(g|0,55528,k|0)|0;l=-2;i=j;return l|0}function uw(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+16|0;f=e;g=0;while(1){h=a[c+g>>0]|0;if(h<<24>>24==0){break}else if(h<<24>>24==58){j=3;break}a[f+g>>0]=h;k=g+1|0;if(k>>>0<16){g=k}else{l=1;j=12;break}}if((j|0)==3){a[f+g>>0]=0}else if((j|0)==12){i=e;return l|0}if(g>>>0>15|(g|0)==0|h<<24>>24==0){l=1;i=e;return l|0}h=Hb(f|0,0,0)|0;f=dx(c+(g+1)|0)|0;g=ar(f,0,0,0)|0;zz(f);if((g|0)==0){l=1;i=e;return l|0}Rq(g,h);if((d|0)!=0){d=gr(b,h)|0;if((d|0)!=0){fr(b,d)|0;Qq(d)}}if((er(b,g)|0)==0){l=0;i=e;return l|0}Qq(g);l=1;i=e;return l|0}function vw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+16|0;e=d;f=Kx(a,0,55640)|0;if((f|0)==0){g=b;i=d;return g|0}else{h=b;j=f}while(1){k=gy(j)|0;if((k|0)==0){l=3;break}f=Cr(h,k)|0;if((f|0)==0){b=uy(h,k)|0;if((b|0)==0){l=6;break}else{m=b}}else{m=f}Vq(m,0);c[e>>2]=Zq(m)|0;c[e+4>>2]=k;Nw(2,55648,55696,e);f=Kx(a,j,55640)|0;if((f|0)==0){g=m;l=8;break}else{h=m;j=f}}if((l|0)==3){Qq(h);g=0;i=d;return g|0}else if((l|0)==6){c[e>>2]=Zq(h)|0;c[e+4>>2]=k;Nw(0,55648,55656,e);Qq(h);g=0;i=d;return g|0}else if((l|0)==8){i=d;return g|0}return 0}function ww(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;d=i;i=i+112|0;e=d;f=d+60|0;g=d+64|0;h=d+32|0;j=d+44|0;k=d+36|0;l=d+40|0;m=d+56|0;n=d+52|0;o=d+48|0;p=d+68|0;q=d+72|0;r=d+76|0;s=d+80|0;t=d+84|0;u=d+88|0;v=d+92|0;w=d+96|0;Px(a,55728,o,0)|0;Sx(a,55736,w,55744)|0;Ox(a,55752,t,0)|0;Ox(a,55760,p,0)|0;Ox(a,55768,q,0)|0;Ox(a,55776,r,0)|0;do{if((Ox(a,55784,s,0)|0)!=0){if((Ox(a,55792,s,0)|0)==0){c[s>>2]=c[s>>2]&-512;break}if((Ox(a,55800,s,0)|0)==0){c[s>>2]=c[s>>2]<<1;break}if((Ox(a,55808,s,0)|0)==0){c[s>>2]=c[s>>2]<<11;break}if((Ox(a,55816,s,0)|0)==0){c[s>>2]=c[s>>2]<<21;break}else{c[s>>2]=0;break}}}while(0);Rx(a,55824,u,0)|0;Rx(a,55840,v,0)|0;x=0;y=0;a:while(1){z=y;do{z=Kx(a,z,55856)|0;if((z|0)==0){A=55;break a}B=gy(z)|0}while((B|0)==0);zz(x);C=dx(B)|0;if((C|0)==0){x=0;y=z;continue}D=Ib(C|0,55864)|0;if((D|0)==0){x=C;y=z;continue}zb(D|0)|0;D=c[w>>2]|0;b:do{if((Fz(D,55872)|0)==0){E=Fy(C,c[s>>2]|0,c[p>>2]|0,c[q>>2]|0,c[r>>2]|0,c[u>>2]|0)|0}else{if((Fz(D,55880)|0)==0){E=Jr(C,c[t>>2]|0,0,c[u>>2]|0)|0;break}if((Fz(D,55888)|0)==0){E=nr(C,c[u>>2]|0)|0;break}if((Fz(D,55896)|0)==0){E=vr(C,c[u>>2]|0)|0;break}if((Fz(D,55904)|0)==0){E=Br(C,c[u>>2]|0)|0;break}if((Fz(D,55912)|0)==0){F=c[p>>2]|0;G=c[q>>2]|0;H=c[r>>2]|0;I=c[u>>2]|0;c[j>>2]=I;J=By(F,G,H,I)|0;if((J|0)==0){x=C;y=z;continue a}else{K=0}while(1){I=Jx(a,K,55912)|0;if((I|0)==0){E=J;break b}Ox(I,55752,k,0)|0;Ox(I,56264,l,0)|0;Ox(I,56280,m,0)|0;Sx(I,55856,n,0)|0;Rx(I,55824,j,0)|0;H=c[n>>2]|0;if((H|0)==0){A=31;break}G=dx(H)|0;H=(Ay(J,G,c[k>>2]|0,0,c[l>>2]|0,c[m>>2]|0,c[j>>2]|0)|0)==0;zz(G);if(H){K=I}else{A=33;break}}if((A|0)==31){A=0;Qq(J);x=C;y=z;continue a}else if((A|0)==33){A=0;Qq(J);x=C;y=z;continue a}}if((Fz(D,55928)|0)==0){E=Dq(C,1,c[u>>2]|0)|0;break}if((Fz(D,55936)|0)==0){E=Dq(C,2,c[u>>2]|0)|0;break}if((Fz(D,55944)|0)==0){E=Dq(C,3,c[u>>2]|0)|0;break}if((Fz(D,55952)|0)==0){E=Dq(C,4,c[u>>2]|0)|0;break}if((Fz(D,55968)|0)==0){E=Dq(C,4,c[u>>2]|0)|0;break}if((Fz(D,55976)|0)==0){E=Dq(C,6,c[u>>2]|0)|0;break}if((Fz(D,55984)|0)==0){E=Dq(C,0,c[u>>2]|0)|0;break}if((Fz(D,56e3)|0)==0){E=Dq(C,11,c[u>>2]|0)|0;break}if((Fz(D,56008)|0)==0){E=Dq(C,16,c[u>>2]|0)|0;break}if((Fz(D,55744)|0)!=0){x=C;y=z;continue a}E=ar(C,c[t>>2]|0,0,c[u>>2]|0)|0}}while(0);if((E|0)==0){x=C;y=z}else{break}}if((A|0)==55){c[b>>2]=0;zz(x);if((c[v>>2]|0)!=0){L=0;i=d;return L|0}c[e>>2]=c[o>>2];Lw(0,56024,e);L=1;i=d;return L|0}Rq(E,c[o>>2]|0);if((c[p>>2]|0)==0){if((c[q>>2]|0)==0){if((c[r>>2]|0)!=0){A=60}}else{A=60}}else{A=60}if((A|0)==60){x=_q(E)|0;Xq(E,x,c[p>>2]|0,c[q>>2]|0,c[r>>2]|0)|0}r=c[w>>2]|0;w=c[E+28>>2]|0;q=E+32|0;p=c[q>>2]|0;x=E+36|0;y=c[x>>2]|0;t=E+40|0;K=c[t>>2]|0;j=(c[u>>2]|0)!=0?56120:56128;c[e>>2]=c[o>>2];c[e+4>>2]=r;c[e+8>>2]=w;c[e+12>>2]=p;c[e+16>>2]=y;c[e+20>>2]=K;c[e+24>>2]=j;c[e+28>>2]=C;Nw(2,55648,56064,e);zz(C);Ox(a,56184,f,0)|0;Ox(a,56200,g,0)|0;Ox(a,56216,h,0)|0;C=c[f>>2]|0;if((C|0)==0){M=c[q>>2]|0}else{M=C}c[f>>2]=M;C=c[g>>2]|0;if((C|0)==0){N=c[x>>2]|0}else{N=C}c[g>>2]=N;C=c[h>>2]|0;if((C|0)==0){O=c[t>>2]|0}else{O=C}c[h>>2]=O;Yq(E,M,N,O);if((c[q>>2]|0)==(c[f>>2]|0)){if((c[x>>2]|0)==(c[g>>2]|0)){if((c[t>>2]|0)!=(c[h>>2]|0)){A=70}}else{A=70}}else{A=70}if((A|0)==70){A=Zq(E)|0;h=c[E+44>>2]|0;t=c[E+48>>2]|0;g=c[E+52>>2]|0;c[e>>2]=A;c[e+4>>2]=h;c[e+8>>2]=t;c[e+12>>2]=g;Nw(2,55648,56232,e)}g=vw(a,E)|0;if((g|0)!=0){c[b>>2]=g;L=0;i=d;return L|0}c[b>>2]=0;if((c[v>>2]|0)!=0){L=0;i=d;return L|0}c[e>>2]=c[o>>2];Lw(0,56136,e);L=1;i=d;return L|0}function xw(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;i=i+16|0;d=b+4|0;e=b;f=dr()|0;g=Jx(a,0,56176)|0;if((g|0)==0){i=b;return f|0}else{h=g}do{Px(h,55728,e,0)|0;if((gr(f,c[e>>2]|0)|0)==0){g=(ww(h,d)|0)==0;j=c[d>>2]|0;if(g&(j|0)!=0){er(f,j)|0}}h=Jx(a,h,56176)|0}while((h|0)!=0);i=b;return f|0}function yw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+32|0;f=e;g=e+24|0;h=e+20|0;j=e+16|0;k=e+12|0;l=(d|0)!=0;if(l){c[d>>2]=0}m=Jx(b,0,56296)|0;if((m|0)==0){n=0;i=e;return n|0}a:do{if(l){o=m;while(1){Sx(o,56304,g,0)|0;if((Ox(o,56312,j,0)|0)!=0){Ox(o,56320,j,0)|0}do{if((Ox(o,56328,k,0)|0)==0){c[k>>2]=c[k>>2]<<20}else{if((Ox(o,56336,k,0)|0)==0){c[k>>2]=c[k>>2]<<10;break}else{Ox(o,56344,k,65536)|0;break}}}while(0);Px(o,56352,h,0)|0;p=dx(c[g>>2]|0)|0;q=c[k>>2]|0;r=(p|0)==0;c[f>>2]=c[j>>2];c[f+4>>2]=q;c[f+8>>2]=r?56400:p;Nw(2,56360,56368,f);q=Np(c[j>>2]|0,c[k>>2]|0,1)|0;if((q|0)==0){s=p;t=26;break a}Wp(q,c[h>>2]&255);Yp(q,0);hq(a,q,1);if((c[j>>2]|0)==0){c[d>>2]=q}if(!r){if((Dw(q,p)|0)!=0){u=p;t=29;break a}}zz(p);p=Jx(b,o,56296)|0;if((p|0)==0){n=0;break}else{o=p}}i=e;return n|0}else{o=m;while(1){Sx(o,56304,g,0)|0;if((Ox(o,56312,j,0)|0)!=0){Ox(o,56320,j,0)|0}do{if((Ox(o,56328,k,0)|0)==0){c[k>>2]=c[k>>2]<<20}else{if((Ox(o,56336,k,0)|0)==0){c[k>>2]=c[k>>2]<<10;break}else{Ox(o,56344,k,65536)|0;break}}}while(0);Px(o,56352,h,0)|0;p=dx(c[g>>2]|0)|0;q=c[k>>2]|0;r=(p|0)==0;c[f>>2]=c[j>>2];c[f+4>>2]=q;c[f+8>>2]=r?56400:p;Nw(2,56360,56368,f);q=Np(c[j>>2]|0,c[k>>2]|0,1)|0;if((q|0)==0){s=p;t=26;break a}Wp(q,c[h>>2]&255);Yp(q,0);hq(a,q,1);if(!r){if((Dw(q,p)|0)!=0){u=p;t=29;break a}}zz(p);p=Jx(b,o,56296)|0;if((p|0)==0){n=0;break}else{o=p}}i=e;return n|0}}while(0);if((t|0)==26){Lw(0,56408,f);zz(s);n=1;i=e;return n|0}else if((t|0)==29){c[f>>2]=u;Lw(0,56448,f);zz(u);n=1;i=e;return n|0}return 0}function zw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;i=i+32|0;e=d;f=d+24|0;g=d+20|0;h=d+16|0;j=d+12|0;k=Jx(b,0,56480)|0;if((k|0)==0){l=0;i=d;return l|0}else{m=k}while(1){Sx(m,56304,f,0)|0;if((Ox(m,56312,h,0)|0)!=0){Ox(m,56320,h,0)|0}do{if((Ox(m,56328,j,0)|0)==0){c[j>>2]=c[j>>2]<<20}else{if((Ox(m,56336,j,0)|0)==0){c[j>>2]=c[j>>2]<<10;break}else{Ox(m,56344,j,65536)|0;break}}}while(0);Px(m,56352,g,0)|0;n=dx(c[f>>2]|0)|0;k=c[j>>2]|0;o=(n|0)!=0;c[e>>2]=c[h>>2];c[e+4>>2]=k;c[e+8>>2]=o?n:56400;Nw(2,56488,56368,e);k=Np(c[h>>2]|0,c[j>>2]|0,1)|0;if((k|0)==0){p=10;break}Wp(k,c[g>>2]&255);Yp(k,1);hq(a,k,1);if(o){if((Dw(k,n)|0)!=0){p=13;break}}zz(n);k=Jx(b,m,56480)|0;if((k|0)==0){l=0;p=15;break}else{m=k}}if((p|0)==10){Lw(0,56408,e);zz(n);l=1;i=d;return l|0}else if((p|0)==13){c[e>>2]=n;Lw(0,56496,e);zz(n);l=1;i=d;return l|0}else if((p|0)==15){i=d;return l|0}return 0}function Aw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+96|0;e=d;f=d+64|0;g=d+68|0;h=d+72|0;j=d+48|0;k=d+44|0;l=d+56|0;m=d+80|0;n=d+88|0;o=d+92|0;p=Jx(a,0,56528)|0;Sx(p,56544,n,56552)|0;q=(p|0)==0;a:do{if((b|0)==0){b:do{if(!q){r=p;while(1){s=c[n>>2]|0;if((Fz(s,56552)|0)==0){t=r;break a}if((Fz(s,56840)|0)==0){break}s=Jx(a,r,56528)|0;Sx(s,56544,n,56552)|0;if((s|0)==0){break b}else{r=s}}if((r|0)!=0){t=r;break a}}}while(0);c[n>>2]=56552;t=0}else{c:do{if(q){u=0}else{s=p;while(1){if((Fz(b,c[n>>2]|0)|0)==0){u=s;break c}v=Jx(a,s,56528)|0;Sx(v,56544,n,56552)|0;if((v|0)==0){u=0;break}else{s=v}}}}while(0);c[n>>2]=b;t=u}}while(0);Sx(t,56560,o,0)|0;Px(t,56568,j,4)|0;Px(t,56584,k,3)|0;Px(t,56600,g,512)|0;Px(t,56608,h,384)|0;Px(t,56616,f,1)|0;Qx(t,56624,l,1)|0;u=l+4|0;Qx(t,56640,u,1)|0;Qx(t,56656,m,1)|0;b=m+4|0;Qx(t,56672,b,1)|0;a=c[o>>2]|0;p=c[j>>2]|0;q=c[k>>2]|0;s=c[g>>2]|0;r=c[h>>2]|0;v=c[f>>2]|0;w=c[l>>2]|0;x=c[u>>2]|0;y=c[m>>2]|0;z=c[b>>2]|0;c[e>>2]=c[n>>2];c[e+4>>2]=(a|0)!=0?a:56776;c[e+8>>2]=p;c[e+12>>2]=q;c[e+16>>2]=s;c[e+20>>2]=r;c[e+24>>2]=v;c[e+28>>2]=w;c[e+32>>2]=x;c[e+36>>2]=y;c[e+40>>2]=z;Nw(2,56688,56696,e);z=c[n>>2]|0;do{if((Fz(z,56784)|0)==0){Lw(0,56792,e)}else{if((Fz(z,56840)|0)==0){n=nz(t)|0;if((n|0)==0){Lw(0,56848,e);break}else{A=n}}else{if((Fz(z,56552)|0)!=0){c[e>>2]=z;Lw(0,56928,e);break}n=My(t)|0;if((n|0)==0){Lw(0,56888,e);break}else{A=n}}n=c[o>>2]|0;if((n|0)!=0){_y(A,n)|0}cz(A,c[f>>2]|0);bz(A,c[g>>2]|0,c[h>>2]|0);dz(A,c[j>>2]|0,c[k>>2]|0);$y(A,c[l>>2]|0,c[u>>2]|0,c[m>>2]|0,c[b>>2]|0);B=A;i=d;return B|0}}while(0);Lw(0,56968,e);B=0;i=d;return B|0}function Bw(c,f,g){c=c|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;h=i;i=i+272|0;j=h;k=j+1|0;l=j+2|0;m=j+260|0;n=j+4|0;o=1;p=0;a:while(1){b:while(1){q=_b(c|0)|0;if((q|0)==10|(q|0)==13){continue}else if((q|0)==-1){r=0;s=66;break a}else if((q|0)!=58){while(1){q=_b(c|0)|0;if((q|0)==10|(q|0)==13|(q|0)==-1){continue b}}}a[k>>0]=0;q=0;t=0;while(1){u=_b(c|0)|0;do{if((u+ -48|0)>>>0<10){v=((q&255)<<4|u+208)&255;a[k>>0]=v;w=v}else{if((u+ -65|0)>>>0<6){v=((q&255)<<4|u+201)&255;a[k>>0]=v;w=v;break}if(!((u+ -97|0)>>>0<6)){r=0;s=66;break a}v=((q&255)<<4|u+169)&255;a[k>>0]=v;w=v}}while(0);u=t+1|0;if(u>>>0<2){q=w;t=u}else{x=0;y=0;break}}while(1){t=_b(c|0)|0;do{if((t+ -48|0)>>>0<10){z=t+208|(x&255)<<4}else{if((t+ -65|0)>>>0<6){z=t+201|(x&255)<<4;break}if(!((t+ -97|0)>>>0<6)){r=0;s=66;break a}z=t+169|(x&255)<<4}}while(0);t=y+1|0;if(t>>>0<2){x=z&255;y=t}else{A=0;B=0;break}}while(1){t=_b(c|0)|0;do{if((t+ -48|0)>>>0<10){C=t+208|(A&255)<<4}else{if((t+ -65|0)>>>0<6){C=t+201|(A&255)<<4;break}if(!((t+ -97|0)>>>0<6)){r=0;s=66;break a}C=t+169|(A&255)<<4}}while(0);B=B+1|0;if(!(B>>>0<2)){break}else{A=C&255}}b[l>>1]=C&255|z<<8;a[j>>0]=0;t=w;q=w;u=0;v=0;while(1){D=_b(c|0)|0;do{if((D+ -48|0)>>>0<10){E=u<<4&4080|D+208;a[j>>0]=E;F=q;G=t;H=E}else{if((D+ -65|0)>>>0<6){E=b[j>>1]|0;I=(E&65535)<<4|D+201;a[j>>0]=I;J=(E&65535)>>>8&255;F=J;G=J;H=I;break}if(!((D+ -97|0)>>>0<6)){r=0;s=66;break a}I=b[j>>1]|0;J=(I&65535)<<4|D+169;a[j>>0]=J;E=(I&65535)>>>8&255;F=E;G=E;H=J}}while(0);v=v+1|0;if(!(v>>>0<2)){break}else{t=G;q=F;u=H}}if(F<<24>>24==0){K=G}else{u=0;while(1){q=j+u+4|0;a[q>>0]=0;t=0;v=0;while(1){D=_b(c|0)|0;do{if((D+ -48|0)>>>0<10){J=((t&255)<<4|D+208)&255;a[q>>0]=J;L=J}else{if((D+ -65|0)>>>0<6){J=((t&255)<<4|D+201)&255;a[q>>0]=J;L=J;break}if(!((D+ -97|0)>>>0<6)){r=0;s=66;break a}J=((t&255)<<4|D+169)&255;a[q>>0]=J;L=J}}while(0);v=v+1|0;if(!(v>>>0<2)){break}else{t=L}}t=u+1|0;v=a[k>>0]|0;if(t>>>0<(v&255)>>>0){u=t}else{K=v;break}}}a[m>>0]=0;u=0;v=0;while(1){t=_b(c|0)|0;do{if((t+ -48|0)>>>0<10){q=((u&255)<<4|t+208)&255;a[m>>0]=q;M=q}else{if((t+ -65|0)>>>0<6){q=((u&255)<<4|t+201)&255;a[m>>0]=q;M=q;break}if(!((t+ -97|0)>>>0<6)){r=0;s=66;break a}q=((u&255)<<4|t+169)&255;a[m>>0]=q;M=q}}while(0);v=v+1|0;if(!(v>>>0<2)){break}else{u=M}}do{u=_b(c|0)|0}while(!((u|0)==10|(u|0)==13|(u|0)==-1));u=e[l>>1]|0;v=K&255;t=b[j>>1]|0;q=t&255;D=u+v+(u>>>8)+(t&255)|0;J=(t&65535)>>>8;N=J&255;if(K<<24>>24==0){O=D}else{t=D;D=0;while(1){E=(d[j+D+4>>0]|0)+(t&255)|0;I=D+1|0;if((I|0)==(v|0)){O=E;break}else{t=E;D=I}}}if(!(M<<24>>24==((O^255)+1&255)<<24>>24)){r=1;s=66;break a}if(q<<24>>24==4){s=61;break}else if(q<<24>>24==2){s=63;break}else if(q<<24>>24==1){r=0;s=66;break a}else if(!(q<<24>>24==0)){continue}if(N<<24>>24==0){continue}D=J&65535;if(o){t=0;while(1){lc[g&31](f,t+p+u|0,a[j+t+4>>0]|0);v=t+1|0;if(v>>>0<D>>>0){t=v}else{continue b}}}else{t=0;while(1){lc[g&31](f,(u+t&65535)+p|0,a[j+t+4>>0]|0);J=t+1|0;if(J>>>0<D>>>0){t=J}else{continue b}}}}if((s|0)==61){s=0;if(!(N<<24>>24==2)){r=1;s=66;break}t=b[n>>1]|0;o=1;p=((t&65535)<<8&65280|(t&65535)>>>8&65535)<<16;continue}else if((s|0)==63){s=0;if(!(N<<24>>24==2)){r=1;s=66;break}t=b[n>>1]|0;o=0;p=((t&65535)<<8&65280|(t&65535)>>>8&65535)<<4;continue}}if((s|0)==66){i=h;return r|0}return 0}function Cw(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;h=i;i=i+272|0;j=h;k=j+8|0;l=j+1|0;m=j+4|0;n=j+268|0;a:while(1){o=_b(e|0)|0;b:do{if((o|0)==10|(o|0)==13){continue a}else if((o|0)==83){p=_b(e|0)|0;do{if((p+ -48|0)>>>0<10){q=p+208|0}else{if((p+ -65|0)>>>0<6){q=p+201|0;break}if(!((p+ -97|0)>>>0<6)){break b}q=p+169|0}}while(0);a[j>>0]=q;p=c[56992+((q&255)<<2)>>2]|0;c[k>>2]=p;r=_b(e|0)|0;do{if((r+ -48|0)>>>0<10){s=r+208|0}else{if((r+ -65|0)>>>0<6){s=r+201|0;break}if(!((r+ -97|0)>>>0<6)){t=0;u=72;break a}s=r+169|0}}while(0);r=_b(e|0)|0;do{if((r+ -48|0)>>>0<10){v=r+208|0}else{if((r+ -65|0)>>>0<6){v=r+201|0;break}if(!((r+ -97|0)>>>0<6)){t=0;u=72;break a}v=r+169|0}}while(0);r=v&15|s<<4;a[l>>0]=r;w=p+1|0;if((r&255)>>>0<w>>>0){t=0;u=72;break a}x=r-w&255;a[l>>0]=x;c[m>>2]=0;w=0;r=0;do{y=_b(e|0)|0;do{if((y+ -48|0)>>>0<10){z=y+208|0}else{if((y+ -65|0)>>>0<6){z=y+201|0;break}if(!((y+ -97|0)>>>0<6)){t=0;u=72;break a}z=y+169|0}}while(0);y=_b(e|0)|0;do{if((y+ -48|0)>>>0<10){A=y+208|0}else{if((y+ -65|0)>>>0<6){A=y+201|0;break}if(!((y+ -97|0)>>>0<6)){t=0;u=72;break a}A=y+169|0}}while(0);w=A&15|z<<4&240|w<<8;c[m>>2]=w;r=r+1|0}while(r>>>0<p>>>0);if(x<<24>>24==0){B=0}else{p=0;while(1){r=j+p+12|0;w=_b(e|0)|0;do{if((w+ -48|0)>>>0<10){C=w+208|0}else{if((w+ -65|0)>>>0<6){C=w+201|0;break}if(!((w+ -97|0)>>>0<6)){t=0;u=72;break a}C=w+169|0}}while(0);w=_b(e|0)|0;do{if((w+ -48|0)>>>0<10){D=w+208|0}else{if((w+ -65|0)>>>0<6){D=w+201|0;break}if(!((w+ -97|0)>>>0<6)){t=0;u=72;break a}D=w+169|0}}while(0);a[r>>0]=D&15|C<<4;w=p+1|0;y=a[l>>0]|0;if(w>>>0<(y&255)>>>0){p=w}else{B=y;break}}}p=_b(e|0)|0;do{if((p+ -48|0)>>>0<10){E=p+208|0}else{if((p+ -65|0)>>>0<6){E=p+201|0;break}if(!((p+ -97|0)>>>0<6)){t=0;u=72;break a}E=p+169|0}}while(0);p=_b(e|0)|0;do{if((p+ -48|0)>>>0<10){F=p+208|0}else{if((p+ -65|0)>>>0<6){F=p+201|0;break}if(!((p+ -97|0)>>>0<6)){t=0;u=72;break a}F=p+169|0}}while(0);p=(F&15|E<<4)&255;a[n>>0]=p;do{x=_b(e|0)|0}while(!((x|0)==10|(x|0)==13|(x|0)==-1));x=B&255;y=c[m>>2]|0;w=(c[k>>2]|0)+1+x+y+(y>>>8)+(y>>>16)+(y>>>24)|0;if(B<<24>>24==0){G=w}else{H=w;w=0;while(1){I=(d[j+w+12>>0]|0)+(H&255)|0;J=w+1|0;if((J|0)==(x|0)){G=I;break}else{H=I;w=J}}}if(!(p<<24>>24==((G^255)&255)<<24>>24)){t=1;u=72;break a}w=b[j>>1]|0;H=(w&65535)>>>8;switch((w&255)<<24>>24){case 3:case 2:case 1:{break};case 7:case 8:case 9:{t=0;u=72;break a;break};default:{continue a}}if(H<<16>>16==0){continue a}w=H&65535;H=0;while(1){lc[g&31](f,y+H|0,a[j+H+12>>0]|0);x=H+1|0;if(x>>>0<w>>>0){H=x}else{continue a}}}else if((o|0)==-1){t=0;u=72;break a}}while(0);while(1){o=_b(e|0)|0;if((o|0)==10|(o|0)==13|(o|0)==-1){continue a}}}if((u|0)==72){i=h;return t|0}return 0}function Dw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=Ib(b|0,57056)|0;if((e|0)==0){f=1;i=d;return f|0}ta(c[a+44>>2]|0,1,c[a+40>>2]|0,e|0)|0;zb(e|0)|0;f=0;i=d;return f|0}function Ew(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+16|0;f=e;c[f>>2]=b;c[f+4>>2]=d;Nw(2,57064,57120,f);f=Ib(b|0,57056)|0;if((f|0)==0){g=1;i=e;return g|0}b=_b(f|0)|0;if(!((b|0)==-1)){h=d;d=b;while(1){nq(a,h,d&255);d=_b(f|0)|0;if((d|0)==-1){break}else{h=h+1|0}}}zb(f|0)|0;g=0;i=e;return g|0}function Fw(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;if((d|0)==0){j=1;i=g;return j|0}if((e|0)==0){k=d;l=0;m=4}else{if((Fz(e,57160)|0)==0){k=d;l=0;m=4}else{n=e}}if((m|0)==4){while(1){m=0;e=a[d+l>>0]|0;if(e<<24>>24==0){break}else if(e<<24>>24==46){e=l+1|0;k=d+e|0;l=e;m=4;continue}else{l=l+1|0;m=4;continue}}if((Ez(k,57168)|0)==0){n=57168}else{if((Ez(k,57176)|0)==0){n=57168}else{if((Ez(k,57184)|0)==0){n=57184}else{if((Ez(k,57192)|0)==0){n=57200}else{j=1;i=g;return j|0}}}}}if((Fz(n,57200)|0)==0){j=Ew(b,d,f)|0;i=g;return j|0}if((Fz(n,57168)|0)==0){c[h>>2]=d;Nw(2,57064,57072,h);f=Ib(d|0,57056)|0;if((f|0)==0){j=1;i=g;return j|0}k=Bw(f,b,20)|0;zb(f|0)|0;j=k;i=g;return j|0}if((Fz(n,57184)|0)!=0){j=1;i=g;return j|0}c[h>>2]=d;Nw(2,57064,57096,h);h=Ib(d|0,57056)|0;if((h|0)==0){j=1;i=g;return j|0}d=Cw(h,b,20)|0;zb(h|0)|0;j=d;i=g;return j|0}function Gw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+16|0;e=d;f=d+12|0;g=d+8|0;h=d+4|0;j=0;k=0;a:while(1){l=k;do{l=Jx(b,l,57208)|0;if((l|0)==0){break a}Sx(l,57216,f,57200)|0;Sx(l,57224,g,0)|0;if((Ox(l,57232,h,0)|0)!=0){Ox(l,57240,h,0)|0}m=c[g>>2]|0}while((m|0)==0);n=dx(m)|0;if((Fw(a,n,c[f>>2]|0,c[h>>2]|0)|0)==0){o=j}else{c[e>>2]=n;Lw(0,57248,e);o=1}zz(n);j=o;k=l}i=d;return j|0}function Hw(){c[14320]=0;return}function Iw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=c[14320]|0;if(f>>>0>15){g=1;i=e;return g|0}c[57288+(f*12|0)>>2]=a;c[57292+(f*12|0)>>2]=(b|0)!=0;c[57296+(f*12|0)>>2]=d;c[14320]=f+1;g=0;i=e;return g|0}function Jw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=Ib(a|0,57480)|0;if((e|0)==0){f=1;i=d;return f|0}a=c[14320]|0;if(a>>>0>15){zb(e|0)|0;f=1;i=d;return f|0}else{c[57288+(a*12|0)>>2]=e;c[57292+(a*12|0)>>2]=1;c[57296+(a*12|0)>>2]=b;c[14320]=a+1;f=0;i=d;return f|0}return 0}function Kw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=c[14320]|0;if((e|0)==0){i=d;return}else{f=0}while(1){g=f+1|0;if((c[57288+(f*12|0)>>2]|0)==(a|0)){break}if(g>>>0<e>>>0){f=g}else{h=5;break}}if((h|0)==5){i=d;return}c[57296+(f*12|0)>>2]=b;i=d;return}function Lw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+16|0;f=e;g=c[14320]|0;if((g|0)==0){i=e;return}h=g;g=0;while(1){if((c[57296+(g*12|0)>>2]|0)>>>0<a>>>0){j=h}else{c[f>>2]=d;k=57288+(g*12|0)|0;nb(c[k>>2]|0,b|0,f|0)|0;Nb(c[k>>2]|0)|0;j=c[14320]|0}g=g+1|0;if(!(g>>>0<j>>>0)){break}else{h=j}}i=e;return}function Mw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=c[14320]|0;if((f|0)==0){i=e;return}else{g=f;h=0}while(1){if((c[57296+(h*12|0)>>2]|0)>>>0<a>>>0){j=g}else{f=57288+(h*12|0)|0;nb(c[f>>2]|0,b|0,d|0)|0;Nb(c[f>>2]|0)|0;j=c[14320]|0}h=h+1|0;if(!(h>>>0<j>>>0)){break}else{g=j}}i=e;return}function Nw(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+32|0;g=f;h=f+8|0;j=(b|0)==0?57488:b;b=c[14320]|0;if((b|0)==0){i=f;return}k=b;b=0;while(1){if((c[57296+(b*12|0)>>2]|0)>>>0<a>>>0){l=k}else{c[h>>2]=e;m=57288+(b*12|0)|0;n=c[m>>2]|0;c[g>>2]=j;hb(n|0,57496,g|0)|0;nb(c[m>>2]|0,d|0,h|0)|0;Nb(c[m>>2]|0)|0;l=c[14320]|0}b=b+1|0;if(!(b>>>0<l>>>0)){break}else{k=l}}i=f;return}function Ow(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;c[d+40>>2]=0;b[d+44>>1]=0;f=d+48|0;c[f>>2]=0;g=d+52|0;c[g>>2]=0;a[d+56>>0]=0;c[d+60>>2]=0;h=d+0|0;j=h+36|0;do{c[h>>2]=0;h=h+4|0}while((h|0)<(j|0));b[d+36>>1]=0;d=Az(0,120)|0;if((d|0)==0){i=e;return}c[g>>2]=d;g=10;h=57504;j=c[f>>2]|0;while(1){a:do{if((j|0)==0){k=0}else{l=j;while(1){m=l+ -1|0;n=d+(m*12|0)|0;if((Fz(c[h>>2]|0,c[n>>2]|0)|0)>-1){k=l;break a}o=d+(l*12|0)|0;c[o+0>>2]=c[n+0>>2];c[o+4>>2]=c[n+4>>2];c[o+8>>2]=c[n+8>>2];if((m|0)==0){k=0;break}else{l=m}}}}while(0);l=d+(k*12|0)|0;c[l+0>>2]=c[h+0>>2];c[l+4>>2]=c[h+4>>2];c[l+8>>2]=c[h+8>>2];j=j+1|0;c[f>>2]=j;g=g+ -1|0;if((g|0)==0){break}else{h=h+12|0}}i=e;return}function Pw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=a+52|0;g=a+48|0;a=Az(c[f>>2]|0,((c[g>>2]|0)+d|0)*12|0)|0;if((a|0)==0){h=1;i=e;return h|0}c[f>>2]=a;if((d|0)==0){h=0;i=e;return h|0}f=d;d=b;b=c[g>>2]|0;while(1){a:do{if((b|0)==0){j=0}else{k=b;while(1){l=k+ -1|0;m=a+(l*12|0)|0;if((Fz(c[d>>2]|0,c[m>>2]|0)|0)>-1){j=k;break a}n=a+(k*12|0)|0;c[n+0>>2]=c[m+0>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];if((l|0)==0){j=0;break}else{k=l}}}}while(0);k=a+(j*12|0)|0;c[k+0>>2]=c[d+0>>2];c[k+4>>2]=c[d+4>>2];c[k+8>>2]=c[d+8>>2];k=b+1|0;c[g>>2]=k;l=f+ -1|0;if((l|0)==0){h=0;break}else{f=l;d=d+12|0;b=k}}i=e;return h|0}function Qw(a,b,d){a=a|0;b=b|0;d=d|0;c[a>>2]=d;c[a+4>>2]=b;return}function Rw(a,b,d){a=a|0;b=b|0;d=d|0;c[a+8>>2]=d;c[a+12>>2]=b;return}function Sw(a,b,d){a=a|0;b=b|0;d=d|0;c[a+16>>2]=b;c[a+20>>2]=d;return}function Tw(a,b,d){a=a|0;b=b|0;d=d|0;c[a+24>>2]=b;c[a+28>>2]=d;return}function Uw(a,b){a=a|0;b=b|0;c[a+32>>2]=b;return}function Vw(b,c){b=b|0;c=c|0;a[b+56>>0]=(c|0)!=0|0;return}function Ww(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=i;d=a+52|0;e=a+48|0;a=Az(c[d>>2]|0,((c[e>>2]|0)*12|0)+48|0)|0;if((a|0)==0){f=1;i=b;return f|0}c[d>>2]=a;d=c[e>>2]|0;if((d|0)==0){c[a+0>>2]=c[57624>>2];c[a+4>>2]=c[57628>>2];c[a+8>>2]=c[57632>>2];g=d+1|0;c[e>>2]=g;h=g;j=9}else{g=c[14406]|0;k=d;while(1){l=k+ -1|0;m=a+(l*12|0)|0;if((Fz(g,c[m>>2]|0)|0)>-1){n=k;break}o=a+(k*12|0)|0;c[o+0>>2]=c[m+0>>2];c[o+4>>2]=c[m+4>>2];c[o+8>>2]=c[m+8>>2];if((l|0)==0){n=0;break}else{k=l}}k=a+(n*12|0)|0;c[k+0>>2]=c[57624>>2];c[k+4>>2]=c[57628>>2];c[k+8>>2]=c[57632>>2];k=d+1|0;c[e>>2]=k;if((k|0)==0){p=0}else{h=k;j=9}}a:do{if((j|0)==9){k=c[57636>>2]|0;n=h;while(1){g=n+ -1|0;l=a+(g*12|0)|0;if((Fz(k,c[l>>2]|0)|0)>-1){p=n;break a}m=a+(n*12|0)|0;c[m+0>>2]=c[l+0>>2];c[m+4>>2]=c[l+4>>2];c[m+8>>2]=c[l+8>>2];if((g|0)==0){p=0;break}else{n=g}}}}while(0);h=a+(p*12|0)|0;c[h+0>>2]=c[57636>>2];c[h+4>>2]=c[57640>>2];c[h+8>>2]=c[57644>>2];h=d+2|0;c[e>>2]=h;b:do{if((h|0)==0){q=0}else{p=c[57648>>2]|0;j=h;while(1){n=j+ -1|0;k=a+(n*12|0)|0;if((Fz(p,c[k>>2]|0)|0)>-1){q=j;break b}g=a+(j*12|0)|0;c[g+0>>2]=c[k+0>>2];c[g+4>>2]=c[k+4>>2];c[g+8>>2]=c[k+8>>2];if((n|0)==0){q=0;break}else{j=n}}}}while(0);h=a+(q*12|0)|0;c[h+0>>2]=c[57648>>2];c[h+4>>2]=c[57652>>2];c[h+8>>2]=c[57656>>2];h=d+3|0;c[e>>2]=h;c:do{if((h|0)==0){r=0}else{q=c[57660>>2]|0;j=h;while(1){p=j+ -1|0;n=a+(p*12|0)|0;if((Fz(q,c[n>>2]|0)|0)>-1){r=j;break c}k=a+(j*12|0)|0;c[k+0>>2]=c[n+0>>2];c[k+4>>2]=c[n+4>>2];c[k+8>>2]=c[n+8>>2];if((p|0)==0){r=0;break}else{j=p}}}}while(0);h=a+(r*12|0)|0;c[h+0>>2]=c[57660>>2];c[h+4>>2]=c[57664>>2];c[h+8>>2]=c[57668>>2];c[e>>2]=d+4;f=0;i=b;return f|0}function Xw(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=a[b>>0]|0;a:do{if(e<<24>>24==0){f=0}else{g=b;h=e;while(1){if((Fz(g,c)|0)==0){f=1;break a}else{j=g;k=h}while(1){if(k<<24>>24==0|k<<24>>24==46){break}l=j+1|0;j=l;k=a[l>>0]|0}l=k<<24>>24==46?j+1|0:j;m=a[l>>0]|0;if(m<<24>>24==0){f=0;break}else{g=l;h=m}}}}while(0);i=d;return f|0}function Yw(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e;g=Hb(b|0,f|0,0)|0;h=c[f>>2]|0;if((h|0)==(b|0)){j=1}else{if((a[h>>0]|0)==0){c[d>>2]=g;j=0}else{j=1}}i=e;return j|0}function Zw(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e;g=Va(b|0,f|0,0)|0;h=c[f>>2]|0;if((h|0)==(b|0)){j=1}else{if((a[h>>0]|0)==0){c[d>>2]=g;j=0}else{j=1}}i=e;return j|0}function _w(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+16|0;f=e;do{if((b|0)==0){g=3}else{if((a[b>>0]|0)==0){g=3}else{if((Fz(b,58376)|0)==0){c[d>>2]=1;h=0;break}if((Fz(b,58384)|0)==0){c[d>>2]=0;h=0;break}j=Hb(b|0,f|0,0)|0;k=c[f>>2]|0;if((k|0)==(b|0)){h=1}else{if((a[k>>0]|0)==0){c[d>>2]=(j|0)!=0;h=0}else{h=1}}}}}while(0);if((g|0)==3){c[d>>2]=0;h=0}i=e;return h|0}function $w(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g+4|0;j=g;k=c[b>>2]|0;c[j>>2]=k;l=ix(k,e,j)|0;e=gx(l,58392,58392)|0;k=Hb(e|0,h|0,0)|0;m=c[h>>2]|0;if((m|0)!=(e|0)){if((a[m>>0]|0)==0){c[d>>2]=k;zz(l);c[b>>2]=hx(c[j>>2]|0,f)|0;n=0;i=g;return n|0}}zz(l);n=1;i=g;return n|0}function ax(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;if(($w(a,g,d,e)|0)!=0){h=1;i=f;return h|0}c[b>>2]=c[g>>2];h=0;i=f;return h|0}function bx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=Kz(b|0)|0;while(1){if((f|0)==0){g=0;break}h=f+ -1|0;if((a[b+h>>0]|0)==47){f=h}else{j=4;break}}do{if((j|0)==4){if((f|0)==0){g=0;break}else if((f|0)==1){if((a[b>>0]|0)==46){g=0;break}}h=yz(f+1|0)|0;if((h|0)==0){k=1;i=e;return k|0}else{Mz(h|0,b|0,f|0)|0;a[h+f>>0]=0;g=h;break}}}while(0);f=Az(c[14602]|0,(c[14600]<<2)+4|0)|0;if((f|0)==0){zz(g);k=1;i=e;return k|0}b=c[14600]|0;if((d|0)==0){if((b|0)!=0){d=b;do{j=d;d=d+ -1|0;c[f+(j<<2)>>2]=c[f+(d<<2)>>2]}while((d|0)!=0)}c[f>>2]=g}else{c[f+(b<<2)>>2]=g}c[14600]=b+1;c[14602]=f;k=0;i=e;return k|0}function cx(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=a[b>>0]|0;if(e<<24>>24==43){f=b+1|0;g=1}else if(e<<24>>24==45){f=b+1|0;g=0}else if(e<<24>>24==61){e=b+1|0;h=c[14602]|0;if((c[14600]|0)==0){j=h}else{k=h;h=0;while(1){zz(c[k+(h<<2)>>2]|0);l=h+1|0;m=c[14602]|0;if(l>>>0<(c[14600]|0)>>>0){k=m;h=l}else{j=m;break}}}zz(j);c[14600]=0;c[14602]=0;f=e;g=1}else{f=b;g=1}b=bx(f,g)|0;i=d;return b|0}function dx(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;if((b|0)==0){e=0;i=d;return e|0}f=Kz(b|0)|0;g=yz(f+1|0)|0;if((g|0)==0){e=0;i=d;return e|0}Mz(g|0,b|0,f|0)|0;a[g+f>>0]=0;if((a[g>>0]|0)==47|(c[14600]|0)==0){e=g;i=d;return e|0}else{h=0}while(1){f=c[(c[14602]|0)+(h<<2)>>2]|0;if((f|0)==0){b=Kz(g|0)|0;j=yz(b+1|0)|0;if((j|0)==0){k=9;break}Mz(j|0,g|0,b|0)|0;a[j+b>>0]=0;l=j}else{j=Kz(f|0)|0;b=Kz(g|0)|0;m=b+j|0;n=yz(m+2|0)|0;if((n|0)==0){k=9;break}Mz(n|0,f|0,j|0)|0;a[n+j>>0]=47;Mz(n+(j+1)|0,g|0,b|0)|0;a[n+(m+1)>>0]=0;l=n}o=Ib(l|0,58416)|0;if((o|0)!=0){k=11;break}zz(l);n=h+1|0;if(n>>>0<(c[14600]|0)>>>0){h=n}else{e=g;k=13;break}}if((k|0)==9){zz(g);e=0;i=d;return e|0}else if((k|0)==11){zb(o|0)|0;zz(g);e=l;i=d;return e|0}else if((k|0)==13){i=d;return e|0}return 0}function ex(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=i;e=0;while(1){f=Kx(b,e,58424)|0;if((f|0)==0){g=0;h=11;break}j=gy(f)|0;if((j|0)==0){g=1;h=11;break}k=a[j>>0]|0;if(k<<24>>24==61){l=j+1|0;m=c[14602]|0;if((c[14600]|0)==0){n=m}else{o=m;m=0;while(1){zz(c[o+(m<<2)>>2]|0);p=m+1|0;q=c[14602]|0;if(p>>>0<(c[14600]|0)>>>0){o=q;m=p}else{n=q;break}}}zz(n);c[14600]=0;c[14602]=0;r=l;s=1}else if(k<<24>>24==45){r=j+1|0;s=0}else if(k<<24>>24==43){r=j+1|0;s=1}else{r=j;s=1}if((bx(r,s)|0)==0){e=f}else{g=1;h=11;break}}if((h|0)==11){i=d;return g|0}return 0}function fx(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;if((b|0)==0){e=0}else{e=Kz(b|0)|0}if((c|0)==0){f=0}else{f=Kz(c|0)|0}g=f+e|0;h=yz(g+1|0)|0;if((h|0)==0){j=0;i=d;return j|0}if((e|0)!=0){Mz(h|0,b|0,e|0)|0}if((f|0)!=0){Mz(h+e|0,c|0,f|0)|0}a[h+g>>0]=0;j=h;i=d;return j|0}function gx(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;if((b|0)==0){f=0;i=e;return f|0}a:do{if((c|0)==0){g=b}else{h=a[b>>0]|0;if(h<<24>>24==0){g=b}else{j=b;k=h;while(1){h=j+1|0;if((vz(c,k<<24>>24)|0)==0){g=j;break a}l=a[h>>0]|0;if(l<<24>>24==0){g=h;break}else{j=h;k=l}}}}}while(0);if((d|0)==0){f=g;i=e;return f|0}c=Kz(g|0)|0;while(1){if((c|0)==0){m=0;break}b=c+ -1|0;if((vz(d,a[g+b>>0]|0)|0)==0){m=c;break}else{c=b}}a[g+m>>0]=0;f=g;i=e;return f|0}function hx(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;a:do{if((b|0)==0){e=0}else{if((c|0)==0){e=b}else{f=a[b>>0]|0;if(f<<24>>24==0){e=b}else{g=b;h=f;while(1){f=g+1|0;if((vz(c,h<<24>>24)|0)==0){e=g;break a}j=a[f>>0]|0;if(j<<24>>24==0){e=f;break}else{g=f;h=j}}}}}}while(0);i=d;return e|0}function ix(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;if((b|0)==0){g=0;i=f;return g|0}h=a[b>>0]|0;a:do{if(h<<24>>24==0){j=b;k=0}else{l=b;m=h;n=0;while(1){o=n+1|0;if((vz(d,m<<24>>24)|0)!=0){j=l;k=n;break a}p=b+o|0;q=a[p>>0]|0;if(q<<24>>24==0){j=p;k=o;break}else{l=p;m=q;n=o}}}}while(0);d=k+1|0;n=yz(d)|0;if((n|0)==0){r=0}else{b:do{if((k|0)==0){s=0}else{m=h;l=0;while(1){if(m<<24>>24==0){s=l;break b}a[n+l>>0]=m;o=l+1|0;if(!(o>>>0<k>>>0)){s=o;break b}m=a[b+o>>0]|0;l=o}}}while(0);a[n+s>>0]=0;r=n}if((c[e>>2]|0)==0){g=r;i=f;return g|0}c[e>>2]=b+((a[j>>0]|0)==0?k:d);g=r;i=f;return g|0}function jx(a){a=a|0;var b=0,d=0;b=i;i=i+16|0;d=b;c[d>>2]=(a>>>0)/1e6|0;c[d+4>>2]=((a>>>0)%1e6|0)*1e3;a=Za(d|0,0)|0;i=b;return a|0}function kx(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;i=i+16|0;d=b;if((ib(d|0,0)|0)!=0){e=0;i=b;return e|0}f=((c[d>>2]|0)*1e6|0)+(c[d+4>>2]|0)|0;d=f-(c[a>>2]|0)|0;c[a>>2]=f;e=d;i=b;return e|0}function lx(a,b){a=a|0;b=b|0;if((c[14608]|0)==0){c[14608]=1}return}function mx(a){a=a|0;var b=0;b=i;if((a|0)!=0){c[a>>2]=0}if((c[14608]|0)!=0){i=b;return}c[14608]=1;i=b;return}function nx(){if((c[14608]|0)==0){c[14608]=1}return}function ox(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=i;i=i+1312|0;d=c;ux(d);wx(d,b);if((px(d,a,c+1048|0)|0)!=0){qx(d,58440,1);vx(d);e=1;i=c;return e|0}if((yx(d,0)|0)<<24>>24==0){vx(d);e=0;i=c;return e|0}else{qx(d,58440,1);vx(d);e=1;i=c;return e|0}return 0}function px(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+48|0;f=e;g=e+32|0;h=e+16|0;if((Cx(a,d,256)|0)==0){j=0;i=e;return j|0}k=g+8|0;l=g+12|0;m=h+8|0;a:while(1){if((Fz(d,58520)|0)==0){if((Cx(a,d,256)|0)==0){j=1;n=46;break}}b:do{if((Gx(a,58528)|0)==0){if((Gx(a,58544)|0)!=0){Wx(h,0);if((hy(a,b,h)|0)!=0){n=15;break a}if((c[m>>2]|0)==0){n=15;break a}if((Nx(b,d,0)|0)==0){p=Nx(b,d,1)|0;if((p|0)==0){n=15;break a}$x(p,h)}Xx(h);break}if((Gx(a,58552)|0)!=0){p=Nx(b,d,1)|0;if((p|0)==0){j=1;n=46;break a}if((hy(a,b,p)|0)!=0){j=1;n=46;break a}if((c[p+8>>2]|0)==0){j=1;n=46;break a}else{break}}if((Fz(d,58560)|0)!=0){if((Fz(d,58568)|0)!=0){j=1;n=46;break a}p=Gx(a,58576)|0;if((Dx(a,d,256)|0)==0){j=1;n=46;break a}if((xx(a,d,0,1)|0)==0|(p|0)!=0){break}else{n=40;break a}}Wx(g,0);if((hy(a,b,g)|0)!=0){n=23;break a}if((c[k>>2]|0)==1){if((c[l>>2]|0)==0){n=26}else{q=1;r=0}}else{n=26}if((n|0)==26){n=0;q=0;r=1}Xx(g);if((tx(a,b,d,r)|0)==0){s=q}else{j=1;n=46;break a}while(1){if((Fx(a,58624)|0)==0){break b}if((Fx(a,58560)|0)==0){break}Wx(g,0);if((hy(a,b,g)|0)!=0){n=31;break a}if((s|0)==0){if((c[k>>2]|0)==1){p=(c[l>>2]|0)==0;t=p&1^1;u=p&1}else{t=0;u=1}}else{t=s;u=1}Xx(g);if((tx(a,b,d,u)|0)==0){s=t}else{j=1;n=46;break a}}if((tx(a,b,d,s)|0)!=0){j=1;n=46;break a}}else{p=Lx(b,d,1)|0;if((p|0)==0){j=1;n=46;break a}if((px(a,p,d)|0)!=0){j=1;n=46;break a}if((Gx(a,58536)|0)==0){j=1;n=46;break a}}}while(0);Gx(a,58616)|0;if((Cx(a,d,256)|0)==0){j=0;n=46;break}}if((n|0)==15){Xx(h);j=1;i=e;return j|0}else if((n|0)==23){Xx(g);j=1;i=e;return j|0}else if((n|0)==31){Xx(g);j=1;i=e;return j|0}else if((n|0)==40){g=a+1040|0;h=c[g>>2]|0;if((h|0)==0){v=0}else{v=c[h+4>>2]|0}h=c[o>>2]|0;b=a+1028|0;a=(c[b>>2]|0)+1|0;c[f>>2]=(v|0)==0?58472:v;c[f+4>>2]=a;c[f+8>>2]=58584;hb(h|0,58480,f|0)|0;$b(10,h|0)|0;a=c[g>>2]|0;if((a|0)==0){w=0}else{w=c[a+4>>2]|0}a=(c[b>>2]|0)+1|0;c[f>>2]=(w|0)==0?58472:w;c[f+4>>2]=a;c[f+8>>2]=d;hb(h|0,58480,f|0)|0;$b(10,h|0)|0;j=1;i=e;return j|0}else if((n|0)==46){i=e;return j|0}return 0}function qx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+16|0;f=e;g=c[a+1040>>2]|0;if((g|0)==0){h=0}else{h=c[g+4>>2]|0}g=c[o>>2]|0;j=(c[a+1028>>2]|0)+1|0;c[f>>2]=(h|0)==0?58472:h;c[f+4>>2]=j;c[f+8>>2]=b;hb(g|0,58480,f|0)|0;if((d|0)==0){$b(10,g|0)|0;i=e;return}fb(58496,2,1,g|0)|0;d=0;while(1){f=yx(a,d)|0;if(f<<24>>24==0){k=6;break}else if(f<<24>>24==10|f<<24>>24==13){k=7;break}$b(f<<24>>24|0,g|0)|0;f=d+1|0;if(f>>>0<64){d=f}else{k=9;break}}if((k|0)==6){fb(58504,5,1,g|0)|0;$b(10,g|0)|0;i=e;return}else if((k|0)==7){fb(58512,4,1,g|0)|0;$b(10,g|0)|0;i=e;return}else if((k|0)==9){$b(10,g|0)|0;i=e;return}}function rx(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=i;i=i+1312|0;e=d;ux(e);do{if((xx(e,c,b,0)|0)==0){if((px(e,a,d+1048|0)|0)!=0){qx(e,58440,1);vx(e);f=1;break}if((yx(e,0)|0)<<24>>24==0){vx(e);f=0;break}else{qx(e,58440,1);vx(e);f=1;break}}else{Ix(a);f=1}}while(0);i=d;return f|0}function sx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=i;d=Ib(b|0,58464)|0;if((d|0)==0){e=1}else{f=rx(a,d,b)|0;zb(d|0)|0;e=f}i=c;return e|0}function tx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;a:do{if((Gx(a,58528)|0)==0){f=1}else{if((d|0)==0){if((px(a,b,c)|0)!=0){f=1;break}f=(Gx(a,58536)|0)==0|0;break}else{g=1}while(1){while(1){h=yx(a,0)|0;if(h<<24>>24==0){f=1;break a}Ax(a,1);if(h<<24>>24==123){j=6;break}else if(h<<24>>24==125){j=7;break}}if((j|0)==6){j=0;g=g+1|0;continue}else if((j|0)==7){j=0;h=g+ -1|0;if((h|0)==0){f=0;break}else{g=h;continue}}}}}while(0);i=e;return f|0}function ux(a){a=a|0;c[a>>2]=0;c[a+1028>>2]=0;c[a+1032>>2]=0;c[a+1040>>2]=0;c[a+1044>>2]=0;return}function vx(a){a=a|0;var b=0,d=0,e=0;b=i;if((a|0)==0){i=b;return}d=c[a+1040>>2]|0;if((d|0)==0){i=b;return}else{e=d}do{d=e;e=c[e>>2]|0;if((c[d+12>>2]|0)!=0){zb(c[d+8>>2]|0)|0}zz(c[d+4>>2]|0);zz(d)}while((e|0)!=0);i=b;return}function wx(a,b){a=a|0;b=b|0;c[a+1044>>2]=b;return}function xx(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;h=yz(24)|0;if((h|0)==0){j=1;i=g;return j|0}c[h+0>>2]=0;c[h+4>>2]=0;c[h+8>>2]=0;c[h+12>>2]=0;k=b+1040|0;l=c[k>>2]|0;if((l|0)==0){m=Kz(d|0)|0;n=yz(m+1|0)|0;if((n|0)==0){o=h;p=16}else{Mz(n|0,d|0,m|0)|0;a[n+m>>0]=0;q=n}}else{n=c[l+4>>2]|0;a:do{if((a[d>>0]|0)==47|(n|0)==0){r=0}else{m=Kz(n|0)|0;while(1){if((m|0)==0){s=0;break}t=m+ -1|0;if((a[n+t>>0]|0)==47){m=t}else{s=m;break}}while(1){if((s|0)==0){r=0;break a}m=s+ -1|0;if((a[n+m>>0]|0)==47){r=s;break}else{s=m}}}}while(0);s=Kz(d|0)|0;m=s+r|0;t=yz(m+1|0)|0;if((t|0)==0){u=0}else{if((r|0)!=0){Mz(t|0,n|0,r|0)|0}Mz(t+r|0,d|0,s|0)|0;a[t+m>>0]=0;u=t}c[l+16>>2]=c[b+1028>>2];c[l+20>>2]=c[b+1032>>2];if((u|0)==0){o=h;p=16}else{q=u}}if((p|0)==16){while(1){p=0;u=c[o>>2]|0;if((c[o+12>>2]|0)!=0){zb(c[o+8>>2]|0)|0}zz(c[o+4>>2]|0);zz(o);if((u|0)==0){j=1;break}else{o=u;p=16}}i=g;return j|0}c[h+4>>2]=q;p=(e|0)!=0;if(p){c[h+8>>2]=e}else{e=Ib(q|0,58632)|0;c[h+8>>2]=e;if((e|0)==0){e=h;while(1){q=c[e>>2]|0;if((c[e+12>>2]|0)!=0){zb(c[e+8>>2]|0)|0}zz(c[e+4>>2]|0);zz(e);if((q|0)==0){j=1;break}else{e=q}}i=g;return j|0}}c[h+12>>2]=p&(f|0)!=0&1;c[h>>2]=c[k>>2];c[k>>2]=h;c[b+1028>>2]=0;c[b+1032>>2]=0;j=0;i=g;return j|0}function yx(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;if(b>>>0>255){e=0;i=d;return e|0}a:do{if(!((c[a>>2]|0)>>>0>b>>>0)){while(1){f=(zx(a)|0)<<24>>24;c[a+(c[a>>2]<<2)+4>>2]=f;f=c[a>>2]|0;if((c[a+(f<<2)+4>>2]|0)==0){e=0;break}g=f+1|0;c[a>>2]=g;if(g>>>0>b>>>0){break a}}i=d;return e|0}}while(0);e=c[a+(b<<2)+4>>2]&255;i=d;return e|0}function zx(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=b+1040|0;f=c[e>>2]|0;if((f|0)==0){g=b+1044|0;h=c[g>>2]|0;if((h|0)==0){j=0;i=d;return j|0}k=a[h>>0]|0;if(k<<24>>24==0){j=0;i=d;return j|0}c[g>>2]=h+1;j=k;i=d;return j|0}k=b+1028|0;h=b+1032|0;b=f;while(1){l=_b(c[b+8>>2]|0)|0;if(!((l|0)==-1)){m=4;break}f=c[e>>2]|0;if((f|0)==0){j=0;m=13;break}c[e>>2]=c[f>>2];c[f>>2]=0;if((c[f+12>>2]|0)!=0){zb(c[f+8>>2]|0)|0}zz(c[f+4>>2]|0);zz(f);f=c[e>>2]|0;if((f|0)==0){j=0;m=13;break}c[k>>2]=c[f+16>>2];c[h>>2]=c[f+20>>2];b=f}if((m|0)==4){j=l&255;i=d;return j|0}else if((m|0)==13){i=d;return j|0}return 0}function Ax(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=c[a>>2]|0;if(e>>>0>b>>>0){if((b|0)==0){f=0}else{g=a+1032|0;h=a+1028|0;j=a+1036|0;k=0;while(1){l=c[a+(k<<2)+4>>2]&255;do{if(!(l<<24>>24==0)){c[g>>2]=(c[g>>2]|0)+1;if(l<<24>>24==10){if((c[j>>2]|0)==0){c[h>>2]=(c[h>>2]|0)+1}c[j>>2]=0;break}else if(l<<24>>24==13){c[h>>2]=(c[h>>2]|0)+1;c[j>>2]=1;break}else{c[j>>2]=0;break}}}while(0);l=k+1|0;if((l|0)==(b|0)){f=b;break}else{k=l}}}do{c[a+(f-b<<2)+4>>2]=c[a+(f<<2)+4>>2];f=f+1|0;m=c[a>>2]|0}while(f>>>0<m>>>0);c[a>>2]=m-b;i=d;return}if((e|0)==0){n=0}else{m=a+1032|0;f=a+1028|0;k=a+1036|0;j=0;while(1){h=c[a+(j<<2)+4>>2]&255;do{if(!(h<<24>>24==0)){c[m>>2]=(c[m>>2]|0)+1;if(h<<24>>24==10){if((c[k>>2]|0)==0){c[f>>2]=(c[f>>2]|0)+1}c[k>>2]=0;break}else if(h<<24>>24==13){c[f>>2]=(c[f>>2]|0)+1;c[k>>2]=1;break}else{c[k>>2]=0;break}}}while(0);h=j+1|0;if(h>>>0<e>>>0){j=h}else{n=e;break}}}c[a>>2]=0;if((n|0)==(b|0)){i=d;return}e=a+1032|0;j=a+1028|0;k=a+1036|0;f=b-n|0;do{n=zx(a)|0;do{if(!(n<<24>>24==0)){c[e>>2]=(c[e>>2]|0)+1;if(n<<24>>24==13){c[j>>2]=(c[j>>2]|0)+1;c[k>>2]=1;break}else if(n<<24>>24==10){if((c[k>>2]|0)==0){c[j>>2]=(c[j>>2]|0)+1}c[k>>2]=0;break}else{c[k>>2]=0;break}}}while(0);f=f+ -1|0}while((f|0)!=0);i=d;return}function Bx(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;d=a+4|0;e=a+8|0;f=0;a:while(1){g=c[a>>2]|0;h=f;b:while(1){if((g|0)==0){while(1){j=(zx(a)|0)<<24>>24;c[a+(c[a>>2]<<2)+4>>2]=j;j=c[a>>2]|0;if((c[a+(j<<2)+4>>2]|0)==0){k=32;break a}l=j+1|0;c[a>>2]=l;if((l|0)!=0){m=l;break}}}else{m=g}switch((c[d>>2]&255)<<24>>24){case 10:case 13:case 9:case 32:{k=7;break b;break};case 35:{l=m;while(1){if((l|0)==0){while(1){j=(zx(a)|0)<<24>>24;c[a+(c[a>>2]<<2)+4>>2]=j;j=c[a>>2]|0;if((c[a+(j<<2)+4>>2]|0)==0){g=j;h=1;continue b}n=j+1|0;c[a>>2]=n;if((n|0)!=0){break}}}n=c[d>>2]&255;if(n<<24>>24==0){f=1;continue a}Ax(a,1);if(n<<24>>24==13){break}else if(n<<24>>24==10){f=1;continue a}l=c[a>>2]|0}if((c[a>>2]|0)!=0){break b}while(1){l=(zx(a)|0)<<24>>24;c[a+(c[a>>2]<<2)+4>>2]=l;l=c[a>>2]|0;if((c[a+(l<<2)+4>>2]|0)==0){g=l;h=1;continue b}n=l+1|0;c[a>>2]=n;if((n|0)!=0){break b}}break};case 47:{break};default:{k=32;break a}}if(!(m>>>0>1)){do{n=(zx(a)|0)<<24>>24;c[a+(c[a>>2]<<2)+4>>2]=n;n=c[a>>2]|0;if((c[a+(n<<2)+4>>2]|0)==0){k=32;break a}l=n+1|0;c[a>>2]=l}while(!(l>>>0>1))}if(!((c[e>>2]&255)<<24>>24==42)){k=32;break a}Ax(a,2);l=0;n=0;while(1){if((c[a>>2]|0)==0){while(1){j=(zx(a)|0)<<24>>24;c[a+(c[a>>2]<<2)+4>>2]=j;j=c[a>>2]|0;if((c[a+(j<<2)+4>>2]|0)==0){g=j;h=1;continue b}o=j+1|0;c[a>>2]=o;if((o|0)!=0){break}}}o=c[d>>2]&255;if(o<<24>>24==0){f=1;continue a}Ax(a,1);if(!(l<<24>>24==42&o<<24>>24==47)){j=l<<24>>24==47&o<<24>>24==42;l=j?0:o;n=(j&1)+n|0;continue}if((n|0)==0){f=1;continue a}l=0;n=n+ -1|0}}if((k|0)==7){k=0;Ax(a,1);f=1;continue}if(!((c[d>>2]&255)<<24>>24==10)){f=1;continue}Ax(a,1);f=1}if((k|0)==32){i=b;return h|0}return 0}function Cx(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;Bx(b)|0;a:do{if((c[b>>2]|0)==0){while(1){g=(zx(b)|0)<<24>>24;c[b+(c[b>>2]<<2)+4>>2]=g;g=c[b>>2]|0;if((c[b+(g<<2)+4>>2]|0)==0){h=0;break a}j=g+1|0;c[b>>2]=j;if((j|0)!=0){k=4;break}}}else{k=4}}while(0);if((k|0)==4){h=c[b+4>>2]&255}if(!((h+ -97<<24>>24&255)<26|(h+ -65<<24>>24&255)<26)){if(!(h<<24>>24==36|h<<24>>24==95)){l=0;i=f;return l|0}}b:do{if((e|0)==0){m=0}else{k=h;j=0;c:while(1){g=j+1|0;n=d+j|0;a[n>>0]=k;d:do{if(g>>>0>255){o=0}else{if(!((c[b>>2]|0)>>>0>g>>>0)){do{p=(zx(b)|0)<<24>>24;c[b+(c[b>>2]<<2)+4>>2]=p;p=c[b>>2]|0;if((c[b+(p<<2)+4>>2]|0)==0){o=0;break d}q=p+1|0;c[b>>2]=q}while(!(q>>>0>g>>>0))}o=c[b+(g<<2)+4>>2]&255}}while(0);e:do{if(!((o+ -97<<24>>24&255)<26|(o+ -65<<24>>24&255)<26|o<<24>>24==95|(o+ -48<<24>>24&255)<10)){switch(o<<24>>24){case 46:case 91:case 93:{break e;break};case 45:{if((a[n>>0]|0)==91&g>>>0<e>>>0){k=o;j=g;continue c}else{m=g;break b}break};case 43:{if((a[n>>0]|0)==91&g>>>0<e>>>0){k=o;j=g;continue c}else{m=g;break b}break};default:{m=g;break b}}}}while(0);if(g>>>0<e>>>0){k=o;j=g}else{m=g;break}}}}while(0);if(!(m>>>0<e>>>0)){l=0;i=f;return l|0}a[d+m>>0]=0;Ax(b,m);l=1;i=f;return l|0}function Dx(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=i;Bx(b)|0;a:do{if((c[b>>2]|0)==0){while(1){g=(zx(b)|0)<<24>>24;c[b+(c[b>>2]<<2)+4>>2]=g;g=c[b>>2]|0;if((c[b+(g<<2)+4>>2]|0)==0){h=0;break}j=g+1|0;c[b>>2]=j;if((j|0)!=0){break a}}i=f;return h|0}}while(0);if((c[b+4>>2]&255)<<24>>24!=34|(e|0)==0){h=0;i=f;return h|0}else{k=1;l=0}b:while(1){if(k>>>0>255){h=1;m=38;break}j=c[b>>2]|0;if(j>>>0>k>>>0){n=j}else{while(1){j=(zx(b)|0)<<24>>24;c[b+(c[b>>2]<<2)+4>>2]=j;j=c[b>>2]|0;if((c[b+(j<<2)+4>>2]|0)==0){h=1;m=38;break b}g=j+1|0;c[b>>2]=g;if(g>>>0>k>>>0){n=g;break}}}g=c[b+(k<<2)+4>>2]&255;c:do{if(g<<24>>24==34){m=37;break b}else if(g<<24>>24==92){j=k+1|0;if(j>>>0>255){o=92;p=k}else{if(n>>>0>j>>>0){q=n}else{while(1){r=(zx(b)|0)<<24>>24;c[b+(c[b>>2]<<2)+4>>2]=r;r=c[b>>2]|0;if((c[b+(r<<2)+4>>2]|0)==0){o=92;p=k;break c}s=r+1|0;c[b>>2]=s;if(s>>>0>j>>>0){q=s;break}}}switch(c[b+(j<<2)+4>>2]<<24>>24|0){case 110:{o=10;p=j;break c;break};case 114:{o=13;p=j;break c;break};case 98:{o=8;p=j;break c;break};case 102:{o=12;p=j;break c;break};case 97:{o=7;p=j;break c;break};case 118:{o=11;p=j;break c;break};case 92:{o=92;p=j;break c;break};case 34:{o=34;p=j;break c;break};case 120:{s=k+2|0;r=q;t=0;u=0;while(1){v=s+t|0;if(v>>>0>255){h=0;m=38;break b}if(r>>>0>v>>>0){w=r}else{while(1){x=(zx(b)|0)<<24>>24;c[b+(c[b>>2]<<2)+4>>2]=x;x=c[b>>2]|0;if((c[b+(x<<2)+4>>2]|0)==0){h=0;m=38;break b}y=x+1|0;c[b>>2]=y;if(y>>>0>v>>>0){w=y;break}}}y=c[b+(v<<2)+4>>2]|0;x=y&255;z=y<<24>>24;do{if((x+ -48<<24>>24&255)<10){A=z+ -48|0}else{if((x+ -97<<24>>24&255)<6){A=z+ -87|0;break}if(!((x+ -65<<24>>24&255)<6)){h=0;m=38;break b}A=z+ -55|0}}while(0);u=A+(u<<4)|0;t=t+1|0;if(!(t>>>0<2)){break}else{r=w}}o=u&255;p=k+3|0;break c;break};default:{o=92;p=k;break c}}}}else if(g<<24>>24==0){h=1;m=38;break b}else{o=g;p=k}}while(0);g=l+1|0;a[d+l>>0]=o;if(g>>>0<e>>>0){k=p+1|0;l=g}else{h=0;m=38;break}}if((m|0)==37){a[d+l>>0]=0;Ax(b,k+1|0);h=1;i=f;return h|0}else if((m|0)==38){i=f;return h|0}return 0}function Ex(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;Bx(b)|0;if((a[d>>0]|0)==0){f=1;i=e;return f|0}g=d;h=0;while(1){a:do{if(h>>>0>255){j=0}else{if(!((c[b>>2]|0)>>>0>h>>>0)){do{k=(zx(b)|0)<<24>>24;c[b+(c[b>>2]<<2)+4>>2]=k;k=c[b>>2]|0;if((c[b+(k<<2)+4>>2]|0)==0){j=0;break a}l=k+1|0;c[b>>2]=l}while(!(l>>>0>h>>>0))}j=c[b+(h<<2)+4>>2]&255}}while(0);l=h+1|0;if(!(j<<24>>24==(a[g>>0]|0))){f=0;m=10;break}k=d+l|0;if((a[k>>0]|0)==0){f=1;m=10;break}else{g=k;h=l}}if((m|0)==10){i=e;return f|0}return 0}function Fx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;Bx(b)|0;f=0;while(1){g=d+f|0;h=(a[g>>0]|0)==0;a:do{if(f>>>0>255){j=0}else{if(!((c[b>>2]|0)>>>0>f>>>0)){do{k=(zx(b)|0)<<24>>24;c[b+(c[b>>2]<<2)+4>>2]=k;k=c[b>>2]|0;if((c[b+(k<<2)+4>>2]|0)==0){j=0;break a}l=k+1|0;c[b>>2]=l}while(!(l>>>0>f>>>0))}j=c[b+(f<<2)+4>>2]&255}}while(0);if(h){break}if(j<<24>>24==(a[g>>0]|0)){f=f+1|0}else{m=0;n=11;break}}if((n|0)==11){i=e;return m|0}if((j+ -97<<24>>24&255)<26|(j+ -65<<24>>24&255)<26|j<<24>>24==95|(j+ -48<<24>>24&255)<10){m=0;i=e;return m|0}Ax(b,f);m=1;i=e;return m|0}function Gx(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;Bx(b)|0;a:do{if((a[d>>0]|0)==0){f=0}else{g=d;h=0;while(1){b:do{if(h>>>0>255){j=0}else{if(!((c[b>>2]|0)>>>0>h>>>0)){do{k=(zx(b)|0)<<24>>24;c[b+(c[b>>2]<<2)+4>>2]=k;k=c[b>>2]|0;if((c[b+(k<<2)+4>>2]|0)==0){j=0;break b}l=k+1|0;c[b>>2]=l}while(!(l>>>0>h>>>0))}j=c[b+(h<<2)+4>>2]&255}}while(0);l=h+1|0;if(!(j<<24>>24==(a[g>>0]|0))){m=0;break}k=d+l|0;if((a[k>>0]|0)==0){f=l;break a}else{g=k;h=l}}i=e;return m|0}}while(0);Ax(b,f);m=1;i=e;return m|0}function Hx(a){a=a|0;var b=0,d=0,e=0;b=i;d=yz(28)|0;if((d|0)==0){e=0;i=b;return e|0}c[d>>2]=0;c[d+4>>2]=0;c[d+8>>2]=xz((a|0)==0?58640:a)|0;a=d+12|0;c[a+0>>2]=0;c[a+4>>2]=0;c[a+8>>2]=0;c[a+12>>2]=0;e=d;i=b;return e|0}function Ix(a){a=a|0;var b=0,d=0;b=i;if((a|0)==0){i=b;return}else{d=a}do{a=d;d=c[d>>2]|0;_x(c[a+20>>2]|0);Ix(c[a+12>>2]|0);zz(c[a+8>>2]|0);zz(a)}while((d|0)!=0);i=b;return}function Jx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;if((b|0)==0){if((a|0)==0){f=0}else{g=a+12|0;h=5}}else{g=b;h=5}a:do{if((h|0)==5){b=c[g>>2]|0;if((b|0)==0){f=0}else{if((d|0)==0){f=b}else{a=b;while(1){if((Fz(c[a+8>>2]|0,d)|0)==0){f=a;break a}b=c[a>>2]|0;if((b|0)==0){f=0;break}else{a=b}}}}}}while(0);i=e;return f|0}function Kx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;if((b|0)==0){if((a|0)==0){f=0}else{g=a+20|0;h=5}}else{g=b;h=5}a:do{if((h|0)==5){b=c[g>>2]|0;if((b|0)==0|(d|0)==0){f=0}else{a=b;while(1){if((Fz(c[a+4>>2]|0,d)|0)==0){f=a;break a}b=c[a>>2]|0;if((b|0)==0){f=0;break}else{a=b}}}}}while(0);i=e;return f|0}function Lx(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;f=i;i=i+288|0;g=f+16|0;h=f+12|0;j=f+8|0;k=f+4|0;l=f;m=f+24|0;c[g>>2]=d;if((b|0)==0){n=0;i=f;return n|0}o=(e|0)==0;p=(e|0)!=0;e=b;b=d;d=1;a:while(1){if((a[b>>0]|0)==0){n=e;q=51;break}if((Mx(g,m,l,h,j,k)|0)!=0){n=0;q=51;break}r=(a[c[g>>2]>>0]|0)==0?d:0;b:do{if((c[j>>2]|0)==0){if(!((r|0)==0|o)){if((c[h>>2]|0)!=0){q=8;break}}if((c[k>>2]|0)!=0){s=e+12|0;t=c[s>>2]|0;if((t|0)==0){u=0}else{v=0;w=t;while(1){t=(Fz(c[w+8>>2]|0,m)|0)==0;x=t?w:v;t=c[w>>2]|0;if((t|0)==0){u=x;break}else{v=x;w=t}}}if(!(p&(u|0)==0)){y=u;break}w=yz(28)|0;if((w|0)==0){n=0;q=51;break a}c[w>>2]=0;v=w+4|0;c[v>>2]=0;c[w+8>>2]=xz(m)|0;t=w+12|0;c[t+0>>2]=0;c[t+4>>2]=0;c[t+8>>2]=0;c[t+12>>2]=0;if((e|0)==0){y=w;break}c[v>>2]=e;if((c[s>>2]|0)==0){c[s>>2]=w;z=e+16|0}else{v=e+16|0;c[c[v>>2]>>2]=w;z=v}c[z>>2]=w;y=w;break}w=c[l>>2]|0;v=e+12|0;t=c[v>>2]|0;if((t|0)==0){A=w}else{x=w;w=t;while(1){if((Fz(c[w+8>>2]|0,m)|0)==0){if((x|0)==0){y=w;break b}B=x+ -1|0}else{B=x}t=c[w>>2]|0;if((t|0)==0){A=B;break}else{x=B;w=t}}}if(o){n=0;q=51;break a}w=(A|0)==0;x=yz(28)|0;if((x|0)==0){C=0}else{c[x>>2]=0;s=x+4|0;c[s>>2]=0;c[x+8>>2]=xz(m)|0;t=x+12|0;c[t+0>>2]=0;c[t+4>>2]=0;c[t+8>>2]=0;c[t+12>>2]=0;if((e|0)==0){C=x}else{c[s>>2]=e;if((c[v>>2]|0)==0){c[v>>2]=x;D=e+16|0}else{s=e+16|0;c[c[s>>2]>>2]=x;D=s}c[D>>2]=x;C=x}}if(w){y=C}else{w=e+16|0;if((e|0)==0){x=A;s=C;while(1){t=x+ -1|0;if((s|0)==0){n=0;q=51;break a}E=yz(28)|0;if((E|0)==0){F=0}else{c[E>>2]=0;c[E+4>>2]=0;c[E+8>>2]=xz(m)|0;G=E+12|0;c[G+0>>2]=0;c[G+4>>2]=0;c[G+8>>2]=0;c[G+12>>2]=0;F=E}if((t|0)==0){y=F;break b}else{x=t;s=F}}}else{H=A;I=C}while(1){s=H+ -1|0;if((I|0)==0){n=0;q=51;break a}x=(s|0)==0;t=yz(28)|0;if((t|0)==0){J=0}else{c[t>>2]=0;E=t+4|0;c[E>>2]=0;c[t+8>>2]=xz(m)|0;G=t+12|0;c[G+0>>2]=0;c[G+4>>2]=0;c[G+8>>2]=0;c[G+12>>2]=0;c[E>>2]=e;if((c[v>>2]|0)==0){c[v>>2]=t}else{c[c[w>>2]>>2]=t}c[w>>2]=t;J=t}if(x){y=J;break}else{H=s;I=J}}}}else{q=8}}while(0);if((q|0)==8){q=0;w=yz(28)|0;if((w|0)==0){n=0;q=51;break}c[w>>2]=0;v=w+4|0;c[v>>2]=0;c[w+8>>2]=xz(m)|0;s=w+12|0;c[s+0>>2]=0;c[s+4>>2]=0;c[s+8>>2]=0;c[s+12>>2]=0;if((e|0)==0){y=w}else{c[v>>2]=e;v=e+12|0;if((c[v>>2]|0)==0){c[v>>2]=w;K=e+16|0}else{v=e+16|0;c[c[v>>2]>>2]=w;K=v}c[K>>2]=w;y=w}}if((y|0)==0){n=0;q=51;break}e=y;b=c[g>>2]|0;d=r}if((q|0)==51){i=f;return n|0}return 0}function Mx(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;j=i;k=c[b>>2]|0;c[e>>2]=0;c[f>>2]=1;c[g>>2]=0;c[h>>2]=0;l=a[k>>0]|0;if(!((l+ -97<<24>>24&255)<26)){if(!((l+ -65<<24>>24&255)<26|l<<24>>24==95)){m=1;i=j;return m|0}}a[d>>0]=l;l=k+1|0;n=a[l>>0]|0;if(n<<24>>24==0){o=k;p=1;q=l}else{r=k;k=n;n=1;s=l;while(1){if(!((k+ -97<<24>>24&255)<26)){if(!((k+ -65<<24>>24&255)<26|k<<24>>24==95|(k+ -48<<24>>24&255)<10)){t=r;u=n;v=s;break}}l=n+1|0;a[d+n>>0]=k;w=s+1|0;x=a[w>>0]|0;if(x<<24>>24!=0&l>>>0<256){y=s;k=x;n=l;s=w;r=y}else{t=s;u=l;v=w;break}}if(u>>>0>255){m=1;i=j;return m|0}else{o=t;p=u;q=v}}a[d+p>>0]=0;p=a[q>>0]|0;if(p<<24>>24==46){c[b>>2]=o+2;m=0;i=j;return m|0}else if(p<<24>>24==0){c[b>>2]=q;m=0;i=j;return m|0}else if(p<<24>>24==91){p=o+2|0;q=a[p>>0]|0;if(q<<24>>24==45){c[h>>2]=1;z=o+3|0}else if(q<<24>>24==43){c[g>>2]=1;z=o+3|0}else{if(!((q+ -48<<24>>24&255)<10)){m=1;i=j;return m|0}o=c[e>>2]|0;g=q;q=p;while(1){p=(g<<24>>24)+ -48+(o*10|0)|0;c[e>>2]=p;h=q+1|0;d=a[h>>0]|0;if((d+ -48<<24>>24&255)<10){o=p;g=d;q=h}else{z=h;break}}}if((a[z>>0]|0)!=93){m=1;i=j;return m|0}q=z+1|0;c[b>>2]=(a[q>>0]|0)==46?z+2|0:q;c[f>>2]=0;m=0;i=j;return m|0}else{m=1;i=j;return m|0}return 0}function Nx(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;f=i;i=i+288|0;g=f+16|0;h=f+12|0;j=f+8|0;k=f+4|0;l=f;m=f+24|0;c[g>>2]=d;if((b|0)==0){n=0;i=f;return n|0}o=(e|0)==0;p=(e|0)!=0;e=b;b=d;d=1;a:while(1){if((a[b>>0]|0)==0){n=0;q=85;break}if((Mx(g,m,l,h,j,k)|0)!=0){n=0;q=85;break}r=(c[j>>2]|0)==0;if((a[c[g>>2]>>0]|0)==0){q=6;break}b:do{if(r){if((c[k>>2]|0)!=0){s=e+12|0;t=c[s>>2]|0;if((t|0)==0){u=0}else{v=0;w=t;while(1){t=(Fz(c[w+8>>2]|0,m)|0)==0;x=t?w:v;t=c[w>>2]|0;if((t|0)==0){u=x;break}else{v=x;w=t}}}if(!(p&(u|0)==0)){y=u;break}w=yz(28)|0;if((w|0)==0){n=0;q=85;break a}c[w>>2]=0;v=w+4|0;c[v>>2]=0;c[w+8>>2]=xz(m)|0;t=w+12|0;c[t+0>>2]=0;c[t+4>>2]=0;c[t+8>>2]=0;c[t+12>>2]=0;if((e|0)==0){y=w;break}c[v>>2]=e;if((c[s>>2]|0)==0){c[s>>2]=w;z=e+16|0}else{v=e+16|0;c[c[v>>2]>>2]=w;z=v}c[z>>2]=w;y=w;break}w=c[l>>2]|0;v=e+12|0;t=c[v>>2]|0;if((t|0)==0){A=w}else{x=w;w=t;while(1){if((Fz(c[w+8>>2]|0,m)|0)==0){if((x|0)==0){y=w;break b}B=x+ -1|0}else{B=x}t=c[w>>2]|0;if((t|0)==0){A=B;break}else{x=B;w=t}}}if(o){n=0;q=85;break a}w=(A|0)==0;x=yz(28)|0;if((x|0)==0){C=0}else{c[x>>2]=0;s=x+4|0;c[s>>2]=0;c[x+8>>2]=xz(m)|0;t=x+12|0;c[t+0>>2]=0;c[t+4>>2]=0;c[t+8>>2]=0;c[t+12>>2]=0;if((e|0)==0){C=x}else{c[s>>2]=e;if((c[v>>2]|0)==0){c[v>>2]=x;D=e+16|0}else{s=e+16|0;c[c[s>>2]>>2]=x;D=s}c[D>>2]=x;C=x}}if(w){y=C}else{w=e+16|0;if((e|0)==0){x=A;s=C;while(1){t=x+ -1|0;if((s|0)==0){n=0;q=85;break a}E=yz(28)|0;if((E|0)==0){F=0}else{c[E>>2]=0;c[E+4>>2]=0;c[E+8>>2]=xz(m)|0;G=E+12|0;c[G+0>>2]=0;c[G+4>>2]=0;c[G+8>>2]=0;c[G+12>>2]=0;F=E}if((t|0)==0){y=F;break b}else{x=t;s=F}}}else{H=A;I=C}while(1){s=H+ -1|0;if((I|0)==0){n=0;q=85;break a}x=(s|0)==0;t=yz(28)|0;if((t|0)==0){J=0}else{c[t>>2]=0;E=t+4|0;c[E>>2]=0;c[t+8>>2]=xz(m)|0;G=t+12|0;c[G+0>>2]=0;c[G+4>>2]=0;c[G+8>>2]=0;c[G+12>>2]=0;c[E>>2]=e;if((c[v>>2]|0)==0){c[v>>2]=t}else{c[c[w>>2]>>2]=t}c[w>>2]=t;J=t}if(x){y=J;break}else{H=s;I=J}}}}else{w=yz(28)|0;if((w|0)==0){n=0;q=85;break a}c[w>>2]=0;v=w+4|0;c[v>>2]=0;c[w+8>>2]=xz(m)|0;s=w+12|0;c[s+0>>2]=0;c[s+4>>2]=0;c[s+8>>2]=0;c[s+12>>2]=0;if((e|0)==0){y=w}else{c[v>>2]=e;v=e+12|0;if((c[v>>2]|0)==0){c[v>>2]=w;K=e+16|0}else{v=e+16|0;c[c[v>>2]>>2]=w;K=v}c[K>>2]=w;y=w}}}while(0);if((y|0)==0){n=0;q=85;break}e=y;b=c[g>>2]|0;d=0}if((q|0)==6){do{if(r){if(!((d|0)==0|o)){if((c[h>>2]|0)!=0){break}}if((c[k>>2]|0)!=0){g=e+20|0;b=c[g>>2]|0;if((b|0)==0){L=0}else{y=0;K=b;while(1){b=(Fz(c[K+4>>2]|0,m)|0)==0;J=b?K:y;b=c[K>>2]|0;if((b|0)==0){L=J;break}else{y=J;K=b}}}if(!(p&(L|0)==0)){n=L;i=f;return n|0}K=Zx(m)|0;if((K|0)==0){n=0;i=f;return n|0}if((e|0)==0){n=K;i=f;return n|0}if((c[g>>2]|0)==0){c[g>>2]=K;M=e+24|0}else{y=e+24|0;c[c[y>>2]>>2]=K;M=y}c[M>>2]=K;n=K;i=f;return n|0}K=c[l>>2]|0;y=e+20|0;b=c[y>>2]|0;c:do{if((b|0)==0){N=K}else{J=K;I=b;while(1){if((Fz(c[I+4>>2]|0,m)|0)==0){if((J|0)==0){n=I;break}O=J+ -1|0}else{O=J}H=c[I>>2]|0;if((H|0)==0){N=O;break c}else{J=O;I=H}}i=f;return n|0}}while(0);if(o){n=0;i=f;return n|0}b=e+24|0;if((e|0)==0){K=N;while(1){g=Zx(m)|0;if((K|0)==0){n=g;q=85;break}if((g|0)==0){n=0;q=85;break}else{K=K+ -1|0}}if((q|0)==85){i=f;return n|0}}else{P=N}while(1){K=(P|0)==0;g=Zx(m)|0;if((g|0)==0){Q=0}else{if((c[y>>2]|0)==0){c[y>>2]=g}else{c[c[b>>2]>>2]=g}c[b>>2]=g;Q=g}if(K){n=Q;q=85;break}if((Q|0)==0){n=0;q=85;break}else{P=P+ -1|0}}if((q|0)==85){i=f;return n|0}}}while(0);P=Zx(m)|0;if((P|0)==0){n=0;i=f;return n|0}if((e|0)==0){n=P;i=f;return n|0}m=e+20|0;if((c[m>>2]|0)==0){c[m>>2]=P;R=e+24|0}else{m=e+24|0;c[c[m>>2]>>2]=P;R=m}c[R>>2]=P;n=P;i=f;return n|0}else if((q|0)==85){i=f;return n|0}return 0}function Ox(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;c[d>>2]=e;e=Nx(a,b,0)|0;if((e|0)==0){g=1;i=f;return g|0}g=(cy(e,d)|0)!=0|0;i=f;return g|0}function Px(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;c[d>>2]=e;e=Nx(a,b,0)|0;if((e|0)==0){g=1;i=f;return g|0}g=(dy(e,d)|0)!=0|0;i=f;return g|0}function Qx(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;c[d>>2]=e;e=Nx(a,b,0)|0;if((e|0)==0){g=1;i=f;return g|0}g=(ey(e,d)|0)!=0|0;i=f;return g|0}function Rx(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;c[d>>2]=(e|0)!=0;e=Nx(a,b,0)|0;if((e|0)==0){g=1;i=f;return g|0}g=(fy(e,d)|0)!=0|0;i=f;return g|0}function Sx(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;c[d>>2]=e;e=Nx(a,b,0)|0;if((e|0)==0){g=1}else{b=gy(e)|0;if((b|0)==0){g=0}else{c[d>>2]=b;g=0}}i=f;return g|0}function Tx(a){a=a|0;c[a>>2]=0;c[a+4>>2]=0;c[a+8>>2]=0;return}function Ux(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;h=(d|0)!=0;if(h){j=Kz(d|0)|0}else{j=0}k=(e|0)!=0;if(k){l=Kz(e|0)|0}else{l=0}m=(f|0)!=0;if(m){n=Kz(f|0)|0}else{n=0}o=j+1+l+n+(c[b>>2]|0)|0;p=b+4|0;q=c[p>>2]|0;do{if(!(o>>>0<q>>>0)){r=(q|0)==0?256:q;while(1){if(o>>>0<r>>>0){break}else{r=r<<1}}s=b+8|0;t=Az(c[s>>2]|0,r)|0;if((t|0)==0){u=1;i=g;return u|0}else{c[p>>2]=r;c[s>>2]=t;break}}}while(0);if(h){Mz((c[b+8>>2]|0)+(c[b>>2]|0)|0,d|0,j|0)|0}if(k){Mz((c[b+8>>2]|0)+((c[b>>2]|0)+j)|0,e|0,l|0)|0}if(m){m=b+8|0;e=l+j|0;Mz((c[m>>2]|0)+(e+(c[b>>2]|0))|0,f|0,n|0)|0;v=m;w=e}else{v=b+8|0;w=l+j|0}j=w+n+(c[b>>2]|0)|0;c[b>>2]=j;a[(c[v>>2]|0)+j>>0]=0;u=0;i=g;return u|0}function Vx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=a+8|0;a=ox(b,c[f>>2]|0)|0;if((d|0)==0){i=e;return a|0}zz(c[f>>2]|0);i=e;return a|0}function Wx(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;c[a>>2]=0;e=a+4|0;c[e>>2]=0;c[a+8>>2]=0;if((b|0)==0){i=d;return}c[e>>2]=xz(b)|0;i=d;return}function Xx(a){a=a|0;var b=0,d=0;b=i;if((a|0)==0){i=b;return}d=a+8|0;if((c[d>>2]|0)==2){zz(c[a+12>>2]|0)}c[d>>2]=0;zz(c[a+4>>2]|0);i=b;return}function Yx(a){a=a|0;var b=0,d=0;b=i;d=a+8|0;if((c[d>>2]|0)==2){zz(c[a+12>>2]|0)}c[d>>2]=0;i=b;return}function Zx(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=yz(16)|0;if((d|0)==0){e=0}else{c[d>>2]=0;f=d+4|0;c[f>>2]=0;c[d+8>>2]=0;if((a|0)==0){e=d}else{c[f>>2]=xz(a)|0;e=d}}i=b;return e|0}function _x(a){a=a|0;var b=0,d=0,e=0;b=i;if((a|0)==0){i=b;return}else{d=a}do{a=d;d=c[d>>2]|0;e=a+8|0;if((c[e>>2]|0)==2){zz(c[a+12>>2]|0)}c[e>>2]=0;zz(c[a+4>>2]|0);zz(a)}while((d|0)!=0);i=b;return}function $x(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=c[b+8>>2]|0;if((e|0)==2){f=c[b+12>>2]|0;g=a+8|0;h=a+12|0;if((c[g>>2]|0)==2){zz(c[h>>2]|0)}c[g>>2]=2;c[h>>2]=xz(f)|0;i=d;return}else if((e|0)==1){e=c[b+12>>2]|0;b=a+8|0;f=a+12|0;if((c[b>>2]|0)==2){zz(c[f>>2]|0)}c[b>>2]=1;c[f>>2]=e;i=d;return}else{e=a+8|0;if((c[e>>2]|0)==2){zz(c[a+12>>2]|0)}c[e>>2]=0;i=d;return}}function ay(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a+8|0;f=a+12|0;if((c[e>>2]|0)==2){zz(c[f>>2]|0)}c[e>>2]=1;c[f>>2]=b;i=d;return}function by(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a+8|0;f=a+12|0;if((c[e>>2]|0)==2){zz(c[f>>2]|0)}c[e>>2]=2;c[f>>2]=xz(b)|0;i=d;return}function cy(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;if((c[a+8>>2]|0)!=1){e=1;i=d;return e|0}c[b>>2]=c[a+12>>2];e=0;i=d;return e|0}function dy(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;if((c[a+8>>2]|0)!=1){e=1;i=d;return e|0}c[b>>2]=c[a+12>>2]&65535;e=0;i=d;return e|0}function ey(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;if((c[a+8>>2]|0)!=1){e=1;i=d;return e|0}f=c[a+12>>2]|0;if((f|0)<0){g=0-(0-f&2147483647)|0}else{g=f}if((g+32767|0)>>>0>65534){e=1;i=d;return e|0}c[b>>2]=g;e=0;i=d;return e|0}function fy(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;if((c[a+8>>2]|0)!=1){e=1;i=d;return e|0}c[b>>2]=(c[a+12>>2]|0)!=0;e=0;i=d;return e|0}function gy(a){a=a|0;var b=0;if((c[a+8>>2]|0)==2){b=c[a+12>>2]|0}else{b=0}return b|0}function hy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+16|0;f=e;do{if((iy(a,b,d)|0)==0){if((Gx(a,58648)|0)==0){g=1}else{Wx(f,0);if((c[d+8>>2]|0)==1){if((c[d+12>>2]|0)==0){h=5}else{j=d;k=f}}else{h=5}if((h|0)==5){j=f;k=d}if((iy(a,b,j)|0)!=0){Xx(f);g=0;break}if((Gx(a,58656)|0)==0){Xx(f);g=0;break}else{l=(iy(a,b,k)|0)==0;Xx(f);g=l;break}}}else{g=0}}while(0);i=e;return g&1^1|0}function iy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+16|0;f=e;if((jy(a,b,d)|0)!=0){g=1;i=e;return g|0}if((Gx(a,58664)|0)==0){g=0;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;d=f+12|0;while(1){Wx(f,0);if((jy(a,b,f)|0)!=0){l=5;break}m=c[h>>2]|0;if(!((m|0)==(c[j>>2]|0)&(m|0)==1)){l=7;break}if((c[k>>2]|0)==0){n=(c[d>>2]|0)!=0}else{n=1}c[k>>2]=n&1;Xx(f);if((Gx(a,58664)|0)==0){g=0;l=11;break}}if((l|0)==5){Xx(f);g=1;i=e;return g|0}else if((l|0)==7){Xx(f);g=1;i=e;return g|0}else if((l|0)==11){i=e;return g|0}return 0}function jy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+16|0;f=e;if((ky(a,b,d)|0)!=0){g=1;i=e;return g|0}if((Gx(a,58672)|0)==0){g=0;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;d=f+12|0;while(1){Wx(f,0);if((ky(a,b,f)|0)!=0){l=5;break}m=c[h>>2]|0;if(!((m|0)==(c[j>>2]|0)&(m|0)==1)){l=7;break}if((c[k>>2]|0)==0){n=0}else{n=(c[d>>2]|0)!=0}c[k>>2]=n&1;Xx(f);if((Gx(a,58672)|0)==0){g=0;l=11;break}}if((l|0)==5){Xx(f);g=1;i=e;return g|0}else if((l|0)==7){Xx(f);g=1;i=e;return g|0}else if((l|0)==11){i=e;return g|0}return 0}function ky(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+16|0;f=e;a:do{if((ly(a,b,d)|0)==0){if((Ex(a,58664)|0)==0){g=d+8|0;h=f+8|0;j=d+12|0;k=f+12|0;while(1){if((Gx(a,58680)|0)==0){l=0;break a}Wx(f,0);if((ly(a,b,f)|0)!=0){m=6;break}n=c[g>>2]|0;if(!((n|0)==(c[h>>2]|0)&(n|0)==1)){m=8;break}c[j>>2]=c[k>>2]|c[j>>2];Xx(f);if((Ex(a,58664)|0)!=0){l=0;break a}}if((m|0)==6){Xx(f);l=1;break}else if((m|0)==8){Xx(f);l=1;break}}else{l=0}}else{l=1}}while(0);i=e;return l|0}function ly(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+16|0;f=e;a:do{if((my(a,b,d)|0)==0){if((Ex(a,58688)|0)==0){g=d+8|0;h=f+8|0;j=d+12|0;k=f+12|0;while(1){if((Gx(a,58696)|0)==0){l=0;break a}Wx(f,0);if((my(a,b,f)|0)!=0){m=6;break}n=c[g>>2]|0;if(!((n|0)==(c[h>>2]|0)&(n|0)==1)){m=8;break}c[j>>2]=c[k>>2]^c[j>>2];Xx(f);if((Ex(a,58688)|0)!=0){l=0;break a}}if((m|0)==6){Xx(f);l=1;break}else if((m|0)==8){Xx(f);l=1;break}}else{l=0}}else{l=1}}while(0);i=e;return l|0}function my(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+16|0;f=e;a:do{if((ny(a,b,d)|0)==0){if((Ex(a,58672)|0)==0){g=d+8|0;h=f+8|0;j=d+12|0;k=f+12|0;while(1){if((Gx(a,58704)|0)==0){l=0;break a}Wx(f,0);if((ny(a,b,f)|0)!=0){m=6;break}n=c[g>>2]|0;if(!((n|0)==(c[h>>2]|0)&(n|0)==1)){m=8;break}c[j>>2]=c[k>>2]&c[j>>2];Xx(f);if((Ex(a,58672)|0)!=0){l=0;break a}}if((m|0)==6){Xx(f);l=1;break}else if((m|0)==8){Xx(f);l=1;break}}else{l=0}}else{l=1}}while(0);i=e;return l|0}function ny(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+16|0;f=e;if((oy(a,b,d)|0)!=0){g=1;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;l=f+12|0;m=d+12|0;n=f+12|0;a:while(1){if((Gx(a,58712)|0)==0){if((Gx(a,58720)|0)==0){g=0;o=18;break}else{p=2}}else{p=1}Wx(f,0);if((oy(a,b,f)|0)!=0){o=6;break}do{if((p|0)==1){q=c[h>>2]|0;if((q|0)!=(c[j>>2]|0)){o=16;break a}if((q|0)==1){c[k>>2]=(c[k>>2]|0)==(c[l>>2]|0);break}else if((q|0)==2){ay(d,(Fz(c[m>>2]|0,c[n>>2]|0)|0)==0|0);break}else{o=16;break a}}else if((p|0)==2){q=c[h>>2]|0;if((q|0)!=(c[j>>2]|0)){o=16;break a}if((q|0)==2){ay(d,(Fz(c[m>>2]|0,c[n>>2]|0)|0)!=0|0);break}else if((q|0)==1){c[k>>2]=(c[k>>2]|0)!=(c[l>>2]|0);break}else{o=16;break a}}else{o=16;break a}}while(0);Xx(f)}if((o|0)==6){Xx(f);g=1;i=e;return g|0}else if((o|0)==16){Xx(f);g=1;i=e;return g|0}else if((o|0)==18){i=e;return g|0}return 0}function oy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=i;i=i+16|0;f=e;if((py(a,b,d)|0)!=0){g=1;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;l=f+12|0;m=d+12|0;n=f+12|0;a:while(1){if((Gx(a,58728)|0)==0){if((Gx(a,58736)|0)==0){if((Gx(a,58744)|0)==0){if((Gx(a,58752)|0)==0){g=0;o=28;break}else{p=3}}else{p=1}}else{p=4}}else{p=2}Wx(f,0);if((py(a,b,f)|0)!=0){o=8;break}do{if((p|0)==1){q=c[h>>2]|0;if((q|0)!=(c[j>>2]|0)){o=26;break a}if((q|0)==2){ay(d,(Fz(c[m>>2]|0,c[n>>2]|0)|0)>>>31);break}else if((q|0)==1){c[k>>2]=(c[k>>2]|0)>>>0<(c[l>>2]|0)>>>0;break}else{o=26;break a}}else if((p|0)==4){q=c[h>>2]|0;if((q|0)!=(c[j>>2]|0)){o=26;break a}if((q|0)==2){ay(d,(Fz(c[m>>2]|0,c[n>>2]|0)|0)>>>31^1);break}else if((q|0)==1){c[k>>2]=(c[k>>2]|0)>>>0>=(c[l>>2]|0)>>>0;break}else{o=26;break a}}else if((p|0)==3){q=c[h>>2]|0;if((q|0)!=(c[j>>2]|0)){o=26;break a}if((q|0)==1){c[k>>2]=(c[k>>2]|0)>>>0>(c[l>>2]|0)>>>0;break}else if((q|0)==2){ay(d,(Fz(c[m>>2]|0,c[n>>2]|0)|0)>0|0);break}else{o=26;break a}}else if((p|0)==2){q=c[h>>2]|0;if((q|0)!=(c[j>>2]|0)){o=26;break a}if((q|0)==2){ay(d,(Fz(c[m>>2]|0,c[n>>2]|0)|0)<1|0);break}else if((q|0)==1){c[k>>2]=(c[k>>2]|0)>>>0<=(c[l>>2]|0)>>>0;break}else{o=26;break a}}else{o=26;break a}}while(0);Xx(f)}if((o|0)==8){Xx(f);g=1;i=e;return g|0}else if((o|0)==26){Xx(f);g=1;i=e;return g|0}else if((o|0)==28){i=e;return g|0}return 0}function py(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;i=i+16|0;f=e;if((qy(a,b,d)|0)!=0){g=1;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;d=f+12|0;while(1){if((Gx(a,58760)|0)==0){if((Gx(a,58768)|0)==0){g=0;l=14;break}else{m=2}}else{m=1}Wx(f,0);if((qy(a,b,f)|0)!=0){l=6;break}if((m|0)==1){n=c[h>>2]|0;if(!((n|0)==(c[j>>2]|0)&(n|0)==1)){l=12;break}o=c[k>>2]<<(c[d>>2]&31)}else if((m|0)==2){n=c[h>>2]|0;if(!((n|0)==(c[j>>2]|0)&(n|0)==1)){l=12;break}o=(c[k>>2]|0)>>>(c[d>>2]&31)}else{l=12;break}c[k>>2]=o;Xx(f)}if((l|0)==6){Xx(f);g=1;i=e;return g|0}else if((l|0)==12){Xx(f);g=1;i=e;return g|0}else if((l|0)==14){i=e;return g|0}return 0}function qy(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=i;i=i+64|0;g=f;h=f+24|0;j=f+8|0;if((ry(b,d,e)|0)!=0){k=1;i=f;return k|0}l=e+8|0;m=j+8|0;n=e+12|0;o=j+12|0;p=e+12|0;q=j+12|0;while(1){if((Gx(b,58776)|0)==0){if((Gx(b,58784)|0)==0){k=0;r=38;break}else{s=2}}else{s=1}Wx(j,0);if((ry(b,d,j)|0)!=0){r=6;break}if((s|0)==2){t=c[l>>2]|0;if(!((t|0)==(c[m>>2]|0)&(t|0)==1)){r=33;break}c[n>>2]=(c[n>>2]|0)-(c[o>>2]|0);Xx(j);continue}else if((s|0)!=1){r=33;break}t=c[l>>2]|0;u=c[m>>2]|0;v=(t|0)==1;w=(u|0)==1;if(v&w){c[n>>2]=(c[o>>2]|0)+(c[n>>2]|0);Xx(j);continue}x=(t|0)==2;t=(u|0)==2;if(x&t){u=c[p>>2]|0;y=c[q>>2]|0;z=Kz(u|0)|0;A=Kz(y|0)|0;B=A+z|0;C=yz(B+1|0)|0;if((C|0)==0){r=36;break}if((z|0)!=0){Mz(C|0,u|0,z|0)|0}if((A|0)!=0){Mz(C+z|0,y|0,A|0)|0}a[C+B>>0]=0;by(e,C);zz(C);Xx(j);continue}if(x&w){c[g>>2]=c[o>>2];ab(h|0,58792,g|0)|0;w=c[p>>2]|0;x=Kz(w|0)|0;C=Kz(h|0)|0;B=C+x|0;A=yz(B+1|0)|0;if((A|0)==0){r=37;break}if((x|0)!=0){Mz(A|0,w|0,x|0)|0}if((C|0)!=0){Mz(A+x|0,h|0,C|0)|0}a[A+B>>0]=0;by(e,A);zz(A);Xx(j);continue}if(!(v&t)){r=35;break}c[g>>2]=c[n>>2];ab(h|0,58792,g|0)|0;t=c[q>>2]|0;v=Kz(h|0)|0;A=Kz(t|0)|0;B=A+v|0;C=yz(B+1|0)|0;if((C|0)==0){r=34;break}if((v|0)!=0){Mz(C|0,h|0,v|0)|0}if((A|0)!=0){Mz(C+v|0,t|0,A|0)|0}a[C+B>>0]=0;by(e,C);zz(C);Xx(j)}if((r|0)==6){Xx(j);k=1;i=f;return k|0}else if((r|0)==33){Xx(j);k=1;i=f;return k|0}else if((r|0)==34){Xx(j);k=1;i=f;return k|0}else if((r|0)==35){Xx(j);k=1;i=f;return k|0}else if((r|0)==36){Xx(j);k=1;i=f;return k|0}else if((r|0)==37){Xx(j);k=1;i=f;return k|0}else if((r|0)==38){i=f;return k|0}return 0}function ry(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+16|0;f=e;if((sy(a,b,d)|0)!=0){g=1;i=e;return g|0}h=d+8|0;j=f+8|0;k=d+12|0;d=f+12|0;while(1){if((Gx(a,58800)|0)==0){if((Gx(a,58808)|0)==0){if((Gx(a,58816)|0)==0){g=0;l=19;break}else{m=3}}else{m=2}}else{m=1}Wx(f,0);if((sy(a,b,f)|0)!=0){l=7;break}if((m|0)==2){n=c[h>>2]|0;if(!((n|0)==(c[j>>2]|0)&(n|0)==1)){l=17;break}n=c[d>>2]|0;if((n|0)==0){l=17;break}c[k>>2]=((c[k>>2]|0)>>>0)/(n>>>0)|0}else if((m|0)==1){n=c[h>>2]|0;if(!((n|0)==(c[j>>2]|0)&(n|0)==1)){l=17;break}c[k>>2]=ca(c[d>>2]|0,c[k>>2]|0)|0}else if((m|0)==3){n=c[h>>2]|0;if(!((n|0)==(c[j>>2]|0)&(n|0)==1)){l=17;break}n=c[d>>2]|0;if((n|0)==0){l=17;break}c[k>>2]=((c[k>>2]|0)>>>0)%(n>>>0)|0}else{l=17;break}Xx(f)}if((l|0)==7){Xx(f);g=1;i=e;return g|0}else if((l|0)==17){Xx(f);g=1;i=e;return g|0}else if((l|0)==19){i=e;return g|0}return 0}function sy(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;if((Gx(b,58776)|0)==0){if((Gx(b,58784)|0)==0){if((Gx(b,58824)|0)==0){g=(Gx(b,58832)|0)==0;h=g?0:4}else{h=3}}else{h=2}}else{h=1}do{if((ty(b,d,e)|0)==0){if((h|0)==4){g=c[e+8>>2]|0;if((g|0)==1){j=e+12|0;c[j>>2]=(c[j>>2]|0)==0;k=0;break}else if((g|0)==2){ay(e,(a[c[e+12>>2]>>0]|0)==0|0);k=0;break}else{k=1;break}}else if((h|0)==2){if((c[e+8>>2]|0)!=1){k=1;break}g=e+12|0;c[g>>2]=0-(c[g>>2]|0);k=0;break}else if((h|0)==1){k=(c[e+8>>2]|0)!=1|0;break}else if((h|0)==3){if((c[e+8>>2]|0)!=1){k=1;break}g=e+12|0;c[g>>2]=~c[g>>2];k=0;break}else{k=0;break}}else{k=1}}while(0);i=f;return k|0}function ty(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+256|0;g=f;if((Gx(b,58840)|0)!=0){if((hy(b,d,e)|0)!=0){h=1;i=f;return h|0}Bx(b)|0;h=(Gx(b,58848)|0)==0|0;i=f;return h|0}if((Dx(b,g,256)|0)!=0){by(e,g);h=0;i=f;return h|0}if((Cx(b,g,256)|0)!=0){if((Fz(g,58856)|0)==0){if((ty(b,d,e)|0)!=0){h=1;i=f;return h|0}ay(e,(c[e+8>>2]|0)!=0|0);h=0;i=f;return h|0}if((Fz(g,58864)|0)==0){ay(e,1);h=0;i=f;return h|0}if((Fz(g,58872)|0)==0){ay(e,0);h=0;i=f;return h|0}a:do{if((d|0)!=0){j=g+((a[g>>0]|0)==36)|0;k=d;while(1){l=Nx(k,j,0)|0;if((l|0)!=0){break}k=c[k+4>>2]|0;if((k|0)==0){break a}}$x(e,l);h=0;i=f;return h|0}}while(0);Yx(e);h=0;i=f;return h|0}if((Gx(b,58880)|0)==0){l=(Gx(b,58888)|0)==0;m=l?10:2}else{m=16}l=yx(b,0)|0;if(l<<24>>24==0){h=1;i=f;return h|0}d=l;g=l<<24>>24;l=1;k=0;b:while(1){do{if((d+ -48<<24>>24&255)<10){n=g+ -48|0}else{if((d+ -97<<24>>24&255)<6){n=g+ -87|0;break}if(!((d+ -65<<24>>24&255)<6)){o=32;break b}n=g+ -55|0}}while(0);if(!(n>>>0<m>>>0)){o=32;break}j=n+(ca(k,m)|0)|0;Ax(b,1);p=yx(b,0)|0;if(p<<24>>24==0){q=j;break}else{d=p;g=p<<24>>24;l=0;k=j}}c:do{if((o|0)==32){if((l|0)!=0){h=1;i=f;return h|0}switch(d<<24>>24){case 75:case 107:{Ax(b,1);q=k<<10;break c;break};case 77:case 109:{Ax(b,1);q=k<<20;break c;break};case 71:case 103:{Ax(b,1);q=k<<30;break c;break};default:{q=k;break c}}}}while(0);ay(e,q);h=0;i=f;return h|0}function uy(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;i=i+32|0;e=d;f=yz(104)|0;if((f|0)==0){g=0;i=d;return g|0}h=f+0|0;j=a+0|0;k=h+68|0;do{c[h>>2]=c[j>>2];h=h+4|0;j=j+4|0}while((h|0)<(k|0));Tq(f,5);c[f+4>>2]=252;c[f+8>>2]=30;c[f+12>>2]=31;c[f+16>>2]=32;c[f+20>>2]=47;c[f+60>>2]=0;c[f+64>>2]=f;c[f+68>>2]=a;a=f+28|0;j=((c[a>>2]|0)+7|0)>>>3;h=f+100|0;c[h>>2]=j;k=yz(j)|0;j=f+96|0;c[j>>2]=k;if((k|0)==0){zz(f);g=0;i=d;return g|0}k=Ib(b|0,58896)|0;l=f+72|0;c[l>>2]=k;do{if((k|0)==0){m=Ib(b|0,58904)|0;c[l>>2]=m;if((m|0)==0){n=16}else{m=((c[a>>2]|0)+7|0)>>>3;c[h>>2]=m;o=f+80|0;p=o;c[p>>2]=20;c[p+4>>2]=0;p=f+88|0;q=p;c[q>>2]=m+531&1073741312;c[q+4>>2]=0;Gq(e,0,1129273120);Gq(e,4,0);Gq(e,8,c[a>>2]|0);Gq(e,12,c[o>>2]|0);Gq(e,16,c[p>>2]|0);if((Mq(c[l>>2]|0,e,0,0,20,0)|0)==0){Oz(c[j>>2]|0,0,c[h>>2]|0)|0;p=o;if((Mq(c[l>>2]|0,c[j>>2]|0,c[p>>2]|0,c[p+4>>2]|0,c[h>>2]|0,0)|0)==0){Nb(c[l>>2]|0)|0;n=17;break}}zb(c[l>>2]|0)|0;n=16}}else{if((Lq(k,e,0,0,20,0)|0)==0){if((Fq(e,0)|0)==1129273120){if((Fq(e,4)|0)==0){p=Fq(e,8)|0;if((p|0)==(c[a>>2]|0)){p=f+80|0;o=p;c[o>>2]=Fq(e,12)|0;c[o+4>>2]=0;o=f+88|0;c[o>>2]=Fq(e,16)|0;c[o+4>>2]=0;o=p;if((Lq(c[l>>2]|0,c[j>>2]|0,c[o>>2]|0,c[o+4>>2]|0,c[h>>2]|0,0)|0)==0){n=17;break}}}}}zb(c[l>>2]|0)|0;n=16}}while(0);if((n|0)==16){zz(c[j>>2]|0);zz(f);g=0;i=d;return g|0}else if((n|0)==17){Wq(f,b);g=f;i=d;return g|0}return 0}function vy(a){a=a|0;var b=0,d=0;b=i;d=c[a+64>>2]|0;Qq(c[d+68>>2]|0);zb(c[d+72>>2]|0)|0;zz(c[d+96>>2]|0);zz(d);i=b;return}function wy(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;h=i;j=c[b+64>>2]|0;k=b+28|0;b=j+68|0;l=j+72|0;if((g|0)==0){m=0;i=h;return m|0}n=Nz(f|0,0,9)|0;o=j+88|0;p=Jz(c[o>>2]|0,c[o+4>>2]|0,n|0,G|0)|0;n=j+96|0;j=g;g=f;f=p;p=G;o=e;while(1){if(!(g>>>0<(c[k>>2]|0)>>>0)){m=1;q=20;break}e=c[n>>2]|0;r=g>>>3;s=128>>>(g&7);t=((d[e+r>>0]|0)&s|0)!=0;a:do{if(j>>>0<2){u=1}else{v=j+ -1|0;if((v|0)==0){u=1}else{w=t?255:0;x=1;y=r;z=s&255;A=v;while(1){b:do{if(z<<24>>24==1){v=y+1|0;if(A>>>0>7){B=x;C=v;D=A;while(1){if((d[e+C>>0]|0|0)!=(w|0)){E=B;F=C;H=-128;I=D;break b}J=D+ -8|0;K=B+8|0;L=C+1|0;if(J>>>0>7){B=K;C=L;D=J}else{M=K;N=L;O=J;break}}}else{M=x;N=v;O=A}if((O|0)==0){u=M;break a}else{E=M;F=N;H=-128;I=O}}else{E=x;F=y;H=(z&255)>>>1;I=A}}while(0);if((a[e+F>>0]&H)<<24>>24!=0^t){u=E;break a}D=E+1|0;C=I+ -1|0;if((C|0)==0){u=D;break}else{x=D;y=F;z=H;A=C}}}}}while(0);if(t){e=u<<9;if((Lq(c[l>>2]|0,o,f,p,e,0)|0)==0){P=e;Q=e;R=0}else{m=1;q=20;break}}else{if((br(c[b>>2]|0,o,g,u)|0)!=0){m=1;q=20;break}e=u<<9;P=e;Q=e;R=0}e=Jz(Q|0,R|0,f|0,p|0)|0;if((j|0)==(u|0)){m=0;q=20;break}else{j=j-u|0;g=u+g|0;f=e;p=G;o=o+P|0}}if((q|0)==20){i=h;return m|0}return 0}function xy(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;h=i;if((a[b+56>>0]|0)!=0){j=1;i=h;return j|0}k=c[b+64>>2]|0;a:do{if((g|0)==0){l=k+72|0}else{m=Nz(f|0,0,9)|0;n=k+88|0;o=Jz(c[n>>2]|0,c[n+4>>2]|0,m|0,G|0)|0;m=b+28|0;n=k+96|0;p=k+72|0;q=k+80|0;r=g;s=f;t=o;o=G;u=e;while(1){if(!(s>>>0<(c[m>>2]|0)>>>0)){j=1;v=26;break}w=c[n>>2]|0;x=s>>>3;y=128>>>(s&7);z=w+x|0;A=d[z>>0]|0;B=(A&y|0)!=0;b:do{if(r>>>0<2){C=1}else{D=r+ -1|0;if((D|0)==0){C=1}else{E=B?255:0;F=1;H=x;I=y&255;J=D;while(1){c:do{if(I<<24>>24==1){D=H+1|0;if(J>>>0>7){K=F;L=D;M=J;while(1){if((d[w+L>>0]|0)!=(E|0)){N=K;O=L;P=-128;Q=M;break c}R=M+ -8|0;S=K+8|0;T=L+1|0;if(R>>>0>7){K=S;L=T;M=R}else{U=S;V=T;W=R;break}}}else{U=F;V=D;W=J}if((W|0)==0){C=U;break b}else{N=U;O=V;P=-128;Q=W}}else{N=F;O=H;P=(I&255)>>>1;Q=J}}while(0);if((a[w+O>>0]&P)<<24>>24!=0^B){C=N;break b}M=N+1|0;L=Q+ -1|0;if((L|0)==0){C=M;break}else{F=M;H=O;I=P;J=L}}}}}while(0);if(!B){w=s+ -1+C|0;J=w>>>3;I=128>>>(w&7);w=y+255|y;H=I+255^255|I;if((x|0)==(J|0)){a[z>>0]=A|H&w}else{a[z>>0]=A|w;w=(c[n>>2]|0)+J|0;a[w>>0]=d[w>>0]|H;H=x+1|0;if(H>>>0<J>>>0){w=H;do{a[(c[n>>2]|0)+w>>0]=-1;w=w+1|0}while(w>>>0<J>>>0)}}w=c[p>>2]|0;A=(c[n>>2]|0)+x|0;z=q;y=Jz(c[z>>2]|0,c[z+4>>2]|0,x|0,0)|0;Mq(w,A,y,G,1-x+J|0,0)|0}y=C<<9;if((Mq(c[p>>2]|0,u,t,o,y,0)|0)!=0){j=1;v=26;break}A=Jz(y|0,0,t|0,o|0)|0;if((r|0)==(C|0)){l=p;break a}else{r=r-C|0;s=C+s|0;t=A;o=G;u=u+y|0}}if((v|0)==26){i=h;return j|0}}}while(0);Nb(c[l>>2]|0)|0;j=0;i=h;return j|0}function yy(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 1}function zy(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;f=i;i=i+4096|0;g=f;if((Fz(e,58912)|0)!=0){h=1;i=f;return h|0}e=c[b+64>>2]|0;b=e+100|0;j=c[b>>2]|0;do{if((j|0)==0){k=e+72|0;l=0}else{m=e+96|0;n=e+68|0;o=e+88|0;p=e+72|0;q=j;r=0;s=0;t=0;while(1){u=a[(c[m>>2]|0)+r>>0]|0;if(u<<24>>24==0){v=q;w=s;x=t}else{y=r<<3;z=u;u=s;A=t;while(1){B=z&255;if((B&128|0)==0){C=B;B=y;while(1){D=C<<1;B=B+1|0;if((D&128|0)!=0){break}else{C=D&254}}E=B;F=D&255}else{E=y;F=z}C=F&255;a:do{if((C&128|0)==0){H=1;I=0;J=F}else{K=C;L=0;while(1){L=L+1|0;M=K<<1;if((M&128|0)==0){break}else{K=M&254}}K=M&255;if((L|0)==0){H=1;I=0;J=K}else{N=Nz(E|0,0,9)|0;O=o;P=Jz(c[O>>2]|0,c[O+4>>2]|0,N|0,G|0)|0;N=L;O=E;Q=P;P=G;while(1){R=N>>>0>8?8:N;S=R<<9;if((Lq(c[p>>2]|0,g,Q,P,S,0)|0)!=0){H=0;I=L;J=K;break a}if((cr(c[n>>2]|0,g,O,R)|0)!=0){H=0;I=L;J=K;break a}Oz(g|0,0,S|0)|0;if((Mq(c[p>>2]|0,g,Q,P,S,0)|0)!=0){H=0;I=L;J=K;break a}if((R|0)!=0){T=N>>>0<8?N:8;U=0;do{V=U+O|0;W=(c[m>>2]|0)+(V>>>3)|0;a[W>>0]=(128>>>(V&7)^255)&(d[W>>0]|0);U=U+1|0}while((U|0)!=(T|0))}T=Jz(S|0,0,Q|0,P|0)|0;if((N|0)==(R|0)){H=1;I=L;J=K;break}else{N=N-R|0;O=R+O|0;Q=T;P=G}}}}}while(0);A=H?A:1;u=(H?I:0)+u|0;if(J<<24>>24==0){break}else{y=I+E|0;z=J}}v=c[b>>2]|0;w=u;x=A}r=r+1|0;if(!(r>>>0<v>>>0)){break}else{q=v;s=w;t=x}}if((w|0)==0){k=p;l=x}else{t=e+80|0;if((Mq(c[p>>2]|0,c[m>>2]|0,c[t>>2]|0,c[t+4>>2]|0,v,0)|0)==0){Nb(c[p>>2]|0)|0;k=p;l=x;break}else{h=1;i=f;return h|0}}}}while(0);Nb(c[k>>2]|0)|0;h=l;i=f;return h|0}function Ay(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0;j=i;if((h|0)==0){k=Ib(b|0,58928)|0}else{k=Ib(b|0,58920)|0}if((k|0)==0){l=1;i=j;return l|0}b=c[a+64>>2]|0;a=b+68|0;m=c[a>>2]|0;n=b+72|0;c[n+(m<<5)>>2]=f;c[n+(m<<5)+4>>2]=g;g=n+(m<<5)+8|0;c[g>>2]=d;c[g+4>>2]=e;c[n+(m<<5)+16>>2]=k;c[n+(m<<5)+20>>2]=1;c[n+(m<<5)+24>>2]=(h|0)!=0;c[a>>2]=m+1;l=0;i=j;return l|0}function By(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=yz(584)|0;if((g|0)==0){h=0;i=f;return h|0}Pq(g,g,0,a,b,d);Vq(g,e);c[g+4>>2]=253;c[g+8>>2]=33;c[g+12>>2]=34;c[g+68>>2]=0;h=g;i=f;return h|0}function Cy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=c[a+64>>2]|0;a=d+68|0;e=c[a>>2]|0;if((e|0)==0){zz(d);i=b;return}f=d+72|0;g=e;e=0;while(1){if((c[f+(e<<5)+20>>2]|0)==0){h=g}else{zb(c[f+(e<<5)+16>>2]|0)|0;h=c[a>>2]|0}e=e+1|0;if(!(e>>>0<h>>>0)){break}else{g=h}}zz(d);i=b;return}function Dy(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){g=1;i=f;return g|0}if((e|0)==0){g=0;i=f;return g|0}h=a+64|0;a=c[h>>2]|0;j=a+72|0;k=b;b=d;d=e;e=a;while(1){a=c[e+68>>2]|0;if((a|0)==0){l=11;break}m=e+72|0;n=0;o=0;while(1){p=c[m+(o<<5)>>2]|0;if(p>>>0>b>>>0){q=p>>>0<(c[m+(n<<5)>>2]|0)>>>0?o:n}else{if((b-p|0)>>>0<(c[m+(o<<5)+4>>2]|0)>>>0){r=o;break}else{q=n}}p=o+1|0;if(p>>>0<a>>>0){n=q;o=p}else{l=10;break}}if((l|0)==10){l=0;if((c[m+(q<<5)>>2]|0)>>>0>b>>>0){r=q}else{l=11;break}}o=c[j+(r<<5)>>2]|0;if(o>>>0>b>>>0){n=o-b|0;a=n>>>0>d>>>0?d:n;n=a<<9;Oz(k|0,-2,n|0)|0;s=n;t=a}else{a=b-o|0;o=(c[j+(r<<5)+4>>2]|0)-a|0;n=o>>>0>d>>>0?d:o;o=j+(r<<5)+8|0;p=c[o>>2]|0;u=c[o+4>>2]|0;o=Nz(a|0,0,9)|0;a=Jz(p|0,u|0,o|0,G|0)|0;o=G;u=Nz(n|0,0,9)|0;if((Lq(c[j+(r<<5)+16>>2]|0,k,a,o,u,G)|0)==0){s=u;t=n}else{g=1;l=17;break}}if((d|0)==(t|0)){g=0;l=17;break}k=k+s|0;b=t+b|0;d=d-t|0;e=c[h>>2]|0}if((l|0)==11){Oz(k|0,-2,d<<9|0)|0;g=0;i=f;return g|0}else if((l|0)==17){i=f;return g|0}return 0}function Ey(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){g=1;i=f;return g|0}h=a+64|0;a=c[h>>2]|0;j=a+72|0;if((e|0)==0){g=0;i=f;return g|0}else{k=b;l=d;m=e;n=a}while(1){a=c[n+68>>2]|0;if((a|0)==0){g=0;o=17;break}e=n+72|0;d=0;b=0;while(1){p=c[e+(b<<5)>>2]|0;if(p>>>0>l>>>0){q=p>>>0<(c[e+(d<<5)>>2]|0)>>>0?b:d}else{if((l-p|0)>>>0<(c[e+(b<<5)+4>>2]|0)>>>0){r=b;break}else{q=d}}p=b+1|0;if(p>>>0<a>>>0){d=q;b=p}else{o=9;break}}if((o|0)==9){o=0;if((c[e+(q<<5)>>2]|0)>>>0>l>>>0){r=q}else{g=0;o=17;break}}b=c[j+(r<<5)>>2]|0;if(b>>>0>l>>>0){d=b-l|0;a=d>>>0>m>>>0?m:d;s=a<<9;t=a}else{if((c[j+(r<<5)+24>>2]|0)!=0){g=1;o=17;break}a=l-b|0;b=(c[j+(r<<5)+4>>2]|0)-a|0;d=b>>>0>m>>>0?m:b;b=j+(r<<5)+8|0;p=c[b>>2]|0;u=c[b+4>>2]|0;b=Nz(a|0,0,9)|0;a=Jz(p|0,u|0,b|0,G|0)|0;b=G;u=Nz(d|0,0,9)|0;p=j+(r<<5)+16|0;if((Mq(c[p>>2]|0,k,a,b,u,G)|0)!=0){g=1;o=17;break}Nb(c[p>>2]|0)|0;s=u;t=d}if((m|0)==(t|0)){g=0;o=17;break}k=k+s|0;l=t+l|0;m=m-t|0;n=c[h>>2]|0}if((o|0)==17){i=f;return g|0}return 0}function Fy(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;j=yz(72)|0;if((j|0)==0){k=0;i=h;return k|0}Pq(j,j,b,d,e,f);Tq(j,2);Vq(j,g);c[j+4>>2]=254;c[j+8>>2]=35;c[j+12>>2]=36;g=j+28|0;f=c[g>>2]<<9;e=yz(f)|0;d=j+68|0;c[d>>2]=e;if((e|0)==0){zz(j);k=0;i=h;return k|0}Oz(e|0,0,f|0)|0;if((a|0)==0){k=j;i=h;return k|0}f=Ib(a|0,58936)|0;if((f|0)!=0){e=c[d>>2]|0;b=Nz(c[g>>2]|0,0,9)|0;g=Lq(f,e,0,0,b,G)|0;zb(f|0)|0;if((g|0)==0){Wq(j,a);k=j;i=h;return k|0}}zz(c[d>>2]|0);zz(j);k=0;i=h;return k|0}function Gy(a){a=a|0;var b=0,d=0;b=i;d=c[a+64>>2]|0;zz(c[d+68>>2]|0);zz(d);i=b;return}function Hy(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){g=1;i=f;return g|0}Mz(b|0,(c[(c[a+64>>2]|0)+68>>2]|0)+(d<<9)|0,e<<9|0)|0;g=0;i=f;return g|0}function Iy(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;if((a[b+56>>0]|0)!=0){h=1;i=g;return h|0}if((f+e|0)>>>0>(c[b+28>>2]|0)>>>0){h=1;i=g;return h|0}Mz((c[(c[b+64>>2]|0)+68>>2]|0)+(e<<9)|0,d|0,f<<9|0)|0;h=0;i=g;return h|0}function Jy(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=60120;e=58944;while(1){if((Ez(d,a)|0)==0){break}f=c[e+12>>2]|0;if((f|0)==0){g=0;h=5;break}else{d=f;e=e+8|0}}if((h|0)==5){i=b;return g|0}g=c[e>>2]|0;i=b;return g|0}function Ky(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=60120;e=58944;while(1){if((c[e>>2]|0)==(a|0)){f=d;g=4;break}h=c[e+12>>2]|0;if((h|0)==0){f=0;g=4;break}else{d=h;e=e+8|0}}if((g|0)==4){i=b;return f|0}return 0}function Ly(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+32|0;g=f;h=b;while(1){b=a[h>>0]|0;if(!(b<<24>>24==9|b<<24>>24==32)){j=h;k=b;l=0;break}h=h+1|0}while(1){if(k<<24>>24==32|k<<24>>24==61|k<<24>>24==0){break}h=j+1|0;b=l+1|0;a[g+l>>0]=k;if(!(b>>>0<32)){m=1;n=17;break}j=h;k=a[h>>0]|0;l=b}if((n|0)==17){i=f;return m|0}if(l>>>0>31){m=1;i=f;return m|0}a[g+l>>0]=0;l=j;while(1){j=a[l>>0]|0;if(j<<24>>24==61){o=l;n=11;break}else if(!(j<<24>>24==32)){p=l;break}l=l+1|0}if((n|0)==11){while(1){n=0;l=o+1|0;if((a[l>>0]|0)==32){o=l;n=11}else{p=l;break}}}c[d>>2]=Hb(g|0,0,0)|0;g=60120;d=58944;while(1){if((Ez(g,p)|0)==0){n=15;break}o=c[d+12>>2]|0;if((o|0)==0){q=0;break}else{g=o;d=d+8|0}}if((n|0)==15){q=c[d>>2]|0}c[e>>2]=q;m=0;i=f;return m|0}function My(a){a=a|0;var b=0,d=0;a=i;b=yz(152)|0;if((b|0)==0){d=0;i=a;return d|0}Ty(b,b);c[b+28>>2]=255;c[b+32>>2]=48;c[b+36>>2]=9;c[b+40>>2]=49;c[b+44>>2]=256;c[b+48>>2]=257;d=b;i=a;return d|0}function Ny(a){a=a|0;var b=0;b=i;if((a|0)!=0){zz(a)}i=b;return}function Oy(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function Py(a){a=a|0;return 0}function Qy(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Ry(a){a=a|0;return}function Sy(a){a=a|0;return}function Ty(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;c[a>>2]=b;b=a+4|0;e=a+40|0;f=a+56|0;c[b+0>>2]=0;c[b+4>>2]=0;c[b+8>>2]=0;c[b+12>>2]=0;c[b+16>>2]=0;c[b+20>>2]=0;c[b+24>>2]=0;c[e+0>>2]=0;c[e+4>>2]=0;c[e+8>>2]=0;c[e+12>>2]=0;c[f>>2]=1;f=a+60|0;e=a+80|0;c[f+0>>2]=0;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=0;c[f+16>>2]=0;c[e>>2]=1;c[a+84>>2]=4;c[a+88>>2]=3;c[a+92>>2]=320;c[a+96>>2]=240;c[a+100>>2]=1;c[a+104>>2]=1;c[a+108>>2]=0;c[a+112>>2]=1;c[a+116>>2]=1;e=a+120|0;c[e+0>>2]=0;c[e+4>>2]=0;c[e+8>>2]=0;c[e+12>>2]=0;c[e+16>>2]=0;c[e+20>>2]=0;c[e+24>>2]=0;c[e+28>>2]=0;i=d;return}function Uy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=a+52|0;do{if((c[f>>2]|0)==0){g=c[a+32>>2]|0;if((g|0)!=0){if((gc[g&63](c[a>>2]|0,b,d)|0)!=0){h=1;break}}c[f>>2]=1;h=0}else{h=0}}while(0);i=e;return h|0}function Vy(a,b,d){a=a|0;b=b|0;d=d|0;c[a+4>>2]=b;c[a+8>>2]=d;return}function Wy(a,b,d){a=a|0;b=b|0;d=d|0;c[a+12>>2]=b;c[a+16>>2]=d;return}function Xy(a,b,d){a=a|0;b=b|0;d=d|0;c[a+20>>2]=b;c[a+24>>2]=d;return}function Yy(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;i=i+272|0;f=e;g=e+16|0;if((d|0)==0){h=3}else{if((a[d>>0]|0)==0){h=3}else{j=d}}if((h|0)==3){h=b+148|0;c[f>>2]=c[h>>2];ab(g|0,61504,f|0)|0;c[h>>2]=(c[h>>2]|0)+1;j=g}g=Ib(j|0,61520)|0;if((g|0)==0){k=1;i=e;return k|0}j=c[b+64>>2]|0;h=c[b+68>>2]|0;d=ca(j*3|0,h)|0;c[f>>2]=j;c[f+4>>2]=h;c[f+8>>2]=255;hb(g|0,61528,f|0)|0;f=fb(c[b+76>>2]|0,1,d|0,g|0)|0;zb(g|0)|0;k=(f|0)!=(d|0)|0;i=e;return k|0}function Zy(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;do{if((Fz(b,61544)|0)==0){f=Jy(d)|0;if((f|0)==0){g=0}else{c[a+56>>2]=f;g=0}}else{if((Fz(b,61560)|0)==0){Yy(a,d)|0;g=0;break}f=c[a+40>>2]|0;if((f|0)==0){g=-1}else{g=gc[f&63](c[a>>2]|0,b,d)|0}}}while(0);i=e;return g|0}function _y(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=Jy(b)|0;if((e|0)==0){f=1}else{c[a+56>>2]=e;f=0}i=d;return f|0}function $y(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;c[a+100>>2]=b;c[a+104>>2]=d;c[a+108>>2]=0;c[a+112>>2]=e;c[a+116>>2]=f;c[a+120>>2]=0;return}function az(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;if((b|0)==0|(d|0)==0){zz(c[a+76>>2]|0);f=a+64|0;c[f+0>>2]=0;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=0;i=e;return}f=a+64|0;if((c[f>>2]|0)==(b|0)){if((c[a+68>>2]|0)==(d|0)){i=e;return}}g=ca(b*3|0,d)|0;h=a+72|0;do{if((c[h>>2]|0)!=(g|0)){j=a+76|0;k=Az(c[j>>2]|0,g)|0;if((k|0)==0){i=e;return}else{c[j>>2]=k;c[h>>2]=g;break}}}while(0);c[f>>2]=b;c[a+68>>2]=d;c[a+132>>2]=0;c[a+136>>2]=0;c[a+140>>2]=b;c[a+144>>2]=d;i=e;return}function bz(a,b,d){a=a|0;b=b|0;d=d|0;c[a+92>>2]=b;c[a+96>>2]=d;return}function cz(a,b){a=a|0;b=b|0;c[a+80>>2]=(b|0)==0?1:b;c[a+132>>2]=0;c[a+136>>2]=0;c[a+140>>2]=c[a+64>>2];c[a+144>>2]=c[a+68>>2];return}function dz(a,b,d){a=a|0;b=b|0;d=d|0;c[a+84>>2]=b;c[a+88>>2]=d;return}function ez(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;g=a+64|0;h=(c[g>>2]|0)*3|0;j=(c[a+76>>2]|0)+(ca(h,d)|0)|0;if((e|0)==0){i=f;return}else{k=e;l=d;m=j;n=b}while(1){if((Dz(m,n,h)|0)!=0){break}b=k+ -1|0;if((b|0)==0){o=14;break}else{k=b;l=l+1|0;m=m+h|0;n=n+h|0}}if((o|0)==14){i=f;return}if((k|0)==0){i=f;return}b=k;j=ca(k,h)|0;while(1){k=j-h|0;d=b+ -1|0;if((Dz(m+k|0,n+k|0,h)|0)!=0){break}if((d|0)==0){o=14;break}else{b=d;j=k}}if((o|0)==14){i=f;return}Mz(m|0,n|0,ca(b,h)|0)|0;c[a+132>>2]=0;c[a+140>>2]=c[g>>2];g=a+144|0;h=c[g>>2]|0;n=a+136|0;if((h|0)==0){c[n>>2]=l;c[g>>2]=b;i=f;return}a=c[n>>2]|0;if(l>>>0<a>>>0){m=h-l+a|0;c[g>>2]=m;c[n>>2]=l;p=m;q=l}else{p=h;q=a}a=b+l|0;if(!(a>>>0>(p+q|0)>>>0)){i=f;return}c[g>>2]=a-q;i=f;return}function fz(a){a=a|0;var b=0,d=0;b=i;if((c[a+140>>2]|0)==0){i=b;return}if((c[a+144>>2]|0)==0){i=b;return}d=c[a+44>>2]|0;if((d|0)!=0){ic[d&511](c[a>>2]|0)}d=a+132|0;c[d+0>>2]=0;c[d+4>>2]=0;c[d+8>>2]=0;c[d+12>>2]=0;i=b;return}function gz(a){a=a|0;var b=0,d=0;b=i;d=c[a+48>>2]|0;if((d|0)==0){i=b;return}ic[d&511](c[a>>2]|0);i=b;return}function hz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=c[a+8>>2]|0;if((f|0)==0){g=1;i=e;return g|0}g=gc[f&63](c[a+4>>2]|0,b,d)|0;i=e;return g|0}function iz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;do{if((b|0)==1){f=(c[a+56>>2]|0)==(d|0);g=a+60|0;h=c[g>>2]|0;if(f){j=h^1;c[g>>2]=j;k=j}else{k=h}h=a+60|0;if((k&1|0)!=0){if(f){i=e;return}jz(a,3,d);i=e;return}if((d|0)==75){f=k|4;c[h>>2]=f;l=f}else if((d|0)==71){f=k|8;c[h>>2]=f;l=f}else if((d|0)==16){if((k&12|0)==0){f=a+40|0;j=c[f>>2]|0;if((j|0)!=0){gc[j&63](c[a>>2]|0,61576,61592)|0;j=c[f>>2]|0;if((j|0)!=0){gc[j&63](c[a>>2]|0,61600,61616)|0}}j=c[a+8>>2]|0;if((j|0)==0){i=e;return}gc[j&63](c[a+4>>2]|0,61624,61640)|0;i=e;return}else{l=k}}else{l=k}if((l&12|0)==12){j=c[a+40>>2]|0;if((j|0)==0){m=l}else{gc[j&63](c[a>>2]|0,61576,61592)|0;m=c[h>>2]|0}c[h>>2]=m&-13}}else if((b|0)==2){h=a+60|0;j=c[h>>2]|0;if((j&1|0)==0){if((d|0)==71){c[h>>2]=j&-9;break}else if((d|0)==75){c[h>>2]=j&-5;break}else if((d|0)==16){i=e;return}else{break}}else{if((c[a+56>>2]|0)==(d|0)){i=e;return}c[h>>2]=j&-2;i=e;return}}}while(0);jz(a,b,d);i=e;return}function jz(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;a:do{if((b|0)==3){do{switch(d|0){case 50:{f=c[a+40>>2]|0;if((f|0)==0){i=e;return}gc[f&63](c[a>>2]|0,61744,61592)|0;i=e;return};case 47:{Yy(a,0)|0;i=e;return};case 32:{f=a+40|0;g=c[f>>2]|0;if((g|0)!=0){gc[g&63](c[a>>2]|0,61576,61592)|0;g=c[f>>2]|0;if((g|0)!=0){gc[g&63](c[a>>2]|0,61600,61616)|0}}g=c[a+8>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a+4>>2]|0,61624,61640)|0;i=e;return};case 41:{g=c[a+8>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a+4>>2]|0,61776,61592)|0;i=e;return};case 21:{g=c[a+8>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a+4>>2]|0,61648,61680)|0;i=e;return};case 22:{g=c[a+8>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a+4>>2]|0,61648,61688)|0;i=e;return};case 20:{g=c[a+8>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a+4>>2]|0,61648,61672)|0;i=e;return};case 35:{g=c[a+8>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a+4>>2]|0,61800,61640)|0;i=e;return};case 23:{g=c[a+8>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a+4>>2]|0,61648,61696)|0;i=e;return};case 24:{g=c[a+8>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a+4>>2]|0,61648,61704)|0;i=e;return};case 27:{g=c[a+8>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a+4>>2]|0,61648,61616)|0;i=e;return};case 94:case 107:{g=a+80|0;f=c[g>>2]|0;if(!(f>>>0>1)){i=e;return}h=f+ -1|0;c[g>>2]=(h|0)==0?1:h;c[a+132>>2]=0;c[a+136>>2]=0;c[a+140>>2]=c[a+64>>2];c[a+144>>2]=c[a+68>>2];i=e;return};case 87:case 105:{h=a+80|0;g=(c[h>>2]|0)+1|0;c[h>>2]=(g|0)==0?1:g;c[a+132>>2]=0;c[a+136>>2]=0;c[a+140>>2]=c[a+64>>2];c[a+144>>2]=c[a+68>>2];i=e;return};case 18:{g=c[a+8>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a+4>>2]|0,61648,61640)|0;i=e;return};case 19:{g=c[a+8>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a+4>>2]|0,61648,61664)|0;i=e;return};case 49:{g=c[a+40>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a>>2]|0,61720,61592)|0;i=e;return};case 25:{g=c[a+8>>2]|0;if((g|0)==0){i=e;return}gc[g&63](c[a+4>>2]|0,61648,61712)|0;i=e;return};case 65:{g=a+40|0;h=c[g>>2]|0;if((h|0)!=0){gc[h&63](c[a>>2]|0,61576,61592)|0;h=c[g>>2]|0;if((h|0)!=0){gc[h&63](c[a>>2]|0,61600,61616)|0}}h=c[a+8>>2]|0;if((h|0)==0){i=e;return}gc[h&63](c[a+4>>2]|0,61760,61640)|0;i=e;return};case 90:case 106:{h=c[a+8>>2]|0;if((h|0)==0){i=e;return}gc[h&63](c[a+4>>2]|0,61816,61840)|0;i=e;return};case 92:case 108:{h=c[a+8>>2]|0;if((h|0)==0){i=e;return}gc[h&63](c[a+4>>2]|0,61816,61848)|0;i=e;return};default:{break a}}}while(0)}}while(0);h=c[a+16>>2]|0;if((h|0)==0){i=e;return}lc[h&31](c[a+12>>2]|0,b,d);i=e;return}function kz(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=ca(c[a+100>>2]|0,b)|0;b=a+108|0;h=g+(c[b>>2]|0)|0;g=c[a+104>>2]|0;j=(h|0)/(g|0)|0;c[b>>2]=h-(ca(j,g)|0);g=ca(c[a+112>>2]|0,d)|0;d=a+120|0;h=g+(c[d>>2]|0)|0;g=c[a+116>>2]|0;b=(h|0)/(g|0)|0;c[d>>2]=h-(ca(b,g)|0);g=c[a+24>>2]|0;if((g|0)==0){i=f;return}qc[g&3](c[a+20>>2]|0,j,b,e);i=f;return}function lz(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;h=c[a+92>>2]|0;a:do{if(h>>>0>b>>>0){j=c[a+96>>2]|0;k=1;while(1){l=k+1|0;if(!((ca(k,d)|0)>>>0<j>>>0)){m=k;break a}if((ca(l,b)|0)>>>0<h>>>0){k=l}else{m=l;break}}}else{m=1}}while(0);h=a+80|0;k=m+ -1|0;c[e>>2]=k+(c[h>>2]|0);m=k+(c[h>>2]|0)|0;c[f>>2]=m;h=a+84|0;k=c[h>>2]|0;if((k|0)==0){i=g;return}j=a+88|0;a=c[j>>2]|0;if((a|0)==0){i=g;return}l=ca(c[e>>2]|0,b)|0;n=ca(m,d)|0;o=((ca(n,k)|0)>>>0)/(a>>>0)|0;p=((ca(l,a)|0)>>>0)/(k>>>0)|0;k=n+d|0;if(!(k>>>0>p>>>0)){n=m;m=k;do{n=n+1|0;m=m+d|0}while(!(m>>>0>p>>>0));c[f>>2]=n}n=l+b|0;if(n>>>0>o>>>0){q=n;r=l}else{l=c[e>>2]|0;f=n;while(1){l=l+1|0;s=f+b|0;if(s>>>0>o>>>0){break}else{f=s}}c[e>>2]=l;q=s;r=f}if(!(r>>>0<o>>>0)){i=g;return}f=ca(c[j>>2]|0,q-o|0)|0;if(!(f>>>0<(ca(c[h>>2]|0,o-r|0)|0)>>>0)){i=g;return}c[e>>2]=(c[e>>2]|0)+1;i=g;return}function mz(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;j=i;k=(g|0)==1;if(k&(h|0)==1){l=d;i=j;return l|0}m=ca(g,e)|0;n=ca(ca(f*3|0,m)|0,h)|0;o=b+124|0;p=b+128|0;b=c[p>>2]|0;do{if(n>>>0>(c[o>>2]|0)>>>0){q=Az(b,n)|0;if((q|0)==0){l=0;i=j;return l|0}else{c[p>>2]=q;c[o>>2]=n;r=q;break}}else{if((b|0)==0){l=0;i=j;return l|0}else{r=b}}}while(0);if(k){k=e*3|0;if((f|0)==0){l=r;i=j;return l|0}if(!(h>>>0>1)){b=d;n=r;o=0;while(1){Mz(n|0,b|0,k|0)|0;p=o+1|0;if((p|0)==(f|0)){l=r;break}else{b=b+k|0;n=n+k|0;o=p}}i=j;return l|0}o=ca(k,h)|0;n=d;b=r;p=0;while(1){Mz(b|0,n|0,k|0)|0;q=b;s=1;do{t=q;q=q+k|0;Mz(q|0,t|0,k|0)|0;s=s+1|0}while((s|0)!=(h|0));s=p+1|0;if((s|0)==(f|0)){l=r;break}else{n=n+k|0;b=b+o|0;p=s}}i=j;return l|0}if((g|0)!=2){p=e*3|0;o=ca(p,g)|0;if((f|0)==0){l=r;i=j;return l|0}b=(e|0)==0;k=(g|0)==0;n=h>>>0>1;s=0-o|0;q=ca((h*3|0)+ -3|0,m)|0;t=g*3|0;u=m*3|0;m=d;v=r;w=0;while(1){if(b){x=v;y=m}else{if(k){z=v}else{A=m;B=v;C=0;while(1){D=A+1|0;E=A+2|0;F=B;G=0;while(1){a[F>>0]=a[A>>0]|0;a[F+1>>0]=a[D>>0]|0;a[F+2>>0]=a[E>>0]|0;G=G+1|0;if((G|0)==(g|0)){break}else{F=F+3|0}}C=C+1|0;if((C|0)==(e|0)){break}else{A=A+3|0;B=B+t|0}}z=v+u|0}x=z;y=m+p|0}if(n){B=x;A=1;while(1){Mz(B|0,B+s|0,o|0)|0;A=A+1|0;if((A|0)==(h|0)){break}else{B=B+o|0}}H=x+q|0}else{H=x}B=w+1|0;if((B|0)==(f|0)){l=r;break}else{m=y;v=H;w=B}}i=j;return l|0}w=e*6|0;if((f|0)==0){l=r;i=j;return l|0}H=h>>>0>1;v=0-w|0;if((e|0)==0){if(H){I=0}else{l=r;i=j;return l|0}while(1){y=r;m=1;while(1){Mz(y|0,y+v|0,w|0)|0;m=m+1|0;if((m|0)==(h|0)){break}else{y=y+w|0}}y=I+1|0;if((y|0)==(f|0)){l=r;break}else{I=y}}i=j;return l|0}I=e*3|0;y=ca(w,h)|0;m=d;d=r;x=0;while(1){q=m;o=d;s=0;while(1){a[o>>0]=a[q>>0]|0;n=q+1|0;a[o+1>>0]=a[n>>0]|0;p=q+2|0;a[o+2>>0]=a[p>>0]|0;a[o+3>>0]=a[q>>0]|0;a[o+4>>0]=a[n>>0]|0;a[o+5>>0]=a[p>>0]|0;s=s+1|0;if((s|0)==(e|0)){break}else{q=q+3|0;o=o+6|0}}o=m+I|0;q=d+w|0;if(H){s=q;p=1;while(1){Mz(s|0,s+v|0,w|0)|0;p=p+1|0;if((p|0)==(h|0)){break}else{s=s+w|0}}J=d+y|0}else{J=q}s=x+1|0;if((s|0)==(f|0)){l=r;break}else{m=o;d=J;x=s}}i=j;return l|0}function nz(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+16|0;e=d+12|0;f=d+8|0;g=d+4|0;h=d;j=yz(208)|0;if((j|0)==0){k=0;i=d;return k|0}Ty(j,j);c[j+28>>2]=258;c[j+32>>2]=50;c[j+36>>2]=10;c[j+40>>2]=51;c[j+44>>2]=259;c[j+48>>2]=260;l=j+152|0;c[l+0>>2]=0;c[l+4>>2]=0;c[l+8>>2]=0;c[l+12>>2]=0;Rx(b,61856,g,0)|0;a[j+168>>0]=(c[g>>2]|0)!=0|0;g=j+180|0;Px(b,61872,g,0)|0;l=c[g>>2]|0;c[j+184>>2]=l;c[j+188>>2]=l;c[j+192>>2]=l;a[j+196>>0]=0;c[j+172>>2]=0;c[j+176>>2]=0;Rx(b,61880,h,0)|0;a[j+197>>0]=(c[h>>2]|0)!=0|0;h=j+200|0;c[h>>2]=0;l=j+204|0;g=yz(888)|0;c[l>>2]=g;if((g|0)!=0){m=g;c[m>>2]=27;c[m+4>>2]=1;m=g+8|0;c[m>>2]=1082;c[m+4>>2]=2;m=g;g=2;while(1){n=61904+(g<<3)|0;o=c[n+4>>2]|0;p=m+(g<<3)|0;c[p>>2]=c[n>>2];c[p+4>>2]=o;o=g+1|0;if((o|0)==111){break}m=c[l>>2]|0;g=o}c[h>>2]=111}g=Kx(b,0,61896)|0;if((g|0)==0){k=j;i=d;return k|0}else{q=g}while(1){g=gy(q)|0;a:do{if((g|0)!=0){if((Ly(g,e,f)|0)==0){m=c[e>>2]|0;o=c[f>>2]|0;p=c[h>>2]|0;n=c[l>>2]|0;do{if((p|0)==0){r=8}else{s=0;while(1){t=s+1|0;if((c[n+(s<<3)>>2]|0)==(m|0)){u=14;break}if(t>>>0<p>>>0){s=t}else{u=15;break}}if((u|0)==14){u=0;c[n+(s<<3)+4>>2]=o;break a}else if((u|0)==15){u=0;r=(p<<3)+8|0;break}}}while(0);p=Az(n,r)|0;if((p|0)!=0){t=c[h>>2]|0;c[p+(t<<3)>>2]=m;c[p+(t<<3)+4>>2]=o;c[l>>2]=p;c[h>>2]=t+1}}}}while(0);g=Kx(b,q,61896)|0;if((g|0)==0){k=j;break}else{q=g}}i=d;return k|0}function oz(a){a=a|0;var b=0;b=i;zz(a);i=b;return}function pz(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f+4|0;h=f;j=(b|0)==0|(e|0)==0;k=j?480:e;e=j?640:b;lz(a,e,k,g,h);b=(c[a+188>>2]|0)+(c[a+180>>2]|0)|0;j=(c[a+192>>2]|0)+(c[a+184>>2]|0)|0;if((Oa(32)|0)==0){if((Ha(32)|0)<0){l=1;i=f;return l|0}}c[a+172>>2]=d[(c[(Ob()|0)+8>>2]|0)+9>>0]|0;c[a+176>>2]=0;Na(63032,63032);ec(500,30)|0;Vb(1024,1)|0;m=b+(ca(c[g>>2]|0,e)|0)|0;uz(a,m,j+(ca(c[h>>2]|0,k)|0)|0)|0;l=0;i=f;return l|0}function qz(b){b=b|0;var d=0,e=0;d=i;a[b+196>>0]=0;lb(1)|0;ub(0)|0;e=b+152|0;b=c[e>>2]|0;if((b|0)==0){i=d;return 0}Ca(b|0);c[e>>2]=0;i=d;return 0}function rz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=(e|0)==0?62888:e;if((Fz(d,62896)|0)==0){a[b+196>>0]=1;lb(0)|0;ub(1)|0;h=0;i=f;return h|0}if((Fz(d,62912)|0)==0){a[b+196>>0]=0;lb(1)|0;ub(0)|0;h=0;i=f;return h|0}if((Fz(d,62928)|0)==0){Na(g|0,g|0);h=0;i=f;return h|0}if((Fz(d,62944)|0)==0){e=Hb(g|0,0,0)|0;c[b+180>>2]=e;c[b+188>>2]=e;sz(b);h=0;i=f;return h|0}if((Fz(d,62968)|0)==0){c[b+184>>2]=Hb(g|0,0,0)|0;c[b+192>>2]=c[b+180>>2];sz(b);h=0;i=f;return h|0}if((Fz(d,62992)|0)==0){e=b+168|0;j=(a[e>>0]|0)==0;k=c[b+152>>2]|0;if((k|0)!=0){cc(k|0)|0}a[e>>0]=j&1;h=0;i=f;return h|0}if((Fz(d,63016)|0)!=0){h=-1;i=f;return h|0}d=(Va(g|0,0,0)|0)!=0;g=b+168|0;if(!(d^(a[g>>0]|0)!=0)){h=0;i=f;return h|0}j=c[b+152>>2]|0;if((j|0)!=0){cc(j|0)|0}a[g>>0]=d&1;h=0;i=f;return h|0}function sz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+32|0;d=b+8|0;e=b+4|0;f=b;g=a+64|0;h=a+68|0;lz(a,c[g>>2]|0,c[h>>2]|0,e,f);j=ca(c[g>>2]|0,c[e>>2]|0)|0;k=ca(c[h>>2]|0,c[f>>2]|0)|0;l=a+180|0;m=a+184|0;if((uz(a,(c[l>>2]|0)+j+(c[a+188>>2]|0)|0,(c[m>>2]|0)+k+(c[a+192>>2]|0)|0)|0)!=0){i=b;return}k=mz(a,c[a+76>>2]|0,c[g>>2]|0,c[h>>2]|0,c[e>>2]|0,c[f>>2]|0)|0;h=c[e>>2]|0;e=ca(c[a+132>>2]|0,h)|0;g=c[f>>2]|0;f=ca(c[a+136>>2]|0,g)|0;n=ca(c[a+140>>2]|0,h)|0;h=Qa(k+(((ca(f,j)|0)+e|0)*3|0)|0,n|0,ca(c[a+144>>2]|0,g)|0,24,j*3|0,255,65280,16711680,0)|0;c[d>>2]=(c[l>>2]|0)+e;c[d+4>>2]=(c[m>>2]|0)+f;if((h|0)==0){i=b;return}f=a+152|0;if((dc(h|0,0,c[f>>2]|0,d|0)|0)!=0){fb(62864,16,1,c[o>>2]|0)|0}Ca(h|0);Fb(c[f>>2]|0)|0;i=b;return}function tz(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+64|0;f=e+48|0;g=e;if((Qb(g|0)|0)==0){i=e;return}h=g+16|0;j=d+200|0;k=c[o>>2]|0;l=d+204|0;m=d+197|0;n=g+20|0;p=d+196|0;q=d+168|0;r=d+152|0;s=d+164|0;t=d+24|0;u=g+28|0;v=g+32|0;w=0;do{a:do{switch(c[g>>2]|0){case 256:{a[p>>0]=0;lb(1)|0;ub(0)|0;hz(d,62800,62816)|0;break};case 1024:{x=c[u>>2]|0;y=c[v>>2]|0;if((a[p>>0]|0)!=0){if((c[t>>2]|0)!=0){z=(yb(0,0)|0)&255;kz(d,x,y,z>>>1&2|z&1)}}break};case 1026:{z=a[h>>0]|0;y=z&255;if((y|0)==0){break a}else if((y|0)==2){A=2}else{A=z<<24>>24==3?1:y+ -1|0}y=c[s>>2]&~(1<<A);c[s>>2]=y;if((a[p>>0]|0)==0){a[p>>0]=1;lb(0)|0;ub(1)|0;break a}if((c[t>>2]|0)!=0){kz(d,0,0,y)}break};case 769:{y=c[h>>2]|0;z=c[j>>2]|0;if((z|0)!=0){x=c[l>>2]|0;B=0;while(1){C=B+1|0;if((c[x+(B<<3)>>2]|0)==(y|0)){break}if(C>>>0<z>>>0){B=C}else{break a}}z=c[x+(B<<3)+4>>2]|0;if(!((y|0)==1094|(z|0)==0)){if((y|0)==1107){iz(d,1,z)}iz(d,2,z)}}break};case 1025:{z=a[h>>0]|0;C=z&255;if((C|0)==0){break a}else if((C|0)==2){D=2}else{D=z<<24>>24==3?1:C+ -1|0}C=c[s>>2]|1<<D;c[s>>2]=C;if((a[p>>0]|0)!=0){if((c[t>>2]|0)!=0){kz(d,0,0,C)}}break};case 768:{C=c[h>>2]|0;if((C|0)==1094){Yy(d,0)|0;break a}else if((C|0)==96){E=5}if((E|0)==5){E=0;if(!((b[n>>1]&64)==0)){a[p>>0]=0;lb(1)|0;ub(0)|0;if((a[q>>0]|0)!=0){z=c[r>>2]|0;if((z|0)!=0){cc(z|0)|0}a[q>>0]=0}hz(d,62824,62816)|0;break a}}z=c[j>>2]|0;b:do{if((z|0)!=0){F=c[l>>2]|0;G=0;while(1){H=G+1|0;if((c[F+(G<<3)>>2]|0)==(C|0)){break}if(H>>>0<z>>>0){G=H}else{break b}}H=c[F+(G<<3)+4>>2]|0;I=(H|0)==0;if((a[m>>0]|0)!=0|I){c[f>>2]=C;hb(k|0,62840,f|0)|0;if(I){break a}}iz(d,1,H);if((C|0)!=1107){break a}iz(d,2,H);break a}}while(0);c[f>>2]=C;hb(k|0,62840,f|0)|0;break};default:{}}}while(0);w=w+1|0}while((Qb(g|0)|0)!=0&w>>>0<8);i=e;return}function uz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=b+152|0;h=c[g>>2]|0;if((h|0)!=0){if((c[b+156>>2]|0)==(d|0)){if((c[b+160>>2]|0)==(e|0)){j=0;i=f;return j|0}}Ca(h|0)}c[g>>2]=0;h=(a[b+168>>0]|0)==0?134217729:142606337;k=c[b+172>>2]|0;if((k|0)==2){l=eb(d|0,e|0,16,h|0)|0;c[g>>2]=l;c[b+176>>2]=2;m=l;n=8}else if((k|0)==4){k=eb(d|0,e|0,32,h|0)|0;c[g>>2]=k;c[b+176>>2]=4;m=k;n=8}else{n=9}if((n|0)==8){if((m|0)==0){n=9}}if((n|0)==9){n=eb(d|0,e|0,16,h|0)|0;c[g>>2]=n;c[b+176>>2]=2;if((n|0)==0){j=1;i=f;return j|0}}c[b+156>>2]=d;c[b+160>>2]=e;j=0;i=f;return j|0}function vz(b,c){b=b|0;c=c|0;var d=0,e=0;d=i;e=wz(b,c)|0;i=d;return((a[e>>0]|0)==(c&255)<<24>>24?e:0)|0}function wz(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=d&255;if((f|0)==0){g=b+(Kz(b|0)|0)|0;i=e;return g|0}a:do{if((b&3|0)==0){h=b}else{j=d&255;k=b;while(1){l=a[k>>0]|0;if(l<<24>>24==0){g=k;m=13;break}n=k+1|0;if(l<<24>>24==j<<24>>24){g=k;m=13;break}if((n&3|0)==0){h=n;break a}else{k=n}}if((m|0)==13){i=e;return g|0}}}while(0);m=ca(f,16843009)|0;f=c[h>>2]|0;b:do{if(((f&-2139062144^-2139062144)&f+ -16843009|0)==0){b=f;k=h;while(1){j=b^m;n=k+4|0;if(((j&-2139062144^-2139062144)&j+ -16843009|0)!=0){o=k;break b}j=c[n>>2]|0;if(((j&-2139062144^-2139062144)&j+ -16843009|0)==0){b=j;k=n}else{o=n;break}}}else{o=h}}while(0);h=d&255;d=o;while(1){o=a[d>>0]|0;if(o<<24>>24==0|o<<24>>24==h<<24>>24){g=d;break}else{d=d+1|0}}i=e;return g|0}function xz(a){a=a|0;var b=0,c=0,d=0,e=0;b=i;c=(Kz(a|0)|0)+1|0;d=yz(c)|0;if((d|0)==0){e=0;i=b;return e|0}Mz(d|0,a|0,c|0)|0;e=d;i=b;return e|0}function yz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Ba=0,Ca=0,Da=0,Ea=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0;b=i;do{if(a>>>0<245){if(a>>>0<11){d=16}else{d=a+11&-8}e=d>>>3;f=c[15760]|0;g=f>>>e;if((g&3|0)!=0){h=(g&1^1)+e|0;j=h<<1;k=63080+(j<<2)|0;l=63080+(j+2<<2)|0;j=c[l>>2]|0;m=j+8|0;n=c[m>>2]|0;do{if((k|0)==(n|0)){c[15760]=f&~(1<<h)}else{if(n>>>0<(c[63056>>2]|0)>>>0){Eb()}o=n+12|0;if((c[o>>2]|0)==(j|0)){c[o>>2]=k;c[l>>2]=n;break}else{Eb()}}}while(0);n=h<<3;c[j+4>>2]=n|3;l=j+(n|4)|0;c[l>>2]=c[l>>2]|1;p=m;i=b;return p|0}if(d>>>0>(c[63048>>2]|0)>>>0){if((g|0)!=0){l=2<<e;n=g<<e&(l|0-l);l=(n&0-n)+ -1|0;n=l>>>12&16;k=l>>>n;l=k>>>5&8;o=k>>>l;k=o>>>2&4;q=o>>>k;o=q>>>1&2;r=q>>>o;q=r>>>1&1;s=(l|n|k|o|q)+(r>>>q)|0;q=s<<1;r=63080+(q<<2)|0;o=63080+(q+2<<2)|0;q=c[o>>2]|0;k=q+8|0;n=c[k>>2]|0;do{if((r|0)==(n|0)){c[15760]=f&~(1<<s)}else{if(n>>>0<(c[63056>>2]|0)>>>0){Eb()}l=n+12|0;if((c[l>>2]|0)==(q|0)){c[l>>2]=r;c[o>>2]=n;break}else{Eb()}}}while(0);n=s<<3;o=n-d|0;c[q+4>>2]=d|3;r=q+d|0;c[q+(d|4)>>2]=o|1;c[q+n>>2]=o;n=c[63048>>2]|0;if((n|0)!=0){f=c[63060>>2]|0;e=n>>>3;n=e<<1;g=63080+(n<<2)|0;m=c[15760]|0;j=1<<e;if((m&j|0)==0){c[15760]=m|j;t=63080+(n+2<<2)|0;u=g}else{j=63080+(n+2<<2)|0;n=c[j>>2]|0;if(n>>>0<(c[63056>>2]|0)>>>0){Eb()}else{t=j;u=n}}c[t>>2]=f;c[u+12>>2]=f;c[f+8>>2]=u;c[f+12>>2]=g}c[63048>>2]=o;c[63060>>2]=r;p=k;i=b;return p|0}r=c[63044>>2]|0;if((r|0)==0){v=d}else{o=(r&0-r)+ -1|0;r=o>>>12&16;g=o>>>r;o=g>>>5&8;f=g>>>o;g=f>>>2&4;n=f>>>g;f=n>>>1&2;j=n>>>f;n=j>>>1&1;m=c[63344+((o|r|g|f|n)+(j>>>n)<<2)>>2]|0;n=(c[m+4>>2]&-8)-d|0;j=m;f=m;while(1){m=c[j+16>>2]|0;if((m|0)==0){g=c[j+20>>2]|0;if((g|0)==0){break}else{w=g}}else{w=m}m=(c[w+4>>2]&-8)-d|0;g=m>>>0<n>>>0;n=g?m:n;j=w;f=g?w:f}j=c[63056>>2]|0;if(f>>>0<j>>>0){Eb()}k=f+d|0;if(!(f>>>0<k>>>0)){Eb()}q=c[f+24>>2]|0;s=c[f+12>>2]|0;do{if((s|0)==(f|0)){g=f+20|0;m=c[g>>2]|0;if((m|0)==0){r=f+16|0;o=c[r>>2]|0;if((o|0)==0){x=0;break}else{y=o;z=r}}else{y=m;z=g}while(1){g=y+20|0;m=c[g>>2]|0;if((m|0)!=0){y=m;z=g;continue}g=y+16|0;m=c[g>>2]|0;if((m|0)==0){break}else{y=m;z=g}}if(z>>>0<j>>>0){Eb()}else{c[z>>2]=0;x=y;break}}else{g=c[f+8>>2]|0;if(g>>>0<j>>>0){Eb()}m=g+12|0;if((c[m>>2]|0)!=(f|0)){Eb()}r=s+8|0;if((c[r>>2]|0)==(f|0)){c[m>>2]=s;c[r>>2]=g;x=s;break}else{Eb()}}}while(0);do{if((q|0)!=0){s=c[f+28>>2]|0;j=63344+(s<<2)|0;if((f|0)==(c[j>>2]|0)){c[j>>2]=x;if((x|0)==0){c[63044>>2]=c[63044>>2]&~(1<<s);break}}else{if(q>>>0<(c[63056>>2]|0)>>>0){Eb()}s=q+16|0;if((c[s>>2]|0)==(f|0)){c[s>>2]=x}else{c[q+20>>2]=x}if((x|0)==0){break}}if(x>>>0<(c[63056>>2]|0)>>>0){Eb()}c[x+24>>2]=q;s=c[f+16>>2]|0;do{if((s|0)!=0){if(s>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[x+16>>2]=s;c[s+24>>2]=x;break}}}while(0);s=c[f+20>>2]|0;if((s|0)!=0){if(s>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[x+20>>2]=s;c[s+24>>2]=x;break}}}}while(0);if(n>>>0<16){q=n+d|0;c[f+4>>2]=q|3;s=f+(q+4)|0;c[s>>2]=c[s>>2]|1}else{c[f+4>>2]=d|3;c[f+(d|4)>>2]=n|1;c[f+(n+d)>>2]=n;s=c[63048>>2]|0;if((s|0)!=0){q=c[63060>>2]|0;j=s>>>3;s=j<<1;g=63080+(s<<2)|0;r=c[15760]|0;m=1<<j;if((r&m|0)==0){c[15760]=r|m;A=63080+(s+2<<2)|0;B=g}else{m=63080+(s+2<<2)|0;s=c[m>>2]|0;if(s>>>0<(c[63056>>2]|0)>>>0){Eb()}else{A=m;B=s}}c[A>>2]=q;c[B+12>>2]=q;c[q+8>>2]=B;c[q+12>>2]=g}c[63048>>2]=n;c[63060>>2]=k}p=f+8|0;i=b;return p|0}}else{v=d}}else{if(a>>>0>4294967231){v=-1}else{g=a+11|0;q=g&-8;s=c[63044>>2]|0;if((s|0)==0){v=q}else{m=0-q|0;r=g>>>8;if((r|0)==0){C=0}else{if(q>>>0>16777215){C=31}else{g=(r+1048320|0)>>>16&8;j=r<<g;r=(j+520192|0)>>>16&4;o=j<<r;j=(o+245760|0)>>>16&2;e=14-(r|g|j)+(o<<j>>>15)|0;C=q>>>(e+7|0)&1|e<<1}}e=c[63344+(C<<2)>>2]|0;a:do{if((e|0)==0){D=m;E=0;F=0}else{if((C|0)==31){G=0}else{G=25-(C>>>1)|0}j=m;o=0;g=q<<G;r=e;h=0;while(1){l=c[r+4>>2]&-8;H=l-q|0;if(H>>>0<j>>>0){if((l|0)==(q|0)){D=H;E=r;F=r;break a}else{I=H;J=r}}else{I=j;J=h}H=c[r+20>>2]|0;l=c[r+(g>>>31<<2)+16>>2]|0;K=(H|0)==0|(H|0)==(l|0)?o:H;if((l|0)==0){D=I;E=K;F=J;break}else{j=I;o=K;g=g<<1;r=l;h=J}}}}while(0);if((E|0)==0&(F|0)==0){e=2<<C;m=s&(e|0-e);if((m|0)==0){v=q;break}e=(m&0-m)+ -1|0;m=e>>>12&16;f=e>>>m;e=f>>>5&8;k=f>>>e;f=k>>>2&4;n=k>>>f;k=n>>>1&2;h=n>>>k;n=h>>>1&1;L=c[63344+((e|m|f|k|n)+(h>>>n)<<2)>>2]|0}else{L=E}if((L|0)==0){M=D;N=F}else{n=D;h=L;k=F;while(1){f=(c[h+4>>2]&-8)-q|0;m=f>>>0<n>>>0;e=m?f:n;f=m?h:k;m=c[h+16>>2]|0;if((m|0)!=0){n=e;h=m;k=f;continue}m=c[h+20>>2]|0;if((m|0)==0){M=e;N=f;break}else{n=e;h=m;k=f}}}if((N|0)==0){v=q}else{if(M>>>0<((c[63048>>2]|0)-q|0)>>>0){k=c[63056>>2]|0;if(N>>>0<k>>>0){Eb()}h=N+q|0;if(!(N>>>0<h>>>0)){Eb()}n=c[N+24>>2]|0;s=c[N+12>>2]|0;do{if((s|0)==(N|0)){f=N+20|0;m=c[f>>2]|0;if((m|0)==0){e=N+16|0;r=c[e>>2]|0;if((r|0)==0){O=0;break}else{P=r;Q=e}}else{P=m;Q=f}while(1){f=P+20|0;m=c[f>>2]|0;if((m|0)!=0){P=m;Q=f;continue}f=P+16|0;m=c[f>>2]|0;if((m|0)==0){break}else{P=m;Q=f}}if(Q>>>0<k>>>0){Eb()}else{c[Q>>2]=0;O=P;break}}else{f=c[N+8>>2]|0;if(f>>>0<k>>>0){Eb()}m=f+12|0;if((c[m>>2]|0)!=(N|0)){Eb()}e=s+8|0;if((c[e>>2]|0)==(N|0)){c[m>>2]=s;c[e>>2]=f;O=s;break}else{Eb()}}}while(0);do{if((n|0)!=0){s=c[N+28>>2]|0;k=63344+(s<<2)|0;if((N|0)==(c[k>>2]|0)){c[k>>2]=O;if((O|0)==0){c[63044>>2]=c[63044>>2]&~(1<<s);break}}else{if(n>>>0<(c[63056>>2]|0)>>>0){Eb()}s=n+16|0;if((c[s>>2]|0)==(N|0)){c[s>>2]=O}else{c[n+20>>2]=O}if((O|0)==0){break}}if(O>>>0<(c[63056>>2]|0)>>>0){Eb()}c[O+24>>2]=n;s=c[N+16>>2]|0;do{if((s|0)!=0){if(s>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[O+16>>2]=s;c[s+24>>2]=O;break}}}while(0);s=c[N+20>>2]|0;if((s|0)!=0){if(s>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[O+20>>2]=s;c[s+24>>2]=O;break}}}}while(0);b:do{if(M>>>0<16){n=M+q|0;c[N+4>>2]=n|3;s=N+(n+4)|0;c[s>>2]=c[s>>2]|1}else{c[N+4>>2]=q|3;c[N+(q|4)>>2]=M|1;c[N+(M+q)>>2]=M;s=M>>>3;if(M>>>0<256){n=s<<1;k=63080+(n<<2)|0;f=c[15760]|0;e=1<<s;if((f&e|0)==0){c[15760]=f|e;R=63080+(n+2<<2)|0;S=k}else{e=63080+(n+2<<2)|0;n=c[e>>2]|0;if(n>>>0<(c[63056>>2]|0)>>>0){Eb()}else{R=e;S=n}}c[R>>2]=h;c[S+12>>2]=h;c[N+(q+8)>>2]=S;c[N+(q+12)>>2]=k;break}k=M>>>8;if((k|0)==0){T=0}else{if(M>>>0>16777215){T=31}else{n=(k+1048320|0)>>>16&8;e=k<<n;k=(e+520192|0)>>>16&4;f=e<<k;e=(f+245760|0)>>>16&2;s=14-(k|n|e)+(f<<e>>>15)|0;T=M>>>(s+7|0)&1|s<<1}}s=63344+(T<<2)|0;c[N+(q+28)>>2]=T;c[N+(q+20)>>2]=0;c[N+(q+16)>>2]=0;e=c[63044>>2]|0;f=1<<T;if((e&f|0)==0){c[63044>>2]=e|f;c[s>>2]=h;c[N+(q+24)>>2]=s;c[N+(q+12)>>2]=h;c[N+(q+8)>>2]=h;break}f=c[s>>2]|0;if((T|0)==31){U=0}else{U=25-(T>>>1)|0}c:do{if((c[f+4>>2]&-8|0)==(M|0)){V=f}else{s=M<<U;e=f;while(1){W=e+(s>>>31<<2)+16|0;n=c[W>>2]|0;if((n|0)==0){break}if((c[n+4>>2]&-8|0)==(M|0)){V=n;break c}else{s=s<<1;e=n}}if(W>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[W>>2]=h;c[N+(q+24)>>2]=e;c[N+(q+12)>>2]=h;c[N+(q+8)>>2]=h;break b}}}while(0);f=V+8|0;s=c[f>>2]|0;n=c[63056>>2]|0;if(V>>>0<n>>>0){Eb()}if(s>>>0<n>>>0){Eb()}else{c[s+12>>2]=h;c[f>>2]=h;c[N+(q+8)>>2]=s;c[N+(q+12)>>2]=V;c[N+(q+24)>>2]=0;break}}}while(0);p=N+8|0;i=b;return p|0}else{v=q}}}}}}while(0);N=c[63048>>2]|0;if(!(v>>>0>N>>>0)){V=N-v|0;W=c[63060>>2]|0;if(V>>>0>15){c[63060>>2]=W+v;c[63048>>2]=V;c[W+(v+4)>>2]=V|1;c[W+N>>2]=V;c[W+4>>2]=v|3}else{c[63048>>2]=0;c[63060>>2]=0;c[W+4>>2]=N|3;V=W+(N+4)|0;c[V>>2]=c[V>>2]|1}p=W+8|0;i=b;return p|0}W=c[63052>>2]|0;if(v>>>0<W>>>0){V=W-v|0;c[63052>>2]=V;W=c[63064>>2]|0;c[63064>>2]=W+v;c[W+(v+4)>>2]=V|1;c[W+4>>2]=v|3;p=W+8|0;i=b;return p|0}do{if((c[15878]|0)==0){W=Fa(30)|0;if((W+ -1&W|0)==0){c[63520>>2]=W;c[63516>>2]=W;c[63524>>2]=-1;c[63528>>2]=-1;c[63532>>2]=0;c[63484>>2]=0;c[15878]=(gb(0)|0)&-16^1431655768;break}else{Eb()}}}while(0);W=v+48|0;V=c[63520>>2]|0;N=v+47|0;M=V+N|0;U=0-V|0;V=M&U;if(!(V>>>0>v>>>0)){p=0;i=b;return p|0}T=c[63480>>2]|0;if((T|0)!=0){S=c[63472>>2]|0;R=S+V|0;if(R>>>0<=S>>>0|R>>>0>T>>>0){p=0;i=b;return p|0}}d:do{if((c[63484>>2]&4|0)==0){T=c[63064>>2]|0;e:do{if((T|0)==0){X=182}else{R=63488|0;while(1){S=c[R>>2]|0;if(!(S>>>0>T>>>0)){Y=R+4|0;if((S+(c[Y>>2]|0)|0)>>>0>T>>>0){break}}S=c[R+8>>2]|0;if((S|0)==0){X=182;break e}else{R=S}}if((R|0)==0){X=182}else{S=M-(c[63052>>2]|0)&U;if(S>>>0<2147483647){O=Aa(S|0)|0;P=(O|0)==((c[R>>2]|0)+(c[Y>>2]|0)|0);Z=O;_=S;$=P?O:-1;aa=P?S:0;X=191}else{ba=0}}}}while(0);do{if((X|0)==182){T=Aa(0)|0;if((T|0)==(-1|0)){ba=0}else{q=T;S=c[63516>>2]|0;P=S+ -1|0;if((P&q|0)==0){ca=V}else{ca=V-q+(P+q&0-S)|0}S=c[63472>>2]|0;q=S+ca|0;if(ca>>>0>v>>>0&ca>>>0<2147483647){P=c[63480>>2]|0;if((P|0)!=0){if(q>>>0<=S>>>0|q>>>0>P>>>0){ba=0;break}}P=Aa(ca|0)|0;q=(P|0)==(T|0);Z=P;_=ca;$=q?T:-1;aa=q?ca:0;X=191}else{ba=0}}}}while(0);f:do{if((X|0)==191){q=0-_|0;if(($|0)!=(-1|0)){da=$;ea=aa;X=202;break d}do{if((Z|0)!=(-1|0)&_>>>0<2147483647&_>>>0<W>>>0){T=c[63520>>2]|0;P=N-_+T&0-T;if(P>>>0<2147483647){if((Aa(P|0)|0)==(-1|0)){Aa(q|0)|0;ba=aa;break f}else{fa=P+_|0;break}}else{fa=_}}else{fa=_}}while(0);if((Z|0)==(-1|0)){ba=aa}else{da=Z;ea=fa;X=202;break d}}}while(0);c[63484>>2]=c[63484>>2]|4;ga=ba;X=199}else{ga=0;X=199}}while(0);if((X|0)==199){if(V>>>0<2147483647){ba=Aa(V|0)|0;V=Aa(0)|0;if((V|0)!=(-1|0)&(ba|0)!=(-1|0)&ba>>>0<V>>>0){fa=V-ba|0;V=fa>>>0>(v+40|0)>>>0;if(V){da=ba;ea=V?fa:ga;X=202}}}}if((X|0)==202){ga=(c[63472>>2]|0)+ea|0;c[63472>>2]=ga;if(ga>>>0>(c[63476>>2]|0)>>>0){c[63476>>2]=ga}ga=c[63064>>2]|0;g:do{if((ga|0)==0){fa=c[63056>>2]|0;if((fa|0)==0|da>>>0<fa>>>0){c[63056>>2]=da}c[63488>>2]=da;c[63492>>2]=ea;c[63500>>2]=0;c[63076>>2]=c[15878];c[63072>>2]=-1;fa=0;do{V=fa<<1;ba=63080+(V<<2)|0;c[63080+(V+3<<2)>>2]=ba;c[63080+(V+2<<2)>>2]=ba;fa=fa+1|0}while((fa|0)!=32);fa=da+8|0;if((fa&7|0)==0){ha=0}else{ha=0-fa&7}fa=ea+ -40-ha|0;c[63064>>2]=da+ha;c[63052>>2]=fa;c[da+(ha+4)>>2]=fa|1;c[da+(ea+ -36)>>2]=40;c[63068>>2]=c[63528>>2]}else{fa=63488|0;while(1){ia=c[fa>>2]|0;ja=fa+4|0;ka=c[ja>>2]|0;if((da|0)==(ia+ka|0)){X=214;break}ba=c[fa+8>>2]|0;if((ba|0)==0){break}else{fa=ba}}if((X|0)==214){if((c[fa+12>>2]&8|0)==0){if(ga>>>0>=ia>>>0&ga>>>0<da>>>0){c[ja>>2]=ka+ea;ba=(c[63052>>2]|0)+ea|0;V=ga+8|0;if((V&7|0)==0){la=0}else{la=0-V&7}V=ba-la|0;c[63064>>2]=ga+la;c[63052>>2]=V;c[ga+(la+4)>>2]=V|1;c[ga+(ba+4)>>2]=40;c[63068>>2]=c[63528>>2];break}}}if(da>>>0<(c[63056>>2]|0)>>>0){c[63056>>2]=da}ba=da+ea|0;V=63488|0;while(1){if((c[V>>2]|0)==(ba|0)){X=224;break}Z=c[V+8>>2]|0;if((Z|0)==0){break}else{V=Z}}if((X|0)==224){if((c[V+12>>2]&8|0)==0){c[V>>2]=da;ba=V+4|0;c[ba>>2]=(c[ba>>2]|0)+ea;ba=da+8|0;if((ba&7|0)==0){ma=0}else{ma=0-ba&7}ba=da+(ea+8)|0;if((ba&7|0)==0){na=0}else{na=0-ba&7}ba=da+(na+ea)|0;fa=ma+v|0;Z=da+fa|0;aa=ba-(da+ma)-v|0;c[da+(ma+4)>>2]=v|3;h:do{if((ba|0)==(c[63064>>2]|0)){_=(c[63052>>2]|0)+aa|0;c[63052>>2]=_;c[63064>>2]=Z;c[da+(fa+4)>>2]=_|1}else{if((ba|0)==(c[63060>>2]|0)){_=(c[63048>>2]|0)+aa|0;c[63048>>2]=_;c[63060>>2]=Z;c[da+(fa+4)>>2]=_|1;c[da+(_+fa)>>2]=_;break}_=ea+4|0;N=c[da+(_+na)>>2]|0;if((N&3|0)==1){W=N&-8;$=N>>>3;do{if(N>>>0<256){ca=c[da+((na|8)+ea)>>2]|0;Y=c[da+(ea+12+na)>>2]|0;U=63080+($<<1<<2)|0;if((ca|0)!=(U|0)){if(ca>>>0<(c[63056>>2]|0)>>>0){Eb()}if((c[ca+12>>2]|0)!=(ba|0)){Eb()}}if((Y|0)==(ca|0)){c[15760]=c[15760]&~(1<<$);break}if((Y|0)==(U|0)){oa=Y+8|0}else{if(Y>>>0<(c[63056>>2]|0)>>>0){Eb()}U=Y+8|0;if((c[U>>2]|0)==(ba|0)){oa=U}else{Eb()}}c[ca+12>>2]=Y;c[oa>>2]=ca}else{ca=c[da+((na|24)+ea)>>2]|0;Y=c[da+(ea+12+na)>>2]|0;do{if((Y|0)==(ba|0)){U=na|16;M=da+(_+U)|0;q=c[M>>2]|0;if((q|0)==0){R=da+(U+ea)|0;U=c[R>>2]|0;if((U|0)==0){pa=0;break}else{qa=U;ra=R}}else{qa=q;ra=M}while(1){M=qa+20|0;q=c[M>>2]|0;if((q|0)!=0){qa=q;ra=M;continue}M=qa+16|0;q=c[M>>2]|0;if((q|0)==0){break}else{qa=q;ra=M}}if(ra>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[ra>>2]=0;pa=qa;break}}else{M=c[da+((na|8)+ea)>>2]|0;if(M>>>0<(c[63056>>2]|0)>>>0){Eb()}q=M+12|0;if((c[q>>2]|0)!=(ba|0)){Eb()}R=Y+8|0;if((c[R>>2]|0)==(ba|0)){c[q>>2]=Y;c[R>>2]=M;pa=Y;break}else{Eb()}}}while(0);if((ca|0)!=0){Y=c[da+(ea+28+na)>>2]|0;e=63344+(Y<<2)|0;if((ba|0)==(c[e>>2]|0)){c[e>>2]=pa;if((pa|0)==0){c[63044>>2]=c[63044>>2]&~(1<<Y);break}}else{if(ca>>>0<(c[63056>>2]|0)>>>0){Eb()}Y=ca+16|0;if((c[Y>>2]|0)==(ba|0)){c[Y>>2]=pa}else{c[ca+20>>2]=pa}if((pa|0)==0){break}}if(pa>>>0<(c[63056>>2]|0)>>>0){Eb()}c[pa+24>>2]=ca;Y=na|16;e=c[da+(Y+ea)>>2]|0;do{if((e|0)!=0){if(e>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[pa+16>>2]=e;c[e+24>>2]=pa;break}}}while(0);e=c[da+(_+Y)>>2]|0;if((e|0)!=0){if(e>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[pa+20>>2]=e;c[e+24>>2]=pa;break}}}}}while(0);sa=da+((W|na)+ea)|0;ta=W+aa|0}else{sa=ba;ta=aa}_=sa+4|0;c[_>>2]=c[_>>2]&-2;c[da+(fa+4)>>2]=ta|1;c[da+(ta+fa)>>2]=ta;_=ta>>>3;if(ta>>>0<256){$=_<<1;N=63080+($<<2)|0;e=c[15760]|0;ca=1<<_;if((e&ca|0)==0){c[15760]=e|ca;ua=63080+($+2<<2)|0;va=N}else{ca=63080+($+2<<2)|0;$=c[ca>>2]|0;if($>>>0<(c[63056>>2]|0)>>>0){Eb()}else{ua=ca;va=$}}c[ua>>2]=Z;c[va+12>>2]=Z;c[da+(fa+8)>>2]=va;c[da+(fa+12)>>2]=N;break}N=ta>>>8;if((N|0)==0){wa=0}else{if(ta>>>0>16777215){wa=31}else{$=(N+1048320|0)>>>16&8;ca=N<<$;N=(ca+520192|0)>>>16&4;e=ca<<N;ca=(e+245760|0)>>>16&2;_=14-(N|$|ca)+(e<<ca>>>15)|0;wa=ta>>>(_+7|0)&1|_<<1}}_=63344+(wa<<2)|0;c[da+(fa+28)>>2]=wa;c[da+(fa+20)>>2]=0;c[da+(fa+16)>>2]=0;ca=c[63044>>2]|0;e=1<<wa;if((ca&e|0)==0){c[63044>>2]=ca|e;c[_>>2]=Z;c[da+(fa+24)>>2]=_;c[da+(fa+12)>>2]=Z;c[da+(fa+8)>>2]=Z;break}e=c[_>>2]|0;if((wa|0)==31){xa=0}else{xa=25-(wa>>>1)|0}i:do{if((c[e+4>>2]&-8|0)==(ta|0)){ya=e}else{_=ta<<xa;ca=e;while(1){za=ca+(_>>>31<<2)+16|0;$=c[za>>2]|0;if(($|0)==0){break}if((c[$+4>>2]&-8|0)==(ta|0)){ya=$;break i}else{_=_<<1;ca=$}}if(za>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[za>>2]=Z;c[da+(fa+24)>>2]=ca;c[da+(fa+12)>>2]=Z;c[da+(fa+8)>>2]=Z;break h}}}while(0);e=ya+8|0;W=c[e>>2]|0;_=c[63056>>2]|0;if(ya>>>0<_>>>0){Eb()}if(W>>>0<_>>>0){Eb()}else{c[W+12>>2]=Z;c[e>>2]=Z;c[da+(fa+8)>>2]=W;c[da+(fa+12)>>2]=ya;c[da+(fa+24)>>2]=0;break}}}while(0);p=da+(ma|8)|0;i=b;return p|0}}fa=63488|0;while(1){Ba=c[fa>>2]|0;if(!(Ba>>>0>ga>>>0)){Ca=c[fa+4>>2]|0;Da=Ba+Ca|0;if(Da>>>0>ga>>>0){break}}fa=c[fa+8>>2]|0}fa=Ba+(Ca+ -39)|0;if((fa&7|0)==0){Ea=0}else{Ea=0-fa&7}fa=Ba+(Ca+ -47+Ea)|0;Z=fa>>>0<(ga+16|0)>>>0?ga:fa;fa=Z+8|0;aa=da+8|0;if((aa&7|0)==0){Ga=0}else{Ga=0-aa&7}aa=ea+ -40-Ga|0;c[63064>>2]=da+Ga;c[63052>>2]=aa;c[da+(Ga+4)>>2]=aa|1;c[da+(ea+ -36)>>2]=40;c[63068>>2]=c[63528>>2];c[Z+4>>2]=27;c[fa+0>>2]=c[63488>>2];c[fa+4>>2]=c[63492>>2];c[fa+8>>2]=c[63496>>2];c[fa+12>>2]=c[63500>>2];c[63488>>2]=da;c[63492>>2]=ea;c[63500>>2]=0;c[63496>>2]=fa;fa=Z+28|0;c[fa>>2]=7;if((Z+32|0)>>>0<Da>>>0){aa=fa;do{fa=aa;aa=aa+4|0;c[aa>>2]=7}while((fa+8|0)>>>0<Da>>>0)}if((Z|0)!=(ga|0)){aa=Z-ga|0;fa=ga+(aa+4)|0;c[fa>>2]=c[fa>>2]&-2;c[ga+4>>2]=aa|1;c[ga+aa>>2]=aa;fa=aa>>>3;if(aa>>>0<256){ba=fa<<1;V=63080+(ba<<2)|0;W=c[15760]|0;e=1<<fa;if((W&e|0)==0){c[15760]=W|e;Ha=63080+(ba+2<<2)|0;Ia=V}else{e=63080+(ba+2<<2)|0;ba=c[e>>2]|0;if(ba>>>0<(c[63056>>2]|0)>>>0){Eb()}else{Ha=e;Ia=ba}}c[Ha>>2]=ga;c[Ia+12>>2]=ga;c[ga+8>>2]=Ia;c[ga+12>>2]=V;break}V=aa>>>8;if((V|0)==0){Ja=0}else{if(aa>>>0>16777215){Ja=31}else{ba=(V+1048320|0)>>>16&8;e=V<<ba;V=(e+520192|0)>>>16&4;W=e<<V;e=(W+245760|0)>>>16&2;fa=14-(V|ba|e)+(W<<e>>>15)|0;Ja=aa>>>(fa+7|0)&1|fa<<1}}fa=63344+(Ja<<2)|0;c[ga+28>>2]=Ja;c[ga+20>>2]=0;c[ga+16>>2]=0;e=c[63044>>2]|0;W=1<<Ja;if((e&W|0)==0){c[63044>>2]=e|W;c[fa>>2]=ga;c[ga+24>>2]=fa;c[ga+12>>2]=ga;c[ga+8>>2]=ga;break}W=c[fa>>2]|0;if((Ja|0)==31){Ka=0}else{Ka=25-(Ja>>>1)|0}j:do{if((c[W+4>>2]&-8|0)==(aa|0)){La=W}else{fa=aa<<Ka;e=W;while(1){Ma=e+(fa>>>31<<2)+16|0;ba=c[Ma>>2]|0;if((ba|0)==0){break}if((c[ba+4>>2]&-8|0)==(aa|0)){La=ba;break j}else{fa=fa<<1;e=ba}}if(Ma>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[Ma>>2]=ga;c[ga+24>>2]=e;c[ga+12>>2]=ga;c[ga+8>>2]=ga;break g}}}while(0);aa=La+8|0;W=c[aa>>2]|0;Z=c[63056>>2]|0;if(La>>>0<Z>>>0){Eb()}if(W>>>0<Z>>>0){Eb()}else{c[W+12>>2]=ga;c[aa>>2]=ga;c[ga+8>>2]=W;c[ga+12>>2]=La;c[ga+24>>2]=0;break}}}}while(0);ga=c[63052>>2]|0;if(ga>>>0>v>>>0){La=ga-v|0;c[63052>>2]=La;ga=c[63064>>2]|0;c[63064>>2]=ga+v;c[ga+(v+4)>>2]=La|1;c[ga+4>>2]=v|3;p=ga+8|0;i=b;return p|0}}c[(Zb()|0)>>2]=12;p=0;i=b;return p|0}function zz(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b=i;if((a|0)==0){i=b;return}d=a+ -8|0;e=c[63056>>2]|0;if(d>>>0<e>>>0){Eb()}f=c[a+ -4>>2]|0;g=f&3;if((g|0)==1){Eb()}h=f&-8;j=a+(h+ -8)|0;do{if((f&1|0)==0){k=c[d>>2]|0;if((g|0)==0){i=b;return}l=-8-k|0;m=a+l|0;n=k+h|0;if(m>>>0<e>>>0){Eb()}if((m|0)==(c[63060>>2]|0)){o=a+(h+ -4)|0;if((c[o>>2]&3|0)!=3){p=m;q=n;break}c[63048>>2]=n;c[o>>2]=c[o>>2]&-2;c[a+(l+4)>>2]=n|1;c[j>>2]=n;i=b;return}o=k>>>3;if(k>>>0<256){k=c[a+(l+8)>>2]|0;r=c[a+(l+12)>>2]|0;s=63080+(o<<1<<2)|0;if((k|0)!=(s|0)){if(k>>>0<e>>>0){Eb()}if((c[k+12>>2]|0)!=(m|0)){Eb()}}if((r|0)==(k|0)){c[15760]=c[15760]&~(1<<o);p=m;q=n;break}if((r|0)==(s|0)){t=r+8|0}else{if(r>>>0<e>>>0){Eb()}s=r+8|0;if((c[s>>2]|0)==(m|0)){t=s}else{Eb()}}c[k+12>>2]=r;c[t>>2]=k;p=m;q=n;break}k=c[a+(l+24)>>2]|0;r=c[a+(l+12)>>2]|0;do{if((r|0)==(m|0)){s=a+(l+20)|0;o=c[s>>2]|0;if((o|0)==0){u=a+(l+16)|0;v=c[u>>2]|0;if((v|0)==0){w=0;break}else{x=v;y=u}}else{x=o;y=s}while(1){s=x+20|0;o=c[s>>2]|0;if((o|0)!=0){x=o;y=s;continue}s=x+16|0;o=c[s>>2]|0;if((o|0)==0){break}else{x=o;y=s}}if(y>>>0<e>>>0){Eb()}else{c[y>>2]=0;w=x;break}}else{s=c[a+(l+8)>>2]|0;if(s>>>0<e>>>0){Eb()}o=s+12|0;if((c[o>>2]|0)!=(m|0)){Eb()}u=r+8|0;if((c[u>>2]|0)==(m|0)){c[o>>2]=r;c[u>>2]=s;w=r;break}else{Eb()}}}while(0);if((k|0)==0){p=m;q=n}else{r=c[a+(l+28)>>2]|0;s=63344+(r<<2)|0;if((m|0)==(c[s>>2]|0)){c[s>>2]=w;if((w|0)==0){c[63044>>2]=c[63044>>2]&~(1<<r);p=m;q=n;break}}else{if(k>>>0<(c[63056>>2]|0)>>>0){Eb()}r=k+16|0;if((c[r>>2]|0)==(m|0)){c[r>>2]=w}else{c[k+20>>2]=w}if((w|0)==0){p=m;q=n;break}}if(w>>>0<(c[63056>>2]|0)>>>0){Eb()}c[w+24>>2]=k;r=c[a+(l+16)>>2]|0;do{if((r|0)!=0){if(r>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[w+16>>2]=r;c[r+24>>2]=w;break}}}while(0);r=c[a+(l+20)>>2]|0;if((r|0)==0){p=m;q=n}else{if(r>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[w+20>>2]=r;c[r+24>>2]=w;p=m;q=n;break}}}}else{p=d;q=h}}while(0);if(!(p>>>0<j>>>0)){Eb()}d=a+(h+ -4)|0;w=c[d>>2]|0;if((w&1|0)==0){Eb()}if((w&2|0)==0){if((j|0)==(c[63064>>2]|0)){e=(c[63052>>2]|0)+q|0;c[63052>>2]=e;c[63064>>2]=p;c[p+4>>2]=e|1;if((p|0)!=(c[63060>>2]|0)){i=b;return}c[63060>>2]=0;c[63048>>2]=0;i=b;return}if((j|0)==(c[63060>>2]|0)){e=(c[63048>>2]|0)+q|0;c[63048>>2]=e;c[63060>>2]=p;c[p+4>>2]=e|1;c[p+e>>2]=e;i=b;return}e=(w&-8)+q|0;x=w>>>3;do{if(w>>>0<256){y=c[a+h>>2]|0;t=c[a+(h|4)>>2]|0;g=63080+(x<<1<<2)|0;if((y|0)!=(g|0)){if(y>>>0<(c[63056>>2]|0)>>>0){Eb()}if((c[y+12>>2]|0)!=(j|0)){Eb()}}if((t|0)==(y|0)){c[15760]=c[15760]&~(1<<x);break}if((t|0)==(g|0)){z=t+8|0}else{if(t>>>0<(c[63056>>2]|0)>>>0){Eb()}g=t+8|0;if((c[g>>2]|0)==(j|0)){z=g}else{Eb()}}c[y+12>>2]=t;c[z>>2]=y}else{y=c[a+(h+16)>>2]|0;t=c[a+(h|4)>>2]|0;do{if((t|0)==(j|0)){g=a+(h+12)|0;f=c[g>>2]|0;if((f|0)==0){r=a+(h+8)|0;k=c[r>>2]|0;if((k|0)==0){A=0;break}else{B=k;C=r}}else{B=f;C=g}while(1){g=B+20|0;f=c[g>>2]|0;if((f|0)!=0){B=f;C=g;continue}g=B+16|0;f=c[g>>2]|0;if((f|0)==0){break}else{B=f;C=g}}if(C>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[C>>2]=0;A=B;break}}else{g=c[a+h>>2]|0;if(g>>>0<(c[63056>>2]|0)>>>0){Eb()}f=g+12|0;if((c[f>>2]|0)!=(j|0)){Eb()}r=t+8|0;if((c[r>>2]|0)==(j|0)){c[f>>2]=t;c[r>>2]=g;A=t;break}else{Eb()}}}while(0);if((y|0)!=0){t=c[a+(h+20)>>2]|0;n=63344+(t<<2)|0;if((j|0)==(c[n>>2]|0)){c[n>>2]=A;if((A|0)==0){c[63044>>2]=c[63044>>2]&~(1<<t);break}}else{if(y>>>0<(c[63056>>2]|0)>>>0){Eb()}t=y+16|0;if((c[t>>2]|0)==(j|0)){c[t>>2]=A}else{c[y+20>>2]=A}if((A|0)==0){break}}if(A>>>0<(c[63056>>2]|0)>>>0){Eb()}c[A+24>>2]=y;t=c[a+(h+8)>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[A+16>>2]=t;c[t+24>>2]=A;break}}}while(0);t=c[a+(h+12)>>2]|0;if((t|0)!=0){if(t>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[A+20>>2]=t;c[t+24>>2]=A;break}}}}}while(0);c[p+4>>2]=e|1;c[p+e>>2]=e;if((p|0)==(c[63060>>2]|0)){c[63048>>2]=e;i=b;return}else{D=e}}else{c[d>>2]=w&-2;c[p+4>>2]=q|1;c[p+q>>2]=q;D=q}q=D>>>3;if(D>>>0<256){w=q<<1;d=63080+(w<<2)|0;e=c[15760]|0;A=1<<q;if((e&A|0)==0){c[15760]=e|A;E=63080+(w+2<<2)|0;F=d}else{A=63080+(w+2<<2)|0;w=c[A>>2]|0;if(w>>>0<(c[63056>>2]|0)>>>0){Eb()}else{E=A;F=w}}c[E>>2]=p;c[F+12>>2]=p;c[p+8>>2]=F;c[p+12>>2]=d;i=b;return}d=D>>>8;if((d|0)==0){G=0}else{if(D>>>0>16777215){G=31}else{F=(d+1048320|0)>>>16&8;E=d<<F;d=(E+520192|0)>>>16&4;w=E<<d;E=(w+245760|0)>>>16&2;A=14-(d|F|E)+(w<<E>>>15)|0;G=D>>>(A+7|0)&1|A<<1}}A=63344+(G<<2)|0;c[p+28>>2]=G;c[p+20>>2]=0;c[p+16>>2]=0;E=c[63044>>2]|0;w=1<<G;a:do{if((E&w|0)==0){c[63044>>2]=E|w;c[A>>2]=p;c[p+24>>2]=A;c[p+12>>2]=p;c[p+8>>2]=p}else{F=c[A>>2]|0;if((G|0)==31){H=0}else{H=25-(G>>>1)|0}b:do{if((c[F+4>>2]&-8|0)==(D|0)){I=F}else{d=D<<H;e=F;while(1){J=e+(d>>>31<<2)+16|0;q=c[J>>2]|0;if((q|0)==0){break}if((c[q+4>>2]&-8|0)==(D|0)){I=q;break b}else{d=d<<1;e=q}}if(J>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[J>>2]=p;c[p+24>>2]=e;c[p+12>>2]=p;c[p+8>>2]=p;break a}}}while(0);F=I+8|0;d=c[F>>2]|0;q=c[63056>>2]|0;if(I>>>0<q>>>0){Eb()}if(d>>>0<q>>>0){Eb()}else{c[d+12>>2]=p;c[F>>2]=p;c[p+8>>2]=d;c[p+12>>2]=I;c[p+24>>2]=0;break}}}while(0);p=(c[63072>>2]|0)+ -1|0;c[63072>>2]=p;if((p|0)==0){K=63496|0}else{i=b;return}while(1){p=c[K>>2]|0;if((p|0)==0){break}else{K=p+8|0}}c[63072>>2]=-1;i=b;return}function Az(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;do{if((a|0)==0){e=yz(b)|0}else{if(b>>>0>4294967231){c[(Zb()|0)>>2]=12;e=0;break}if(b>>>0<11){f=16}else{f=b+11&-8}g=Bz(a+ -8|0,f)|0;if((g|0)!=0){e=g+8|0;break}g=yz(b)|0;if((g|0)==0){e=0}else{h=c[a+ -4>>2]|0;j=(h&-8)-((h&3|0)==0?8:4)|0;Mz(g|0,a|0,(j>>>0<b>>>0?j:b)|0)|0;zz(a);e=g}}}while(0);i=d;return e|0}function Bz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;e=a+4|0;f=c[e>>2]|0;g=f&-8;h=a+g|0;j=c[63056>>2]|0;if(a>>>0<j>>>0){Eb()}k=f&3;if(!((k|0)!=1&a>>>0<h>>>0)){Eb()}l=a+(g|4)|0;m=c[l>>2]|0;if((m&1|0)==0){Eb()}if((k|0)==0){if(b>>>0<256){n=0;i=d;return n|0}if(!(g>>>0<(b+4|0)>>>0)){if(!((g-b|0)>>>0>c[63520>>2]<<1>>>0)){n=a;i=d;return n|0}}n=0;i=d;return n|0}if(!(g>>>0<b>>>0)){k=g-b|0;if(!(k>>>0>15)){n=a;i=d;return n|0}c[e>>2]=f&1|b|2;c[a+(b+4)>>2]=k|3;c[l>>2]=c[l>>2]|1;Cz(a+b|0,k);n=a;i=d;return n|0}if((h|0)==(c[63064>>2]|0)){k=(c[63052>>2]|0)+g|0;if(!(k>>>0>b>>>0)){n=0;i=d;return n|0}l=k-b|0;c[e>>2]=f&1|b|2;c[a+(b+4)>>2]=l|1;c[63064>>2]=a+b;c[63052>>2]=l;n=a;i=d;return n|0}if((h|0)==(c[63060>>2]|0)){l=(c[63048>>2]|0)+g|0;if(l>>>0<b>>>0){n=0;i=d;return n|0}k=l-b|0;if(k>>>0>15){c[e>>2]=f&1|b|2;c[a+(b+4)>>2]=k|1;c[a+l>>2]=k;o=a+(l+4)|0;c[o>>2]=c[o>>2]&-2;p=a+b|0;q=k}else{c[e>>2]=f&1|l|2;f=a+(l+4)|0;c[f>>2]=c[f>>2]|1;p=0;q=0}c[63048>>2]=q;c[63060>>2]=p;n=a;i=d;return n|0}if((m&2|0)!=0){n=0;i=d;return n|0}p=(m&-8)+g|0;if(p>>>0<b>>>0){n=0;i=d;return n|0}q=p-b|0;f=m>>>3;do{if(m>>>0<256){l=c[a+(g+8)>>2]|0;k=c[a+(g+12)>>2]|0;o=63080+(f<<1<<2)|0;if((l|0)!=(o|0)){if(l>>>0<j>>>0){Eb()}if((c[l+12>>2]|0)!=(h|0)){Eb()}}if((k|0)==(l|0)){c[15760]=c[15760]&~(1<<f);break}if((k|0)==(o|0)){r=k+8|0}else{if(k>>>0<j>>>0){Eb()}o=k+8|0;if((c[o>>2]|0)==(h|0)){r=o}else{Eb()}}c[l+12>>2]=k;c[r>>2]=l}else{l=c[a+(g+24)>>2]|0;k=c[a+(g+12)>>2]|0;do{if((k|0)==(h|0)){o=a+(g+20)|0;s=c[o>>2]|0;if((s|0)==0){t=a+(g+16)|0;u=c[t>>2]|0;if((u|0)==0){v=0;break}else{w=u;x=t}}else{w=s;x=o}while(1){o=w+20|0;s=c[o>>2]|0;if((s|0)!=0){w=s;x=o;continue}o=w+16|0;s=c[o>>2]|0;if((s|0)==0){break}else{w=s;x=o}}if(x>>>0<j>>>0){Eb()}else{c[x>>2]=0;v=w;break}}else{o=c[a+(g+8)>>2]|0;if(o>>>0<j>>>0){Eb()}s=o+12|0;if((c[s>>2]|0)!=(h|0)){Eb()}t=k+8|0;if((c[t>>2]|0)==(h|0)){c[s>>2]=k;c[t>>2]=o;v=k;break}else{Eb()}}}while(0);if((l|0)!=0){k=c[a+(g+28)>>2]|0;o=63344+(k<<2)|0;if((h|0)==(c[o>>2]|0)){c[o>>2]=v;if((v|0)==0){c[63044>>2]=c[63044>>2]&~(1<<k);break}}else{if(l>>>0<(c[63056>>2]|0)>>>0){Eb()}k=l+16|0;if((c[k>>2]|0)==(h|0)){c[k>>2]=v}else{c[l+20>>2]=v}if((v|0)==0){break}}if(v>>>0<(c[63056>>2]|0)>>>0){Eb()}c[v+24>>2]=l;k=c[a+(g+16)>>2]|0;do{if((k|0)!=0){if(k>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[v+16>>2]=k;c[k+24>>2]=v;break}}}while(0);k=c[a+(g+20)>>2]|0;if((k|0)!=0){if(k>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[v+20>>2]=k;c[k+24>>2]=v;break}}}}}while(0);if(q>>>0<16){c[e>>2]=p|c[e>>2]&1|2;v=a+(p|4)|0;c[v>>2]=c[v>>2]|1;n=a;i=d;return n|0}else{c[e>>2]=c[e>>2]&1|b|2;c[a+(b+4)>>2]=q|3;e=a+(p|4)|0;c[e>>2]=c[e>>2]|1;Cz(a+b|0,q);n=a;i=d;return n|0}return 0}function Cz(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;d=i;e=a+b|0;f=c[a+4>>2]|0;do{if((f&1|0)==0){g=c[a>>2]|0;if((f&3|0)==0){i=d;return}h=a+(0-g)|0;j=g+b|0;k=c[63056>>2]|0;if(h>>>0<k>>>0){Eb()}if((h|0)==(c[63060>>2]|0)){l=a+(b+4)|0;if((c[l>>2]&3|0)!=3){m=h;n=j;break}c[63048>>2]=j;c[l>>2]=c[l>>2]&-2;c[a+(4-g)>>2]=j|1;c[e>>2]=j;i=d;return}l=g>>>3;if(g>>>0<256){o=c[a+(8-g)>>2]|0;p=c[a+(12-g)>>2]|0;q=63080+(l<<1<<2)|0;if((o|0)!=(q|0)){if(o>>>0<k>>>0){Eb()}if((c[o+12>>2]|0)!=(h|0)){Eb()}}if((p|0)==(o|0)){c[15760]=c[15760]&~(1<<l);m=h;n=j;break}if((p|0)==(q|0)){r=p+8|0}else{if(p>>>0<k>>>0){Eb()}q=p+8|0;if((c[q>>2]|0)==(h|0)){r=q}else{Eb()}}c[o+12>>2]=p;c[r>>2]=o;m=h;n=j;break}o=c[a+(24-g)>>2]|0;p=c[a+(12-g)>>2]|0;do{if((p|0)==(h|0)){q=16-g|0;l=a+(q+4)|0;s=c[l>>2]|0;if((s|0)==0){t=a+q|0;q=c[t>>2]|0;if((q|0)==0){u=0;break}else{v=q;w=t}}else{v=s;w=l}while(1){l=v+20|0;s=c[l>>2]|0;if((s|0)!=0){v=s;w=l;continue}l=v+16|0;s=c[l>>2]|0;if((s|0)==0){break}else{v=s;w=l}}if(w>>>0<k>>>0){Eb()}else{c[w>>2]=0;u=v;break}}else{l=c[a+(8-g)>>2]|0;if(l>>>0<k>>>0){Eb()}s=l+12|0;if((c[s>>2]|0)!=(h|0)){Eb()}t=p+8|0;if((c[t>>2]|0)==(h|0)){c[s>>2]=p;c[t>>2]=l;u=p;break}else{Eb()}}}while(0);if((o|0)==0){m=h;n=j}else{p=c[a+(28-g)>>2]|0;k=63344+(p<<2)|0;if((h|0)==(c[k>>2]|0)){c[k>>2]=u;if((u|0)==0){c[63044>>2]=c[63044>>2]&~(1<<p);m=h;n=j;break}}else{if(o>>>0<(c[63056>>2]|0)>>>0){Eb()}p=o+16|0;if((c[p>>2]|0)==(h|0)){c[p>>2]=u}else{c[o+20>>2]=u}if((u|0)==0){m=h;n=j;break}}if(u>>>0<(c[63056>>2]|0)>>>0){Eb()}c[u+24>>2]=o;p=16-g|0;k=c[a+p>>2]|0;do{if((k|0)!=0){if(k>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[u+16>>2]=k;c[k+24>>2]=u;break}}}while(0);k=c[a+(p+4)>>2]|0;if((k|0)==0){m=h;n=j}else{if(k>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[u+20>>2]=k;c[k+24>>2]=u;m=h;n=j;break}}}}else{m=a;n=b}}while(0);u=c[63056>>2]|0;if(e>>>0<u>>>0){Eb()}v=a+(b+4)|0;w=c[v>>2]|0;if((w&2|0)==0){if((e|0)==(c[63064>>2]|0)){r=(c[63052>>2]|0)+n|0;c[63052>>2]=r;c[63064>>2]=m;c[m+4>>2]=r|1;if((m|0)!=(c[63060>>2]|0)){i=d;return}c[63060>>2]=0;c[63048>>2]=0;i=d;return}if((e|0)==(c[63060>>2]|0)){r=(c[63048>>2]|0)+n|0;c[63048>>2]=r;c[63060>>2]=m;c[m+4>>2]=r|1;c[m+r>>2]=r;i=d;return}r=(w&-8)+n|0;f=w>>>3;do{if(w>>>0<256){k=c[a+(b+8)>>2]|0;g=c[a+(b+12)>>2]|0;o=63080+(f<<1<<2)|0;if((k|0)!=(o|0)){if(k>>>0<u>>>0){Eb()}if((c[k+12>>2]|0)!=(e|0)){Eb()}}if((g|0)==(k|0)){c[15760]=c[15760]&~(1<<f);break}if((g|0)==(o|0)){x=g+8|0}else{if(g>>>0<u>>>0){Eb()}o=g+8|0;if((c[o>>2]|0)==(e|0)){x=o}else{Eb()}}c[k+12>>2]=g;c[x>>2]=k}else{k=c[a+(b+24)>>2]|0;g=c[a+(b+12)>>2]|0;do{if((g|0)==(e|0)){o=a+(b+20)|0;l=c[o>>2]|0;if((l|0)==0){t=a+(b+16)|0;s=c[t>>2]|0;if((s|0)==0){y=0;break}else{z=s;A=t}}else{z=l;A=o}while(1){o=z+20|0;l=c[o>>2]|0;if((l|0)!=0){z=l;A=o;continue}o=z+16|0;l=c[o>>2]|0;if((l|0)==0){break}else{z=l;A=o}}if(A>>>0<u>>>0){Eb()}else{c[A>>2]=0;y=z;break}}else{o=c[a+(b+8)>>2]|0;if(o>>>0<u>>>0){Eb()}l=o+12|0;if((c[l>>2]|0)!=(e|0)){Eb()}t=g+8|0;if((c[t>>2]|0)==(e|0)){c[l>>2]=g;c[t>>2]=o;y=g;break}else{Eb()}}}while(0);if((k|0)!=0){g=c[a+(b+28)>>2]|0;j=63344+(g<<2)|0;if((e|0)==(c[j>>2]|0)){c[j>>2]=y;if((y|0)==0){c[63044>>2]=c[63044>>2]&~(1<<g);break}}else{if(k>>>0<(c[63056>>2]|0)>>>0){Eb()}g=k+16|0;if((c[g>>2]|0)==(e|0)){c[g>>2]=y}else{c[k+20>>2]=y}if((y|0)==0){break}}if(y>>>0<(c[63056>>2]|0)>>>0){Eb()}c[y+24>>2]=k;g=c[a+(b+16)>>2]|0;do{if((g|0)!=0){if(g>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[y+16>>2]=g;c[g+24>>2]=y;break}}}while(0);g=c[a+(b+20)>>2]|0;if((g|0)!=0){if(g>>>0<(c[63056>>2]|0)>>>0){Eb()}else{c[y+20>>2]=g;c[g+24>>2]=y;break}}}}}while(0);c[m+4>>2]=r|1;c[m+r>>2]=r;if((m|0)==(c[63060>>2]|0)){c[63048>>2]=r;i=d;return}else{B=r}}else{c[v>>2]=w&-2;c[m+4>>2]=n|1;c[m+n>>2]=n;B=n}n=B>>>3;if(B>>>0<256){w=n<<1;v=63080+(w<<2)|0;r=c[15760]|0;y=1<<n;if((r&y|0)==0){c[15760]=r|y;C=63080+(w+2<<2)|0;D=v}else{y=63080+(w+2<<2)|0;w=c[y>>2]|0;if(w>>>0<(c[63056>>2]|0)>>>0){Eb()}else{C=y;D=w}}c[C>>2]=m;c[D+12>>2]=m;c[m+8>>2]=D;c[m+12>>2]=v;i=d;return}v=B>>>8;if((v|0)==0){E=0}else{if(B>>>0>16777215){E=31}else{D=(v+1048320|0)>>>16&8;C=v<<D;v=(C+520192|0)>>>16&4;w=C<<v;C=(w+245760|0)>>>16&2;y=14-(v|D|C)+(w<<C>>>15)|0;E=B>>>(y+7|0)&1|y<<1}}y=63344+(E<<2)|0;c[m+28>>2]=E;c[m+20>>2]=0;c[m+16>>2]=0;C=c[63044>>2]|0;w=1<<E;if((C&w|0)==0){c[63044>>2]=C|w;c[y>>2]=m;c[m+24>>2]=y;c[m+12>>2]=m;c[m+8>>2]=m;i=d;return}w=c[y>>2]|0;if((E|0)==31){F=0}else{F=25-(E>>>1)|0}a:do{if((c[w+4>>2]&-8|0)==(B|0)){G=w}else{E=B<<F;y=w;while(1){H=y+(E>>>31<<2)+16|0;C=c[H>>2]|0;if((C|0)==0){break}if((c[C+4>>2]&-8|0)==(B|0)){G=C;break a}else{E=E<<1;y=C}}if(H>>>0<(c[63056>>2]|0)>>>0){Eb()}c[H>>2]=m;c[m+24>>2]=y;c[m+12>>2]=m;c[m+8>>2]=m;i=d;return}}while(0);H=G+8|0;B=c[H>>2]|0;w=c[63056>>2]|0;if(G>>>0<w>>>0){Eb()}if(B>>>0<w>>>0){Eb()}c[B+12>>2]=m;c[H>>2]=m;c[m+8>>2]=B;c[m+12>>2]=G;c[m+24>>2]=0;i=d;return}



function kw(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0;f=i;i=i+21224|0;h=c[b>>2]|0;if((lw(b,d,e)|0)==0){j=0;i=f;return j|0}a:while(1){k=c[b>>2]|0;while(1){l=a[b+k+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}k=k+1|0}c[b>>2]=k;l=55328;m=61;n=k;while(1){if(!((a[b+n+4>>0]|0)==m<<24>>24)){o=k;p=8;break}q=n+1|0;r=l+1|0;s=a[r>>0]|0;if(s<<24>>24==0){t=1;u=q;break}else{l=r;m=s;n=q}}if((p|0)==8){while(1){p=0;n=a[b+o+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}o=o+1|0;p=8}c[b>>2]=o;n=55336;m=33;l=o;while(1){if(!((a[b+l+4>>0]|0)==m<<24>>24)){break a}k=l+1|0;q=n+1|0;s=a[q>>0]|0;if(s<<24>>24==0){t=2;u=k;break}else{n=q;m=s;l=k}}}c[b>>2]=u;if((lw(b,f+384|0,e)|0)==0){p=15;break}if((t|0)==1){c[d>>2]=(c[d>>2]|0)==(c[(f+384|0)>>2]|0);continue}else if((t|0)==2){c[d>>2]=(c[d>>2]|0)!=(c[(f+384|0)>>2]|0);continue}else{continue}}if((p|0)==15){c[b>>2]=h;j=0;i=f;return j|0}t=o;b:while(1){o=t;while(1){u=a[b+o+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}o=o+1|0}c[b>>2]=o;u=55320;l=38;m=o;while(1){if(!((a[b+m+4>>0]|0)==l<<24>>24)){v=o;break}n=u+1|0;k=a[n>>0]|0;if(k<<24>>24==0){p=25;break b}else{u=n;l=k;m=m+1|0}}while(1){m=a[b+v+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}v=v+1|0}c[b>>2]=v;if((a[b+v+4>>0]|0)!=38){w=v;break}y=v+1|0;c[b>>2]=y;if((lw(b,f+288|0,e)|0)==0){p=47;break}c:while(1){m=c[b>>2]|0;while(1){l=a[b+m+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}m=m+1|0}c[b>>2]=m;l=55328;u=61;o=m;while(1){if(!((a[b+o+4>>0]|0)==u<<24>>24)){z=m;p=37;break}k=o+1|0;n=l+1|0;s=a[n>>0]|0;if(s<<24>>24==0){A=1;B=k;break}else{l=n;u=s;o=k}}if((p|0)==37){while(1){p=0;o=a[b+z+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}z=z+1|0;p=37}c[b>>2]=z;o=55336;u=33;l=z;while(1){if(!((a[b+l+4>>0]|0)==u<<24>>24)){break c}m=l+1|0;k=o+1|0;s=a[k>>0]|0;if(s<<24>>24==0){A=2;B=m;break}else{o=k;u=s;l=m}}}c[b>>2]=B;if((lw(b,f+404|0,e)|0)==0){p=43;break b}if((A|0)==1){c[(f+288|0)>>2]=(c[(f+288|0)>>2]|0)==(c[(f+404|0)>>2]|0);continue}else if((A|0)==2){c[(f+288|0)>>2]=(c[(f+288|0)>>2]|0)!=(c[(f+404|0)>>2]|0);continue}else{continue}}c[d>>2]=c[(f+288|0)>>2]&c[d>>2];t=z}if((p|0)==25){c[b>>2]=t;w=t}else if((p|0)==43){c[b>>2]=y;p=47}if((p|0)==47){c[b>>2]=h;j=0;i=f;return j|0}y=w;d:while(1){w=a[b+y+4>>0]|0;if(w<<24>>24==10|w<<24>>24==9|w<<24>>24==32|w<<24>>24==13){y=y+1|0;continue}c[b>>2]=y;if((a[b+y+4>>0]|0)!=94){p=52;break}C=y+1|0;c[b>>2]=C;if((lw(b,f+340|0,e)|0)==0){break}e:while(1){w=c[b>>2]|0;while(1){t=a[b+w+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}w=w+1|0}c[b>>2]=w;t=55328;z=61;A=w;while(1){if(!((a[b+A+4>>0]|0)==z<<24>>24)){D=w;p=60;break}B=A+1|0;v=t+1|0;l=a[v>>0]|0;if(l<<24>>24==0){G=1;H=B;break}else{t=v;z=l;A=B}}if((p|0)==60){while(1){p=0;A=a[b+D+4>>0]|0;if(!(A<<24>>24==10|A<<24>>24==9|A<<24>>24==32|A<<24>>24==13)){break}D=D+1|0;p=60}c[b>>2]=D;A=55336;z=33;t=D;while(1){if(!((a[b+t+4>>0]|0)==z<<24>>24)){I=D;break e}w=t+1|0;B=A+1|0;l=a[B>>0]|0;if(l<<24>>24==0){G=2;H=w;break}else{A=B;z=l;t=w}}}c[b>>2]=H;if((lw(b,f+376|0,e)|0)==0){p=66;break d}if((G|0)==1){c[(f+340|0)>>2]=(c[(f+340|0)>>2]|0)==(c[(f+376|0)>>2]|0);continue}else if((G|0)==2){c[(f+340|0)>>2]=(c[(f+340|0)>>2]|0)!=(c[(f+376|0)>>2]|0);continue}else{continue}}f:while(1){t=I;while(1){z=a[b+t+4>>0]|0;if(!(z<<24>>24==10|z<<24>>24==9|z<<24>>24==32|z<<24>>24==13)){break}t=t+1|0}c[b>>2]=t;z=55320;A=38;w=t;while(1){if(!((a[b+w+4>>0]|0)==A<<24>>24)){J=t;break}l=z+1|0;B=a[l>>0]|0;if(B<<24>>24==0){p=76;break f}else{z=l;A=B;w=w+1|0}}while(1){w=a[b+J+4>>0]|0;if(!(w<<24>>24==10|w<<24>>24==9|w<<24>>24==32|w<<24>>24==13)){break}J=J+1|0}c[b>>2]=J;if((a[b+J+4>>0]|0)!=38){K=J;break}L=J+1|0;c[b>>2]=L;if((lw(b,f+396|0,e)|0)==0){p=97;break d}g:while(1){w=c[b>>2]|0;while(1){A=a[b+w+4>>0]|0;if(!(A<<24>>24==10|A<<24>>24==9|A<<24>>24==32|A<<24>>24==13)){break}w=w+1|0}c[b>>2]=w;A=55328;z=61;t=w;while(1){if(!((a[b+t+4>>0]|0)==z<<24>>24)){M=w;p=87;break}B=t+1|0;l=A+1|0;v=a[l>>0]|0;if(v<<24>>24==0){N=1;O=B;break}else{A=l;z=v;t=B}}if((p|0)==87){while(1){p=0;t=a[b+M+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}M=M+1|0;p=87}c[b>>2]=M;t=55336;z=33;A=M;while(1){if(!((a[b+A+4>>0]|0)==z<<24>>24)){break g}w=A+1|0;B=t+1|0;v=a[B>>0]|0;if(v<<24>>24==0){N=2;O=w;break}else{t=B;z=v;A=w}}}c[b>>2]=O;if((lw(b,f+404|0,e)|0)==0){p=93;break d}if((N|0)==1){c[(f+396|0)>>2]=(c[(f+396|0)>>2]|0)==(c[(f+404|0)>>2]|0);continue}else if((N|0)==2){c[(f+396|0)>>2]=(c[(f+396|0)>>2]|0)!=(c[(f+404|0)>>2]|0);continue}else{continue}}c[(f+340|0)>>2]=c[(f+396|0)>>2]&c[(f+340|0)>>2];I=M}if((p|0)==76){p=0;c[b>>2]=I;K=I}c[d>>2]=c[(f+340|0)>>2]^c[d>>2];y=K}K=1;if(K){K=0;if((p|0)==52){I=y;h:while(1){y=I;while(1){M=a[b+y+4>>0]|0;if(!(M<<24>>24==10|M<<24>>24==9|M<<24>>24==32|M<<24>>24==13)){break}y=y+1|0}c[b>>2]=y;M=55312;N=124;O=y;while(1){if(!((a[b+O+4>>0]|0)==N<<24>>24)){P=y;break}J=M+1|0;G=a[J>>0]|0;if(G<<24>>24==0){p=107;break h}else{M=J;N=G;O=O+1|0}}while(1){O=a[b+P+4>>0]|0;if(!(O<<24>>24==10|O<<24>>24==9|O<<24>>24==32|O<<24>>24==13)){break}P=P+1|0}c[b>>2]=P;if((a[b+P+4>>0]|0)!=124){Q=P;p=111;break}R=P+1|0;c[b>>2]=R;if((lw(b,f+12|0,e)|0)==0){break}i:while(1){O=c[b>>2]|0;while(1){N=a[b+O+4>>0]|0;if(!(N<<24>>24==10|N<<24>>24==9|N<<24>>24==32|N<<24>>24==13)){break}O=O+1|0}c[b>>2]=O;N=55328;M=61;y=O;while(1){if(!((a[b+y+4>>0]|0)==M<<24>>24)){S=O;p=119;break}G=y+1|0;J=N+1|0;H=a[J>>0]|0;if(H<<24>>24==0){T=1;U=G;break}else{N=J;M=H;y=G}}if((p|0)==119){while(1){p=0;y=a[b+S+4>>0]|0;if(!(y<<24>>24==10|y<<24>>24==9|y<<24>>24==32|y<<24>>24==13)){break}S=S+1|0;p=119}c[b>>2]=S;y=55336;M=33;N=S;while(1){if(!((a[b+N+4>>0]|0)==M<<24>>24)){V=S;break i}O=N+1|0;G=y+1|0;H=a[G>>0]|0;if(H<<24>>24==0){T=2;U=O;break}else{y=G;M=H;N=O}}}c[b>>2]=U;if((lw(b,f+368|0,e)|0)==0){p=125;break h}if((T|0)==1){c[(f+12|0)>>2]=(c[(f+12|0)>>2]|0)==(c[(f+368|0)>>2]|0);continue}else if((T|0)==2){c[(f+12|0)>>2]=(c[(f+12|0)>>2]|0)!=(c[(f+368|0)>>2]|0);continue}else{continue}}j:while(1){N=V;while(1){M=a[b+N+4>>0]|0;if(!(M<<24>>24==10|M<<24>>24==9|M<<24>>24==32|M<<24>>24==13)){break}N=N+1|0}c[b>>2]=N;M=55320;y=38;O=N;while(1){if(!((a[b+O+4>>0]|0)==y<<24>>24)){W=N;break}H=M+1|0;G=a[H>>0]|0;if(G<<24>>24==0){p=135;break j}else{M=H;y=G;O=O+1|0}}while(1){O=a[b+W+4>>0]|0;if(!(O<<24>>24==10|O<<24>>24==9|O<<24>>24==32|O<<24>>24==13)){break}W=W+1|0}c[b>>2]=W;if((a[b+W+4>>0]|0)!=38){X=W;break}Y=W+1|0;c[b>>2]=Y;if((lw(b,f+284|0,e)|0)==0){p=156;break h}k:while(1){O=c[b>>2]|0;while(1){y=a[b+O+4>>0]|0;if(!(y<<24>>24==10|y<<24>>24==9|y<<24>>24==32|y<<24>>24==13)){break}O=O+1|0}c[b>>2]=O;y=55328;M=61;N=O;while(1){if(!((a[b+N+4>>0]|0)==M<<24>>24)){Z=O;p=146;break}G=N+1|0;H=y+1|0;J=a[H>>0]|0;if(J<<24>>24==0){_=1;$=G;break}else{y=H;M=J;N=G}}if((p|0)==146){while(1){p=0;N=a[b+Z+4>>0]|0;if(!(N<<24>>24==10|N<<24>>24==9|N<<24>>24==32|N<<24>>24==13)){break}Z=Z+1|0;p=146}c[b>>2]=Z;N=55336;M=33;y=Z;while(1){if(!((a[b+y+4>>0]|0)==M<<24>>24)){break k}O=y+1|0;G=N+1|0;J=a[G>>0]|0;if(J<<24>>24==0){_=2;$=O;break}else{N=G;M=J;y=O}}}c[b>>2]=$;if((lw(b,f+404|0,e)|0)==0){p=152;break h}if((_|0)==1){c[(f+284|0)>>2]=(c[(f+284|0)>>2]|0)==(c[(f+404|0)>>2]|0);continue}else if((_|0)==2){c[(f+284|0)>>2]=(c[(f+284|0)>>2]|0)!=(c[(f+404|0)>>2]|0);continue}else{continue}}c[(f+12|0)>>2]=c[(f+284|0)>>2]&c[(f+12|0)>>2];V=Z}if((p|0)==135){p=0;c[b>>2]=V;X=V}while(1){y=a[b+X+4>>0]|0;if(y<<24>>24==10|y<<24>>24==9|y<<24>>24==32|y<<24>>24==13){X=X+1|0;continue}c[b>>2]=X;if((a[b+X+4>>0]|0)!=94){break}aa=X+1|0;c[b>>2]=aa;if((lw(b,f+372|0,e)|0)==0){p=207;break h}l:while(1){y=c[b>>2]|0;while(1){M=a[b+y+4>>0]|0;if(!(M<<24>>24==10|M<<24>>24==9|M<<24>>24==32|M<<24>>24==13)){break}y=y+1|0}c[b>>2]=y;M=55328;N=61;O=y;while(1){if(!((a[b+O+4>>0]|0)==N<<24>>24)){ba=y;p=168;break}J=O+1|0;G=M+1|0;H=a[G>>0]|0;if(H<<24>>24==0){ca=1;da=J;break}else{M=G;N=H;O=J}}if((p|0)==168){while(1){p=0;O=a[b+ba+4>>0]|0;if(!(O<<24>>24==10|O<<24>>24==9|O<<24>>24==32|O<<24>>24==13)){break}ba=ba+1|0;p=168}c[b>>2]=ba;O=55336;N=33;M=ba;while(1){if(!((a[b+M+4>>0]|0)==N<<24>>24)){ea=ba;break l}y=M+1|0;J=O+1|0;H=a[J>>0]|0;if(H<<24>>24==0){ca=2;da=y;break}else{O=J;N=H;M=y}}}c[b>>2]=da;if((lw(b,f+176|0,e)|0)==0){p=174;break h}if((ca|0)==1){c[(f+372|0)>>2]=(c[(f+372|0)>>2]|0)==(c[(f+176|0)>>2]|0);continue}else if((ca|0)==2){c[(f+372|0)>>2]=(c[(f+372|0)>>2]|0)!=(c[(f+176|0)>>2]|0);continue}else{continue}}m:while(1){M=ea;while(1){N=a[b+M+4>>0]|0;if(!(N<<24>>24==10|N<<24>>24==9|N<<24>>24==32|N<<24>>24==13)){break}M=M+1|0}c[b>>2]=M;N=55320;O=38;y=M;while(1){if(!((a[b+y+4>>0]|0)==O<<24>>24)){fa=M;break}H=N+1|0;J=a[H>>0]|0;if(J<<24>>24==0){p=184;break m}else{N=H;O=J;y=y+1|0}}while(1){y=a[b+fa+4>>0]|0;if(!(y<<24>>24==10|y<<24>>24==9|y<<24>>24==32|y<<24>>24==13)){break}fa=fa+1|0}c[b>>2]=fa;if((a[b+fa+4>>0]|0)!=38){ga=fa;break}ha=fa+1|0;c[b>>2]=ha;if((lw(b,f+396|0,e)|0)==0){p=205;break h}n:while(1){y=c[b>>2]|0;while(1){O=a[b+y+4>>0]|0;if(!(O<<24>>24==10|O<<24>>24==9|O<<24>>24==32|O<<24>>24==13)){break}y=y+1|0}c[b>>2]=y;O=55328;N=61;M=y;while(1){if(!((a[b+M+4>>0]|0)==N<<24>>24)){ia=y;p=195;break}J=M+1|0;H=O+1|0;G=a[H>>0]|0;if(G<<24>>24==0){ja=1;ka=J;break}else{O=H;N=G;M=J}}if((p|0)==195){while(1){p=0;M=a[b+ia+4>>0]|0;if(!(M<<24>>24==10|M<<24>>24==9|M<<24>>24==32|M<<24>>24==13)){break}ia=ia+1|0;p=195}c[b>>2]=ia;M=55336;N=33;O=ia;while(1){if(!((a[b+O+4>>0]|0)==N<<24>>24)){break n}y=O+1|0;J=M+1|0;G=a[J>>0]|0;if(G<<24>>24==0){ja=2;ka=y;break}else{M=J;N=G;O=y}}}c[b>>2]=ka;if((lw(b,f+404|0,e)|0)==0){p=201;break h}if((ja|0)==1){c[(f+396|0)>>2]=(c[(f+396|0)>>2]|0)==(c[(f+404|0)>>2]|0);continue}else if((ja|0)==2){c[(f+396|0)>>2]=(c[(f+396|0)>>2]|0)!=(c[(f+404|0)>>2]|0);continue}else{continue}}c[(f+372|0)>>2]=c[(f+396|0)>>2]&c[(f+372|0)>>2];ea=ia}if((p|0)==184){p=0;c[b>>2]=ea;ga=ea}c[(f+12|0)>>2]=c[(f+372|0)>>2]^c[(f+12|0)>>2];X=ga}c[d>>2]=c[(f+12|0)>>2]|c[d>>2];I=X}if((p|0)==107){c[b>>2]=I;Q=I;p=111}else if((p|0)==125){c[b>>2]=R}else if((p|0)==152){c[b>>2]=Y;p=156}else if((p|0)==174){c[b>>2]=aa;p=207}else if((p|0)==201){c[b>>2]=ha;p=205}ha=1;if(ha){ha=0;if((p|0)==111){Y=Q;o:while(1){Q=a[b+Y+4>>0]|0;if(Q<<24>>24==10|Q<<24>>24==9|Q<<24>>24==32|Q<<24>>24==13){Y=Y+1|0;continue}c[b>>2]=Y;Q=55320;I=38;la=Y;do{if(!((a[b+la+4>>0]|0)==I<<24>>24)){p=215;break o}la=la+1|0;Q=Q+1|0;I=a[Q>>0]|0}while(!(I<<24>>24==0));c[b>>2]=la;if((lw(b,f+180|0,e)|0)==0){break}p:while(1){I=c[b>>2]|0;while(1){Q=a[b+I+4>>0]|0;if(!(Q<<24>>24==10|Q<<24>>24==9|Q<<24>>24==32|Q<<24>>24==13)){break}I=I+1|0}c[b>>2]=I;Q=55328;X=61;ga=I;while(1){if(!((a[b+ga+4>>0]|0)==X<<24>>24)){ma=I;p=224;break}ea=ga+1|0;ia=Q+1|0;ja=a[ia>>0]|0;if(ja<<24>>24==0){na=1;oa=ea;break}else{Q=ia;X=ja;ga=ea}}if((p|0)==224){while(1){p=0;ga=a[b+ma+4>>0]|0;if(!(ga<<24>>24==10|ga<<24>>24==9|ga<<24>>24==32|ga<<24>>24==13)){break}ma=ma+1|0;p=224}c[b>>2]=ma;ga=55336;X=33;Q=ma;while(1){if(!((a[b+Q+4>>0]|0)==X<<24>>24)){pa=ma;break p}I=Q+1|0;ea=ga+1|0;ja=a[ea>>0]|0;if(ja<<24>>24==0){na=2;oa=I;break}else{ga=ea;X=ja;Q=I}}}c[b>>2]=oa;if((lw(b,f+172|0,e)|0)==0){p=230;break o}if((na|0)==1){c[(f+180|0)>>2]=(c[(f+180|0)>>2]|0)==(c[(f+172|0)>>2]|0);continue}else if((na|0)==2){c[(f+180|0)>>2]=(c[(f+180|0)>>2]|0)!=(c[(f+172|0)>>2]|0);continue}else{continue}}q:while(1){Q=pa;while(1){X=a[b+Q+4>>0]|0;if(!(X<<24>>24==10|X<<24>>24==9|X<<24>>24==32|X<<24>>24==13)){break}Q=Q+1|0}c[b>>2]=Q;X=55320;ga=38;I=Q;while(1){if(!((a[b+I+4>>0]|0)==ga<<24>>24)){qa=Q;break}ja=X+1|0;ea=a[ja>>0]|0;if(ea<<24>>24==0){p=240;break q}else{X=ja;ga=ea;I=I+1|0}}while(1){I=a[b+qa+4>>0]|0;if(!(I<<24>>24==10|I<<24>>24==9|I<<24>>24==32|I<<24>>24==13)){break}qa=qa+1|0}c[b>>2]=qa;if((a[b+qa+4>>0]|0)!=38){ra=qa;break}sa=qa+1|0;c[b>>2]=sa;if((lw(b,f+280|0,e)|0)==0){p=261;break o}r:while(1){I=c[b>>2]|0;while(1){ga=a[b+I+4>>0]|0;if(!(ga<<24>>24==10|ga<<24>>24==9|ga<<24>>24==32|ga<<24>>24==13)){break}I=I+1|0}c[b>>2]=I;ga=55328;X=61;Q=I;while(1){if(!((a[b+Q+4>>0]|0)==X<<24>>24)){ta=I;p=251;break}ea=Q+1|0;ja=ga+1|0;ia=a[ja>>0]|0;if(ia<<24>>24==0){ua=1;va=ea;break}else{ga=ja;X=ia;Q=ea}}if((p|0)==251){while(1){p=0;Q=a[b+ta+4>>0]|0;if(!(Q<<24>>24==10|Q<<24>>24==9|Q<<24>>24==32|Q<<24>>24==13)){break}ta=ta+1|0;p=251}c[b>>2]=ta;Q=55336;X=33;ga=ta;while(1){if(!((a[b+ga+4>>0]|0)==X<<24>>24)){break r}I=ga+1|0;ea=Q+1|0;ia=a[ea>>0]|0;if(ia<<24>>24==0){ua=2;va=I;break}else{Q=ea;X=ia;ga=I}}}c[b>>2]=va;if((lw(b,f+404|0,e)|0)==0){p=257;break o}if((ua|0)==1){c[(f+280|0)>>2]=(c[(f+280|0)>>2]|0)==(c[(f+404|0)>>2]|0);continue}else if((ua|0)==2){c[(f+280|0)>>2]=(c[(f+280|0)>>2]|0)!=(c[(f+404|0)>>2]|0);continue}else{continue}}c[(f+180|0)>>2]=c[(f+280|0)>>2]&c[(f+180|0)>>2];pa=ta}if((p|0)==240){p=0;c[b>>2]=pa;ra=pa}while(1){ga=a[b+ra+4>>0]|0;if(ga<<24>>24==10|ga<<24>>24==9|ga<<24>>24==32|ga<<24>>24==13){ra=ra+1|0;continue}c[b>>2]=ra;if((a[b+ra+4>>0]|0)!=94){wa=ra;break}xa=ra+1|0;c[b>>2]=xa;if((lw(b,f+336|0,e)|0)==0){p=312;break o}s:while(1){ga=c[b>>2]|0;while(1){X=a[b+ga+4>>0]|0;if(!(X<<24>>24==10|X<<24>>24==9|X<<24>>24==32|X<<24>>24==13)){break}ga=ga+1|0}c[b>>2]=ga;X=55328;Q=61;I=ga;while(1){if(!((a[b+I+4>>0]|0)==Q<<24>>24)){ya=ga;p=273;break}ia=I+1|0;ea=X+1|0;ja=a[ea>>0]|0;if(ja<<24>>24==0){za=1;Aa=ia;break}else{X=ea;Q=ja;I=ia}}if((p|0)==273){while(1){p=0;I=a[b+ya+4>>0]|0;if(!(I<<24>>24==10|I<<24>>24==9|I<<24>>24==32|I<<24>>24==13)){break}ya=ya+1|0;p=273}c[b>>2]=ya;I=55336;Q=33;X=ya;while(1){if(!((a[b+X+4>>0]|0)==Q<<24>>24)){Ba=ya;break s}ga=X+1|0;ia=I+1|0;ja=a[ia>>0]|0;if(ja<<24>>24==0){za=2;Aa=ga;break}else{I=ia;Q=ja;X=ga}}}c[b>>2]=Aa;if((lw(b,f+168|0,e)|0)==0){p=279;break o}if((za|0)==1){c[(f+336|0)>>2]=(c[(f+336|0)>>2]|0)==(c[(f+168|0)>>2]|0);continue}else if((za|0)==2){c[(f+336|0)>>2]=(c[(f+336|0)>>2]|0)!=(c[(f+168|0)>>2]|0);continue}else{continue}}t:while(1){X=Ba;while(1){Q=a[b+X+4>>0]|0;if(!(Q<<24>>24==10|Q<<24>>24==9|Q<<24>>24==32|Q<<24>>24==13)){break}X=X+1|0}c[b>>2]=X;Q=55320;I=38;ga=X;while(1){if(!((a[b+ga+4>>0]|0)==I<<24>>24)){Ca=X;break}ja=Q+1|0;ia=a[ja>>0]|0;if(ia<<24>>24==0){p=289;break t}else{Q=ja;I=ia;ga=ga+1|0}}while(1){ga=a[b+Ca+4>>0]|0;if(!(ga<<24>>24==10|ga<<24>>24==9|ga<<24>>24==32|ga<<24>>24==13)){break}Ca=Ca+1|0}c[b>>2]=Ca;if((a[b+Ca+4>>0]|0)!=38){Da=Ca;break}Ea=Ca+1|0;c[b>>2]=Ea;if((lw(b,f+396|0,e)|0)==0){p=310;break o}u:while(1){ga=c[b>>2]|0;while(1){I=a[b+ga+4>>0]|0;if(!(I<<24>>24==10|I<<24>>24==9|I<<24>>24==32|I<<24>>24==13)){break}ga=ga+1|0}c[b>>2]=ga;I=55328;Q=61;X=ga;while(1){if(!((a[b+X+4>>0]|0)==Q<<24>>24)){Fa=ga;p=300;break}ia=X+1|0;ja=I+1|0;ea=a[ja>>0]|0;if(ea<<24>>24==0){Ga=1;Ha=ia;break}else{I=ja;Q=ea;X=ia}}if((p|0)==300){while(1){p=0;X=a[b+Fa+4>>0]|0;if(!(X<<24>>24==10|X<<24>>24==9|X<<24>>24==32|X<<24>>24==13)){break}Fa=Fa+1|0;p=300}c[b>>2]=Fa;X=55336;Q=33;I=Fa;while(1){if(!((a[b+I+4>>0]|0)==Q<<24>>24)){break u}ga=I+1|0;ia=X+1|0;ea=a[ia>>0]|0;if(ea<<24>>24==0){Ga=2;Ha=ga;break}else{X=ia;Q=ea;I=ga}}}c[b>>2]=Ha;if((lw(b,f+404|0,e)|0)==0){p=306;break o}if((Ga|0)==1){c[(f+396|0)>>2]=(c[(f+396|0)>>2]|0)==(c[(f+404|0)>>2]|0);continue}else if((Ga|0)==2){c[(f+396|0)>>2]=(c[(f+396|0)>>2]|0)!=(c[(f+404|0)>>2]|0);continue}else{continue}}c[(f+336|0)>>2]=c[(f+396|0)>>2]&c[(f+336|0)>>2];Ba=Fa}if((p|0)==289){p=0;c[b>>2]=Ba;Da=Ba}c[(f+180|0)>>2]=c[(f+336|0)>>2]^c[(f+180|0)>>2];ra=Da}v:while(1){I=wa;while(1){Q=a[b+I+4>>0]|0;if(!(Q<<24>>24==10|Q<<24>>24==9|Q<<24>>24==32|Q<<24>>24==13)){break}I=I+1|0}c[b>>2]=I;Q=55312;X=124;ga=I;while(1){if(!((a[b+ga+4>>0]|0)==X<<24>>24)){Ia=I;break}ea=Q+1|0;ia=a[ea>>0]|0;if(ia<<24>>24==0){p=320;break v}else{Q=ea;X=ia;ga=ga+1|0}}while(1){ga=a[b+Ia+4>>0]|0;if(!(ga<<24>>24==10|ga<<24>>24==9|ga<<24>>24==32|ga<<24>>24==13)){break}Ia=Ia+1|0}c[b>>2]=Ia;if((a[b+Ia+4>>0]|0)!=124){Ja=Ia;break}Ka=Ia+1|0;c[b>>2]=Ka;if((lw(b,f,e)|0)==0){p=421;break o}w:while(1){ga=c[b>>2]|0;while(1){X=a[b+ga+4>>0]|0;if(!(X<<24>>24==10|X<<24>>24==9|X<<24>>24==32|X<<24>>24==13)){break}ga=ga+1|0}c[b>>2]=ga;X=55328;Q=61;I=ga;while(1){if(!((a[b+I+4>>0]|0)==Q<<24>>24)){La=ga;p=331;break}ia=I+1|0;ea=X+1|0;ja=a[ea>>0]|0;if(ja<<24>>24==0){Ma=1;Na=ia;break}else{X=ea;Q=ja;I=ia}}if((p|0)==331){while(1){p=0;I=a[b+La+4>>0]|0;if(!(I<<24>>24==10|I<<24>>24==9|I<<24>>24==32|I<<24>>24==13)){break}La=La+1|0;p=331}c[b>>2]=La;I=55336;Q=33;X=La;while(1){if(!((a[b+X+4>>0]|0)==Q<<24>>24)){Oa=La;break w}ga=X+1|0;ia=I+1|0;ja=a[ia>>0]|0;if(ja<<24>>24==0){Ma=2;Na=ga;break}else{I=ia;Q=ja;X=ga}}}c[b>>2]=Na;if((lw(b,f+164|0,e)|0)==0){p=337;break o}if((Ma|0)==1){c[f>>2]=(c[f>>2]|0)==(c[(f+164|0)>>2]|0);continue}else if((Ma|0)==2){c[f>>2]=(c[f>>2]|0)!=(c[(f+164|0)>>2]|0);continue}else{continue}}x:while(1){X=Oa;while(1){Q=a[b+X+4>>0]|0;if(!(Q<<24>>24==10|Q<<24>>24==9|Q<<24>>24==32|Q<<24>>24==13)){break}X=X+1|0}c[b>>2]=X;Q=55320;I=38;ga=X;while(1){if(!((a[b+ga+4>>0]|0)==I<<24>>24)){Pa=X;break}ja=Q+1|0;ia=a[ja>>0]|0;if(ia<<24>>24==0){p=347;break x}else{Q=ja;I=ia;ga=ga+1|0}}while(1){ga=a[b+Pa+4>>0]|0;if(!(ga<<24>>24==10|ga<<24>>24==9|ga<<24>>24==32|ga<<24>>24==13)){break}Pa=Pa+1|0}c[b>>2]=Pa;if((a[b+Pa+4>>0]|0)!=38){Qa=Pa;break}Ra=Pa+1|0;c[b>>2]=Ra;if((lw(b,f+276|0,e)|0)==0){p=368;break o}y:while(1){ga=c[b>>2]|0;while(1){I=a[b+ga+4>>0]|0;if(!(I<<24>>24==10|I<<24>>24==9|I<<24>>24==32|I<<24>>24==13)){break}ga=ga+1|0}c[b>>2]=ga;I=55328;Q=61;X=ga;while(1){if(!((a[b+X+4>>0]|0)==Q<<24>>24)){Sa=ga;p=358;break}ia=X+1|0;ja=I+1|0;ea=a[ja>>0]|0;if(ea<<24>>24==0){Ta=1;Ua=ia;break}else{I=ja;Q=ea;X=ia}}if((p|0)==358){while(1){p=0;X=a[b+Sa+4>>0]|0;if(!(X<<24>>24==10|X<<24>>24==9|X<<24>>24==32|X<<24>>24==13)){break}Sa=Sa+1|0;p=358}c[b>>2]=Sa;X=55336;Q=33;I=Sa;while(1){if(!((a[b+I+4>>0]|0)==Q<<24>>24)){break y}ga=I+1|0;ia=X+1|0;ea=a[ia>>0]|0;if(ea<<24>>24==0){Ta=2;Ua=ga;break}else{X=ia;Q=ea;I=ga}}}c[b>>2]=Ua;if((lw(b,f+404|0,e)|0)==0){p=364;break o}if((Ta|0)==1){c[(f+276|0)>>2]=(c[(f+276|0)>>2]|0)==(c[(f+404|0)>>2]|0);continue}else if((Ta|0)==2){c[(f+276|0)>>2]=(c[(f+276|0)>>2]|0)!=(c[(f+404|0)>>2]|0);continue}else{continue}}c[f>>2]=c[(f+276|0)>>2]&c[f>>2];Oa=Sa}if((p|0)==347){p=0;c[b>>2]=Oa;Qa=Oa}while(1){I=a[b+Qa+4>>0]|0;if(I<<24>>24==10|I<<24>>24==9|I<<24>>24==32|I<<24>>24==13){Qa=Qa+1|0;continue}c[b>>2]=Qa;if((a[b+Qa+4>>0]|0)!=94){break}Va=Qa+1|0;c[b>>2]=Va;if((lw(b,f+372|0,e)|0)==0){p=419;break o}z:while(1){I=c[b>>2]|0;while(1){Q=a[b+I+4>>0]|0;if(!(Q<<24>>24==10|Q<<24>>24==9|Q<<24>>24==32|Q<<24>>24==13)){break}I=I+1|0}c[b>>2]=I;Q=55328;X=61;ga=I;while(1){if(!((a[b+ga+4>>0]|0)==X<<24>>24)){Wa=I;p=380;break}ea=ga+1|0;ia=Q+1|0;ja=a[ia>>0]|0;if(ja<<24>>24==0){Xa=1;Ya=ea;break}else{Q=ia;X=ja;ga=ea}}if((p|0)==380){while(1){p=0;ga=a[b+Wa+4>>0]|0;if(!(ga<<24>>24==10|ga<<24>>24==9|ga<<24>>24==32|ga<<24>>24==13)){break}Wa=Wa+1|0;p=380}c[b>>2]=Wa;ga=55336;X=33;Q=Wa;while(1){if(!((a[b+Q+4>>0]|0)==X<<24>>24)){Za=Wa;break z}I=Q+1|0;ea=ga+1|0;ja=a[ea>>0]|0;if(ja<<24>>24==0){Xa=2;Ya=I;break}else{ga=ea;X=ja;Q=I}}}c[b>>2]=Ya;if((lw(b,f+160|0,e)|0)==0){p=386;break o}if((Xa|0)==1){c[(f+372|0)>>2]=(c[(f+372|0)>>2]|0)==(c[(f+160|0)>>2]|0);continue}else if((Xa|0)==2){c[(f+372|0)>>2]=(c[(f+372|0)>>2]|0)!=(c[(f+160|0)>>2]|0);continue}else{continue}}A:while(1){Q=Za;while(1){X=a[b+Q+4>>0]|0;if(!(X<<24>>24==10|X<<24>>24==9|X<<24>>24==32|X<<24>>24==13)){break}Q=Q+1|0}c[b>>2]=Q;X=55320;ga=38;I=Q;while(1){if(!((a[b+I+4>>0]|0)==ga<<24>>24)){_a=Q;break}ja=X+1|0;ea=a[ja>>0]|0;if(ea<<24>>24==0){p=396;break A}else{X=ja;ga=ea;I=I+1|0}}while(1){I=a[b+_a+4>>0]|0;if(!(I<<24>>24==10|I<<24>>24==9|I<<24>>24==32|I<<24>>24==13)){break}_a=_a+1|0}c[b>>2]=_a;if((a[b+_a+4>>0]|0)!=38){$a=_a;break}ab=_a+1|0;c[b>>2]=ab;if((lw(b,f+396|0,e)|0)==0){p=417;break o}B:while(1){I=c[b>>2]|0;while(1){ga=a[b+I+4>>0]|0;if(!(ga<<24>>24==10|ga<<24>>24==9|ga<<24>>24==32|ga<<24>>24==13)){break}I=I+1|0}c[b>>2]=I;ga=55328;X=61;Q=I;while(1){if(!((a[b+Q+4>>0]|0)==X<<24>>24)){bb=I;p=407;break}ea=Q+1|0;ja=ga+1|0;ia=a[ja>>0]|0;if(ia<<24>>24==0){cb=1;db=ea;break}else{ga=ja;X=ia;Q=ea}}if((p|0)==407){while(1){p=0;Q=a[b+bb+4>>0]|0;if(!(Q<<24>>24==10|Q<<24>>24==9|Q<<24>>24==32|Q<<24>>24==13)){break}bb=bb+1|0;p=407}c[b>>2]=bb;Q=55336;X=33;ga=bb;while(1){if(!((a[b+ga+4>>0]|0)==X<<24>>24)){break B}I=ga+1|0;ea=Q+1|0;ia=a[ea>>0]|0;if(ia<<24>>24==0){cb=2;db=I;break}else{Q=ea;X=ia;ga=I}}}c[b>>2]=db;if((lw(b,f+404|0,e)|0)==0){p=413;break o}if((cb|0)==1){c[(f+396|0)>>2]=(c[(f+396|0)>>2]|0)==(c[(f+404|0)>>2]|0);continue}else if((cb|0)==2){c[(f+396|0)>>2]=(c[(f+396|0)>>2]|0)!=(c[(f+404|0)>>2]|0);continue}else{continue}}c[(f+372|0)>>2]=c[(f+396|0)>>2]&c[(f+372|0)>>2];Za=bb}if((p|0)==396){p=0;c[b>>2]=Za;$a=Za}c[f>>2]=c[(f+372|0)>>2]^c[f>>2];Qa=$a}c[(f+180|0)>>2]=c[f>>2]|c[(f+180|0)>>2];wa=Qa}if((p|0)==320){p=0;c[b>>2]=wa;Ja=wa}if((c[d>>2]|0)==0){eb=0}else{eb=(c[(f+180|0)>>2]|0)!=0}c[d>>2]=eb&1;Y=Ja}Ja=1;if(Ja){Ja=0;if((p|0)==215){eb=Y;c[f+424>>2]=b;c[f+432>>2]=d;c[f+440>>2]=e;c[f+448>>2]=j;c[f+4632>>2]=h;c[f+15352>>2]=eb;c[f+20912>>2]=p;c[f+21048>>2]=0;c[f+21052>>2]=0;_cmd_match_expr_cond$2(f);j=c[f+448>>2]|0;eb=c[f+15352>>2]|0;p=c[f+20912>>2]|0;E=c[f+21048>>2]|0;x=c[f+21052>>2]|0;F=+g[f+21052>>2];c[f+21048>>2]=0;c[f+21052>>2]=0;if((E|0)==6){return x|0}}else{Ja=1}}if(Ja){Ja=0;if((p|0)==230){c[b>>2]=la}else if((p|0)==257){c[b>>2]=sa;p=261}else if((p|0)==279){c[b>>2]=xa;p=312}else if((p|0)==306){c[b>>2]=Ea;p=310}else if((p|0)==337){c[b>>2]=Ka;p=421}else if((p|0)==364){c[b>>2]=Ra;p=368}else if((p|0)==386){c[b>>2]=Va;p=419}else if((p|0)==413)if(1){c[b>>2]=ab;p=417}else{Ja=1}}if((p|0)==261){c[b>>2]=la}else if((p|0)==310){c[b>>2]=xa;p=312}else if((p|0)==368){c[b>>2]=Ka;p=421}else if((p|0)==417){c[b>>2]=Va;p=419}if((p|0)==312){c[b>>2]=la}else if((p|0)==419){c[b>>2]=Ka;p=421}if((p|0)==421){c[b>>2]=la}c[b>>2]=h;j=0;i=f;return j|0}else{ha=1}}if(ha){ha=0;if((p|0)==156){c[b>>2]=R}else if((p|0)==205)if(1){c[b>>2]=aa;p=207}else{ha=1}}if((p|0)==207){c[b>>2]=R}c[b>>2]=h;j=0;i=f;return j|0}else{K=1}}if(K){K=0;if((p|0)==66){c[b>>2]=C}else if((p|0)==93)if(1){c[b>>2]=L;p=97}else{K=1}}if((p|0)==97){c[b>>2]=C}c[b>>2]=h;j=0;i=f;return j|0}function _cmd_match_expr_cond$0(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0;d=c[b+424>>2]|0;e=c[b+432>>2]|0;f=c[b+440>>2]|0;g=c[b+448>>2]|0;h=c[b+10280>>2]|0;j=c[b+10776>>2]|0;k=c[b+20912>>2]|0;a:do{b:while(1){l=j;while(1){m=a[d+l+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;m=55312;n=124;o=l;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){p=l;break}q=m+1|0;r=a[q>>0]|0;if(r<<24>>24==0){k=1827;break b}else{m=q;n=r;o=o+1|0}}while(1){o=a[d+p+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}p=p+1|0}c[d>>2]=p;if((a[d+p+4>>0]|0)!=124){s=p;k=1831;break}t=p+1|0;c[d>>2]=t;if((lw(d,b+352|0,f)|0)==0){break}c:while(1){o=c[d>>2]|0;while(1){n=a[d+o+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;n=55328;m=61;l=o;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){u=o;k=1839;break}r=l+1|0;q=n+1|0;v=a[q>>0]|0;if(v<<24>>24==0){w=1;x=r;break}else{n=q;m=v;l=r}}if((k|0)==1839){while(1){k=0;l=a[d+u+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}u=u+1|0;k=1839}c[d>>2]=u;l=55336;m=33;n=u;while(1){if(!((a[d+n+4>>0]|0)==m<<24>>24)){y=u;break c}o=n+1|0;r=l+1|0;v=a[r>>0]|0;if(v<<24>>24==0){w=2;x=o;break}else{l=r;m=v;n=o}}}c[d>>2]=x;if((lw(d,b+52|0,f)|0)==0){k=1845;break b}if((w|0)==1){c[(b+352|0)>>2]=(c[(b+352|0)>>2]|0)==(c[(b+52|0)>>2]|0);continue}else if((w|0)==2){c[(b+352|0)>>2]=(c[(b+352|0)>>2]|0)!=(c[(b+52|0)>>2]|0);continue}else{continue}}d:while(1){n=y;while(1){m=a[d+n+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;m=55320;l=38;o=n;while(1){if(!((a[d+o+4>>0]|0)==l<<24>>24)){z=n;break}v=m+1|0;r=a[v>>0]|0;if(r<<24>>24==0){k=1855;break d}else{m=v;l=r;o=o+1|0}}while(1){o=a[d+z+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}z=z+1|0}c[d>>2]=z;if((a[d+z+4>>0]|0)!=38){A=z;break}B=z+1|0;c[d>>2]=B;if((lw(d,b+220|0,f)|0)==0){k=1876;break b}e:while(1){o=c[d>>2]|0;while(1){l=a[d+o+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;l=55328;m=61;n=o;while(1){if(!((a[d+n+4>>0]|0)==m<<24>>24)){C=o;k=1866;break}r=n+1|0;v=l+1|0;q=a[v>>0]|0;if(q<<24>>24==0){D=1;E=r;break}else{l=v;m=q;n=r}}if((k|0)==1866){while(1){k=0;n=a[d+C+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}C=C+1|0;k=1866}c[d>>2]=C;n=55336;m=33;l=C;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){break e}o=l+1|0;r=n+1|0;q=a[r>>0]|0;if(q<<24>>24==0){D=2;E=o;break}else{n=r;m=q;l=o}}}c[d>>2]=E;if((lw(d,b+404|0,f)|0)==0){k=1872;break b}if((D|0)==1){c[(b+220|0)>>2]=(c[(b+220|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((D|0)==2){c[(b+220|0)>>2]=(c[(b+220|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+352|0)>>2]=c[(b+220|0)>>2]&c[(b+352|0)>>2];y=C}if((k|0)==1855){k=0;c[d>>2]=y;A=y}while(1){l=a[d+A+4>>0]|0;if(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13){A=A+1|0;continue}c[d>>2]=A;if((a[d+A+4>>0]|0)!=94){break}F=A+1|0;c[d>>2]=F;if((lw(d,b+372|0,f)|0)==0){k=1927;break b}f:while(1){l=c[d>>2]|0;while(1){m=a[d+l+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;m=55328;n=61;o=l;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){G=l;k=1888;break}q=o+1|0;r=m+1|0;v=a[r>>0]|0;if(v<<24>>24==0){H=1;I=q;break}else{m=r;n=v;o=q}}if((k|0)==1888){while(1){k=0;o=a[d+G+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}G=G+1|0;k=1888}c[d>>2]=G;o=55336;n=33;m=G;while(1){if(!((a[d+m+4>>0]|0)==n<<24>>24)){J=G;break f}l=m+1|0;q=o+1|0;v=a[q>>0]|0;if(v<<24>>24==0){H=2;I=l;break}else{o=q;n=v;m=l}}}c[d>>2]=I;if((lw(d,b+48|0,f)|0)==0){k=1894;break b}if((H|0)==1){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)==(c[(b+48|0)>>2]|0);continue}else if((H|0)==2){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)!=(c[(b+48|0)>>2]|0);continue}else{continue}}g:while(1){m=J;while(1){n=a[d+m+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}m=m+1|0}c[d>>2]=m;n=55320;o=38;l=m;while(1){if(!((a[d+l+4>>0]|0)==o<<24>>24)){K=m;break}v=n+1|0;q=a[v>>0]|0;if(q<<24>>24==0){k=1904;break g}else{n=v;o=q;l=l+1|0}}while(1){l=a[d+K+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}K=K+1|0}c[d>>2]=K;if((a[d+K+4>>0]|0)!=38){L=K;break}M=K+1|0;c[d>>2]=M;if((lw(d,b+396|0,f)|0)==0){k=1925;break b}h:while(1){l=c[d>>2]|0;while(1){o=a[d+l+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;o=55328;n=61;m=l;while(1){if(!((a[d+m+4>>0]|0)==n<<24>>24)){N=l;k=1915;break}q=m+1|0;v=o+1|0;r=a[v>>0]|0;if(r<<24>>24==0){O=1;P=q;break}else{o=v;n=r;m=q}}if((k|0)==1915){while(1){k=0;m=a[d+N+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}N=N+1|0;k=1915}c[d>>2]=N;m=55336;n=33;o=N;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){break h}l=o+1|0;q=m+1|0;r=a[q>>0]|0;if(r<<24>>24==0){O=2;P=l;break}else{m=q;n=r;o=l}}}c[d>>2]=P;if((lw(d,b+404|0,f)|0)==0){k=1921;break b}if((O|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((O|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+372|0)>>2]=c[(b+396|0)>>2]&c[(b+372|0)>>2];J=N}if((k|0)==1904){k=0;c[d>>2]=J;L=J}c[(b+352|0)>>2]=c[(b+372|0)>>2]^c[(b+352|0)>>2];A=L}c[(b+388|0)>>2]=c[(b+352|0)>>2]|c[(b+388|0)>>2];j=A}if((k|0)==1827){c[d>>2]=j;s=j;k=1831}else if((k|0)==1845){c[d>>2]=t}else if((k|0)==1872){c[d>>2]=B;k=1876}else if((k|0)==1894){c[d>>2]=F;k=1927}else if((k|0)==1921){c[d>>2]=M;k=1925}o=1;if(o){o=0;if((k|0)==1831){n=s;i:while(1){m=a[d+n+4>>0]|0;if(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13){n=n+1|0;continue}c[d>>2]=n;m=55320;l=38;Q=n;do{if(!((a[d+Q+4>>0]|0)==l<<24>>24)){k=1935;break i}Q=Q+1|0;m=m+1|0;l=a[m>>0]|0}while(!(l<<24>>24==0));c[d>>2]=Q;if((lw(d,b+16|0,f)|0)==0){break}j:while(1){l=c[d>>2]|0;while(1){m=a[d+l+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;m=55328;r=61;q=l;while(1){if(!((a[d+q+4>>0]|0)==r<<24>>24)){R=l;k=1944;break}v=q+1|0;S=m+1|0;T=a[S>>0]|0;if(T<<24>>24==0){U=1;V=v;break}else{m=S;r=T;q=v}}if((k|0)==1944){while(1){k=0;q=a[d+R+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}R=R+1|0;k=1944}c[d>>2]=R;q=55336;r=33;m=R;while(1){if(!((a[d+m+4>>0]|0)==r<<24>>24)){W=R;break j}l=m+1|0;v=q+1|0;T=a[v>>0]|0;if(T<<24>>24==0){U=2;V=l;break}else{q=v;r=T;m=l}}}c[d>>2]=V;if((lw(d,b+44|0,f)|0)==0){k=1950;break i}if((U|0)==1){c[(b+16|0)>>2]=(c[(b+16|0)>>2]|0)==(c[(b+44|0)>>2]|0);continue}else if((U|0)==2){c[(b+16|0)>>2]=(c[(b+16|0)>>2]|0)!=(c[(b+44|0)>>2]|0);continue}else{continue}}k:while(1){m=W;while(1){r=a[d+m+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}m=m+1|0}c[d>>2]=m;r=55320;q=38;l=m;while(1){if(!((a[d+l+4>>0]|0)==q<<24>>24)){X=m;break}T=r+1|0;v=a[T>>0]|0;if(v<<24>>24==0){k=1960;break k}else{r=T;q=v;l=l+1|0}}while(1){l=a[d+X+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}X=X+1|0}c[d>>2]=X;if((a[d+X+4>>0]|0)!=38){Y=X;break}Z=X+1|0;c[d>>2]=Z;if((lw(d,b+216|0,f)|0)==0){k=1981;break i}l:while(1){l=c[d>>2]|0;while(1){q=a[d+l+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;q=55328;r=61;m=l;while(1){if(!((a[d+m+4>>0]|0)==r<<24>>24)){_=l;k=1971;break}v=m+1|0;T=q+1|0;S=a[T>>0]|0;if(S<<24>>24==0){$=1;aa=v;break}else{q=T;r=S;m=v}}if((k|0)==1971){while(1){k=0;m=a[d+_+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}_=_+1|0;k=1971}c[d>>2]=_;m=55336;r=33;q=_;while(1){if(!((a[d+q+4>>0]|0)==r<<24>>24)){break l}l=q+1|0;v=m+1|0;S=a[v>>0]|0;if(S<<24>>24==0){$=2;aa=l;break}else{m=v;r=S;q=l}}}c[d>>2]=aa;if((lw(d,b+404|0,f)|0)==0){k=1977;break i}if(($|0)==1){c[(b+216|0)>>2]=(c[(b+216|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if(($|0)==2){c[(b+216|0)>>2]=(c[(b+216|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+16|0)>>2]=c[(b+216|0)>>2]&c[(b+16|0)>>2];W=_}if((k|0)==1960){k=0;c[d>>2]=W;Y=W}while(1){q=a[d+Y+4>>0]|0;if(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13){Y=Y+1|0;continue}c[d>>2]=Y;if((a[d+Y+4>>0]|0)!=94){ba=Y;break}ca=Y+1|0;c[d>>2]=ca;if((lw(d,b+304|0,f)|0)==0){k=2032;break i}m:while(1){q=c[d>>2]|0;while(1){r=a[d+q+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;r=55328;m=61;l=q;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){da=q;k=1993;break}S=l+1|0;v=r+1|0;T=a[v>>0]|0;if(T<<24>>24==0){ea=1;fa=S;break}else{r=v;m=T;l=S}}if((k|0)==1993){while(1){k=0;l=a[d+da+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}da=da+1|0;k=1993}c[d>>2]=da;l=55336;m=33;r=da;while(1){if(!((a[d+r+4>>0]|0)==m<<24>>24)){ga=da;break m}q=r+1|0;S=l+1|0;T=a[S>>0]|0;if(T<<24>>24==0){ea=2;fa=q;break}else{l=S;m=T;r=q}}}c[d>>2]=fa;if((lw(d,b+40|0,f)|0)==0){k=1999;break i}if((ea|0)==1){c[(b+304|0)>>2]=(c[(b+304|0)>>2]|0)==(c[(b+40|0)>>2]|0);continue}else if((ea|0)==2){c[(b+304|0)>>2]=(c[(b+304|0)>>2]|0)!=(c[(b+40|0)>>2]|0);continue}else{continue}}n:while(1){r=ga;while(1){m=a[d+r+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;m=55320;l=38;q=r;while(1){if(!((a[d+q+4>>0]|0)==l<<24>>24)){ha=r;break}T=m+1|0;S=a[T>>0]|0;if(S<<24>>24==0){k=2009;break n}else{m=T;l=S;q=q+1|0}}while(1){q=a[d+ha+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}ha=ha+1|0}c[d>>2]=ha;if((a[d+ha+4>>0]|0)!=38){ia=ha;break}ja=ha+1|0;c[d>>2]=ja;if((lw(d,b+396|0,f)|0)==0){k=2030;break i}o:while(1){q=c[d>>2]|0;while(1){l=a[d+q+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;l=55328;m=61;r=q;while(1){if(!((a[d+r+4>>0]|0)==m<<24>>24)){ka=q;k=2020;break}S=r+1|0;T=l+1|0;v=a[T>>0]|0;if(v<<24>>24==0){la=1;ma=S;break}else{l=T;m=v;r=S}}if((k|0)==2020){while(1){k=0;r=a[d+ka+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}ka=ka+1|0;k=2020}c[d>>2]=ka;r=55336;m=33;l=ka;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){break o}q=l+1|0;S=r+1|0;v=a[S>>0]|0;if(v<<24>>24==0){la=2;ma=q;break}else{r=S;m=v;l=q}}}c[d>>2]=ma;if((lw(d,b+404|0,f)|0)==0){k=2026;break i}if((la|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((la|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+304|0)>>2]=c[(b+396|0)>>2]&c[(b+304|0)>>2];ga=ka}if((k|0)==2009){k=0;c[d>>2]=ga;ia=ga}c[(b+16|0)>>2]=c[(b+304|0)>>2]^c[(b+16|0)>>2];Y=ia}p:while(1){l=ba;while(1){m=a[d+l+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;m=55312;r=124;q=l;while(1){if(!((a[d+q+4>>0]|0)==r<<24>>24)){na=l;break}v=m+1|0;S=a[v>>0]|0;if(S<<24>>24==0){k=2040;break p}else{m=v;r=S;q=q+1|0}}while(1){q=a[d+na+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}na=na+1|0}c[d>>2]=na;if((a[d+na+4>>0]|0)!=124){oa=na;break}pa=na+1|0;c[d>>2]=pa;if((lw(d,b,f)|0)==0){k=2141;break i}q:while(1){q=c[d>>2]|0;while(1){r=a[d+q+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;r=55328;m=61;l=q;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){qa=q;k=2051;break}S=l+1|0;v=r+1|0;T=a[v>>0]|0;if(T<<24>>24==0){ra=1;sa=S;break}else{r=v;m=T;l=S}}if((k|0)==2051){while(1){k=0;l=a[d+qa+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}qa=qa+1|0;k=2051}c[d>>2]=qa;l=55336;m=33;r=qa;while(1){if(!((a[d+r+4>>0]|0)==m<<24>>24)){ta=qa;break q}q=r+1|0;S=l+1|0;T=a[S>>0]|0;if(T<<24>>24==0){ra=2;sa=q;break}else{l=S;m=T;r=q}}}c[d>>2]=sa;if((lw(d,b+36|0,f)|0)==0){k=2057;break i}if((ra|0)==1){c[b>>2]=(c[b>>2]|0)==(c[(b+36|0)>>2]|0);continue}else if((ra|0)==2){c[b>>2]=(c[b>>2]|0)!=(c[(b+36|0)>>2]|0);continue}else{continue}}r:while(1){r=ta;while(1){m=a[d+r+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;m=55320;l=38;q=r;while(1){if(!((a[d+q+4>>0]|0)==l<<24>>24)){ua=r;break}T=m+1|0;S=a[T>>0]|0;if(S<<24>>24==0){k=2067;break r}else{m=T;l=S;q=q+1|0}}while(1){q=a[d+ua+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}ua=ua+1|0}c[d>>2]=ua;if((a[d+ua+4>>0]|0)!=38){va=ua;break}wa=ua+1|0;c[d>>2]=wa;if((lw(d,b+212|0,f)|0)==0){k=2088;break i}s:while(1){q=c[d>>2]|0;while(1){l=a[d+q+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;l=55328;m=61;r=q;while(1){if(!((a[d+r+4>>0]|0)==m<<24>>24)){xa=q;k=2078;break}S=r+1|0;T=l+1|0;v=a[T>>0]|0;if(v<<24>>24==0){ya=1;za=S;break}else{l=T;m=v;r=S}}if((k|0)==2078){while(1){k=0;r=a[d+xa+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}xa=xa+1|0;k=2078}c[d>>2]=xa;r=55336;m=33;l=xa;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){break s}q=l+1|0;S=r+1|0;v=a[S>>0]|0;if(v<<24>>24==0){ya=2;za=q;break}else{r=S;m=v;l=q}}}c[d>>2]=za;if((lw(d,b+404|0,f)|0)==0){k=2084;break i}if((ya|0)==1){c[(b+212|0)>>2]=(c[(b+212|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((ya|0)==2){c[(b+212|0)>>2]=(c[(b+212|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[b>>2]=c[(b+212|0)>>2]&c[b>>2];ta=xa}if((k|0)==2067){k=0;c[d>>2]=ta;va=ta}while(1){l=a[d+va+4>>0]|0;if(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13){va=va+1|0;continue}c[d>>2]=va;if((a[d+va+4>>0]|0)!=94){break}Aa=va+1|0;c[d>>2]=Aa;if((lw(d,b+372|0,f)|0)==0){k=2139;break i}t:while(1){l=c[d>>2]|0;while(1){m=a[d+l+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;m=55328;r=61;q=l;while(1){if(!((a[d+q+4>>0]|0)==r<<24>>24)){Ba=l;k=2100;break}v=q+1|0;S=m+1|0;T=a[S>>0]|0;if(T<<24>>24==0){Ca=1;Da=v;break}else{m=S;r=T;q=v}}if((k|0)==2100){while(1){k=0;q=a[d+Ba+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}Ba=Ba+1|0;k=2100}c[d>>2]=Ba;q=55336;r=33;m=Ba;while(1){if(!((a[d+m+4>>0]|0)==r<<24>>24)){Ea=Ba;break t}l=m+1|0;v=q+1|0;T=a[v>>0]|0;if(T<<24>>24==0){Ca=2;Da=l;break}else{q=v;r=T;m=l}}}c[d>>2]=Da;if((lw(d,b+32|0,f)|0)==0){k=2106;break i}if((Ca|0)==1){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)==(c[(b+32|0)>>2]|0);continue}else if((Ca|0)==2){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)!=(c[(b+32|0)>>2]|0);continue}else{continue}}u:while(1){m=Ea;while(1){r=a[d+m+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}m=m+1|0}c[d>>2]=m;r=55320;q=38;l=m;while(1){if(!((a[d+l+4>>0]|0)==q<<24>>24)){Fa=m;break}T=r+1|0;v=a[T>>0]|0;if(v<<24>>24==0){k=2116;break u}else{r=T;q=v;l=l+1|0}}while(1){l=a[d+Fa+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}Fa=Fa+1|0}c[d>>2]=Fa;if((a[d+Fa+4>>0]|0)!=38){Ga=Fa;break}Ha=Fa+1|0;c[d>>2]=Ha;if((lw(d,b+396|0,f)|0)==0){k=2137;break i}v:while(1){l=c[d>>2]|0;while(1){q=a[d+l+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;q=55328;r=61;m=l;while(1){if(!((a[d+m+4>>0]|0)==r<<24>>24)){Ia=l;k=2127;break}v=m+1|0;T=q+1|0;S=a[T>>0]|0;if(S<<24>>24==0){Ja=1;Ka=v;break}else{q=T;r=S;m=v}}if((k|0)==2127){while(1){k=0;m=a[d+Ia+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}Ia=Ia+1|0;k=2127}c[d>>2]=Ia;m=55336;r=33;q=Ia;while(1){if(!((a[d+q+4>>0]|0)==r<<24>>24)){break v}l=q+1|0;v=m+1|0;S=a[v>>0]|0;if(S<<24>>24==0){Ja=2;Ka=l;break}else{m=v;r=S;q=l}}}c[d>>2]=Ka;if((lw(d,b+404|0,f)|0)==0){k=2133;break i}if((Ja|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((Ja|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+372|0)>>2]=c[(b+396|0)>>2]&c[(b+372|0)>>2];Ea=Ia}if((k|0)==2116){k=0;c[d>>2]=Ea;Ga=Ea}c[b>>2]=c[(b+372|0)>>2]^c[b>>2];va=Ga}c[(b+16|0)>>2]=c[b>>2]|c[(b+16|0)>>2];ba=va}if((k|0)==2040){k=0;c[d>>2]=ba;oa=ba}if((c[(b+388|0)>>2]|0)==0){La=0}else{La=(c[(b+16|0)>>2]|0)!=0}c[(b+388|0)>>2]=La&1;n=oa}q=1;if(q){q=0;if((k|0)==1935){r=n;w:while(1){m=a[d+r+4>>0]|0;if(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13){r=r+1|0;continue}c[d>>2]=r;m=55312;l=124;Ma=r;do{if(!((a[d+Ma+4>>0]|0)==l<<24>>24)){k=2578;break w}Ma=Ma+1|0;m=m+1|0;l=a[m>>0]|0}while(!(l<<24>>24==0));c[d>>2]=Ma;if((lw(d,b+364|0,f)|0)==0){break}x:while(1){l=c[d>>2]|0;while(1){m=a[d+l+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;m=55328;S=61;v=l;while(1){if(!((a[d+v+4>>0]|0)==S<<24>>24)){Na=l;k=2159;break}T=v+1|0;Oa=m+1|0;Pa=a[Oa>>0]|0;if(Pa<<24>>24==0){Qa=1;Ra=T;break}else{m=Oa;S=Pa;v=T}}if((k|0)==2159){while(1){k=0;v=a[d+Na+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}Na=Na+1|0;k=2159}c[d>>2]=Na;v=55336;S=33;m=Na;while(1){if(!((a[d+m+4>>0]|0)==S<<24>>24)){Sa=Na;break x}l=m+1|0;T=v+1|0;Pa=a[T>>0]|0;if(Pa<<24>>24==0){Qa=2;Ra=l;break}else{v=T;S=Pa;m=l}}}c[d>>2]=Ra;if((lw(d,b+28|0,f)|0)==0){k=2165;break w}if((Qa|0)==1){c[(b+364|0)>>2]=(c[(b+364|0)>>2]|0)==(c[(b+28|0)>>2]|0);continue}else if((Qa|0)==2){c[(b+364|0)>>2]=(c[(b+364|0)>>2]|0)!=(c[(b+28|0)>>2]|0);continue}else{continue}}y:while(1){m=Sa;while(1){S=a[d+m+4>>0]|0;if(!(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13)){break}m=m+1|0}c[d>>2]=m;S=55320;v=38;l=m;while(1){if(!((a[d+l+4>>0]|0)==v<<24>>24)){Ta=m;break}Pa=S+1|0;T=a[Pa>>0]|0;if(T<<24>>24==0){k=2175;break y}else{S=Pa;v=T;l=l+1|0}}while(1){l=a[d+Ta+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}Ta=Ta+1|0}c[d>>2]=Ta;if((a[d+Ta+4>>0]|0)!=38){Ua=Ta;break}Va=Ta+1|0;c[d>>2]=Va;if((lw(d,b+208|0,f)|0)==0){k=2196;break w}z:while(1){l=c[d>>2]|0;while(1){v=a[d+l+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;v=55328;S=61;m=l;while(1){if(!((a[d+m+4>>0]|0)==S<<24>>24)){Wa=l;k=2186;break}T=m+1|0;Pa=v+1|0;Oa=a[Pa>>0]|0;if(Oa<<24>>24==0){Xa=1;Ya=T;break}else{v=Pa;S=Oa;m=T}}if((k|0)==2186){while(1){k=0;m=a[d+Wa+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}Wa=Wa+1|0;k=2186}c[d>>2]=Wa;m=55336;S=33;v=Wa;while(1){if(!((a[d+v+4>>0]|0)==S<<24>>24)){break z}l=v+1|0;T=m+1|0;Oa=a[T>>0]|0;if(Oa<<24>>24==0){Xa=2;Ya=l;break}else{m=T;S=Oa;v=l}}}c[d>>2]=Ya;if((lw(d,b+404|0,f)|0)==0){k=2192;break w}if((Xa|0)==1){c[(b+208|0)>>2]=(c[(b+208|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((Xa|0)==2){c[(b+208|0)>>2]=(c[(b+208|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+364|0)>>2]=c[(b+208|0)>>2]&c[(b+364|0)>>2];Sa=Wa}if((k|0)==2175){k=0;c[d>>2]=Sa;Ua=Sa}while(1){v=a[d+Ua+4>>0]|0;if(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13){Ua=Ua+1|0;continue}c[d>>2]=Ua;if((a[d+Ua+4>>0]|0)!=94){Za=Ua;break}_a=Ua+1|0;c[d>>2]=_a;if((lw(d,b+300|0,f)|0)==0){k=2247;break w}A:while(1){v=c[d>>2]|0;while(1){S=a[d+v+4>>0]|0;if(!(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13)){break}v=v+1|0}c[d>>2]=v;S=55328;m=61;l=v;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){$a=v;k=2208;break}Oa=l+1|0;T=S+1|0;Pa=a[T>>0]|0;if(Pa<<24>>24==0){ab=1;bb=Oa;break}else{S=T;m=Pa;l=Oa}}if((k|0)==2208){while(1){k=0;l=a[d+$a+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}$a=$a+1|0;k=2208}c[d>>2]=$a;l=55336;m=33;S=$a;while(1){if(!((a[d+S+4>>0]|0)==m<<24>>24)){cb=$a;break A}v=S+1|0;Oa=l+1|0;Pa=a[Oa>>0]|0;if(Pa<<24>>24==0){ab=2;bb=v;break}else{l=Oa;m=Pa;S=v}}}c[d>>2]=bb;if((lw(d,b+196|0,f)|0)==0){k=2214;break w}if((ab|0)==1){c[(b+300|0)>>2]=(c[(b+300|0)>>2]|0)==(c[(b+196|0)>>2]|0);continue}else if((ab|0)==2){c[(b+300|0)>>2]=(c[(b+300|0)>>2]|0)!=(c[(b+196|0)>>2]|0);continue}else{continue}}B:while(1){S=cb;while(1){m=a[d+S+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}S=S+1|0}c[d>>2]=S;m=55320;l=38;v=S;while(1){if(!((a[d+v+4>>0]|0)==l<<24>>24)){db=S;break}Pa=m+1|0;Oa=a[Pa>>0]|0;if(Oa<<24>>24==0){k=2224;break B}else{m=Pa;l=Oa;v=v+1|0}}while(1){v=a[d+db+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}db=db+1|0}c[d>>2]=db;if((a[d+db+4>>0]|0)!=38){eb=db;break}fb=db+1|0;c[d>>2]=fb;if((lw(d,b+392|0,f)|0)==0){k=2245;break w}C:while(1){v=c[d>>2]|0;while(1){l=a[d+v+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}v=v+1|0}c[d>>2]=v;l=55328;m=61;S=v;while(1){if(!((a[d+S+4>>0]|0)==m<<24>>24)){gb=v;k=2235;break}Oa=S+1|0;Pa=l+1|0;T=a[Pa>>0]|0;if(T<<24>>24==0){hb=1;ib=Oa;break}else{l=Pa;m=T;S=Oa}}if((k|0)==2235){while(1){k=0;S=a[d+gb+4>>0]|0;if(!(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13)){break}gb=gb+1|0;k=2235}c[d>>2]=gb;S=55336;m=33;l=gb;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){break C}v=l+1|0;Oa=S+1|0;T=a[Oa>>0]|0;if(T<<24>>24==0){hb=2;ib=v;break}else{S=Oa;m=T;l=v}}}c[d>>2]=ib;if((lw(d,b+404|0,f)|0)==0){k=2241;break w}if((hb|0)==1){c[(b+392|0)>>2]=(c[(b+392|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((hb|0)==2){c[(b+392|0)>>2]=(c[(b+392|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+300|0)>>2]=c[(b+392|0)>>2]&c[(b+300|0)>>2];cb=gb}if((k|0)==2224){k=0;c[d>>2]=cb;eb=cb}c[(b+364|0)>>2]=c[(b+300|0)>>2]^c[(b+364|0)>>2];Ua=eb}D:while(1){l=Za;while(1){m=a[d+l+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;m=55312;S=124;v=l;while(1){if(!((a[d+v+4>>0]|0)==S<<24>>24)){jb=l;break}T=m+1|0;Oa=a[T>>0]|0;if(Oa<<24>>24==0){k=2255;break D}else{m=T;S=Oa;v=v+1|0}}while(1){v=a[d+jb+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}jb=jb+1|0}c[d>>2]=jb;if((a[d+jb+4>>0]|0)!=124){kb=jb;break}lb=jb+1|0;c[d>>2]=lb;if((lw(d,b+348|0,f)|0)==0){k=2356;break w}E:while(1){v=c[d>>2]|0;while(1){S=a[d+v+4>>0]|0;if(!(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13)){break}v=v+1|0}c[d>>2]=v;S=55328;m=61;l=v;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){mb=v;k=2266;break}Oa=l+1|0;T=S+1|0;Pa=a[T>>0]|0;if(Pa<<24>>24==0){nb=1;ob=Oa;break}else{S=T;m=Pa;l=Oa}}if((k|0)==2266){while(1){k=0;l=a[d+mb+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}mb=mb+1|0;k=2266}c[d>>2]=mb;l=55336;m=33;S=mb;while(1){if(!((a[d+S+4>>0]|0)==m<<24>>24)){pb=mb;break E}v=S+1|0;Oa=l+1|0;Pa=a[Oa>>0]|0;if(Pa<<24>>24==0){nb=2;ob=v;break}else{l=Oa;m=Pa;S=v}}}c[d>>2]=ob;if((lw(d,b+200|0,f)|0)==0){k=2272;break w}if((nb|0)==1){c[(b+348|0)>>2]=(c[(b+348|0)>>2]|0)==(c[(b+200|0)>>2]|0);continue}else if((nb|0)==2){c[(b+348|0)>>2]=(c[(b+348|0)>>2]|0)!=(c[(b+200|0)>>2]|0);continue}else{continue}}F:while(1){S=pb;while(1){m=a[d+S+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}S=S+1|0}c[d>>2]=S;m=55320;l=38;v=S;while(1){if(!((a[d+v+4>>0]|0)==l<<24>>24)){qb=S;break}Pa=m+1|0;Oa=a[Pa>>0]|0;if(Oa<<24>>24==0){k=2282;break F}else{m=Pa;l=Oa;v=v+1|0}}while(1){v=a[d+qb+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}qb=qb+1|0}c[d>>2]=qb;if((a[d+qb+4>>0]|0)!=38){rb=qb;break}sb=qb+1|0;c[d>>2]=sb;if((lw(d,b+204|0,f)|0)==0){k=2303;break w}G:while(1){v=c[d>>2]|0;while(1){l=a[d+v+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}v=v+1|0}c[d>>2]=v;l=55328;m=61;S=v;while(1){if(!((a[d+S+4>>0]|0)==m<<24>>24)){tb=v;k=2293;break}Oa=S+1|0;Pa=l+1|0;T=a[Pa>>0]|0;if(T<<24>>24==0){ub=1;vb=Oa;break}else{l=Pa;m=T;S=Oa}}if((k|0)==2293){while(1){k=0;S=a[d+tb+4>>0]|0;if(!(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13)){break}tb=tb+1|0;k=2293}c[d>>2]=tb;S=55336;m=33;l=tb;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){break G}v=l+1|0;Oa=S+1|0;T=a[Oa>>0]|0;if(T<<24>>24==0){ub=2;vb=v;break}else{S=Oa;m=T;l=v}}}c[d>>2]=vb;if((lw(d,b+404|0,f)|0)==0){k=2299;break w}if((ub|0)==1){c[(b+204|0)>>2]=(c[(b+204|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((ub|0)==2){c[(b+204|0)>>2]=(c[(b+204|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+348|0)>>2]=c[(b+204|0)>>2]&c[(b+348|0)>>2];pb=tb}if((k|0)==2282){k=0;c[d>>2]=pb;rb=pb}while(1){l=a[d+rb+4>>0]|0;if(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13){rb=rb+1|0;continue}c[d>>2]=rb;if((a[d+rb+4>>0]|0)!=94){break}wb=rb+1|0;c[d>>2]=wb;if((lw(d,b+292|0,f)|0)==0){k=2354;break w}H:while(1){l=c[d>>2]|0;while(1){m=a[d+l+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;m=55328;S=61;v=l;while(1){if(!((a[d+v+4>>0]|0)==S<<24>>24)){xb=l;k=2315;break}T=v+1|0;Oa=m+1|0;Pa=a[Oa>>0]|0;if(Pa<<24>>24==0){yb=1;zb=T;break}else{m=Oa;S=Pa;v=T}}if((k|0)==2315){while(1){k=0;v=a[d+xb+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}xb=xb+1|0;k=2315}c[d>>2]=xb;v=55336;S=33;m=xb;while(1){if(!((a[d+m+4>>0]|0)==S<<24>>24)){Ab=xb;break H}l=m+1|0;T=v+1|0;Pa=a[T>>0]|0;if(Pa<<24>>24==0){yb=2;zb=l;break}else{v=T;S=Pa;m=l}}}c[d>>2]=zb;if((lw(d,b+188|0,f)|0)==0){k=2321;break w}if((yb|0)==1){c[(b+292|0)>>2]=(c[(b+292|0)>>2]|0)==(c[(b+188|0)>>2]|0);continue}else if((yb|0)==2){c[(b+292|0)>>2]=(c[(b+292|0)>>2]|0)!=(c[(b+188|0)>>2]|0);continue}else{continue}}I:while(1){m=Ab;while(1){S=a[d+m+4>>0]|0;if(!(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13)){break}m=m+1|0}c[d>>2]=m;S=55320;v=38;l=m;while(1){if(!((a[d+l+4>>0]|0)==v<<24>>24)){Bb=m;break}Pa=S+1|0;T=a[Pa>>0]|0;if(T<<24>>24==0){k=2331;break I}else{S=Pa;v=T;l=l+1|0}}while(1){l=a[d+Bb+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}Bb=Bb+1|0}c[d>>2]=Bb;if((a[d+Bb+4>>0]|0)!=38){Cb=Bb;break}Db=Bb+1|0;c[d>>2]=Db;if((lw(d,b+392|0,f)|0)==0){k=2352;break w}J:while(1){l=c[d>>2]|0;while(1){v=a[d+l+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;v=55328;S=61;m=l;while(1){if(!((a[d+m+4>>0]|0)==S<<24>>24)){Eb=l;k=2342;break}T=m+1|0;Pa=v+1|0;Oa=a[Pa>>0]|0;if(Oa<<24>>24==0){Fb=1;Gb=T;break}else{v=Pa;S=Oa;m=T}}if((k|0)==2342){while(1){k=0;m=a[d+Eb+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}Eb=Eb+1|0;k=2342}c[d>>2]=Eb;m=55336;S=33;v=Eb;while(1){if(!((a[d+v+4>>0]|0)==S<<24>>24)){break J}l=v+1|0;T=m+1|0;Oa=a[T>>0]|0;if(Oa<<24>>24==0){Fb=2;Gb=l;break}else{m=T;S=Oa;v=l}}}c[d>>2]=Gb;if((lw(d,b+404|0,f)|0)==0){k=2348;break w}if((Fb|0)==1){c[(b+392|0)>>2]=(c[(b+392|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((Fb|0)==2){c[(b+392|0)>>2]=(c[(b+392|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+292|0)>>2]=c[(b+392|0)>>2]&c[(b+292|0)>>2];Ab=Eb}if((k|0)==2331){k=0;c[d>>2]=Ab;Cb=Ab}c[(b+348|0)>>2]=c[(b+292|0)>>2]^c[(b+348|0)>>2];rb=Cb}c[(b+364|0)>>2]=c[(b+348|0)>>2]|c[(b+364|0)>>2];Za=rb}if((k|0)==2255){k=0;c[d>>2]=Za;kb=Za}K:while(1){v=a[d+kb+4>>0]|0;if(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13){kb=kb+1|0;continue}c[d>>2]=kb;v=55320;S=38;Hb=kb;do{if(!((a[d+Hb+4>>0]|0)==S<<24>>24)){break K}Hb=Hb+1|0;v=v+1|0;S=a[v>>0]|0}while(!(S<<24>>24==0));c[d>>2]=Hb;if((lw(d,b+4|0,f)|0)==0){k=2569;break w}L:while(1){S=c[d>>2]|0;while(1){v=a[d+S+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}S=S+1|0}c[d>>2]=S;v=55328;m=61;l=S;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){Ib=S;k=2370;break}Oa=l+1|0;T=v+1|0;Pa=a[T>>0]|0;if(Pa<<24>>24==0){Jb=1;Kb=Oa;break}else{v=T;m=Pa;l=Oa}}if((k|0)==2370){while(1){k=0;l=a[d+Ib+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}Ib=Ib+1|0;k=2370}c[d>>2]=Ib;l=55336;m=33;v=Ib;while(1){if(!((a[d+v+4>>0]|0)==m<<24>>24)){Lb=Ib;break L}S=v+1|0;Oa=l+1|0;Pa=a[Oa>>0]|0;if(Pa<<24>>24==0){Jb=2;Kb=S;break}else{l=Oa;m=Pa;v=S}}}c[d>>2]=Kb;if((lw(d,b+20|0,f)|0)==0){k=2376;break w}if((Jb|0)==1){c[(b+4|0)>>2]=(c[(b+4|0)>>2]|0)==(c[(b+20|0)>>2]|0);continue}else if((Jb|0)==2){c[(b+4|0)>>2]=(c[(b+4|0)>>2]|0)!=(c[(b+20|0)>>2]|0);continue}else{continue}}M:while(1){v=Lb;while(1){m=a[d+v+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}v=v+1|0}c[d>>2]=v;m=55320;l=38;S=v;while(1){if(!((a[d+S+4>>0]|0)==l<<24>>24)){Mb=v;break}Pa=m+1|0;Oa=a[Pa>>0]|0;if(Oa<<24>>24==0){k=2386;break M}else{m=Pa;l=Oa;S=S+1|0}}while(1){S=a[d+Mb+4>>0]|0;if(!(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13)){break}Mb=Mb+1|0}c[d>>2]=Mb;if((a[d+Mb+4>>0]|0)!=38){Nb=Mb;break}Ob=Mb+1|0;c[d>>2]=Ob;if((lw(d,b+408|0,f)|0)==0){k=2407;break w}N:while(1){S=c[d>>2]|0;while(1){l=a[d+S+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}S=S+1|0}c[d>>2]=S;l=55328;m=61;v=S;while(1){if(!((a[d+v+4>>0]|0)==m<<24>>24)){Pb=S;k=2397;break}Oa=v+1|0;Pa=l+1|0;T=a[Pa>>0]|0;if(T<<24>>24==0){Qb=1;Rb=Oa;break}else{l=Pa;m=T;v=Oa}}if((k|0)==2397){while(1){k=0;v=a[d+Pb+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}Pb=Pb+1|0;k=2397}c[d>>2]=Pb;v=55336;m=33;l=Pb;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){break N}S=l+1|0;Oa=v+1|0;T=a[Oa>>0]|0;if(T<<24>>24==0){Qb=2;Rb=S;break}else{v=Oa;m=T;l=S}}}c[d>>2]=Rb;if((lw(d,b+404|0,f)|0)==0){k=2403;break w}if((Qb|0)==1){c[(b+408|0)>>2]=(c[(b+408|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((Qb|0)==2){c[(b+408|0)>>2]=(c[(b+408|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+4|0)>>2]=c[(b+408|0)>>2]&c[(b+4|0)>>2];Lb=Pb}if((k|0)==2386){k=0;c[d>>2]=Lb;Nb=Lb}while(1){l=a[d+Nb+4>>0]|0;if(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13){Nb=Nb+1|0;continue}c[d>>2]=Nb;if((a[d+Nb+4>>0]|0)!=94){Sb=Nb;break}Tb=Nb+1|0;c[d>>2]=Tb;if((lw(d,b+296|0,f)|0)==0){k=2458;break w}O:while(1){l=c[d>>2]|0;while(1){m=a[d+l+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;m=55328;v=61;S=l;while(1){if(!((a[d+S+4>>0]|0)==v<<24>>24)){Ub=l;k=2419;break}T=S+1|0;Oa=m+1|0;Pa=a[Oa>>0]|0;if(Pa<<24>>24==0){Vb=1;Wb=T;break}else{m=Oa;v=Pa;S=T}}if((k|0)==2419){while(1){k=0;S=a[d+Ub+4>>0]|0;if(!(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13)){break}Ub=Ub+1|0;k=2419}c[d>>2]=Ub;S=55336;v=33;m=Ub;while(1){if(!((a[d+m+4>>0]|0)==v<<24>>24)){Xb=Ub;break O}l=m+1|0;T=S+1|0;Pa=a[T>>0]|0;if(Pa<<24>>24==0){Vb=2;Wb=l;break}else{S=T;v=Pa;m=l}}}c[d>>2]=Wb;if((lw(d,b,f)|0)==0){k=2425;break w}if((Vb|0)==1){c[(b+296|0)>>2]=(c[(b+296|0)>>2]|0)==(c[b>>2]|0);continue}else if((Vb|0)==2){c[(b+296|0)>>2]=(c[(b+296|0)>>2]|0)!=(c[b>>2]|0);continue}else{continue}}P:while(1){m=Xb;while(1){v=a[d+m+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}m=m+1|0}c[d>>2]=m;v=55320;S=38;l=m;while(1){if(!((a[d+l+4>>0]|0)==S<<24>>24)){Yb=m;break}Pa=v+1|0;T=a[Pa>>0]|0;if(T<<24>>24==0){k=2435;break P}else{v=Pa;S=T;l=l+1|0}}while(1){l=a[d+Yb+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}Yb=Yb+1|0}c[d>>2]=Yb;if((a[d+Yb+4>>0]|0)!=38){Zb=Yb;break}_b=Yb+1|0;c[d>>2]=_b;if((lw(d,b+392|0,f)|0)==0){k=2456;break w}Q:while(1){l=c[d>>2]|0;while(1){S=a[d+l+4>>0]|0;if(!(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;S=55328;v=61;m=l;while(1){if(!((a[d+m+4>>0]|0)==v<<24>>24)){$b=l;k=2446;break}T=m+1|0;Pa=S+1|0;Oa=a[Pa>>0]|0;if(Oa<<24>>24==0){ac=1;bc=T;break}else{S=Pa;v=Oa;m=T}}if((k|0)==2446){while(1){k=0;m=a[d+$b+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}$b=$b+1|0;k=2446}c[d>>2]=$b;m=55336;v=33;S=$b;while(1){if(!((a[d+S+4>>0]|0)==v<<24>>24)){break Q}l=S+1|0;T=m+1|0;Oa=a[T>>0]|0;if(Oa<<24>>24==0){ac=2;bc=l;break}else{m=T;v=Oa;S=l}}}c[d>>2]=bc;if((lw(d,b+404|0,f)|0)==0){k=2452;break w}if((ac|0)==1){c[(b+392|0)>>2]=(c[(b+392|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((ac|0)==2){c[(b+392|0)>>2]=(c[(b+392|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+296|0)>>2]=c[(b+392|0)>>2]&c[(b+296|0)>>2];Xb=$b}if((k|0)==2435){k=0;c[d>>2]=Xb;Zb=Xb}c[(b+4|0)>>2]=c[(b+296|0)>>2]^c[(b+4|0)>>2];Nb=Zb}R:while(1){S=Sb;while(1){v=a[d+S+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}S=S+1|0}c[d>>2]=S;v=55312;m=124;l=S;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){cc=S;break}Oa=v+1|0;T=a[Oa>>0]|0;if(T<<24>>24==0){k=2466;break R}else{v=Oa;m=T;l=l+1|0}}while(1){l=a[d+cc+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}cc=cc+1|0}c[d>>2]=cc;if((a[d+cc+4>>0]|0)!=124){dc=cc;break}ec=cc+1|0;c[d>>2]=ec;if((lw(d,b+344|0,f)|0)==0){k=2567;break w}S:while(1){l=c[d>>2]|0;while(1){m=a[d+l+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;m=55328;v=61;S=l;while(1){if(!((a[d+S+4>>0]|0)==v<<24>>24)){fc=l;k=2477;break}T=S+1|0;Oa=m+1|0;Pa=a[Oa>>0]|0;if(Pa<<24>>24==0){gc=1;hc=T;break}else{m=Oa;v=Pa;S=T}}if((k|0)==2477){while(1){k=0;S=a[d+fc+4>>0]|0;if(!(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13)){break}fc=fc+1|0;k=2477}c[d>>2]=fc;S=55336;v=33;m=fc;while(1){if(!((a[d+m+4>>0]|0)==v<<24>>24)){ic=fc;break S}l=m+1|0;T=S+1|0;Pa=a[T>>0]|0;if(Pa<<24>>24==0){gc=2;hc=l;break}else{S=T;v=Pa;m=l}}}c[d>>2]=hc;if((lw(d,b+372|0,f)|0)==0){k=2483;break w}if((gc|0)==1){c[(b+344|0)>>2]=(c[(b+344|0)>>2]|0)==(c[(b+372|0)>>2]|0);continue}else if((gc|0)==2){c[(b+344|0)>>2]=(c[(b+344|0)>>2]|0)!=(c[(b+372|0)>>2]|0);continue}else{continue}}T:while(1){m=ic;while(1){v=a[d+m+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}m=m+1|0}c[d>>2]=m;v=55320;S=38;l=m;while(1){if(!((a[d+l+4>>0]|0)==S<<24>>24)){jc=m;break}Pa=v+1|0;T=a[Pa>>0]|0;if(T<<24>>24==0){k=2493;break T}else{v=Pa;S=T;l=l+1|0}}while(1){l=a[d+jc+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}jc=jc+1|0}c[d>>2]=jc;if((a[d+jc+4>>0]|0)!=38){kc=jc;break}lc=jc+1|0;c[d>>2]=lc;if((lw(d,b+400|0,f)|0)==0){k=2514;break w}U:while(1){l=c[d>>2]|0;while(1){S=a[d+l+4>>0]|0;if(!(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13)){break}l=l+1|0}c[d>>2]=l;S=55328;v=61;m=l;while(1){if(!((a[d+m+4>>0]|0)==v<<24>>24)){mc=l;k=2504;break}T=m+1|0;Pa=S+1|0;Oa=a[Pa>>0]|0;if(Oa<<24>>24==0){nc=1;oc=T;break}else{S=Pa;v=Oa;m=T}}if((k|0)==2504){while(1){k=0;m=a[d+mc+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}mc=mc+1|0;k=2504}c[d>>2]=mc;m=55336;v=33;S=mc;while(1){if(!((a[d+S+4>>0]|0)==v<<24>>24)){break U}l=S+1|0;T=m+1|0;Oa=a[T>>0]|0;if(Oa<<24>>24==0){nc=2;oc=l;break}else{m=T;v=Oa;S=l}}}c[d>>2]=oc;if((lw(d,b+404|0,f)|0)==0){k=2510;break w}if((nc|0)==1){c[(b+400|0)>>2]=(c[(b+400|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((nc|0)==2){c[(b+400|0)>>2]=(c[(b+400|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+344|0)>>2]=c[(b+400|0)>>2]&c[(b+344|0)>>2];ic=mc}if((k|0)==2493){k=0;c[d>>2]=ic;kc=ic}while(1){S=a[d+kc+4>>0]|0;if(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13){kc=kc+1|0;continue}c[d>>2]=kc;if((a[d+kc+4>>0]|0)!=94){break}pc=kc+1|0;c[d>>2]=pc;if((lw(d,b+292|0,f)|0)==0){k=2565;break w}V:while(1){S=c[d>>2]|0;while(1){v=a[d+S+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}S=S+1|0}c[d>>2]=S;v=55328;m=61;l=S;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){qc=S;k=2526;break}Oa=l+1|0;T=v+1|0;Pa=a[T>>0]|0;if(Pa<<24>>24==0){rc=1;sc=Oa;break}else{v=T;m=Pa;l=Oa}}if((k|0)==2526){while(1){k=0;l=a[d+qc+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}qc=qc+1|0;k=2526}c[d>>2]=qc;l=55336;m=33;v=qc;while(1){if(!((a[d+v+4>>0]|0)==m<<24>>24)){tc=qc;break V}S=v+1|0;Oa=l+1|0;Pa=a[Oa>>0]|0;if(Pa<<24>>24==0){rc=2;sc=S;break}else{l=Oa;m=Pa;v=S}}}c[d>>2]=sc;if((lw(d,b+396|0,f)|0)==0){k=2532;break w}if((rc|0)==1){c[(b+292|0)>>2]=(c[(b+292|0)>>2]|0)==(c[(b+396|0)>>2]|0);continue}else if((rc|0)==2){c[(b+292|0)>>2]=(c[(b+292|0)>>2]|0)!=(c[(b+396|0)>>2]|0);continue}else{continue}}W:while(1){v=tc;while(1){m=a[d+v+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}v=v+1|0}c[d>>2]=v;m=55320;l=38;S=v;while(1){if(!((a[d+S+4>>0]|0)==l<<24>>24)){uc=v;break}Pa=m+1|0;Oa=a[Pa>>0]|0;if(Oa<<24>>24==0){k=2542;break W}else{m=Pa;l=Oa;S=S+1|0}}while(1){S=a[d+uc+4>>0]|0;if(!(S<<24>>24==10|S<<24>>24==9|S<<24>>24==32|S<<24>>24==13)){break}uc=uc+1|0}c[d>>2]=uc;if((a[d+uc+4>>0]|0)!=38){vc=uc;break}wc=uc+1|0;c[d>>2]=wc;if((lw(d,b+392|0,f)|0)==0){k=2563;break w}X:while(1){S=c[d>>2]|0;while(1){l=a[d+S+4>>0]|0;if(!(l<<24>>24==10|l<<24>>24==9|l<<24>>24==32|l<<24>>24==13)){break}S=S+1|0}c[d>>2]=S;l=55328;m=61;v=S;while(1){if(!((a[d+v+4>>0]|0)==m<<24>>24)){xc=S;k=2553;break}Oa=v+1|0;Pa=l+1|0;T=a[Pa>>0]|0;if(T<<24>>24==0){yc=1;zc=Oa;break}else{l=Pa;m=T;v=Oa}}if((k|0)==2553){while(1){k=0;v=a[d+xc+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}xc=xc+1|0;k=2553}c[d>>2]=xc;v=55336;m=33;l=xc;while(1){if(!((a[d+l+4>>0]|0)==m<<24>>24)){break X}S=l+1|0;Oa=v+1|0;T=a[Oa>>0]|0;if(T<<24>>24==0){yc=2;zc=S;break}else{v=Oa;m=T;l=S}}}c[d>>2]=zc;if((lw(d,b+404|0,f)|0)==0){k=2559;break w}if((yc|0)==1){c[(b+392|0)>>2]=(c[(b+392|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((yc|0)==2){c[(b+392|0)>>2]=(c[(b+392|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+292|0)>>2]=c[(b+392|0)>>2]&c[(b+292|0)>>2];tc=xc}if((k|0)==2542){k=0;c[d>>2]=tc;vc=tc}c[(b+344|0)>>2]=c[(b+292|0)>>2]^c[(b+344|0)>>2];kc=vc}c[(b+4|0)>>2]=c[(b+344|0)>>2]|c[(b+4|0)>>2];Sb=kc}if((k|0)==2466){k=0;c[d>>2]=Sb;dc=Sb}if((c[(b+364|0)>>2]|0)==0){Ac=0}else{Ac=(c[(b+4|0)>>2]|0)!=0}c[(b+364|0)>>2]=Ac&1;kb=dc}if((c[(b+388|0)>>2]|0)==0){Bc=(c[(b+364|0)>>2]|0)!=0}else{Bc=1}c[(b+388|0)>>2]=Bc&1;r=kb}switch(k|0){case 2165:{c[d>>2]=Ma;break};case 2192:{c[d>>2]=Va;k=2196;break};case 2214:{c[d>>2]=_a;k=2247;break};case 2241:{c[d>>2]=fb;k=2245;break};case 2272:{c[d>>2]=lb;k=2356;break};case 2299:{c[d>>2]=sb;k=2303;break};case 2321:{c[d>>2]=wb;k=2354;break};case 2348:{c[d>>2]=Db;k=2352;break};case 2376:{c[d>>2]=Hb;k=2569;break};case 2403:{c[d>>2]=Ob;k=2407;break};case 2425:{c[d>>2]=Tb;k=2458;break};case 2452:{c[d>>2]=_b;k=2456;break};case 2483:{c[d>>2]=ec;k=2567;break};case 2510:{c[d>>2]=lc;k=2514;break};case 2532:{c[d>>2]=pc;k=2565;break};case 2559:{c[d>>2]=wc;k=2563;break};case 2578:{c[e>>2]=(c[e>>2]|0)!=0?c[(b+192|0)>>2]|0:c[(b+388|0)>>2]|0;g=1;i=b;c[b+21032>>2]=6;c[b+21036>>2]=g|0;break a}}if((k|0)==2196){c[d>>2]=Ma}else if((k|0)==2245){c[d>>2]=_a;k=2247}else if((k|0)==2303){c[d>>2]=lb;k=2356}else if((k|0)==2352){c[d>>2]=wb;k=2354}else if((k|0)==2407){c[d>>2]=Hb;k=2569}else if((k|0)==2456){c[d>>2]=Tb;k=2458}else if((k|0)==2514){c[d>>2]=ec;k=2567}else if((k|0)==2563){c[d>>2]=pc;k=2565}if((k|0)==2247){c[d>>2]=Ma}else if((k|0)==2354){c[d>>2]=lb;k=2356}else if((k|0)==2458){c[d>>2]=Hb;k=2569}else if((k|0)==2565){c[d>>2]=ec;k=2567}if((k|0)==2356){c[d>>2]=Ma}else if((k|0)==2567){c[d>>2]=Hb;k=2569}if((k|0)==2569){c[d>>2]=Ma}c[d>>2]=h;c[b+21032>>2]=1;break a}else{q=1}}if(q){q=0;if((k|0)==1950){c[d>>2]=Q}else if((k|0)==1977){c[d>>2]=Z;k=1981}else if((k|0)==1999){c[d>>2]=ca;k=2032}else if((k|0)==2026){c[d>>2]=ja;k=2030}else if((k|0)==2057){c[d>>2]=pa;k=2141}else if((k|0)==2084){c[d>>2]=wa;k=2088}else if((k|0)==2106){c[d>>2]=Aa;k=2139}else if((k|0)==2133)if(1){c[d>>2]=Ha;k=2137}else{q=1}}if((k|0)==1981){c[d>>2]=Q}else if((k|0)==2030){c[d>>2]=ca;k=2032}else if((k|0)==2088){c[d>>2]=pa;k=2141}else if((k|0)==2137){c[d>>2]=Aa;k=2139}if((k|0)==2032){c[d>>2]=Q}else if((k|0)==2139){c[d>>2]=pa;k=2141}if((k|0)==2141){c[d>>2]=Q}c[d>>2]=h;c[b+21032>>2]=1;break a}else{o=1}}if(o){o=0;if((k|0)==1876){c[d>>2]=t}else if((k|0)==1925)if(1){c[d>>2]=F;k=1927}else{o=1}}if((k|0)==1927){c[d>>2]=t}c[d>>2]=h;c[b+21032>>2]=1;break a}while(0);c[b+448>>2]=g;c[b+10776>>2]=j;c[b+20912>>2]=k}function _cmd_match_expr_cond$1(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0,gc=0,hc=0,ic=0,jc=0,kc=0,lc=0,mc=0,nc=0,oc=0,pc=0,qc=0,rc=0,sc=0,tc=0,uc=0,vc=0,wc=0,xc=0,yc=0,zc=0,Ac=0,Bc=0,Cc=0,Dc=0,Ec=0;d=c[b+424>>2]|0;e=c[b+432>>2]|0;f=c[b+440>>2]|0;h=c[b+448>>2]|0;j=c[b+4632>>2]|0;k=c[b+6264>>2]|0;l=c[b+17256>>2]|0;m=c[b+20912>>2]|0;a:do{b:while(1){n=a[d+l+4>>0]|0;if(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13){l=l+1|0;continue}c[d>>2]=l;n=55320;o=38;p=l;do{if(!((a[d+p+4>>0]|0)==o<<24>>24)){m=1074;break b}p=p+1|0;n=n+1|0;o=a[n>>0]|0}while(!(o<<24>>24==0));c[d>>2]=p;if((lw(d,b+360|0,f)|0)==0){break}c:while(1){o=c[d>>2]|0;while(1){n=a[d+o+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;n=55328;q=61;r=o;while(1){if(!((a[d+r+4>>0]|0)==q<<24>>24)){s=o;m=1083;break}t=r+1|0;u=n+1|0;v=a[u>>0]|0;if(v<<24>>24==0){w=1;y=t;break}else{n=u;q=v;r=t}}if((m|0)==1083){while(1){m=0;r=a[d+s+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}s=s+1|0;m=1083}c[d>>2]=s;r=55336;q=33;n=s;while(1){if(!((a[d+n+4>>0]|0)==q<<24>>24)){z=s;break c}o=n+1|0;t=r+1|0;v=a[t>>0]|0;if(v<<24>>24==0){w=2;y=o;break}else{r=t;q=v;n=o}}}c[d>>2]=y;if((lw(d,b+108|0,f)|0)==0){m=1089;break b}if((w|0)==1){c[(b+360|0)>>2]=(c[(b+360|0)>>2]|0)==(c[(b+108|0)>>2]|0);continue}else if((w|0)==2){c[(b+360|0)>>2]=(c[(b+360|0)>>2]|0)!=(c[(b+108|0)>>2]|0);continue}else{continue}}d:while(1){n=z;while(1){q=a[d+n+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;q=55320;r=38;o=n;while(1){if(!((a[d+o+4>>0]|0)==r<<24>>24)){A=n;break}v=q+1|0;t=a[v>>0]|0;if(t<<24>>24==0){m=1099;break d}else{q=v;r=t;o=o+1|0}}while(1){o=a[d+A+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}A=A+1|0}c[d>>2]=A;if((a[d+A+4>>0]|0)!=38){B=A;break}C=A+1|0;c[d>>2]=C;if((lw(d,b+248|0,f)|0)==0){m=1120;break b}e:while(1){o=c[d>>2]|0;while(1){r=a[d+o+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;r=55328;q=61;n=o;while(1){if(!((a[d+n+4>>0]|0)==q<<24>>24)){D=o;m=1110;break}t=n+1|0;v=r+1|0;u=a[v>>0]|0;if(u<<24>>24==0){G=1;H=t;break}else{r=v;q=u;n=t}}if((m|0)==1110){while(1){m=0;n=a[d+D+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}D=D+1|0;m=1110}c[d>>2]=D;n=55336;q=33;r=D;while(1){if(!((a[d+r+4>>0]|0)==q<<24>>24)){break e}o=r+1|0;t=n+1|0;u=a[t>>0]|0;if(u<<24>>24==0){G=2;H=o;break}else{n=t;q=u;r=o}}}c[d>>2]=H;if((lw(d,b+404|0,f)|0)==0){m=1116;break b}if((G|0)==1){c[(b+248|0)>>2]=(c[(b+248|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((G|0)==2){c[(b+248|0)>>2]=(c[(b+248|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+360|0)>>2]=c[(b+248|0)>>2]&c[(b+360|0)>>2];z=D}if((m|0)==1099){m=0;c[d>>2]=z;B=z}while(1){r=a[d+B+4>>0]|0;if(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13){B=B+1|0;continue}c[d>>2]=B;if((a[d+B+4>>0]|0)!=94){I=B;break}J=B+1|0;c[d>>2]=J;if((lw(d,b+320|0,f)|0)==0){m=1171;break b}f:while(1){r=c[d>>2]|0;while(1){q=a[d+r+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;q=55328;n=61;o=r;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){K=r;m=1132;break}u=o+1|0;t=q+1|0;v=a[t>>0]|0;if(v<<24>>24==0){L=1;M=u;break}else{q=t;n=v;o=u}}if((m|0)==1132){while(1){m=0;o=a[d+K+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}K=K+1|0;m=1132}c[d>>2]=K;o=55336;n=33;q=K;while(1){if(!((a[d+q+4>>0]|0)==n<<24>>24)){N=K;break f}r=q+1|0;u=o+1|0;v=a[u>>0]|0;if(v<<24>>24==0){L=2;M=r;break}else{o=u;n=v;q=r}}}c[d>>2]=M;if((lw(d,b+104|0,f)|0)==0){m=1138;break b}if((L|0)==1){c[(b+320|0)>>2]=(c[(b+320|0)>>2]|0)==(c[(b+104|0)>>2]|0);continue}else if((L|0)==2){c[(b+320|0)>>2]=(c[(b+320|0)>>2]|0)!=(c[(b+104|0)>>2]|0);continue}else{continue}}g:while(1){q=N;while(1){n=a[d+q+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;n=55320;o=38;r=q;while(1){if(!((a[d+r+4>>0]|0)==o<<24>>24)){O=q;break}v=n+1|0;u=a[v>>0]|0;if(u<<24>>24==0){m=1148;break g}else{n=v;o=u;r=r+1|0}}while(1){r=a[d+O+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}O=O+1|0}c[d>>2]=O;if((a[d+O+4>>0]|0)!=38){P=O;break}Q=O+1|0;c[d>>2]=Q;if((lw(d,b+396|0,f)|0)==0){m=1169;break b}h:while(1){r=c[d>>2]|0;while(1){o=a[d+r+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;o=55328;n=61;q=r;while(1){if(!((a[d+q+4>>0]|0)==n<<24>>24)){R=r;m=1159;break}u=q+1|0;v=o+1|0;t=a[v>>0]|0;if(t<<24>>24==0){S=1;T=u;break}else{o=v;n=t;q=u}}if((m|0)==1159){while(1){m=0;q=a[d+R+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}R=R+1|0;m=1159}c[d>>2]=R;q=55336;n=33;o=R;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){break h}r=o+1|0;u=q+1|0;t=a[u>>0]|0;if(t<<24>>24==0){S=2;T=r;break}else{q=u;n=t;o=r}}}c[d>>2]=T;if((lw(d,b+404|0,f)|0)==0){m=1165;break b}if((S|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((S|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+320|0)>>2]=c[(b+396|0)>>2]&c[(b+320|0)>>2];N=R}if((m|0)==1148){m=0;c[d>>2]=N;P=N}c[(b+360|0)>>2]=c[(b+320|0)>>2]^c[(b+360|0)>>2];B=P}i:while(1){o=I;while(1){n=a[d+o+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;n=55312;q=124;r=o;while(1){if(!((a[d+r+4>>0]|0)==q<<24>>24)){U=o;break}t=n+1|0;u=a[t>>0]|0;if(u<<24>>24==0){m=1179;break i}else{n=t;q=u;r=r+1|0}}while(1){r=a[d+U+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}U=U+1|0}c[d>>2]=U;if((a[d+U+4>>0]|0)!=124){V=U;break}W=U+1|0;c[d>>2]=W;if((lw(d,b,f)|0)==0){m=1280;break b}j:while(1){r=c[d>>2]|0;while(1){q=a[d+r+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;q=55328;n=61;o=r;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){X=r;m=1190;break}u=o+1|0;t=q+1|0;v=a[t>>0]|0;if(v<<24>>24==0){Y=1;Z=u;break}else{q=t;n=v;o=u}}if((m|0)==1190){while(1){m=0;o=a[d+X+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}X=X+1|0;m=1190}c[d>>2]=X;o=55336;n=33;q=X;while(1){if(!((a[d+q+4>>0]|0)==n<<24>>24)){_=X;break j}r=q+1|0;u=o+1|0;v=a[u>>0]|0;if(v<<24>>24==0){Y=2;Z=r;break}else{o=u;n=v;q=r}}}c[d>>2]=Z;if((lw(d,b+100|0,f)|0)==0){m=1196;break b}if((Y|0)==1){c[b>>2]=(c[b>>2]|0)==(c[(b+100|0)>>2]|0);continue}else if((Y|0)==2){c[b>>2]=(c[b>>2]|0)!=(c[(b+100|0)>>2]|0);continue}else{continue}}k:while(1){q=_;while(1){n=a[d+q+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;n=55320;o=38;r=q;while(1){if(!((a[d+r+4>>0]|0)==o<<24>>24)){$=q;break}v=n+1|0;u=a[v>>0]|0;if(u<<24>>24==0){m=1206;break k}else{n=v;o=u;r=r+1|0}}while(1){r=a[d+$+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}$=$+1|0}c[d>>2]=$;if((a[d+$+4>>0]|0)!=38){aa=$;break}ba=$+1|0;c[d>>2]=ba;if((lw(d,b+244|0,f)|0)==0){m=1227;break b}l:while(1){r=c[d>>2]|0;while(1){o=a[d+r+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;o=55328;n=61;q=r;while(1){if(!((a[d+q+4>>0]|0)==n<<24>>24)){ca=r;m=1217;break}u=q+1|0;v=o+1|0;t=a[v>>0]|0;if(t<<24>>24==0){da=1;ea=u;break}else{o=v;n=t;q=u}}if((m|0)==1217){while(1){m=0;q=a[d+ca+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}ca=ca+1|0;m=1217}c[d>>2]=ca;q=55336;n=33;o=ca;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){break l}r=o+1|0;u=q+1|0;t=a[u>>0]|0;if(t<<24>>24==0){da=2;ea=r;break}else{q=u;n=t;o=r}}}c[d>>2]=ea;if((lw(d,b+404|0,f)|0)==0){m=1223;break b}if((da|0)==1){c[(b+244|0)>>2]=(c[(b+244|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((da|0)==2){c[(b+244|0)>>2]=(c[(b+244|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[b>>2]=c[(b+244|0)>>2]&c[b>>2];_=ca}if((m|0)==1206){m=0;c[d>>2]=_;aa=_}while(1){o=a[d+aa+4>>0]|0;if(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13){aa=aa+1|0;continue}c[d>>2]=aa;if((a[d+aa+4>>0]|0)!=94){break}fa=aa+1|0;c[d>>2]=fa;if((lw(d,b+372|0,f)|0)==0){m=1278;break b}m:while(1){o=c[d>>2]|0;while(1){n=a[d+o+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;n=55328;q=61;r=o;while(1){if(!((a[d+r+4>>0]|0)==q<<24>>24)){ga=o;m=1239;break}t=r+1|0;u=n+1|0;v=a[u>>0]|0;if(v<<24>>24==0){ha=1;ia=t;break}else{n=u;q=v;r=t}}if((m|0)==1239){while(1){m=0;r=a[d+ga+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}ga=ga+1|0;m=1239}c[d>>2]=ga;r=55336;q=33;n=ga;while(1){if(!((a[d+n+4>>0]|0)==q<<24>>24)){ja=ga;break m}o=n+1|0;t=r+1|0;v=a[t>>0]|0;if(v<<24>>24==0){ha=2;ia=o;break}else{r=t;q=v;n=o}}}c[d>>2]=ia;if((lw(d,b+96|0,f)|0)==0){m=1245;break b}if((ha|0)==1){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)==(c[(b+96|0)>>2]|0);continue}else if((ha|0)==2){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)!=(c[(b+96|0)>>2]|0);continue}else{continue}}n:while(1){n=ja;while(1){q=a[d+n+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;q=55320;r=38;o=n;while(1){if(!((a[d+o+4>>0]|0)==r<<24>>24)){ka=n;break}v=q+1|0;t=a[v>>0]|0;if(t<<24>>24==0){m=1255;break n}else{q=v;r=t;o=o+1|0}}while(1){o=a[d+ka+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}ka=ka+1|0}c[d>>2]=ka;if((a[d+ka+4>>0]|0)!=38){la=ka;break}ma=ka+1|0;c[d>>2]=ma;if((lw(d,b+396|0,f)|0)==0){m=1276;break b}o:while(1){o=c[d>>2]|0;while(1){r=a[d+o+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;r=55328;q=61;n=o;while(1){if(!((a[d+n+4>>0]|0)==q<<24>>24)){na=o;m=1266;break}t=n+1|0;v=r+1|0;u=a[v>>0]|0;if(u<<24>>24==0){oa=1;pa=t;break}else{r=v;q=u;n=t}}if((m|0)==1266){while(1){m=0;n=a[d+na+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}na=na+1|0;m=1266}c[d>>2]=na;n=55336;q=33;r=na;while(1){if(!((a[d+r+4>>0]|0)==q<<24>>24)){break o}o=r+1|0;t=n+1|0;u=a[t>>0]|0;if(u<<24>>24==0){oa=2;pa=o;break}else{n=t;q=u;r=o}}}c[d>>2]=pa;if((lw(d,b+404|0,f)|0)==0){m=1272;break b}if((oa|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((oa|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+372|0)>>2]=c[(b+396|0)>>2]&c[(b+372|0)>>2];ja=na}if((m|0)==1255){m=0;c[d>>2]=ja;la=ja}c[b>>2]=c[(b+372|0)>>2]^c[b>>2];aa=la}c[(b+360|0)>>2]=c[b>>2]|c[(b+360|0)>>2];I=aa}if((m|0)==1179){m=0;c[d>>2]=I;V=I}if((c[(b+192|0)>>2]|0)==0){qa=0}else{qa=(c[(b+360|0)>>2]|0)!=0}c[(b+192|0)>>2]=qa&1;l=V}r=1;if(r){r=0;if((m|0)==1074){q=l;p:while(1){n=a[d+q+4>>0]|0;if(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13){q=q+1|0;continue}c[d>>2]=q;n=55312;o=124;ra=q;do{if(!((a[d+ra+4>>0]|0)==o<<24>>24)){sa=q;m=1717;break p}ra=ra+1|0;n=n+1|0;o=a[n>>0]|0}while(!(o<<24>>24==0));c[d>>2]=ra;if((lw(d,b+184|0,f)|0)==0){break}q:while(1){o=c[d>>2]|0;while(1){n=a[d+o+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;n=55328;u=61;t=o;while(1){if(!((a[d+t+4>>0]|0)==u<<24>>24)){ta=o;m=1298;break}v=t+1|0;ua=n+1|0;va=a[ua>>0]|0;if(va<<24>>24==0){wa=1;xa=v;break}else{n=ua;u=va;t=v}}if((m|0)==1298){while(1){m=0;t=a[d+ta+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}ta=ta+1|0;m=1298}c[d>>2]=ta;t=55336;u=33;n=ta;while(1){if(!((a[d+n+4>>0]|0)==u<<24>>24)){ya=ta;break q}o=n+1|0;v=t+1|0;va=a[v>>0]|0;if(va<<24>>24==0){wa=2;xa=o;break}else{t=v;u=va;n=o}}}c[d>>2]=xa;if((lw(d,b+92|0,f)|0)==0){m=1304;break p}if((wa|0)==1){c[(b+184|0)>>2]=(c[(b+184|0)>>2]|0)==(c[(b+92|0)>>2]|0);continue}else if((wa|0)==2){c[(b+184|0)>>2]=(c[(b+184|0)>>2]|0)!=(c[(b+92|0)>>2]|0);continue}else{continue}}r:while(1){n=ya;while(1){u=a[d+n+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;u=55320;t=38;o=n;while(1){if(!((a[d+o+4>>0]|0)==t<<24>>24)){za=n;break}va=u+1|0;v=a[va>>0]|0;if(v<<24>>24==0){m=1314;break r}else{u=va;t=v;o=o+1|0}}while(1){o=a[d+za+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}za=za+1|0}c[d>>2]=za;if((a[d+za+4>>0]|0)!=38){Aa=za;break}Ba=za+1|0;c[d>>2]=Ba;if((lw(d,b+240|0,f)|0)==0){m=1335;break p}s:while(1){o=c[d>>2]|0;while(1){t=a[d+o+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;t=55328;u=61;n=o;while(1){if(!((a[d+n+4>>0]|0)==u<<24>>24)){Ca=o;m=1325;break}v=n+1|0;va=t+1|0;ua=a[va>>0]|0;if(ua<<24>>24==0){Da=1;Ea=v;break}else{t=va;u=ua;n=v}}if((m|0)==1325){while(1){m=0;n=a[d+Ca+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}Ca=Ca+1|0;m=1325}c[d>>2]=Ca;n=55336;u=33;t=Ca;while(1){if(!((a[d+t+4>>0]|0)==u<<24>>24)){break s}o=t+1|0;v=n+1|0;ua=a[v>>0]|0;if(ua<<24>>24==0){Da=2;Ea=o;break}else{n=v;u=ua;t=o}}}c[d>>2]=Ea;if((lw(d,b+404|0,f)|0)==0){m=1331;break p}if((Da|0)==1){c[(b+240|0)>>2]=(c[(b+240|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((Da|0)==2){c[(b+240|0)>>2]=(c[(b+240|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+184|0)>>2]=c[(b+240|0)>>2]&c[(b+184|0)>>2];ya=Ca}if((m|0)==1314){m=0;c[d>>2]=ya;Aa=ya}while(1){t=a[d+Aa+4>>0]|0;if(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13){Aa=Aa+1|0;continue}c[d>>2]=Aa;if((a[d+Aa+4>>0]|0)!=94){Fa=Aa;break}Ga=Aa+1|0;c[d>>2]=Ga;if((lw(d,b+316|0,f)|0)==0){m=1386;break p}t:while(1){t=c[d>>2]|0;while(1){u=a[d+t+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}t=t+1|0}c[d>>2]=t;u=55328;n=61;o=t;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){Ha=t;m=1347;break}ua=o+1|0;v=u+1|0;va=a[v>>0]|0;if(va<<24>>24==0){Ia=1;Ja=ua;break}else{u=v;n=va;o=ua}}if((m|0)==1347){while(1){m=0;o=a[d+Ha+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}Ha=Ha+1|0;m=1347}c[d>>2]=Ha;o=55336;n=33;u=Ha;while(1){if(!((a[d+u+4>>0]|0)==n<<24>>24)){Ka=Ha;break t}t=u+1|0;ua=o+1|0;va=a[ua>>0]|0;if(va<<24>>24==0){Ia=2;Ja=t;break}else{o=ua;n=va;u=t}}}c[d>>2]=Ja;if((lw(d,b+88|0,f)|0)==0){m=1353;break p}if((Ia|0)==1){c[(b+316|0)>>2]=(c[(b+316|0)>>2]|0)==(c[(b+88|0)>>2]|0);continue}else if((Ia|0)==2){c[(b+316|0)>>2]=(c[(b+316|0)>>2]|0)!=(c[(b+88|0)>>2]|0);continue}else{continue}}u:while(1){u=Ka;while(1){n=a[d+u+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}u=u+1|0}c[d>>2]=u;n=55320;o=38;t=u;while(1){if(!((a[d+t+4>>0]|0)==o<<24>>24)){La=u;break}va=n+1|0;ua=a[va>>0]|0;if(ua<<24>>24==0){m=1363;break u}else{n=va;o=ua;t=t+1|0}}while(1){t=a[d+La+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}La=La+1|0}c[d>>2]=La;if((a[d+La+4>>0]|0)!=38){Ma=La;break}Na=La+1|0;c[d>>2]=Na;if((lw(d,b+396|0,f)|0)==0){m=1384;break p}v:while(1){t=c[d>>2]|0;while(1){o=a[d+t+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}t=t+1|0}c[d>>2]=t;o=55328;n=61;u=t;while(1){if(!((a[d+u+4>>0]|0)==n<<24>>24)){Oa=t;m=1374;break}ua=u+1|0;va=o+1|0;v=a[va>>0]|0;if(v<<24>>24==0){Pa=1;Qa=ua;break}else{o=va;n=v;u=ua}}if((m|0)==1374){while(1){m=0;u=a[d+Oa+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}Oa=Oa+1|0;m=1374}c[d>>2]=Oa;u=55336;n=33;o=Oa;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){break v}t=o+1|0;ua=u+1|0;v=a[ua>>0]|0;if(v<<24>>24==0){Pa=2;Qa=t;break}else{u=ua;n=v;o=t}}}c[d>>2]=Qa;if((lw(d,b+404|0,f)|0)==0){m=1380;break p}if((Pa|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((Pa|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+316|0)>>2]=c[(b+396|0)>>2]&c[(b+316|0)>>2];Ka=Oa}if((m|0)==1363){m=0;c[d>>2]=Ka;Ma=Ka}c[(b+184|0)>>2]=c[(b+316|0)>>2]^c[(b+184|0)>>2];Aa=Ma}w:while(1){o=Fa;while(1){n=a[d+o+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;n=55312;u=124;t=o;while(1){if(!((a[d+t+4>>0]|0)==u<<24>>24)){Ra=o;break}v=n+1|0;ua=a[v>>0]|0;if(ua<<24>>24==0){m=1394;break w}else{n=v;u=ua;t=t+1|0}}while(1){t=a[d+Ra+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}Ra=Ra+1|0}c[d>>2]=Ra;if((a[d+Ra+4>>0]|0)!=124){Sa=Ra;break}Ta=Ra+1|0;c[d>>2]=Ta;if((lw(d,b+356|0,f)|0)==0){m=1495;break p}x:while(1){t=c[d>>2]|0;while(1){u=a[d+t+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}t=t+1|0}c[d>>2]=t;u=55328;n=61;o=t;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){Ua=t;m=1405;break}ua=o+1|0;v=u+1|0;va=a[v>>0]|0;if(va<<24>>24==0){Va=1;Wa=ua;break}else{u=v;n=va;o=ua}}if((m|0)==1405){while(1){m=0;o=a[d+Ua+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}Ua=Ua+1|0;m=1405}c[d>>2]=Ua;o=55336;n=33;u=Ua;while(1){if(!((a[d+u+4>>0]|0)==n<<24>>24)){Xa=Ua;break x}t=u+1|0;ua=o+1|0;va=a[ua>>0]|0;if(va<<24>>24==0){Va=2;Wa=t;break}else{o=ua;n=va;u=t}}}c[d>>2]=Wa;if((lw(d,b+84|0,f)|0)==0){m=1411;break p}if((Va|0)==1){c[(b+356|0)>>2]=(c[(b+356|0)>>2]|0)==(c[(b+84|0)>>2]|0);continue}else if((Va|0)==2){c[(b+356|0)>>2]=(c[(b+356|0)>>2]|0)!=(c[(b+84|0)>>2]|0);continue}else{continue}}y:while(1){u=Xa;while(1){n=a[d+u+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}u=u+1|0}c[d>>2]=u;n=55320;o=38;t=u;while(1){if(!((a[d+t+4>>0]|0)==o<<24>>24)){Ya=u;break}va=n+1|0;ua=a[va>>0]|0;if(ua<<24>>24==0){m=1421;break y}else{n=va;o=ua;t=t+1|0}}while(1){t=a[d+Ya+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}Ya=Ya+1|0}c[d>>2]=Ya;if((a[d+Ya+4>>0]|0)!=38){Za=Ya;break}_a=Ya+1|0;c[d>>2]=_a;if((lw(d,b+236|0,f)|0)==0){m=1442;break p}z:while(1){t=c[d>>2]|0;while(1){o=a[d+t+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}t=t+1|0}c[d>>2]=t;o=55328;n=61;u=t;while(1){if(!((a[d+u+4>>0]|0)==n<<24>>24)){$a=t;m=1432;break}ua=u+1|0;va=o+1|0;v=a[va>>0]|0;if(v<<24>>24==0){ab=1;bb=ua;break}else{o=va;n=v;u=ua}}if((m|0)==1432){while(1){m=0;u=a[d+$a+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}$a=$a+1|0;m=1432}c[d>>2]=$a;u=55336;n=33;o=$a;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){break z}t=o+1|0;ua=u+1|0;v=a[ua>>0]|0;if(v<<24>>24==0){ab=2;bb=t;break}else{u=ua;n=v;o=t}}}c[d>>2]=bb;if((lw(d,b+404|0,f)|0)==0){m=1438;break p}if((ab|0)==1){c[(b+236|0)>>2]=(c[(b+236|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((ab|0)==2){c[(b+236|0)>>2]=(c[(b+236|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+356|0)>>2]=c[(b+236|0)>>2]&c[(b+356|0)>>2];Xa=$a}if((m|0)==1421){m=0;c[d>>2]=Xa;Za=Xa}while(1){o=a[d+Za+4>>0]|0;if(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13){Za=Za+1|0;continue}c[d>>2]=Za;if((a[d+Za+4>>0]|0)!=94){break}cb=Za+1|0;c[d>>2]=cb;if((lw(d,b+372|0,f)|0)==0){m=1493;break p}A:while(1){o=c[d>>2]|0;while(1){n=a[d+o+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;n=55328;u=61;t=o;while(1){if(!((a[d+t+4>>0]|0)==u<<24>>24)){db=o;m=1454;break}v=t+1|0;ua=n+1|0;va=a[ua>>0]|0;if(va<<24>>24==0){eb=1;fb=v;break}else{n=ua;u=va;t=v}}if((m|0)==1454){while(1){m=0;t=a[d+db+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}db=db+1|0;m=1454}c[d>>2]=db;t=55336;u=33;n=db;while(1){if(!((a[d+n+4>>0]|0)==u<<24>>24)){gb=db;break A}o=n+1|0;v=t+1|0;va=a[v>>0]|0;if(va<<24>>24==0){eb=2;fb=o;break}else{t=v;u=va;n=o}}}c[d>>2]=fb;if((lw(d,b+80|0,f)|0)==0){m=1460;break p}if((eb|0)==1){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)==(c[(b+80|0)>>2]|0);continue}else if((eb|0)==2){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)!=(c[(b+80|0)>>2]|0);continue}else{continue}}B:while(1){n=gb;while(1){u=a[d+n+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;u=55320;t=38;o=n;while(1){if(!((a[d+o+4>>0]|0)==t<<24>>24)){hb=n;break}va=u+1|0;v=a[va>>0]|0;if(v<<24>>24==0){m=1470;break B}else{u=va;t=v;o=o+1|0}}while(1){o=a[d+hb+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}hb=hb+1|0}c[d>>2]=hb;if((a[d+hb+4>>0]|0)!=38){ib=hb;break}jb=hb+1|0;c[d>>2]=jb;if((lw(d,b+396|0,f)|0)==0){m=1491;break p}C:while(1){o=c[d>>2]|0;while(1){t=a[d+o+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;t=55328;u=61;n=o;while(1){if(!((a[d+n+4>>0]|0)==u<<24>>24)){kb=o;m=1481;break}v=n+1|0;va=t+1|0;ua=a[va>>0]|0;if(ua<<24>>24==0){lb=1;mb=v;break}else{t=va;u=ua;n=v}}if((m|0)==1481){while(1){m=0;n=a[d+kb+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}kb=kb+1|0;m=1481}c[d>>2]=kb;n=55336;u=33;t=kb;while(1){if(!((a[d+t+4>>0]|0)==u<<24>>24)){break C}o=t+1|0;v=n+1|0;ua=a[v>>0]|0;if(ua<<24>>24==0){lb=2;mb=o;break}else{n=v;u=ua;t=o}}}c[d>>2]=mb;if((lw(d,b+404|0,f)|0)==0){m=1487;break p}if((lb|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((lb|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+372|0)>>2]=c[(b+396|0)>>2]&c[(b+372|0)>>2];gb=kb}if((m|0)==1470){m=0;c[d>>2]=gb;ib=gb}c[(b+356|0)>>2]=c[(b+372|0)>>2]^c[(b+356|0)>>2];Za=ib}c[(b+184|0)>>2]=c[(b+356|0)>>2]|c[(b+184|0)>>2];Fa=Za}if((m|0)==1394){m=0;c[d>>2]=Fa;Sa=Fa}D:while(1){t=a[d+Sa+4>>0]|0;if(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13){Sa=Sa+1|0;continue}c[d>>2]=Sa;t=55320;u=38;nb=Sa;do{if(!((a[d+nb+4>>0]|0)==u<<24>>24)){break D}nb=nb+1|0;t=t+1|0;u=a[t>>0]|0}while(!(u<<24>>24==0));c[d>>2]=nb;if((lw(d,b+20|0,f)|0)==0){m=1708;break p}E:while(1){u=c[d>>2]|0;while(1){t=a[d+u+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}u=u+1|0}c[d>>2]=u;t=55328;n=61;o=u;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){ob=u;m=1509;break}ua=o+1|0;v=t+1|0;va=a[v>>0]|0;if(va<<24>>24==0){pb=1;qb=ua;break}else{t=v;n=va;o=ua}}if((m|0)==1509){while(1){m=0;o=a[d+ob+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}ob=ob+1|0;m=1509}c[d>>2]=ob;o=55336;n=33;t=ob;while(1){if(!((a[d+t+4>>0]|0)==n<<24>>24)){rb=ob;break E}u=t+1|0;ua=o+1|0;va=a[ua>>0]|0;if(va<<24>>24==0){pb=2;qb=u;break}else{o=ua;n=va;t=u}}}c[d>>2]=qb;if((lw(d,b+76|0,f)|0)==0){m=1515;break p}if((pb|0)==1){c[(b+20|0)>>2]=(c[(b+20|0)>>2]|0)==(c[(b+76|0)>>2]|0);continue}else if((pb|0)==2){c[(b+20|0)>>2]=(c[(b+20|0)>>2]|0)!=(c[(b+76|0)>>2]|0);continue}else{continue}}F:while(1){t=rb;while(1){n=a[d+t+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}t=t+1|0}c[d>>2]=t;n=55320;o=38;u=t;while(1){if(!((a[d+u+4>>0]|0)==o<<24>>24)){sb=t;break}va=n+1|0;ua=a[va>>0]|0;if(ua<<24>>24==0){m=1525;break F}else{n=va;o=ua;u=u+1|0}}while(1){u=a[d+sb+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}sb=sb+1|0}c[d>>2]=sb;if((a[d+sb+4>>0]|0)!=38){tb=sb;break}ub=sb+1|0;c[d>>2]=ub;if((lw(d,b+232|0,f)|0)==0){m=1546;break p}G:while(1){u=c[d>>2]|0;while(1){o=a[d+u+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}u=u+1|0}c[d>>2]=u;o=55328;n=61;t=u;while(1){if(!((a[d+t+4>>0]|0)==n<<24>>24)){vb=u;m=1536;break}ua=t+1|0;va=o+1|0;v=a[va>>0]|0;if(v<<24>>24==0){wb=1;xb=ua;break}else{o=va;n=v;t=ua}}if((m|0)==1536){while(1){m=0;t=a[d+vb+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}vb=vb+1|0;m=1536}c[d>>2]=vb;t=55336;n=33;o=vb;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){break G}u=o+1|0;ua=t+1|0;v=a[ua>>0]|0;if(v<<24>>24==0){wb=2;xb=u;break}else{t=ua;n=v;o=u}}}c[d>>2]=xb;if((lw(d,b+404|0,f)|0)==0){m=1542;break p}if((wb|0)==1){c[(b+232|0)>>2]=(c[(b+232|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((wb|0)==2){c[(b+232|0)>>2]=(c[(b+232|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+20|0)>>2]=c[(b+232|0)>>2]&c[(b+20|0)>>2];rb=vb}if((m|0)==1525){m=0;c[d>>2]=rb;tb=rb}while(1){o=a[d+tb+4>>0]|0;if(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13){tb=tb+1|0;continue}c[d>>2]=tb;if((a[d+tb+4>>0]|0)!=94){yb=tb;break}zb=tb+1|0;c[d>>2]=zb;if((lw(d,b+312|0,f)|0)==0){m=1597;break p}H:while(1){o=c[d>>2]|0;while(1){n=a[d+o+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;n=55328;t=61;u=o;while(1){if(!((a[d+u+4>>0]|0)==t<<24>>24)){Ab=o;m=1558;break}v=u+1|0;ua=n+1|0;va=a[ua>>0]|0;if(va<<24>>24==0){Bb=1;Cb=v;break}else{n=ua;t=va;u=v}}if((m|0)==1558){while(1){m=0;u=a[d+Ab+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}Ab=Ab+1|0;m=1558}c[d>>2]=Ab;u=55336;t=33;n=Ab;while(1){if(!((a[d+n+4>>0]|0)==t<<24>>24)){Db=Ab;break H}o=n+1|0;v=u+1|0;va=a[v>>0]|0;if(va<<24>>24==0){Bb=2;Cb=o;break}else{u=v;t=va;n=o}}}c[d>>2]=Cb;if((lw(d,b+72|0,f)|0)==0){m=1564;break p}if((Bb|0)==1){c[(b+312|0)>>2]=(c[(b+312|0)>>2]|0)==(c[(b+72|0)>>2]|0);continue}else if((Bb|0)==2){c[(b+312|0)>>2]=(c[(b+312|0)>>2]|0)!=(c[(b+72|0)>>2]|0);continue}else{continue}}I:while(1){n=Db;while(1){t=a[d+n+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;t=55320;u=38;o=n;while(1){if(!((a[d+o+4>>0]|0)==u<<24>>24)){Eb=n;break}va=t+1|0;v=a[va>>0]|0;if(v<<24>>24==0){m=1574;break I}else{t=va;u=v;o=o+1|0}}while(1){o=a[d+Eb+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}Eb=Eb+1|0}c[d>>2]=Eb;if((a[d+Eb+4>>0]|0)!=38){Fb=Eb;break}Gb=Eb+1|0;c[d>>2]=Gb;if((lw(d,b+396|0,f)|0)==0){m=1595;break p}J:while(1){o=c[d>>2]|0;while(1){u=a[d+o+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;u=55328;t=61;n=o;while(1){if(!((a[d+n+4>>0]|0)==t<<24>>24)){Hb=o;m=1585;break}v=n+1|0;va=u+1|0;ua=a[va>>0]|0;if(ua<<24>>24==0){Ib=1;Jb=v;break}else{u=va;t=ua;n=v}}if((m|0)==1585){while(1){m=0;n=a[d+Hb+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}Hb=Hb+1|0;m=1585}c[d>>2]=Hb;n=55336;t=33;u=Hb;while(1){if(!((a[d+u+4>>0]|0)==t<<24>>24)){break J}o=u+1|0;v=n+1|0;ua=a[v>>0]|0;if(ua<<24>>24==0){Ib=2;Jb=o;break}else{n=v;t=ua;u=o}}}c[d>>2]=Jb;if((lw(d,b+404|0,f)|0)==0){m=1591;break p}if((Ib|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((Ib|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+312|0)>>2]=c[(b+396|0)>>2]&c[(b+312|0)>>2];Db=Hb}if((m|0)==1574){m=0;c[d>>2]=Db;Fb=Db}c[(b+20|0)>>2]=c[(b+312|0)>>2]^c[(b+20|0)>>2];tb=Fb}K:while(1){u=yb;while(1){t=a[d+u+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}u=u+1|0}c[d>>2]=u;t=55312;n=124;o=u;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){Kb=u;break}ua=t+1|0;v=a[ua>>0]|0;if(v<<24>>24==0){m=1605;break K}else{t=ua;n=v;o=o+1|0}}while(1){o=a[d+Kb+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}Kb=Kb+1|0}c[d>>2]=Kb;if((a[d+Kb+4>>0]|0)!=124){Lb=Kb;break}Mb=Kb+1|0;c[d>>2]=Mb;if((lw(d,b,f)|0)==0){m=1706;break p}L:while(1){o=c[d>>2]|0;while(1){n=a[d+o+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;n=55328;t=61;u=o;while(1){if(!((a[d+u+4>>0]|0)==t<<24>>24)){Nb=o;m=1616;break}v=u+1|0;ua=n+1|0;va=a[ua>>0]|0;if(va<<24>>24==0){Ob=1;Pb=v;break}else{n=ua;t=va;u=v}}if((m|0)==1616){while(1){m=0;u=a[d+Nb+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}Nb=Nb+1|0;m=1616}c[d>>2]=Nb;u=55336;t=33;n=Nb;while(1){if(!((a[d+n+4>>0]|0)==t<<24>>24)){Qb=Nb;break L}o=n+1|0;v=u+1|0;va=a[v>>0]|0;if(va<<24>>24==0){Ob=2;Pb=o;break}else{u=v;t=va;n=o}}}c[d>>2]=Pb;if((lw(d,b+68|0,f)|0)==0){m=1622;break p}if((Ob|0)==1){c[b>>2]=(c[b>>2]|0)==(c[(b+68|0)>>2]|0);continue}else if((Ob|0)==2){c[b>>2]=(c[b>>2]|0)!=(c[(b+68|0)>>2]|0);continue}else{continue}}M:while(1){n=Qb;while(1){t=a[d+n+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;t=55320;u=38;o=n;while(1){if(!((a[d+o+4>>0]|0)==u<<24>>24)){Rb=n;break}va=t+1|0;v=a[va>>0]|0;if(v<<24>>24==0){m=1632;break M}else{t=va;u=v;o=o+1|0}}while(1){o=a[d+Rb+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}Rb=Rb+1|0}c[d>>2]=Rb;if((a[d+Rb+4>>0]|0)!=38){Sb=Rb;break}Tb=Rb+1|0;c[d>>2]=Tb;if((lw(d,b+228|0,f)|0)==0){m=1653;break p}N:while(1){o=c[d>>2]|0;while(1){u=a[d+o+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}o=o+1|0}c[d>>2]=o;u=55328;t=61;n=o;while(1){if(!((a[d+n+4>>0]|0)==t<<24>>24)){Ub=o;m=1643;break}v=n+1|0;va=u+1|0;ua=a[va>>0]|0;if(ua<<24>>24==0){Vb=1;Wb=v;break}else{u=va;t=ua;n=v}}if((m|0)==1643){while(1){m=0;n=a[d+Ub+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}Ub=Ub+1|0;m=1643}c[d>>2]=Ub;n=55336;t=33;u=Ub;while(1){if(!((a[d+u+4>>0]|0)==t<<24>>24)){break N}o=u+1|0;v=n+1|0;ua=a[v>>0]|0;if(ua<<24>>24==0){Vb=2;Wb=o;break}else{n=v;t=ua;u=o}}}c[d>>2]=Wb;if((lw(d,b+404|0,f)|0)==0){m=1649;break p}if((Vb|0)==1){c[(b+228|0)>>2]=(c[(b+228|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((Vb|0)==2){c[(b+228|0)>>2]=(c[(b+228|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[b>>2]=c[(b+228|0)>>2]&c[b>>2];Qb=Ub}if((m|0)==1632){m=0;c[d>>2]=Qb;Sb=Qb}while(1){u=a[d+Sb+4>>0]|0;if(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13){Sb=Sb+1|0;continue}c[d>>2]=Sb;if((a[d+Sb+4>>0]|0)!=94){break}Xb=Sb+1|0;c[d>>2]=Xb;if((lw(d,b+372|0,f)|0)==0){m=1704;break p}O:while(1){u=c[d>>2]|0;while(1){t=a[d+u+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}u=u+1|0}c[d>>2]=u;t=55328;n=61;o=u;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){Yb=u;m=1665;break}ua=o+1|0;v=t+1|0;va=a[v>>0]|0;if(va<<24>>24==0){Zb=1;_b=ua;break}else{t=v;n=va;o=ua}}if((m|0)==1665){while(1){m=0;o=a[d+Yb+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}Yb=Yb+1|0;m=1665}c[d>>2]=Yb;o=55336;n=33;t=Yb;while(1){if(!((a[d+t+4>>0]|0)==n<<24>>24)){$b=Yb;break O}u=t+1|0;ua=o+1|0;va=a[ua>>0]|0;if(va<<24>>24==0){Zb=2;_b=u;break}else{o=ua;n=va;t=u}}}c[d>>2]=_b;if((lw(d,b+64|0,f)|0)==0){m=1671;break p}if((Zb|0)==1){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)==(c[(b+64|0)>>2]|0);continue}else if((Zb|0)==2){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)!=(c[(b+64|0)>>2]|0);continue}else{continue}}P:while(1){t=$b;while(1){n=a[d+t+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}t=t+1|0}c[d>>2]=t;n=55320;o=38;u=t;while(1){if(!((a[d+u+4>>0]|0)==o<<24>>24)){ac=t;break}va=n+1|0;ua=a[va>>0]|0;if(ua<<24>>24==0){m=1681;break P}else{n=va;o=ua;u=u+1|0}}while(1){u=a[d+ac+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}ac=ac+1|0}c[d>>2]=ac;if((a[d+ac+4>>0]|0)!=38){bc=ac;break}cc=ac+1|0;c[d>>2]=cc;if((lw(d,b+396|0,f)|0)==0){m=1702;break p}Q:while(1){u=c[d>>2]|0;while(1){o=a[d+u+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}u=u+1|0}c[d>>2]=u;o=55328;n=61;t=u;while(1){if(!((a[d+t+4>>0]|0)==n<<24>>24)){dc=u;m=1692;break}ua=t+1|0;va=o+1|0;v=a[va>>0]|0;if(v<<24>>24==0){ec=1;fc=ua;break}else{o=va;n=v;t=ua}}if((m|0)==1692){while(1){m=0;t=a[d+dc+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}dc=dc+1|0;m=1692}c[d>>2]=dc;t=55336;n=33;o=dc;while(1){if(!((a[d+o+4>>0]|0)==n<<24>>24)){break Q}u=o+1|0;ua=t+1|0;v=a[ua>>0]|0;if(v<<24>>24==0){ec=2;fc=u;break}else{t=ua;n=v;o=u}}}c[d>>2]=fc;if((lw(d,b+404|0,f)|0)==0){m=1698;break p}if((ec|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((ec|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+372|0)>>2]=c[(b+396|0)>>2]&c[(b+372|0)>>2];$b=dc}if((m|0)==1681){m=0;c[d>>2]=$b;bc=$b}c[b>>2]=c[(b+372|0)>>2]^c[b>>2];Sb=bc}c[(b+20|0)>>2]=c[b>>2]|c[(b+20|0)>>2];yb=Sb}if((m|0)==1605){m=0;c[d>>2]=yb;Lb=yb}if((c[(b+184|0)>>2]|0)==0){gc=0}else{gc=(c[(b+20|0)>>2]|0)!=0}c[(b+184|0)>>2]=gc&1;Sa=Lb}if((c[(b+192|0)>>2]|0)==0){hc=(c[(b+184|0)>>2]|0)!=0}else{hc=1}c[(b+192|0)>>2]=hc&1;q=Sa}q=1;o=m|0;if(q){q=0;switch(o|0){case 1304:{c[d>>2]=ra;break};case 1331:{c[d>>2]=Ba;m=1335;break};case 1353:{c[d>>2]=Ga;m=1386;break};case 1380:{c[d>>2]=Na;m=1384;break};case 1411:{c[d>>2]=Ta;m=1495;break};case 1438:{c[d>>2]=_a;m=1442;break};case 1460:{c[d>>2]=cb;m=1493;break};case 1487:{c[d>>2]=jb;m=1491;break};case 1515:{c[d>>2]=nb;m=1708;break};case 1542:{c[d>>2]=ub;m=1546;break};case 1564:{c[d>>2]=zb;m=1597;break};case 1591:{c[d>>2]=Gb;m=1595;break};case 1622:{c[d>>2]=Mb;m=1706;break};case 1649:{c[d>>2]=Tb;m=1653;break};case 1671:{c[d>>2]=Xb;m=1704;break};case 1698:{c[d>>2]=cc;m=1702;break};default:{q=1}}}if(q){q=0;switch(o|0){case 1717:{while(1){m=0;o=a[d+sa+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}sa=sa+1|0;m=1717}c[d>>2]=sa;if((a[d+sa+4>>0]|0)!=58){c[d>>2]=j;h=0;i=b;c[b+21040>>2]=6;c[b+21044>>2]=h|0;break a}o=sa+1|0;c[d>>2]=o;do{if((lw(d,b+388|0,f)|0)!=0){R:while(1){n=c[d>>2]|0;while(1){t=a[d+n+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;t=55328;u=61;v=n;while(1){if(!((a[d+v+4>>0]|0)==u<<24>>24)){ic=n;m=1728;break}ua=v+1|0;va=t+1|0;jc=a[va>>0]|0;if(jc<<24>>24==0){kc=1;lc=ua;break}else{t=va;u=jc;v=ua}}if((m|0)==1728){while(1){m=0;v=a[d+ic+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}ic=ic+1|0;m=1728}c[d>>2]=ic;v=55336;u=33;t=ic;while(1){if(!((a[d+t+4>>0]|0)==u<<24>>24)){break R}n=t+1|0;ua=v+1|0;jc=a[ua>>0]|0;if(jc<<24>>24==0){kc=2;lc=n;break}else{v=ua;u=jc;t=n}}}c[d>>2]=lc;if((lw(d,b+60|0,f)|0)==0){m=1735;break}if((kc|0)==1){c[(b+388|0)>>2]=(c[(b+388|0)>>2]|0)==(c[(b+60|0)>>2]|0);continue}else if((kc|0)==2){c[(b+388|0)>>2]=(c[(b+388|0)>>2]|0)!=(c[(b+60|0)>>2]|0);continue}else{continue}}if((m|0)==1735){c[d>>2]=o;break}t=ic;S:while(1){u=t;while(1){v=a[d+u+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}u=u+1|0}c[d>>2]=u;v=55320;n=38;jc=u;while(1){if(!((a[d+jc+4>>0]|0)==n<<24>>24)){mc=u;break}ua=v+1|0;va=a[ua>>0]|0;if(va<<24>>24==0){m=1745;break S}else{v=ua;n=va;jc=jc+1|0}}while(1){jc=a[d+mc+4>>0]|0;if(!(jc<<24>>24==10|jc<<24>>24==9|jc<<24>>24==32|jc<<24>>24==13)){break}mc=mc+1|0}c[d>>2]=mc;if((a[d+mc+4>>0]|0)!=38){nc=mc;break}oc=mc+1|0;c[d>>2]=oc;if((lw(d,b+224|0,f)|0)==0){m=1767;break}T:while(1){jc=c[d>>2]|0;while(1){n=a[d+jc+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}jc=jc+1|0}c[d>>2]=jc;n=55328;v=61;u=jc;while(1){if(!((a[d+u+4>>0]|0)==v<<24>>24)){pc=jc;m=1757;break}va=u+1|0;ua=n+1|0;qc=a[ua>>0]|0;if(qc<<24>>24==0){rc=1;sc=va;break}else{n=ua;v=qc;u=va}}if((m|0)==1757){while(1){m=0;u=a[d+pc+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}pc=pc+1|0;m=1757}c[d>>2]=pc;u=55336;v=33;n=pc;while(1){if(!((a[d+n+4>>0]|0)==v<<24>>24)){break T}jc=n+1|0;va=u+1|0;qc=a[va>>0]|0;if(qc<<24>>24==0){rc=2;sc=jc;break}else{u=va;v=qc;n=jc}}}c[d>>2]=sc;if((lw(d,b+404|0,f)|0)==0){m=1763;break S}if((rc|0)==1){c[(b+224|0)>>2]=(c[(b+224|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((rc|0)==2){c[(b+224|0)>>2]=(c[(b+224|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+388|0)>>2]=c[(b+224|0)>>2]&c[(b+388|0)>>2];t=pc}if((m|0)==1745){c[d>>2]=t;nc=t}else if((m|0)==1763){c[d>>2]=oc;m=1767}if((m|0)==1767){c[d>>2]=o;break}n=nc;U:while(1){v=a[d+n+4>>0]|0;if(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13){n=n+1|0;continue}c[d>>2]=n;if((a[d+n+4>>0]|0)!=94){m=1772;break}tc=n+1|0;c[d>>2]=tc;if((lw(d,b+308|0,f)|0)==0){break}V:while(1){v=c[d>>2]|0;while(1){u=a[d+v+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}v=v+1|0}c[d>>2]=v;u=55328;jc=61;qc=v;while(1){if(!((a[d+qc+4>>0]|0)==jc<<24>>24)){uc=v;m=1780;break}va=qc+1|0;ua=u+1|0;vc=a[ua>>0]|0;if(vc<<24>>24==0){wc=1;xc=va;break}else{u=ua;jc=vc;qc=va}}if((m|0)==1780){while(1){m=0;qc=a[d+uc+4>>0]|0;if(!(qc<<24>>24==10|qc<<24>>24==9|qc<<24>>24==32|qc<<24>>24==13)){break}uc=uc+1|0;m=1780}c[d>>2]=uc;qc=55336;jc=33;u=uc;while(1){if(!((a[d+u+4>>0]|0)==jc<<24>>24)){yc=uc;break V}v=u+1|0;va=qc+1|0;vc=a[va>>0]|0;if(vc<<24>>24==0){wc=2;xc=v;break}else{qc=va;jc=vc;u=v}}}c[d>>2]=xc;if((lw(d,b+56|0,f)|0)==0){m=1786;break U}if((wc|0)==1){c[(b+308|0)>>2]=(c[(b+308|0)>>2]|0)==(c[(b+56|0)>>2]|0);continue}else if((wc|0)==2){c[(b+308|0)>>2]=(c[(b+308|0)>>2]|0)!=(c[(b+56|0)>>2]|0);continue}else{continue}}W:while(1){u=yc;while(1){jc=a[d+u+4>>0]|0;if(!(jc<<24>>24==10|jc<<24>>24==9|jc<<24>>24==32|jc<<24>>24==13)){break}u=u+1|0}c[d>>2]=u;jc=55320;qc=38;v=u;while(1){if(!((a[d+v+4>>0]|0)==qc<<24>>24)){zc=u;break}vc=jc+1|0;va=a[vc>>0]|0;if(va<<24>>24==0){m=1796;break W}else{jc=vc;qc=va;v=v+1|0}}while(1){v=a[d+zc+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}zc=zc+1|0}c[d>>2]=zc;if((a[d+zc+4>>0]|0)!=38){Ac=zc;break}Bc=zc+1|0;c[d>>2]=Bc;if((lw(d,b+396|0,f)|0)==0){m=1817;break U}X:while(1){v=c[d>>2]|0;while(1){qc=a[d+v+4>>0]|0;if(!(qc<<24>>24==10|qc<<24>>24==9|qc<<24>>24==32|qc<<24>>24==13)){break}v=v+1|0}c[d>>2]=v;qc=55328;jc=61;u=v;while(1){if(!((a[d+u+4>>0]|0)==jc<<24>>24)){Cc=v;m=1807;break}va=u+1|0;vc=qc+1|0;ua=a[vc>>0]|0;if(ua<<24>>24==0){Dc=1;Ec=va;break}else{qc=vc;jc=ua;u=va}}if((m|0)==1807){while(1){m=0;u=a[d+Cc+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}Cc=Cc+1|0;m=1807}c[d>>2]=Cc;u=55336;jc=33;qc=Cc;while(1){if(!((a[d+qc+4>>0]|0)==jc<<24>>24)){break X}v=qc+1|0;va=u+1|0;ua=a[va>>0]|0;if(ua<<24>>24==0){Dc=2;Ec=v;break}else{u=va;jc=ua;qc=v}}}c[d>>2]=Ec;if((lw(d,b+404|0,f)|0)==0){m=1813;break U}if((Dc|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((Dc|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+308|0)>>2]=c[(b+396|0)>>2]&c[(b+308|0)>>2];yc=Cc}if((m|0)==1796){m=0;c[d>>2]=yc;Ac=yc}c[(b+388|0)>>2]=c[(b+308|0)>>2]^c[(b+388|0)>>2];n=Ac}t=1;if(t){t=0;if((m|0)==1772){qc=n;c[b+424>>2]=d;c[b+432>>2]=e;c[b+440>>2]=f;c[b+448>>2]=h;c[b+10280>>2]=o;c[b+10776>>2]=qc;c[b+20912>>2]=m;c[b+21032>>2]=0;c[b+21036>>2]=0;_cmd_match_expr_cond$0(b);h=c[b+448>>2]|0;qc=c[b+10776>>2]|0;m=c[b+20912>>2]|0;E=c[b+21032>>2]|0;x=c[b+21036>>2]|0;F=+g[b+21036>>2];c[b+21032>>2]=0;c[b+21036>>2]=0;if((E|0)==6){c[b+21040>>2]=6;c[b+21044>>2]=x|0;break a}if((E|0)==1){break}}else{t=1}}if(t){t=0;if((m|0)==1786){c[d>>2]=tc}else if((m|0)==1813)if(1){c[d>>2]=Bc;m=1817}else{t=1}}if((m|0)==1817){c[d>>2]=tc}c[d>>2]=o}}while(0);c[d>>2]=j;h=0;i=b;c[b+21040>>2]=6;c[b+21044>>2]=h|0;break a};default:{q=1}}}if((m|0)==1335){c[d>>2]=ra}else if((m|0)==1384){c[d>>2]=Ga;m=1386}else if((m|0)==1442){c[d>>2]=Ta;m=1495}else if((m|0)==1491){c[d>>2]=cb;m=1493}else if((m|0)==1546){c[d>>2]=nb;m=1708}else if((m|0)==1595){c[d>>2]=zb;m=1597}else if((m|0)==1653){c[d>>2]=Mb;m=1706}else if((m|0)==1702){c[d>>2]=Xb;m=1704}if((m|0)==1386){c[d>>2]=ra}else if((m|0)==1493){c[d>>2]=Ta;m=1495}else if((m|0)==1597){c[d>>2]=nb;m=1708}else if((m|0)==1704){c[d>>2]=Mb;m=1706}if((m|0)==1495){c[d>>2]=ra}else if((m|0)==1706){c[d>>2]=nb;m=1708}if((m|0)==1708){c[d>>2]=ra}c[d>>2]=k;c[b+21040>>2]=1;break a}else{r=1}}if(r){r=0;if((m|0)==1089){c[d>>2]=p}else if((m|0)==1116){c[d>>2]=C;m=1120}else if((m|0)==1138){c[d>>2]=J;m=1171}else if((m|0)==1165){c[d>>2]=Q;m=1169}else if((m|0)==1196){c[d>>2]=W;m=1280}else if((m|0)==1223){c[d>>2]=ba;m=1227}else if((m|0)==1245){c[d>>2]=fa;m=1278}else if((m|0)==1272)if(1){c[d>>2]=ma;m=1276}else{r=1}}if((m|0)==1120){c[d>>2]=p}else if((m|0)==1169){c[d>>2]=J;m=1171}else if((m|0)==1227){c[d>>2]=W;m=1280}else if((m|0)==1276){c[d>>2]=fa;m=1278}if((m|0)==1171){c[d>>2]=p}else if((m|0)==1278){c[d>>2]=W;m=1280}if((m|0)==1280){c[d>>2]=p}c[d>>2]=k;c[b+21040>>2]=1;break a}while(0);c[b+448>>2]=h;c[b+17256>>2]=l;c[b+20912>>2]=m}function _cmd_match_expr_cond$2(b){b=b|0;var d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=0,Za=0,_a=0,$a=0,ab=0,bb=0,cb=0,db=0,eb=0,fb=0,gb=0,hb=0,ib=0,jb=0,kb=0,lb=0,mb=0,nb=0,ob=0,pb=0,qb=0,rb=0,sb=0,tb=0,ub=0,vb=0,wb=0,xb=0,yb=0,zb=0,Ab=0,Bb=0,Cb=0,Db=0,Eb=0,Fb=0,Gb=0,Hb=0,Ib=0,Jb=0,Kb=0,Lb=0,Mb=0,Nb=0,Ob=0,Pb=0,Qb=0,Rb=0,Sb=0,Tb=0,Ub=0,Vb=0,Wb=0,Xb=0,Yb=0,Zb=0,_b=0,$b=0,ac=0,bc=0,cc=0,dc=0,ec=0,fc=0;d=c[b+424>>2]|0;e=c[b+432>>2]|0;f=c[b+440>>2]|0;h=c[b+448>>2]|0;j=c[b+4632>>2]|0;k=c[b+15352>>2]|0;l=c[b+20912>>2]|0;a:do{b:while(1){m=a[d+k+4>>0]|0;if(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13){k=k+1|0;continue}c[d>>2]=k;m=55312;n=124;o=k;do{if(!((a[d+o+4>>0]|0)==n<<24>>24)){p=k;l=857;break b}o=o+1|0;m=m+1|0;n=a[m>>0]|0}while(!(n<<24>>24==0));c[d>>2]=o;if((lw(d,b+380|0,f)|0)==0){break}c:while(1){n=c[d>>2]|0;while(1){m=a[d+n+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;m=55328;q=61;r=n;while(1){if(!((a[d+r+4>>0]|0)==q<<24>>24)){s=n;l=439;break}t=r+1|0;u=m+1|0;v=a[u>>0]|0;if(v<<24>>24==0){w=1;y=t;break}else{m=u;q=v;r=t}}if((l|0)==439){while(1){l=0;r=a[d+s+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}s=s+1|0;l=439}c[d>>2]=s;r=55336;q=33;m=s;while(1){if(!((a[d+m+4>>0]|0)==q<<24>>24)){z=s;break c}n=m+1|0;t=r+1|0;v=a[t>>0]|0;if(v<<24>>24==0){w=2;y=n;break}else{r=t;q=v;m=n}}}c[d>>2]=y;if((lw(d,b+156|0,f)|0)==0){l=445;break b}if((w|0)==1){c[(b+380|0)>>2]=(c[(b+380|0)>>2]|0)==(c[(b+156|0)>>2]|0);continue}else if((w|0)==2){c[(b+380|0)>>2]=(c[(b+380|0)>>2]|0)!=(c[(b+156|0)>>2]|0);continue}else{continue}}d:while(1){m=z;while(1){q=a[d+m+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}m=m+1|0}c[d>>2]=m;q=55320;r=38;n=m;while(1){if(!((a[d+n+4>>0]|0)==r<<24>>24)){A=m;break}v=q+1|0;t=a[v>>0]|0;if(t<<24>>24==0){l=455;break d}else{q=v;r=t;n=n+1|0}}while(1){n=a[d+A+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}A=A+1|0}c[d>>2]=A;if((a[d+A+4>>0]|0)!=38){B=A;break}C=A+1|0;c[d>>2]=C;if((lw(d,b+272|0,f)|0)==0){l=476;break b}e:while(1){n=c[d>>2]|0;while(1){r=a[d+n+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;r=55328;q=61;m=n;while(1){if(!((a[d+m+4>>0]|0)==q<<24>>24)){D=n;l=466;break}t=m+1|0;v=r+1|0;u=a[v>>0]|0;if(u<<24>>24==0){G=1;H=t;break}else{r=v;q=u;m=t}}if((l|0)==466){while(1){l=0;m=a[d+D+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}D=D+1|0;l=466}c[d>>2]=D;m=55336;q=33;r=D;while(1){if(!((a[d+r+4>>0]|0)==q<<24>>24)){break e}n=r+1|0;t=m+1|0;u=a[t>>0]|0;if(u<<24>>24==0){G=2;H=n;break}else{m=t;q=u;r=n}}}c[d>>2]=H;if((lw(d,b+404|0,f)|0)==0){l=472;break b}if((G|0)==1){c[(b+272|0)>>2]=(c[(b+272|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((G|0)==2){c[(b+272|0)>>2]=(c[(b+272|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+380|0)>>2]=c[(b+272|0)>>2]&c[(b+380|0)>>2];z=D}if((l|0)==455){l=0;c[d>>2]=z;B=z}while(1){r=a[d+B+4>>0]|0;if(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13){B=B+1|0;continue}c[d>>2]=B;if((a[d+B+4>>0]|0)!=94){I=B;break}J=B+1|0;c[d>>2]=J;if((lw(d,b+332|0,f)|0)==0){l=527;break b}f:while(1){r=c[d>>2]|0;while(1){q=a[d+r+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;q=55328;m=61;n=r;while(1){if(!((a[d+n+4>>0]|0)==m<<24>>24)){K=r;l=488;break}u=n+1|0;t=q+1|0;v=a[t>>0]|0;if(v<<24>>24==0){L=1;M=u;break}else{q=t;m=v;n=u}}if((l|0)==488){while(1){l=0;n=a[d+K+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}K=K+1|0;l=488}c[d>>2]=K;n=55336;m=33;q=K;while(1){if(!((a[d+q+4>>0]|0)==m<<24>>24)){N=K;break f}r=q+1|0;u=n+1|0;v=a[u>>0]|0;if(v<<24>>24==0){L=2;M=r;break}else{n=u;m=v;q=r}}}c[d>>2]=M;if((lw(d,b+152|0,f)|0)==0){l=494;break b}if((L|0)==1){c[(b+332|0)>>2]=(c[(b+332|0)>>2]|0)==(c[(b+152|0)>>2]|0);continue}else if((L|0)==2){c[(b+332|0)>>2]=(c[(b+332|0)>>2]|0)!=(c[(b+152|0)>>2]|0);continue}else{continue}}g:while(1){q=N;while(1){m=a[d+q+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;m=55320;n=38;r=q;while(1){if(!((a[d+r+4>>0]|0)==n<<24>>24)){O=q;break}v=m+1|0;u=a[v>>0]|0;if(u<<24>>24==0){l=504;break g}else{m=v;n=u;r=r+1|0}}while(1){r=a[d+O+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}O=O+1|0}c[d>>2]=O;if((a[d+O+4>>0]|0)!=38){P=O;break}Q=O+1|0;c[d>>2]=Q;if((lw(d,b+396|0,f)|0)==0){l=525;break b}h:while(1){r=c[d>>2]|0;while(1){n=a[d+r+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;n=55328;m=61;q=r;while(1){if(!((a[d+q+4>>0]|0)==m<<24>>24)){R=r;l=515;break}u=q+1|0;v=n+1|0;t=a[v>>0]|0;if(t<<24>>24==0){S=1;T=u;break}else{n=v;m=t;q=u}}if((l|0)==515){while(1){l=0;q=a[d+R+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}R=R+1|0;l=515}c[d>>2]=R;q=55336;m=33;n=R;while(1){if(!((a[d+n+4>>0]|0)==m<<24>>24)){break h}r=n+1|0;u=q+1|0;t=a[u>>0]|0;if(t<<24>>24==0){S=2;T=r;break}else{q=u;m=t;n=r}}}c[d>>2]=T;if((lw(d,b+404|0,f)|0)==0){l=521;break b}if((S|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((S|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+332|0)>>2]=c[(b+396|0)>>2]&c[(b+332|0)>>2];N=R}if((l|0)==504){l=0;c[d>>2]=N;P=N}c[(b+380|0)>>2]=c[(b+332|0)>>2]^c[(b+380|0)>>2];B=P}i:while(1){n=I;while(1){m=a[d+n+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;m=55312;q=124;r=n;while(1){if(!((a[d+r+4>>0]|0)==q<<24>>24)){U=n;break}t=m+1|0;u=a[t>>0]|0;if(u<<24>>24==0){l=535;break i}else{m=t;q=u;r=r+1|0}}while(1){r=a[d+U+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}U=U+1|0}c[d>>2]=U;if((a[d+U+4>>0]|0)!=124){V=U;break}W=U+1|0;c[d>>2]=W;if((lw(d,b+8|0,f)|0)==0){l=636;break b}j:while(1){r=c[d>>2]|0;while(1){q=a[d+r+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;q=55328;m=61;n=r;while(1){if(!((a[d+n+4>>0]|0)==m<<24>>24)){X=r;l=546;break}u=n+1|0;t=q+1|0;v=a[t>>0]|0;if(v<<24>>24==0){Y=1;Z=u;break}else{q=t;m=v;n=u}}if((l|0)==546){while(1){l=0;n=a[d+X+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}X=X+1|0;l=546}c[d>>2]=X;n=55336;m=33;q=X;while(1){if(!((a[d+q+4>>0]|0)==m<<24>>24)){_=X;break j}r=q+1|0;u=n+1|0;v=a[u>>0]|0;if(v<<24>>24==0){Y=2;Z=r;break}else{n=u;m=v;q=r}}}c[d>>2]=Z;if((lw(d,b+148|0,f)|0)==0){l=552;break b}if((Y|0)==1){c[(b+8|0)>>2]=(c[(b+8|0)>>2]|0)==(c[(b+148|0)>>2]|0);continue}else if((Y|0)==2){c[(b+8|0)>>2]=(c[(b+8|0)>>2]|0)!=(c[(b+148|0)>>2]|0);continue}else{continue}}k:while(1){q=_;while(1){m=a[d+q+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;m=55320;n=38;r=q;while(1){if(!((a[d+r+4>>0]|0)==n<<24>>24)){$=q;break}v=m+1|0;u=a[v>>0]|0;if(u<<24>>24==0){l=562;break k}else{m=v;n=u;r=r+1|0}}while(1){r=a[d+$+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}$=$+1|0}c[d>>2]=$;if((a[d+$+4>>0]|0)!=38){aa=$;break}ba=$+1|0;c[d>>2]=ba;if((lw(d,b+268|0,f)|0)==0){l=583;break b}l:while(1){r=c[d>>2]|0;while(1){n=a[d+r+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;n=55328;m=61;q=r;while(1){if(!((a[d+q+4>>0]|0)==m<<24>>24)){ca=r;l=573;break}u=q+1|0;v=n+1|0;t=a[v>>0]|0;if(t<<24>>24==0){da=1;ea=u;break}else{n=v;m=t;q=u}}if((l|0)==573){while(1){l=0;q=a[d+ca+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}ca=ca+1|0;l=573}c[d>>2]=ca;q=55336;m=33;n=ca;while(1){if(!((a[d+n+4>>0]|0)==m<<24>>24)){break l}r=n+1|0;u=q+1|0;t=a[u>>0]|0;if(t<<24>>24==0){da=2;ea=r;break}else{q=u;m=t;n=r}}}c[d>>2]=ea;if((lw(d,b+404|0,f)|0)==0){l=579;break b}if((da|0)==1){c[(b+268|0)>>2]=(c[(b+268|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((da|0)==2){c[(b+268|0)>>2]=(c[(b+268|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+8|0)>>2]=c[(b+268|0)>>2]&c[(b+8|0)>>2];_=ca}if((l|0)==562){l=0;c[d>>2]=_;aa=_}while(1){n=a[d+aa+4>>0]|0;if(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13){aa=aa+1|0;continue}c[d>>2]=aa;if((a[d+aa+4>>0]|0)!=94){break}fa=aa+1|0;c[d>>2]=fa;if((lw(d,b+372|0,f)|0)==0){l=634;break b}m:while(1){n=c[d>>2]|0;while(1){m=a[d+n+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;m=55328;q=61;r=n;while(1){if(!((a[d+r+4>>0]|0)==q<<24>>24)){ga=n;l=595;break}t=r+1|0;u=m+1|0;v=a[u>>0]|0;if(v<<24>>24==0){ha=1;ia=t;break}else{m=u;q=v;r=t}}if((l|0)==595){while(1){l=0;r=a[d+ga+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}ga=ga+1|0;l=595}c[d>>2]=ga;r=55336;q=33;m=ga;while(1){if(!((a[d+m+4>>0]|0)==q<<24>>24)){ja=ga;break m}n=m+1|0;t=r+1|0;v=a[t>>0]|0;if(v<<24>>24==0){ha=2;ia=n;break}else{r=t;q=v;m=n}}}c[d>>2]=ia;if((lw(d,b+144|0,f)|0)==0){l=601;break b}if((ha|0)==1){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)==(c[(b+144|0)>>2]|0);continue}else if((ha|0)==2){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)!=(c[(b+144|0)>>2]|0);continue}else{continue}}n:while(1){m=ja;while(1){q=a[d+m+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}m=m+1|0}c[d>>2]=m;q=55320;r=38;n=m;while(1){if(!((a[d+n+4>>0]|0)==r<<24>>24)){ka=m;break}v=q+1|0;t=a[v>>0]|0;if(t<<24>>24==0){l=611;break n}else{q=v;r=t;n=n+1|0}}while(1){n=a[d+ka+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}ka=ka+1|0}c[d>>2]=ka;if((a[d+ka+4>>0]|0)!=38){la=ka;break}ma=ka+1|0;c[d>>2]=ma;if((lw(d,b+396|0,f)|0)==0){l=632;break b}o:while(1){n=c[d>>2]|0;while(1){r=a[d+n+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;r=55328;q=61;m=n;while(1){if(!((a[d+m+4>>0]|0)==q<<24>>24)){na=n;l=622;break}t=m+1|0;v=r+1|0;u=a[v>>0]|0;if(u<<24>>24==0){oa=1;pa=t;break}else{r=v;q=u;m=t}}if((l|0)==622){while(1){l=0;m=a[d+na+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}na=na+1|0;l=622}c[d>>2]=na;m=55336;q=33;r=na;while(1){if(!((a[d+r+4>>0]|0)==q<<24>>24)){break o}n=r+1|0;t=m+1|0;u=a[t>>0]|0;if(u<<24>>24==0){oa=2;pa=n;break}else{m=t;q=u;r=n}}}c[d>>2]=pa;if((lw(d,b+404|0,f)|0)==0){l=628;break b}if((oa|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((oa|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+372|0)>>2]=c[(b+396|0)>>2]&c[(b+372|0)>>2];ja=na}if((l|0)==611){l=0;c[d>>2]=ja;la=ja}c[(b+8|0)>>2]=c[(b+372|0)>>2]^c[(b+8|0)>>2];aa=la}c[(b+380|0)>>2]=c[(b+8|0)>>2]|c[(b+380|0)>>2];I=aa}if((l|0)==535){l=0;c[d>>2]=I;V=I}p:while(1){r=a[d+V+4>>0]|0;if(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13){V=V+1|0;continue}c[d>>2]=V;r=55320;q=38;qa=V;do{if(!((a[d+qa+4>>0]|0)==q<<24>>24)){break p}qa=qa+1|0;r=r+1|0;q=a[r>>0]|0}while(!(q<<24>>24==0));c[d>>2]=qa;if((lw(d,b+20|0,f)|0)==0){l=849;break b}q:while(1){q=c[d>>2]|0;while(1){r=a[d+q+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;r=55328;m=61;n=q;while(1){if(!((a[d+n+4>>0]|0)==m<<24>>24)){ra=q;l=650;break}u=n+1|0;t=r+1|0;v=a[t>>0]|0;if(v<<24>>24==0){sa=1;ta=u;break}else{r=t;m=v;n=u}}if((l|0)==650){while(1){l=0;n=a[d+ra+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}ra=ra+1|0;l=650}c[d>>2]=ra;n=55336;m=33;r=ra;while(1){if(!((a[d+r+4>>0]|0)==m<<24>>24)){ua=ra;break q}q=r+1|0;u=n+1|0;v=a[u>>0]|0;if(v<<24>>24==0){sa=2;ta=q;break}else{n=u;m=v;r=q}}}c[d>>2]=ta;if((lw(d,b+140|0,f)|0)==0){l=656;break b}if((sa|0)==1){c[(b+20|0)>>2]=(c[(b+20|0)>>2]|0)==(c[(b+140|0)>>2]|0);continue}else if((sa|0)==2){c[(b+20|0)>>2]=(c[(b+20|0)>>2]|0)!=(c[(b+140|0)>>2]|0);continue}else{continue}}r:while(1){r=ua;while(1){m=a[d+r+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;m=55320;n=38;q=r;while(1){if(!((a[d+q+4>>0]|0)==n<<24>>24)){va=r;break}v=m+1|0;u=a[v>>0]|0;if(u<<24>>24==0){l=666;break r}else{m=v;n=u;q=q+1|0}}while(1){q=a[d+va+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}va=va+1|0}c[d>>2]=va;if((a[d+va+4>>0]|0)!=38){wa=va;break}xa=va+1|0;c[d>>2]=xa;if((lw(d,b+264|0,f)|0)==0){l=687;break b}s:while(1){q=c[d>>2]|0;while(1){n=a[d+q+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;n=55328;m=61;r=q;while(1){if(!((a[d+r+4>>0]|0)==m<<24>>24)){ya=q;l=677;break}u=r+1|0;v=n+1|0;t=a[v>>0]|0;if(t<<24>>24==0){za=1;Aa=u;break}else{n=v;m=t;r=u}}if((l|0)==677){while(1){l=0;r=a[d+ya+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}ya=ya+1|0;l=677}c[d>>2]=ya;r=55336;m=33;n=ya;while(1){if(!((a[d+n+4>>0]|0)==m<<24>>24)){break s}q=n+1|0;u=r+1|0;t=a[u>>0]|0;if(t<<24>>24==0){za=2;Aa=q;break}else{r=u;m=t;n=q}}}c[d>>2]=Aa;if((lw(d,b+404|0,f)|0)==0){l=683;break b}if((za|0)==1){c[(b+264|0)>>2]=(c[(b+264|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((za|0)==2){c[(b+264|0)>>2]=(c[(b+264|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+20|0)>>2]=c[(b+264|0)>>2]&c[(b+20|0)>>2];ua=ya}if((l|0)==666){l=0;c[d>>2]=ua;wa=ua}while(1){n=a[d+wa+4>>0]|0;if(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13){wa=wa+1|0;continue}c[d>>2]=wa;if((a[d+wa+4>>0]|0)!=94){Ba=wa;break}Ca=wa+1|0;c[d>>2]=Ca;if((lw(d,b+328|0,f)|0)==0){l=738;break b}t:while(1){n=c[d>>2]|0;while(1){m=a[d+n+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;m=55328;r=61;q=n;while(1){if(!((a[d+q+4>>0]|0)==r<<24>>24)){Da=n;l=699;break}t=q+1|0;u=m+1|0;v=a[u>>0]|0;if(v<<24>>24==0){Ea=1;Fa=t;break}else{m=u;r=v;q=t}}if((l|0)==699){while(1){l=0;q=a[d+Da+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}Da=Da+1|0;l=699}c[d>>2]=Da;q=55336;r=33;m=Da;while(1){if(!((a[d+m+4>>0]|0)==r<<24>>24)){Ga=Da;break t}n=m+1|0;t=q+1|0;v=a[t>>0]|0;if(v<<24>>24==0){Ea=2;Fa=n;break}else{q=t;r=v;m=n}}}c[d>>2]=Fa;if((lw(d,b+136|0,f)|0)==0){l=705;break b}if((Ea|0)==1){c[(b+328|0)>>2]=(c[(b+328|0)>>2]|0)==(c[(b+136|0)>>2]|0);continue}else if((Ea|0)==2){c[(b+328|0)>>2]=(c[(b+328|0)>>2]|0)!=(c[(b+136|0)>>2]|0);continue}else{continue}}u:while(1){m=Ga;while(1){r=a[d+m+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}m=m+1|0}c[d>>2]=m;r=55320;q=38;n=m;while(1){if(!((a[d+n+4>>0]|0)==q<<24>>24)){Ha=m;break}v=r+1|0;t=a[v>>0]|0;if(t<<24>>24==0){l=715;break u}else{r=v;q=t;n=n+1|0}}while(1){n=a[d+Ha+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}Ha=Ha+1|0}c[d>>2]=Ha;if((a[d+Ha+4>>0]|0)!=38){Ia=Ha;break}Ja=Ha+1|0;c[d>>2]=Ja;if((lw(d,b+396|0,f)|0)==0){l=736;break b}v:while(1){n=c[d>>2]|0;while(1){q=a[d+n+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;q=55328;r=61;m=n;while(1){if(!((a[d+m+4>>0]|0)==r<<24>>24)){Ka=n;l=726;break}t=m+1|0;v=q+1|0;u=a[v>>0]|0;if(u<<24>>24==0){La=1;Ma=t;break}else{q=v;r=u;m=t}}if((l|0)==726){while(1){l=0;m=a[d+Ka+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}Ka=Ka+1|0;l=726}c[d>>2]=Ka;m=55336;r=33;q=Ka;while(1){if(!((a[d+q+4>>0]|0)==r<<24>>24)){break v}n=q+1|0;t=m+1|0;u=a[t>>0]|0;if(u<<24>>24==0){La=2;Ma=n;break}else{m=t;r=u;q=n}}}c[d>>2]=Ma;if((lw(d,b+404|0,f)|0)==0){l=732;break b}if((La|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((La|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+328|0)>>2]=c[(b+396|0)>>2]&c[(b+328|0)>>2];Ga=Ka}if((l|0)==715){l=0;c[d>>2]=Ga;Ia=Ga}c[(b+20|0)>>2]=c[(b+328|0)>>2]^c[(b+20|0)>>2];wa=Ia}w:while(1){q=Ba;while(1){r=a[d+q+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;r=55312;m=124;n=q;while(1){if(!((a[d+n+4>>0]|0)==m<<24>>24)){Na=q;break}u=r+1|0;t=a[u>>0]|0;if(t<<24>>24==0){l=746;break w}else{r=u;m=t;n=n+1|0}}while(1){n=a[d+Na+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}Na=Na+1|0}c[d>>2]=Na;if((a[d+Na+4>>0]|0)!=124){Oa=Na;break}Pa=Na+1|0;c[d>>2]=Pa;if((lw(d,b,f)|0)==0){l=847;break b}x:while(1){n=c[d>>2]|0;while(1){m=a[d+n+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;m=55328;r=61;q=n;while(1){if(!((a[d+q+4>>0]|0)==r<<24>>24)){Qa=n;l=757;break}t=q+1|0;u=m+1|0;v=a[u>>0]|0;if(v<<24>>24==0){Ra=1;Sa=t;break}else{m=u;r=v;q=t}}if((l|0)==757){while(1){l=0;q=a[d+Qa+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}Qa=Qa+1|0;l=757}c[d>>2]=Qa;q=55336;r=33;m=Qa;while(1){if(!((a[d+m+4>>0]|0)==r<<24>>24)){Ta=Qa;break x}n=m+1|0;t=q+1|0;v=a[t>>0]|0;if(v<<24>>24==0){Ra=2;Sa=n;break}else{q=t;r=v;m=n}}}c[d>>2]=Sa;if((lw(d,b+132|0,f)|0)==0){l=763;break b}if((Ra|0)==1){c[b>>2]=(c[b>>2]|0)==(c[(b+132|0)>>2]|0);continue}else if((Ra|0)==2){c[b>>2]=(c[b>>2]|0)!=(c[(b+132|0)>>2]|0);continue}else{continue}}y:while(1){m=Ta;while(1){r=a[d+m+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}m=m+1|0}c[d>>2]=m;r=55320;q=38;n=m;while(1){if(!((a[d+n+4>>0]|0)==q<<24>>24)){Ua=m;break}v=r+1|0;t=a[v>>0]|0;if(t<<24>>24==0){l=773;break y}else{r=v;q=t;n=n+1|0}}while(1){n=a[d+Ua+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}Ua=Ua+1|0}c[d>>2]=Ua;if((a[d+Ua+4>>0]|0)!=38){Va=Ua;break}Wa=Ua+1|0;c[d>>2]=Wa;if((lw(d,b+260|0,f)|0)==0){l=794;break b}z:while(1){n=c[d>>2]|0;while(1){q=a[d+n+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}n=n+1|0}c[d>>2]=n;q=55328;r=61;m=n;while(1){if(!((a[d+m+4>>0]|0)==r<<24>>24)){Xa=n;l=784;break}t=m+1|0;v=q+1|0;u=a[v>>0]|0;if(u<<24>>24==0){Ya=1;Za=t;break}else{q=v;r=u;m=t}}if((l|0)==784){while(1){l=0;m=a[d+Xa+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}Xa=Xa+1|0;l=784}c[d>>2]=Xa;m=55336;r=33;q=Xa;while(1){if(!((a[d+q+4>>0]|0)==r<<24>>24)){break z}n=q+1|0;t=m+1|0;u=a[t>>0]|0;if(u<<24>>24==0){Ya=2;Za=n;break}else{m=t;r=u;q=n}}}c[d>>2]=Za;if((lw(d,b+404|0,f)|0)==0){l=790;break b}if((Ya|0)==1){c[(b+260|0)>>2]=(c[(b+260|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((Ya|0)==2){c[(b+260|0)>>2]=(c[(b+260|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[b>>2]=c[(b+260|0)>>2]&c[b>>2];Ta=Xa}if((l|0)==773){l=0;c[d>>2]=Ta;Va=Ta}while(1){q=a[d+Va+4>>0]|0;if(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13){Va=Va+1|0;continue}c[d>>2]=Va;if((a[d+Va+4>>0]|0)!=94){break}_a=Va+1|0;c[d>>2]=_a;if((lw(d,b+372|0,f)|0)==0){l=845;break b}A:while(1){q=c[d>>2]|0;while(1){r=a[d+q+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;r=55328;m=61;n=q;while(1){if(!((a[d+n+4>>0]|0)==m<<24>>24)){$a=q;l=806;break}u=n+1|0;t=r+1|0;v=a[t>>0]|0;if(v<<24>>24==0){ab=1;bb=u;break}else{r=t;m=v;n=u}}if((l|0)==806){while(1){l=0;n=a[d+$a+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}$a=$a+1|0;l=806}c[d>>2]=$a;n=55336;m=33;r=$a;while(1){if(!((a[d+r+4>>0]|0)==m<<24>>24)){cb=$a;break A}q=r+1|0;u=n+1|0;v=a[u>>0]|0;if(v<<24>>24==0){ab=2;bb=q;break}else{n=u;m=v;r=q}}}c[d>>2]=bb;if((lw(d,b+128|0,f)|0)==0){l=812;break b}if((ab|0)==1){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)==(c[(b+128|0)>>2]|0);continue}else if((ab|0)==2){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)!=(c[(b+128|0)>>2]|0);continue}else{continue}}B:while(1){r=cb;while(1){m=a[d+r+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;m=55320;n=38;q=r;while(1){if(!((a[d+q+4>>0]|0)==n<<24>>24)){db=r;break}v=m+1|0;u=a[v>>0]|0;if(u<<24>>24==0){l=822;break B}else{m=v;n=u;q=q+1|0}}while(1){q=a[d+db+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}db=db+1|0}c[d>>2]=db;if((a[d+db+4>>0]|0)!=38){eb=db;break}fb=db+1|0;c[d>>2]=fb;if((lw(d,b+396|0,f)|0)==0){l=843;break b}C:while(1){q=c[d>>2]|0;while(1){n=a[d+q+4>>0]|0;if(!(n<<24>>24==10|n<<24>>24==9|n<<24>>24==32|n<<24>>24==13)){break}q=q+1|0}c[d>>2]=q;n=55328;m=61;r=q;while(1){if(!((a[d+r+4>>0]|0)==m<<24>>24)){gb=q;l=833;break}u=r+1|0;v=n+1|0;t=a[v>>0]|0;if(t<<24>>24==0){hb=1;ib=u;break}else{n=v;m=t;r=u}}if((l|0)==833){while(1){l=0;r=a[d+gb+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}gb=gb+1|0;l=833}c[d>>2]=gb;r=55336;m=33;n=gb;while(1){if(!((a[d+n+4>>0]|0)==m<<24>>24)){break C}q=n+1|0;u=r+1|0;t=a[u>>0]|0;if(t<<24>>24==0){hb=2;ib=q;break}else{r=u;m=t;n=q}}}c[d>>2]=ib;if((lw(d,b+404|0,f)|0)==0){l=839;break b}if((hb|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((hb|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+372|0)>>2]=c[(b+396|0)>>2]&c[(b+372|0)>>2];cb=gb}if((l|0)==822){l=0;c[d>>2]=cb;eb=cb}c[b>>2]=c[(b+372|0)>>2]^c[b>>2];Va=eb}c[(b+20|0)>>2]=c[b>>2]|c[(b+20|0)>>2];Ba=Va}if((l|0)==746){l=0;c[d>>2]=Ba;Oa=Ba}if((c[(b+380|0)>>2]|0)==0){jb=0}else{jb=(c[(b+20|0)>>2]|0)!=0}c[(b+380|0)>>2]=jb&1;V=Oa}if((c[e>>2]|0)==0){kb=(c[(b+380|0)>>2]|0)!=0}else{kb=1}c[e>>2]=kb&1;k=V}n=1;m=l|0;if(n){n=0;switch(m|0){case 445:{c[d>>2]=o;break};case 472:{c[d>>2]=C;l=476;break};case 494:{c[d>>2]=J;l=527;break};case 521:{c[d>>2]=Q;l=525;break};case 552:{c[d>>2]=W;l=636;break};case 579:{c[d>>2]=ba;l=583;break};case 601:{c[d>>2]=fa;l=634;break};case 628:{c[d>>2]=ma;l=632;break};case 656:{c[d>>2]=qa;l=849;break};case 683:{c[d>>2]=xa;l=687;break};case 705:{c[d>>2]=Ca;l=738;break};case 732:{c[d>>2]=Ja;l=736;break};case 763:{c[d>>2]=Pa;l=847;break};case 790:{c[d>>2]=Wa;l=794;break};case 812:{c[d>>2]=_a;l=845;break};case 839:{c[d>>2]=fb;l=843;break};default:{n=1}}}if(n){n=0;switch(m|0){case 857:{while(1){l=0;m=a[d+p+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}p=p+1|0;l=857}c[d>>2]=p;if((a[d+p+4>>0]|0)!=63){h=1;i=b;c[b+21048>>2]=6;c[b+21052>>2]=h|0;break a}m=p+1|0;c[d>>2]=m;do{if((lw(d,b+192|0,f)|0)!=0){D:while(1){r=c[d>>2]|0;while(1){q=a[d+r+4>>0]|0;if(!(q<<24>>24==10|q<<24>>24==9|q<<24>>24==32|q<<24>>24==13)){break}r=r+1|0}c[d>>2]=r;q=55328;t=61;u=r;while(1){if(!((a[d+u+4>>0]|0)==t<<24>>24)){lb=r;l=867;break}v=u+1|0;mb=q+1|0;nb=a[mb>>0]|0;if(nb<<24>>24==0){ob=1;pb=v;break}else{q=mb;t=nb;u=v}}if((l|0)==867){while(1){l=0;u=a[d+lb+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}lb=lb+1|0;l=867}c[d>>2]=lb;u=55336;t=33;q=lb;while(1){if(!((a[d+q+4>>0]|0)==t<<24>>24)){break D}r=q+1|0;v=u+1|0;nb=a[v>>0]|0;if(nb<<24>>24==0){ob=2;pb=r;break}else{u=v;t=nb;q=r}}}c[d>>2]=pb;if((lw(d,b+124|0,f)|0)==0){l=874;break}if((ob|0)==1){c[(b+192|0)>>2]=(c[(b+192|0)>>2]|0)==(c[(b+124|0)>>2]|0);continue}else if((ob|0)==2){c[(b+192|0)>>2]=(c[(b+192|0)>>2]|0)!=(c[(b+124|0)>>2]|0);continue}else{continue}}if((l|0)==874){c[d>>2]=m;break}q=lb;E:while(1){t=q;while(1){u=a[d+t+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}t=t+1|0}c[d>>2]=t;u=55320;r=38;nb=t;while(1){if(!((a[d+nb+4>>0]|0)==r<<24>>24)){qb=t;break}v=u+1|0;mb=a[v>>0]|0;if(mb<<24>>24==0){l=884;break E}else{u=v;r=mb;nb=nb+1|0}}while(1){nb=a[d+qb+4>>0]|0;if(!(nb<<24>>24==10|nb<<24>>24==9|nb<<24>>24==32|nb<<24>>24==13)){break}qb=qb+1|0}c[d>>2]=qb;if((a[d+qb+4>>0]|0)!=38){rb=qb;break}sb=qb+1|0;c[d>>2]=sb;if((lw(d,b+256|0,f)|0)==0){l=906;break}F:while(1){nb=c[d>>2]|0;while(1){r=a[d+nb+4>>0]|0;if(!(r<<24>>24==10|r<<24>>24==9|r<<24>>24==32|r<<24>>24==13)){break}nb=nb+1|0}c[d>>2]=nb;r=55328;u=61;t=nb;while(1){if(!((a[d+t+4>>0]|0)==u<<24>>24)){tb=nb;l=896;break}mb=t+1|0;v=r+1|0;ub=a[v>>0]|0;if(ub<<24>>24==0){vb=1;wb=mb;break}else{r=v;u=ub;t=mb}}if((l|0)==896){while(1){l=0;t=a[d+tb+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}tb=tb+1|0;l=896}c[d>>2]=tb;t=55336;u=33;r=tb;while(1){if(!((a[d+r+4>>0]|0)==u<<24>>24)){break F}nb=r+1|0;mb=t+1|0;ub=a[mb>>0]|0;if(ub<<24>>24==0){vb=2;wb=nb;break}else{t=mb;u=ub;r=nb}}}c[d>>2]=wb;if((lw(d,b+404|0,f)|0)==0){l=902;break E}if((vb|0)==1){c[(b+256|0)>>2]=(c[(b+256|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((vb|0)==2){c[(b+256|0)>>2]=(c[(b+256|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+192|0)>>2]=c[(b+256|0)>>2]&c[(b+192|0)>>2];q=tb}if((l|0)==884){c[d>>2]=q;rb=q}else if((l|0)==902){c[d>>2]=sb;l=906}if((l|0)==906){c[d>>2]=m;break}r=rb;G:while(1){u=a[d+r+4>>0]|0;if(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13){r=r+1|0;continue}c[d>>2]=r;if((a[d+r+4>>0]|0)!=94){l=911;break}xb=r+1|0;c[d>>2]=xb;if((lw(d,b+324|0,f)|0)==0){break}H:while(1){u=c[d>>2]|0;while(1){t=a[d+u+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}u=u+1|0}c[d>>2]=u;t=55328;nb=61;ub=u;while(1){if(!((a[d+ub+4>>0]|0)==nb<<24>>24)){yb=u;l=919;break}mb=ub+1|0;v=t+1|0;zb=a[v>>0]|0;if(zb<<24>>24==0){Ab=1;Bb=mb;break}else{t=v;nb=zb;ub=mb}}if((l|0)==919){while(1){l=0;ub=a[d+yb+4>>0]|0;if(!(ub<<24>>24==10|ub<<24>>24==9|ub<<24>>24==32|ub<<24>>24==13)){break}yb=yb+1|0;l=919}c[d>>2]=yb;ub=55336;nb=33;t=yb;while(1){if(!((a[d+t+4>>0]|0)==nb<<24>>24)){Cb=yb;break H}u=t+1|0;mb=ub+1|0;zb=a[mb>>0]|0;if(zb<<24>>24==0){Ab=2;Bb=u;break}else{ub=mb;nb=zb;t=u}}}c[d>>2]=Bb;if((lw(d,b+120|0,f)|0)==0){l=925;break G}if((Ab|0)==1){c[(b+324|0)>>2]=(c[(b+324|0)>>2]|0)==(c[(b+120|0)>>2]|0);continue}else if((Ab|0)==2){c[(b+324|0)>>2]=(c[(b+324|0)>>2]|0)!=(c[(b+120|0)>>2]|0);continue}else{continue}}I:while(1){t=Cb;while(1){nb=a[d+t+4>>0]|0;if(!(nb<<24>>24==10|nb<<24>>24==9|nb<<24>>24==32|nb<<24>>24==13)){break}t=t+1|0}c[d>>2]=t;nb=55320;ub=38;u=t;while(1){if(!((a[d+u+4>>0]|0)==ub<<24>>24)){Db=t;break}zb=nb+1|0;mb=a[zb>>0]|0;if(mb<<24>>24==0){l=935;break I}else{nb=zb;ub=mb;u=u+1|0}}while(1){u=a[d+Db+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}Db=Db+1|0}c[d>>2]=Db;if((a[d+Db+4>>0]|0)!=38){Eb=Db;break}Fb=Db+1|0;c[d>>2]=Fb;if((lw(d,b+396|0,f)|0)==0){l=956;break G}J:while(1){u=c[d>>2]|0;while(1){ub=a[d+u+4>>0]|0;if(!(ub<<24>>24==10|ub<<24>>24==9|ub<<24>>24==32|ub<<24>>24==13)){break}u=u+1|0}c[d>>2]=u;ub=55328;nb=61;t=u;while(1){if(!((a[d+t+4>>0]|0)==nb<<24>>24)){Gb=u;l=946;break}mb=t+1|0;zb=ub+1|0;v=a[zb>>0]|0;if(v<<24>>24==0){Hb=1;Ib=mb;break}else{ub=zb;nb=v;t=mb}}if((l|0)==946){while(1){l=0;t=a[d+Gb+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}Gb=Gb+1|0;l=946}c[d>>2]=Gb;t=55336;nb=33;ub=Gb;while(1){if(!((a[d+ub+4>>0]|0)==nb<<24>>24)){break J}u=ub+1|0;mb=t+1|0;v=a[mb>>0]|0;if(v<<24>>24==0){Hb=2;Ib=u;break}else{t=mb;nb=v;ub=u}}}c[d>>2]=Ib;if((lw(d,b+404|0,f)|0)==0){l=952;break G}if((Hb|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((Hb|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+324|0)>>2]=c[(b+396|0)>>2]&c[(b+324|0)>>2];Cb=Gb}if((l|0)==935){l=0;c[d>>2]=Cb;Eb=Cb}c[(b+192|0)>>2]=c[(b+324|0)>>2]^c[(b+192|0)>>2];r=Eb}q=1;if(q){q=0;if((l|0)==911){ub=r;K:while(1){nb=ub;while(1){t=a[d+nb+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}nb=nb+1|0}c[d>>2]=nb;t=55312;u=124;v=nb;while(1){if(!((a[d+v+4>>0]|0)==u<<24>>24)){Jb=nb;break}mb=t+1|0;zb=a[mb>>0]|0;if(zb<<24>>24==0){l=966;break K}else{t=mb;u=zb;v=v+1|0}}while(1){v=a[d+Jb+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}Jb=Jb+1|0}c[d>>2]=Jb;if((a[d+Jb+4>>0]|0)!=124){Kb=Jb;l=970;break}Lb=Jb+1|0;c[d>>2]=Lb;if((lw(d,b+24|0,f)|0)==0){break}L:while(1){v=c[d>>2]|0;while(1){u=a[d+v+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}v=v+1|0}c[d>>2]=v;u=55328;t=61;nb=v;while(1){if(!((a[d+nb+4>>0]|0)==t<<24>>24)){Mb=v;l=978;break}zb=nb+1|0;mb=u+1|0;Nb=a[mb>>0]|0;if(Nb<<24>>24==0){Ob=1;Pb=zb;break}else{u=mb;t=Nb;nb=zb}}if((l|0)==978){while(1){l=0;nb=a[d+Mb+4>>0]|0;if(!(nb<<24>>24==10|nb<<24>>24==9|nb<<24>>24==32|nb<<24>>24==13)){break}Mb=Mb+1|0;l=978}c[d>>2]=Mb;nb=55336;t=33;u=Mb;while(1){if(!((a[d+u+4>>0]|0)==t<<24>>24)){Qb=Mb;break L}v=u+1|0;zb=nb+1|0;Nb=a[zb>>0]|0;if(Nb<<24>>24==0){Ob=2;Pb=v;break}else{nb=zb;t=Nb;u=v}}}c[d>>2]=Pb;if((lw(d,b+116|0,f)|0)==0){l=984;break K}if((Ob|0)==1){c[(b+24|0)>>2]=(c[(b+24|0)>>2]|0)==(c[(b+116|0)>>2]|0);continue}else if((Ob|0)==2){c[(b+24|0)>>2]=(c[(b+24|0)>>2]|0)!=(c[(b+116|0)>>2]|0);continue}else{continue}}M:while(1){u=Qb;while(1){t=a[d+u+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}u=u+1|0}c[d>>2]=u;t=55320;nb=38;v=u;while(1){if(!((a[d+v+4>>0]|0)==nb<<24>>24)){Rb=u;break}Nb=t+1|0;zb=a[Nb>>0]|0;if(zb<<24>>24==0){l=994;break M}else{t=Nb;nb=zb;v=v+1|0}}while(1){v=a[d+Rb+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}Rb=Rb+1|0}c[d>>2]=Rb;if((a[d+Rb+4>>0]|0)!=38){Sb=Rb;break}Tb=Rb+1|0;c[d>>2]=Tb;if((lw(d,b+252|0,f)|0)==0){l=1015;break K}N:while(1){v=c[d>>2]|0;while(1){nb=a[d+v+4>>0]|0;if(!(nb<<24>>24==10|nb<<24>>24==9|nb<<24>>24==32|nb<<24>>24==13)){break}v=v+1|0}c[d>>2]=v;nb=55328;t=61;u=v;while(1){if(!((a[d+u+4>>0]|0)==t<<24>>24)){Ub=v;l=1005;break}zb=u+1|0;Nb=nb+1|0;mb=a[Nb>>0]|0;if(mb<<24>>24==0){Vb=1;Wb=zb;break}else{nb=Nb;t=mb;u=zb}}if((l|0)==1005){while(1){l=0;u=a[d+Ub+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}Ub=Ub+1|0;l=1005}c[d>>2]=Ub;u=55336;t=33;nb=Ub;while(1){if(!((a[d+nb+4>>0]|0)==t<<24>>24)){break N}v=nb+1|0;zb=u+1|0;mb=a[zb>>0]|0;if(mb<<24>>24==0){Vb=2;Wb=v;break}else{u=zb;t=mb;nb=v}}}c[d>>2]=Wb;if((lw(d,b+404|0,f)|0)==0){l=1011;break K}if((Vb|0)==1){c[(b+252|0)>>2]=(c[(b+252|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((Vb|0)==2){c[(b+252|0)>>2]=(c[(b+252|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+24|0)>>2]=c[(b+252|0)>>2]&c[(b+24|0)>>2];Qb=Ub}if((l|0)==994){l=0;c[d>>2]=Qb;Sb=Qb}while(1){nb=a[d+Sb+4>>0]|0;if(nb<<24>>24==10|nb<<24>>24==9|nb<<24>>24==32|nb<<24>>24==13){Sb=Sb+1|0;continue}c[d>>2]=Sb;if((a[d+Sb+4>>0]|0)!=94){break}Xb=Sb+1|0;c[d>>2]=Xb;if((lw(d,b+372|0,f)|0)==0){l=1066;break K}O:while(1){nb=c[d>>2]|0;while(1){t=a[d+nb+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}nb=nb+1|0}c[d>>2]=nb;t=55328;u=61;v=nb;while(1){if(!((a[d+v+4>>0]|0)==u<<24>>24)){Yb=nb;l=1027;break}mb=v+1|0;zb=t+1|0;Nb=a[zb>>0]|0;if(Nb<<24>>24==0){Zb=1;_b=mb;break}else{t=zb;u=Nb;v=mb}}if((l|0)==1027){while(1){l=0;v=a[d+Yb+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}Yb=Yb+1|0;l=1027}c[d>>2]=Yb;v=55336;u=33;t=Yb;while(1){if(!((a[d+t+4>>0]|0)==u<<24>>24)){$b=Yb;break O}nb=t+1|0;mb=v+1|0;Nb=a[mb>>0]|0;if(Nb<<24>>24==0){Zb=2;_b=nb;break}else{v=mb;u=Nb;t=nb}}}c[d>>2]=_b;if((lw(d,b+112|0,f)|0)==0){l=1033;break K}if((Zb|0)==1){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)==(c[(b+112|0)>>2]|0);continue}else if((Zb|0)==2){c[(b+372|0)>>2]=(c[(b+372|0)>>2]|0)!=(c[(b+112|0)>>2]|0);continue}else{continue}}P:while(1){t=$b;while(1){u=a[d+t+4>>0]|0;if(!(u<<24>>24==10|u<<24>>24==9|u<<24>>24==32|u<<24>>24==13)){break}t=t+1|0}c[d>>2]=t;u=55320;v=38;nb=t;while(1){if(!((a[d+nb+4>>0]|0)==v<<24>>24)){ac=t;break}Nb=u+1|0;mb=a[Nb>>0]|0;if(mb<<24>>24==0){l=1043;break P}else{u=Nb;v=mb;nb=nb+1|0}}while(1){nb=a[d+ac+4>>0]|0;if(!(nb<<24>>24==10|nb<<24>>24==9|nb<<24>>24==32|nb<<24>>24==13)){break}ac=ac+1|0}c[d>>2]=ac;if((a[d+ac+4>>0]|0)!=38){bc=ac;break}cc=ac+1|0;c[d>>2]=cc;if((lw(d,b+396|0,f)|0)==0){l=1064;break K}Q:while(1){nb=c[d>>2]|0;while(1){v=a[d+nb+4>>0]|0;if(!(v<<24>>24==10|v<<24>>24==9|v<<24>>24==32|v<<24>>24==13)){break}nb=nb+1|0}c[d>>2]=nb;v=55328;u=61;t=nb;while(1){if(!((a[d+t+4>>0]|0)==u<<24>>24)){dc=nb;l=1054;break}mb=t+1|0;Nb=v+1|0;zb=a[Nb>>0]|0;if(zb<<24>>24==0){ec=1;fc=mb;break}else{v=Nb;u=zb;t=mb}}if((l|0)==1054){while(1){l=0;t=a[d+dc+4>>0]|0;if(!(t<<24>>24==10|t<<24>>24==9|t<<24>>24==32|t<<24>>24==13)){break}dc=dc+1|0;l=1054}c[d>>2]=dc;t=55336;u=33;v=dc;while(1){if(!((a[d+v+4>>0]|0)==u<<24>>24)){break Q}nb=v+1|0;mb=t+1|0;zb=a[mb>>0]|0;if(zb<<24>>24==0){ec=2;fc=nb;break}else{t=mb;u=zb;v=nb}}}c[d>>2]=fc;if((lw(d,b+404|0,f)|0)==0){l=1060;break K}if((ec|0)==1){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)==(c[(b+404|0)>>2]|0);continue}else if((ec|0)==2){c[(b+396|0)>>2]=(c[(b+396|0)>>2]|0)!=(c[(b+404|0)>>2]|0);continue}else{continue}}c[(b+372|0)>>2]=c[(b+396|0)>>2]&c[(b+372|0)>>2];$b=dc}if((l|0)==1043){l=0;c[d>>2]=$b;bc=$b}c[(b+24|0)>>2]=c[(b+372|0)>>2]^c[(b+24|0)>>2];Sb=bc}c[(b+192|0)>>2]=c[(b+24|0)>>2]|c[(b+192|0)>>2];ub=Sb}if((l|0)==966){c[d>>2]=ub;Kb=ub;l=970}else if((l|0)==984){c[d>>2]=Lb}else if((l|0)==1011){c[d>>2]=Tb;l=1015}else if((l|0)==1033){c[d>>2]=Xb;l=1066}else if((l|0)==1060){c[d>>2]=cc;l=1064}r=1;if(r){r=0;if((l|0)==970){v=Kb;c[b+424>>2]=d;c[b+432>>2]=e;c[b+440>>2]=f;c[b+448>>2]=h;c[b+4632>>2]=j;c[b+6264>>2]=m;c[b+17256>>2]=v;c[b+20912>>2]=l;c[b+21040>>2]=0;c[b+21044>>2]=0;_cmd_match_expr_cond$1(b);h=c[b+448>>2]|0;v=c[b+17256>>2]|0;l=c[b+20912>>2]|0;E=c[b+21040>>2]|0;x=c[b+21044>>2]|0;F=+g[b+21044>>2];c[b+21040>>2]=0;c[b+21044>>2]=0;if((E|0)==6){c[b+21048>>2]=6;c[b+21052>>2]=x|0;break a}if((E|0)==1){break}}else{r=1}}if(r){r=0;if((l|0)==1015){c[d>>2]=Lb}else if((l|0)==1064)if(1){c[d>>2]=Xb;l=1066}else{r=1}}if((l|0)==1066){c[d>>2]=Lb}c[d>>2]=m;break}else{q=1}}if(q){q=0;if((l|0)==925){c[d>>2]=xb}else if((l|0)==952)if(1){c[d>>2]=Fb;l=956}else{q=1}}if((l|0)==956){c[d>>2]=xb}c[d>>2]=m}}while(0);c[d>>2]=j;h=0;i=b;c[b+21048>>2]=6;c[b+21052>>2]=h|0;break a};default:{n=1}}}if((l|0)==476){c[d>>2]=o}else if((l|0)==525){c[d>>2]=J;l=527}else if((l|0)==583){c[d>>2]=W;l=636}else if((l|0)==632){c[d>>2]=fa;l=634}else if((l|0)==687){c[d>>2]=qa;l=849}else if((l|0)==736){c[d>>2]=Ca;l=738}else if((l|0)==794){c[d>>2]=Pa;l=847}else if((l|0)==843){c[d>>2]=_a;l=845}if((l|0)==527){c[d>>2]=o}else if((l|0)==634){c[d>>2]=W;l=636}else if((l|0)==738){c[d>>2]=qa;l=849}else if((l|0)==845){c[d>>2]=Pa;l=847}if((l|0)==636){c[d>>2]=o}else if((l|0)==847){c[d>>2]=qa;l=849}if((l|0)==849){c[d>>2]=o}c[d>>2]=j;h=0;i=b;c[b+21048>>2]=6;c[b+21052>>2]=h|0;break a}while(0);c[b+448>>2]=h;c[b+15352>>2]=k;c[b+20912>>2]=l}



function rc(a){a=a|0;var b=0;b=i;i=i+a|0;i=i+7&-8;return b|0}function sc(){return i|0}function tc(a){a=a|0;i=a}function uc(a,b){a=a|0;b=b|0;if((r|0)==0){r=a;s=b}}function vc(b){b=b|0;a[k>>0]=a[b>>0];a[k+1>>0]=a[b+1>>0];a[k+2>>0]=a[b+2>>0];a[k+3>>0]=a[b+3>>0]}function wc(b){b=b|0;a[k>>0]=a[b>>0];a[k+1>>0]=a[b+1>>0];a[k+2>>0]=a[b+2>>0];a[k+3>>0]=a[b+3>>0];a[k+4>>0]=a[b+4>>0];a[k+5>>0]=a[b+5>>0];a[k+6>>0]=a[b+6>>0];a[k+7>>0]=a[b+7>>0]}function xc(a){a=a|0;G=a}function yc(){return G|0}function zc(b){b=b|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a[b+5>>0]|0;a[b+4>>0]=f;g=b+20|0;h=b+7|0;j=h+13|0;do{a[h>>0]=0;h=h+1|0}while((h|0)<(j|0));c[g>>2]=(f&255)<<8&3840|(d[b+6>>0]|0)|24576;i=e;return}function Ac(b){b=b|0;a[b+7>>0]=0;return}function Bc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;if((d|0)!=3){g=0;i=f;return g|0}d=b+20|0;a[e+1>>0]=c[d>>2];a[e>>0]=(c[d>>2]|0)>>>8;g=2;i=f;return g|0}function Cc(a,b){a=a|0;b=b|0;return}function Dc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0;g=i;if((d|0)!=3|f>>>0<2){i=g;return}if(!((a[e+1>>0]|0)==-2)){i=g;return}f=a[e>>0]&15;a[b+4>>0]=f;e=b+20|0;c[e>>2]=f<<8|c[e>>2]&61695;i=g;return}function Ec(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;c[b>>2]=0;g=d&255;a[b+4>>0]=g;a[b+5>>0]=g;a[b+6>>0]=e;g=b+20|0;h=b+7|0;j=h+13|0;do{a[h>>0]=0;h=h+1|0}while((h|0)<(j|0));c[g>>2]=d<<8&3840|e&255|24576;c[b+24>>2]=0;c[b+28>>2]=208;c[b+32>>2]=209;c[b+36>>2]=23;c[b+40>>2]=145;c[b+44>>2]=1;i=f;return}function Fc(){var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=yz(120)|0;if((d|0)==0){e=0;i=b;return e|0}a[d>>0]=3;f=d+1|0;g=d+14|0;h=d+92|0;c[d+112>>2]=0;c[d+116>>2]=0;a[f+0>>0]=0;a[f+1>>0]=0;a[f+2>>0]=0;a[f+3>>0]=0;a[f+4>>0]=0;f=g+0|0;g=f+14|0;do{a[f>>0]=0;f=f+1|0}while((f|0)<(g|0));c[h+0>>2]=0;c[h+4>>2]=0;c[h+8>>2]=0;c[h+12>>2]=0;a[h+16>>0]=0;e=d;i=b;return e|0}function Gc(a,b,d){a=a|0;b=b|0;d=d|0;c[a+92>>2]=b;c[a+96>>2]=d;return}function Hc(a,b,d){a=a|0;b=b|0;d=d|0;c[a+100>>2]=b;c[a+104>>2]=d;return}function Ic(a,b,d){a=a|0;b=b|0;d=d|0;c[a+112>>2]=b;c[a+116>>2]=d;return}function Jc(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=a+24|0;f=c[e>>2]|0;if((f|0)==0){g=0}else{h=0;do{j=h;h=h+1|0;if((c[a+(j<<2)+28>>2]|0)==(b|0)){k=1;l=6;break}}while(h>>>0<f>>>0);if((l|0)==6){i=d;return k|0}if(f>>>0>15){k=1;i=d;return k|0}else{g=f}}c[e>>2]=g+1;c[a+(g<<2)+28>>2]=b;k=0;i=d;return k|0}function Kc(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;e=b+24|0;if((c[e>>2]|0)!=0){f=0;do{g=c[b+(f<<2)+28>>2]|0;ic[c[g+28>>2]&511](g);f=f+1|0}while(f>>>0<(c[e>>2]|0)>>>0)}a[b>>0]=3;a[b+1>>0]=1;e=b+2|0;f=b+108|0;a[e>>0]=0;a[e+1>>0]=0;a[e+2>>0]=0;a[e+3>>0]=0;e=b+14|0;g=e+10|0;do{a[e>>0]=0;e=e+1|0}while((e|0)<(g|0));if((a[f>>0]|0)==0){i=d;return}a[f>>0]=0;f=c[b+116>>2]|0;if((f|0)==0){i=d;return}jc[f&255](c[b+112>>2]|0,0);i=d;return}function Lc(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;g=e&3;e=g&255;if((d[b>>0]|0)==(g|0)){i=f;return}h=b+16|0;c[h>>2]=(c[h>>2]|0)+783;a:do{if((g|0)==0|(g|0)==3){h=a[b+5>>0]|0;if((d[b+4>>0]|0)<(h&255)){j=a[b+2>>0]|0;if((j&12)==8){a[b+1>>0]=0;k=j&255;j=k>>>4;l=c[b+24>>2]|0;if((l|0)!=0){m=0;while(1){n=c[b+(m<<2)+28>>2]|0;m=m+1|0;if((d[n+4>>0]|0)==(j|0)){break}if(!(m>>>0<l>>>0)){break a}}if((n|0)!=0){qc[c[n+44>>2]&3](n,k&3,b+6|0,h&255)}}}}}}while(0);a[b>>0]=e;e=b+108|0;if((a[e>>0]|0)!=0){a[e>>0]=0;n=c[b+116>>2]|0;if((n|0)!=0){jc[n&255](c[b+112>>2]|0,0)}}if((g|0)==0){a[b+1>>0]=0;a[b+4>>0]=0;a[b+5>>0]=0;a[b+14>>0]=8;a[b+15>>0]=0;i=f;return}else if((g|0)==2|(g|0)==1){if((a[b+1>>0]|0)==0){a[b+14>>0]=8;a[b+15>>0]=0;i=f;return}n=b+4|0;l=a[n>>0]|0;m=a[b+5>>0]|0;a[b+14>>0]=8;if(!((l&255)<(m&255))){a[b+15>>0]=-86;if((a[e>>0]|0)==1){i=f;return}a[e>>0]=1;e=c[b+116>>2]|0;if((e|0)==0){i=f;return}jc[e&255](c[b+112>>2]|0,1);i=f;return}e=l+1<<24>>24;a[n>>0]=e;a[b+15>>0]=a[b+(l&255)+6>>0]|0;if((e&255)<(m&255)){i=f;return}m=d[b+2>>0]|0;e=m>>>4;l=c[b+24>>2]|0;if((l|0)==0){i=f;return}else{o=0}while(1){p=c[b+(o<<2)+28>>2]|0;n=o+1|0;if((d[p+4>>0]|0)==(e|0)){break}if(n>>>0<l>>>0){o=n}else{q=28;break}}if((q|0)==28){i=f;return}if((p|0)==0){i=f;return}jc[c[p+40>>2]&255](p,m&3);i=f;return}else if((g|0)==3){a[b+1>>0]=1;a[b+4>>0]=0;a[b+5>>0]=0;a[b+14>>0]=0;a[b+15>>0]=0;c[b+20>>2]=0;i=f;return}else{i=f;return}}function Mc(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=b+14|0;h=a[g>>0]|0;if(h<<24>>24==0){if((a[b>>0]|0)!=3){i=f;return}j=b+20|0;k=(c[j>>2]|0)+e|0;c[j>>2]=k;if(k>>>0<86170){i=f;return}c[j>>2]=0;j=a[b+3>>0]|0;if(j<<24>>24==0){i=f;return}Nc(b,j,1);if((d[b+4>>0]|0)<(d[b+5>>0]|0)){a[g>>0]=8;a[b+15>>0]=-86;i=f;return}if((a[b+108>>0]|0)==0){i=f;return}a[g>>0]=8;a[b+15>>0]=-86;i=f;return}c[b+20>>2]=0;j=b+16|0;k=c[j>>2]|0;if(k>>>0>e>>>0){c[j>>2]=k-e;i=f;return}c[j>>2]=0;do{if((a[b+1>>0]|0)==0){e=b+15|0;a[e>>0]=d[e>>0]<<1;k=(h&255)+255&255;a[g>>0]=k;l=c[b+104>>2]|0;if((l|0)==0){m=k}else{if(!((kc[l&15](c[b+100>>2]|0)|0)<<24>>24==0)){a[e>>0]=d[e>>0]|1}m=a[g>>0]|0}if(m<<24>>24==0){if((a[b>>0]|0)==0){Nc(b,a[e>>0]|0,0);break}l=b+5|0;k=a[l>>0]|0;if((k&255)<8){n=a[e>>0]|0;a[l>>0]=k+1<<24>>24;a[b+(k&255)+6>>0]=n}}}else{n=c[b+96>>2]|0;if((n|0)==0){o=b+15|0;p=h}else{k=b+15|0;jc[n&255](c[b+92>>2]|0,(d[k>>0]|0)>>>7);o=k;p=a[g>>0]|0}a[o>>0]=d[o>>0]<<1;a[g>>0]=(p&255)+255}}while(0);c[j>>2]=(c[j>>2]|0)+783;i=f;return}function Nc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+16|0;h=g;j=b+108|0;if((a[j>>0]|0)!=0){a[j>>0]=0;k=c[b+116>>2]|0;if((k|0)!=0){jc[k&255](c[b+112>>2]|0,0)}}k=b+2|0;a[k>>0]=e;a[b+4>>0]=0;l=b+5|0;a[l>>0]=0;m=e&255;n=m&15;a:do{if((n|0)==0){o=b+24|0;if((c[o>>2]|0)!=0){p=0;do{q=c[b+(p<<2)+28>>2]|0;ic[c[q+28>>2]&511](q);p=p+1|0}while(p>>>0<(c[o>>2]|0)>>>0)}a[b>>0]=3;o=b+1|0;a[o>>0]=1;a[k>>0]=0;a[k+1>>0]=0;a[k+2>>0]=0;a[k+3>>0]=0;p=b+14|0;q=p+10|0;do{a[p>>0]=0;p=p+1|0}while((p|0)<(q|0));if((a[j>>0]|0)!=0){a[j>>0]=0;p=c[b+116>>2]|0;if((p|0)!=0){jc[p&255](c[b+112>>2]|0,0)}}a[o>>0]=1}else{p=m&12;if((p|0)==12){a[b+1>>0]=1;q=m>>>4;r=c[b+24>>2]|0;if((r|0)==0){break}else{s=0}while(1){t=c[b+(s<<2)+28>>2]|0;s=s+1|0;if((d[t+4>>0]|0)==(q|0)){break}if(!(s>>>0<r>>>0)){break a}}if((t|0)==0){break}a[l>>0]=gc[c[t+36>>2]&63](t,m&3,b+6|0)|0;a[b+3>>0]=e;break}else if((p|0)==8){break}if((n|0)!=1){c[h>>2]=m;te(8,h);break}a[b+1>>0]=1;r=m>>>4;q=c[b+24>>2]|0;if((q|0)!=0){o=0;while(1){u=c[b+(o<<2)+28>>2]|0;o=o+1|0;if((d[u+4>>0]|0)==(r|0)){break}if(!(o>>>0<q>>>0)){break a}}if((u|0)!=0){ic[c[u+32>>2]&511](u)}}}}while(0);if((f|0)==0){i=g;return}f=m>>>4;m=b+24|0;u=c[m>>2]|0;if((u|0)==0){i=g;return}h=b+116|0;n=b+112|0;e=u;u=0;while(1){t=c[b+(u<<2)+28>>2]|0;if((a[t+7>>0]|0)==0){v=e}else{if((d[t+4>>0]|0)==(f|0)){v=e}else{if((c[t+20>>2]&8192|0)==0){v=e}else{if((a[j>>0]|0)==1){v=e}else{a[j>>0]=1;t=c[h>>2]|0;if((t|0)==0){v=e}else{jc[t&255](c[n>>2]|0,1);v=c[m>>2]|0}}}}}u=u+1|0;if(!(u>>>0<v>>>0)){break}else{e=v}}i=g;return}function Oc(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;f=c[b+320>>2]|0;if((d|0)==0){d=c[240]|0;if((d|0)!=0){g=960;h=d;do{d=c[f>>2]|0;a:do{if((d|0)!=0){j=d;k=h;l=f;while(1){if((j|0)==(k|0)){m=g;n=c[m+4>>2]|0;o=l;c[o>>2]=c[m>>2];c[o+4>>2]=n}n=l+8|0;o=c[n>>2]|0;if((o|0)==0){break a}j=o;k=c[g>>2]|0;l=n}}}while(0);g=g+8|0;h=c[g>>2]|0}while((h|0)!=0)}a[b+316>>0]=0;i=e;return}else{h=c[266]|0;if((h|0)!=0){g=1064;d=h;do{h=c[f>>2]|0;b:do{if((h|0)!=0){l=h;k=d;j=f;while(1){if((l|0)==(k|0)){n=g;o=c[n+4>>2]|0;m=j;c[m>>2]=c[n>>2];c[m+4>>2]=o}o=j+8|0;m=c[o>>2]|0;if((m|0)==0){break b}l=m;k=c[g>>2]|0;j=o}}}while(0);g=g+8|0;d=c[g>>2]|0}while((d|0)!=0)}a[b+316>>0]=1;i=e;return}}function Pc(b){b=b|0;return a[b+316>>0]|0}function Qc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=c[b+320>>2]|0;while(1){k=c[j>>2]|0;l=(k|0)==0;if(l|(k|0)==(f|0)){break}else{j=j+8|0}}if(l){l=Ky(f)|0;c[h>>2]=f;c[h+4>>2]=(l|0)!=0?l:72;Lw(2,40,h);i=g;return}if((e|0)==1){h=b+56|0;l=c[h>>2]|0;f=l+1&255;k=b+52|0;if((f|0)==(c[k>>2]|0)){m=h;n=k}else{a[b+l+60>>0]=a[j+4>>0]|0;c[h>>2]=f;m=h;n=k}}else if((e|0)==2){e=b+56|0;k=c[e>>2]|0;h=k+1&255;f=b+52|0;if((h|0)==(c[f>>2]|0)){m=e;n=f}else{a[b+k+60>>0]=d[j+4>>0]|0|128;c[e>>2]=h;m=e;n=f}}else{m=b+56|0;n=b+52|0}a[b+7>>0]=(c[n>>2]|0)!=(c[m>>2]|0)|0;i=g;return}function Rc(a){a=a|0;var b=0,d=0;b=i;d=c[a>>2]|0;zz(c[d+320>>2]|0);zz(d);i=b;return}function Sc(b){b=b|0;var d=0,e=0;d=i;e=c[b>>2]|0;zc(b);a[e+48>>0]=0;c[e+52>>2]=0;c[e+56>>2]=0;i=d;return}function Tc(b){b=b|0;var d=0,e=0;d=i;e=c[b>>2]|0;Ac(b);a[e+48>>0]=0;c[e+52>>2]=0;c[e+56>>2]=0;i=d;return}function Uc(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+16|0;g=f;if((d|0)==2){a[e>>0]=-1;a[e+1>>0]=-1;te(936,g);h=2;i=f;return h|0}else if((d|0)==0){j=c[b>>2]|0;k=j+48|0;if((a[k>>0]|0)==0){l=j+52|0;m=c[l>>2]|0;n=c[j+56>>2]|0;if((m|0)==(n|0)){h=0;i=f;return h|0}o=a[j+m+60>>0]|0;p=m+1&255;c[l>>2]=p;if((p|0)==(n|0)){q=-1}else{n=a[j+p+60>>0]|0;c[l>>2]=m+2&255;q=n}n=b+8|0;c[n>>2]=q&255|(o&255)<<8;r=n}else{r=b+8|0}a[k>>0]=1;a[e>>0]=(c[r>>2]|0)>>>8;a[e+1>>0]=c[r>>2];h=2;i=f;return h|0}else if((d|0)!=3){c[g>>2]=d;te(912,g)}h=Bc(b,d,e)|0;i=f;return h|0}function Vc(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=c[b>>2]|0;if((d|0)!=0){i=e;return}a[f+48>>0]=0;a[f+7>>0]=(c[f+52>>2]|0)!=(c[f+56>>2]|0)|0;i=e;return}function Wc(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0;g=i;i=i+16|0;h=g;if((b|0)!=3){c[h>>2]=b;te(888,h);if((b|0)==2&(f|0)==2){c[a+16>>2]=(d[e>>0]|0)<<8|(d[e+1>>0]|0);i=g;return}}Dc(a,b,e,f);i=g;return}function Xc(){var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=yz(324)|0;if((d|0)==0){e=0;i=b;return e|0}Ec(d,2,2);c[d>>2]=d;c[d+24>>2]=210;c[d+28>>2]=211;c[d+32>>2]=212;c[d+36>>2]=24;c[d+40>>2]=146;c[d+44>>2]=2;c[d+52>>2]=0;c[d+56>>2]=0;a[d+316>>0]=0;f=0;do{g=f;f=f+1|0}while((c[80+(g<<3)>>2]|0)!=0);g=f<<3;f=yz(g)|0;if((f|0)==0){h=0}else{Mz(f|0,80,g|0)|0;h=f}c[d+320>>2]=h;e=d;i=b;return e|0}function Yc(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=b+56|0;if(((c[h>>2]^d)&1|0)!=0){c[b+52>>2]=1}c[h>>2]=d;d=b+60|0;h=(c[d>>2]|0)+e|0;c[d>>2]=h;d=b+64|0;e=(c[d>>2]|0)+f|0;c[d>>2]=e;d=b+52|0;if((h|e|0)==0){j=c[d>>2]&255;k=b+7|0;a[k>>0]=j;i=g;return}else{c[d>>2]=1;j=1;k=b+7|0;a[k>>0]=j;i=g;return}}function Zc(a){a=a|0;var b=0;b=i;zz(c[a>>2]|0);i=b;return}function _c(a){a=a|0;var b=0,d=0,e=0;b=i;d=c[a>>2]|0;zc(a);e=d+52|0;d=a+8|0;c[e+0>>2]=0;c[e+4>>2]=0;c[e+8>>2]=0;c[e+12>>2]=0;c[e+16>>2]=0;c[e+20>>2]=0;c[e+24>>2]=0;c[d>>2]=32896;i=b;return}function $c(a){a=a|0;var b=0,d=0;b=i;d=c[a>>2]|0;Ac(a);a=d+52|0;c[a+0>>2]=0;c[a+4>>2]=0;c[a+8>>2]=0;c[a+12>>2]=0;c[a+16>>2]=0;c[a+20>>2]=0;c[a+24>>2]=0;i=b;return}function ad(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;if((d|0)!=0){g=Bc(b,d,e)|0;i=f;return g|0}d=c[b>>2]|0;if((c[d+52>>2]|0)==0){g=0;i=f;return g|0}a[d+48>>0]=1;h=c[d+56>>2]|0;c[d+68>>2]=h;j=c[d+60>>2]|0;c[d+72>>2]=j;k=c[d+64>>2]|0;c[d+76>>2]=k;d=b+8|0;b=h<<15&32768^32896;c[d>>2]=b;if((j|0)<0){l=(j|0)<-63?65:j&127}else{l=(j|0)>63?63:j}j=l|b;c[d>>2]=j;if((k|0)<0){m=(k|0)<-63?65:k&127}else{m=(k|0)>63?63:k}k=m<<8|j&33023;c[d>>2]=k;a[e>>0]=k>>>8;a[e+1>>0]=c[d>>2];g=2;i=f;return g|0}function bd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=c[b>>2]|0;if((d|0)!=0){i=e;return}d=f+48|0;if((a[d>>0]|0)==0){i=e;return}a[d>>0]=0;d=f+52|0;g=(c[f+68>>2]|0)!=(c[f+56>>2]|0)|0;c[d>>2]=g;h=c[f+72>>2]|0;j=f+60|0;k=c[j>>2]|0;c[j>>2]=k-h;j=c[f+76>>2]|0;l=f+64|0;f=c[l>>2]|0;c[l>>2]=f-j;if((k|0)==(h|0)&(f|0)==(j|0)){m=g}else{c[d>>2]=1;m=1}a[b+7>>0]=m;i=e;return}function cd(){var a=0,b=0,d=0,e=0;a=i;b=yz(80)|0;if((b|0)==0){d=0;i=a;return d|0}Ec(b,3,1);c[b>>2]=b;c[b+24>>2]=213;c[b+28>>2]=214;c[b+32>>2]=215;c[b+36>>2]=25;c[b+40>>2]=147;e=b+52|0;c[e+0>>2]=0;c[e+4>>2]=0;c[e+8>>2]=0;c[e+12>>2]=0;c[e+16>>2]=0;c[e+20>>2]=0;c[e+24>>2]=0;d=b;i=a;return d|0}function dd(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;f=i;i=i+304|0;g=f;h=f+32|0;Zv(h,b);if((dw(h)|0)!=0){i=f;return}if((dw(h)|0)!=0){i=f;return}b=a+49|0;j=a+48|0;k=a+50|0;l=a+51|0;m=a+124|0;n=a+44|0;o=a+45|0;p=a+68|0;r=a+52|0;s=a+46|0;t=a+47|0;u=a+42|0;v=a+43|0;w=a+69|0;x=a+56|0;y=a+54|0;z=a+40|0;A=a+41|0;B=a+60|0;C=a+4624|0;D=a+4625|0;E=a+64|0;F=a+62|0;G=a+1424|0;H=a+8|0;I=c[q>>2]|0;J=a+4|0;a:while(1){do{if((fw(h,1776)|0)==0){if((fw(h,1784)|0)!=0){qw(2536);gq(c[H>>2]|0,I);break}if((fw(h,1792)|0)==0){if((fw(h,1800)|0)==0){break a}qw(2184);K=d[j>>0]|0;L=d[k>>0]|0;M=d[l>>0]|0;N=d[m>>0]|0;c[g>>2]=d[b>>0]|0;c[g+4>>2]=K;c[g+8>>2]=L;c[g+12>>2]=M;c[g+16>>2]=N;pw(2200,g);N=d[o>>0]|0;M=d[p>>0]|0;L=e[r>>1]|0;K=d[s>>0]|0;O=d[t>>0]|0;c[g>>2]=d[n>>0]|0;c[g+4>>2]=N;c[g+8>>2]=M;c[g+12>>2]=L;c[g+16>>2]=K;c[g+20>>2]=O;pw(2256,g);O=d[v>>0]|0;K=d[w>>0]|0;L=(c[x>>2]|0)!=0?42:32;M=e[y>>1]|0;c[g>>2]=d[u>>0]|0;c[g+4>>2]=O;c[g+8>>2]=K;c[g+12>>2]=L;c[g+16>>2]=M;pw(2312,g);M=d[A>>0]|0;L=e[B>>1]|0;c[g>>2]=d[z>>0]|0;c[g+4>>2]=M;c[g+8>>2]=0;c[g+12>>2]=L;pw(2360,g);L=d[D>>0]|0;M=(c[E>>2]|0)!=0?42:32;K=e[F>>1]|0;c[g>>2]=d[C>>0]|0;c[g+4>>2]=L;c[g+8>>2]=0;c[g+12>>2]=M;c[g+16>>2]=K;pw(2400,g);break}else{qw(2448);c[g>>2]=d[G>>0]|0;pw(2464,g);K=0;do{M=d[a+K+132>>0]|0;L=d[a+K+148>>0]|0;O=d[a+K+772>>0]|0;N=d[a+K+788>>0]|0;c[g>>2]=K;c[g+4>>2]=M;c[g+8>>2]=K;c[g+12>>2]=L;c[g+16>>2]=K;c[g+20>>2]=O;c[g+24>>2]=K;c[g+28>>2]=N;pw(2480,g);K=K+1|0}while((K|0)!=16)}}else{ed(c[J>>2]|0)}}while(0);if((dw(h)|0)!=0){P=15;break}}if((P|0)==15){i=f;return}c[g>>2]=_v(h)|0;pw(1808,g);i=f;return}function ed(b){b=b|0;var d=0,f=0,g=0,j=0,l=0,m=0,n=0,o=0.0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;d=i;i=i+672|0;f=d;g=d+56|0;j=d+408|0;qw(2544);l=wj(b)|0;m=xj(b)|0;n=yj(b)|0;if((l|0)==0){o=1.0}else{o=+((n+m|0)>>>0)/+(l>>>0)}c[f>>2]=m;c[f+4>>2]=l;c[f+8>>2]=n;n=f+12|0;h[k>>3]=o;c[n>>2]=c[k>>2];c[n+4>>2]=c[k+4>>2];pw(2552,f);n=b+166|0;l=e[n>>1]|0;m=Bj(b)|0;p=Cj(b)|0;q=(Ej(b)|0)&65535;r=(e[n>>1]|0)>>>8&7;n=c[b+364>>2]|0;c[f>>2]=l;c[f+4>>2]=(l&32768|0)!=0?84:45;c[f+8>>2]=(l&8192|0)!=0?83:45;c[f+12>>2]=l&255;c[f+16>>2]=(l&1|0)!=0?67:45;c[f+20>>2]=(l&2|0)!=0?86:45;c[f+24>>2]=(l&4|0)!=0?90:45;c[f+28>>2]=(l&8|0)!=0?78:45;c[f+32>>2]=(l&16|0)!=0?88:45;c[f+36>>2]=m;c[f+40>>2]=p;c[f+44>>2]=q;c[f+48>>2]=r;c[f+52>>2]=n;pw(2592,f);n=c[b+104>>2]|0;r=c[b+120>>2]|0;q=c[b+136>>2]|0;p=b+152|0;m=c[p>>2]|0;c[f>>2]=c[b+88>>2];c[f+4>>2]=n;c[f+8>>2]=r;c[f+12>>2]=q;c[f+16>>2]=m;pw(2672,f);m=c[b+92>>2]|0;q=c[b+108>>2]|0;r=c[b+124>>2]|0;n=c[b+140>>2]|0;l=Dj(b,0)|0;c[f>>2]=m;c[f+4>>2]=q;c[f+8>>2]=r;c[f+12>>2]=n;c[f+16>>2]=l;pw(2728,f);l=c[b+112>>2]|0;n=c[b+128>>2]|0;r=c[b+144>>2]|0;q=b+334|0;m=b+148|0;s=c[((a[q>>0]|0)==0?m:b+168|0)>>2]|0;c[f>>2]=c[b+96>>2];c[f+4>>2]=l;c[f+8>>2]=n;c[f+12>>2]=r;c[f+16>>2]=s;pw(2784,f);s=c[b+100>>2]|0;r=c[b+116>>2]|0;n=c[b+132>>2]|0;l=c[m>>2]|0;if((a[q>>0]|0)!=0){t=l;c[f>>2]=s;u=f+4|0;c[u>>2]=r;v=f+8|0;c[v>>2]=n;w=f+12|0;c[w>>2]=l;x=f+16|0;c[x>>2]=t;pw(2840,f);y=c[p>>2]|0;Ag(b,g,y);nd(j,g);z=c[p>>2]|0;c[f>>2]=z;A=f+4|0;c[A>>2]=j;pw(2e3,f);i=d;return}t=c[b+172>>2]|0;c[f>>2]=s;u=f+4|0;c[u>>2]=r;v=f+8|0;c[v>>2]=n;w=f+12|0;c[w>>2]=l;x=f+16|0;c[x>>2]=t;pw(2840,f);y=c[p>>2]|0;Ag(b,g,y);nd(j,g);z=c[p>>2]|0;c[f>>2]=z;A=f+4|0;c[A>>2]=j;pw(2e3,f);i=d;return}function fd(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;e=b+4680|0;mx(e);Wd(b);be(c[2640]|0,0);be(c[2640]|0,0);if((c[e>>2]|0)!=0){nx();i=d;return}f=b+4676|0;g=b+3480|0;do{if((a[f>>0]|0)!=0){do{jx(5e4)|0;gz(c[g>>2]|0)}while((a[f>>0]|0)!=0)}be(c[2640]|0,0);be(c[2640]|0,0)}while((c[e>>2]|0)==0);nx();i=d;return}function gd(a){a=a|0;var b=0;b=i;c[458]=a;mx(a+4680|0);Wd(a);Yb(1,100,1);i=b;return}function hd(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;i=i+16|0;d=b+4|0;e=b;f=Ob()|0;g=c[f+12>>2]|0;h=c[f+16>>2]|0;f=0;while(1){do{if(((f|0)%100|0|0)==0){yb(d|0,e|0)|0;j=c[d>>2]|0;if((j|0)>(g|0)){k=g}else{k=(j|0)<0?0:j}c[d>>2]=k;j=c[e>>2]|0;if((j|0)>(h|0)){l=h}else{l=(j|0)<0?0:j}c[e>>2]=l;j=c[(c[458]|0)+4>>2]|0;m=l&65535;if((c[j+36>>2]|0)>>>0>2089){n=j+32|0;a[(c[n>>2]|0)+2088>>0]=(m&65535)>>>8;a[(c[n>>2]|0)+2089>>0]=l}else{lc[c[j+24>>2]&31](c[j+4>>2]|0,2088,m)}m=c[(c[458]|0)+4>>2]|0;j=c[d>>2]|0;n=j&65535;if((c[m+36>>2]|0)>>>0>2091){o=m+32|0;a[(c[o>>2]|0)+2090>>0]=(n&65535)>>>8;a[(c[o>>2]|0)+2091>>0]=j}else{lc[c[m+24>>2]&31](c[m+4>>2]|0,2090,n)}n=c[(c[458]|0)+4>>2]|0;m=c[e>>2]|0;j=m&65535;if((c[n+36>>2]|0)>>>0>2093){o=n+32|0;a[(c[o>>2]|0)+2092>>0]=(j&65535)>>>8;a[(c[o>>2]|0)+2093>>0]=m}else{lc[c[n+24>>2]&31](c[n+4>>2]|0,2092,j)}j=c[(c[458]|0)+4>>2]|0;n=c[d>>2]|0;m=n&65535;if((c[j+36>>2]|0)>>>0>2095){o=j+32|0;a[(c[o>>2]|0)+2094>>0]=(m&65535)>>>8;a[(c[o>>2]|0)+2095>>0]=n}else{lc[c[j+24>>2]&31](c[j+4>>2]|0,2094,m)}m=c[(c[458]|0)+4>>2]|0;j=c[e>>2]|0;n=j&65535;if((c[m+36>>2]|0)>>>0>2097){o=m+32|0;a[(c[o>>2]|0)+2096>>0]=(n&65535)>>>8;a[(c[o>>2]|0)+2097>>0]=j}else{lc[c[m+24>>2]&31](c[m+4>>2]|0,2096,n)}n=c[(c[458]|0)+4>>2]|0;m=c[d>>2]|0;j=m&65535;if((c[n+36>>2]|0)>>>0>2099){o=n+32|0;a[(c[o>>2]|0)+2098>>0]=(j&65535)>>>8;a[(c[o>>2]|0)+2099>>0]=m;break}else{lc[c[n+24>>2]&31](c[n+4>>2]|0,2098,j);break}}}while(0);be(c[2640]|0,0);be(c[2640]|0,0);j=c[458]|0;if((c[j+4680>>2]|0)!=0){break}if((a[j+4676>>0]|0)!=0){do{jx(5e4)|0;gz(c[(c[458]|0)+3480>>2]|0)}while((a[(c[458]|0)+4676>>0]|0)!=0)}j=f+1|0;if((j|0)<1e4){f=j}else{p=30;break}}if((p|0)==30){i=b;return}nx();ac();i=b;return}function id(a,b,c){a=a|0;b=b|0;c=c|0;return}function jd(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;f=i;i=i+3008|0;g=f;h=f+2112|0;j=f+8|0;k=f+16|0;l=f+1760|0;m=f+2116|0;n=f+2472|0;o=f+1408|0;p=f+2488|0;r=f+1040|0;s=f+2744|0;t=f+1048|0;u=f+1404|0;v=f+2120|0;w=f+2482|0;x=f+2480|0;y=f+1400|0;z=f+2476|0;A=a+3480|0;B=c[A>>2]|0;if((B|0)!=0){gz(B)}do{if((fw(d,1840)|0)==0){if((fw(d,1168)|0)!=0){c[z>>2]=1;iw(d,z)|0;if((ew(d)|0)==0){break}if((c[z>>2]|0)!=0){do{be(a,1);B=(c[z>>2]|0)+ -1|0;c[z>>2]=B}while((B|0)!=0)}ed(c[a+4>>2]|0);break}if((fw(d,1296)|0)!=0){if((fw(d,1840)|0)!=0){if((iw(d,y)|0)!=0){B=a+28|0;do{Wv(B,Lv(c[y>>2]|0)|0)|0}while((iw(d,y)|0)!=0)}if((ew(d)|0)==0){break}B=a+4680|0;mx(B);Wd(a);C=a+4|0;D=a+28|0;E=c[q>>2]|0;a:while(1){F=wj(c[C>>2]|0)|0;while(1){if((wj(c[C>>2]|0)|0)!=(F|0)){continue a}be(a,0);if((Xv(D,0,c[(c[C>>2]|0)+152>>2]&16777215,E)|0)!=0){break a}if((c[B>>2]|0)!=0){break a}}}nx();break}if((fw(d,2152)|0)==0){if((ew(d)|0)==0){break}fd(a);break}if((hw(d,x)|0)==0){b[x>>1]=-1}if((ew(d)|0)==0){break}B=a+4|0;E=Aj(c[B>>2]|0)|0;C=a+4680|0;mx(C);Wd(a);D=a+28|0;F=c[q>>2]|0;while(1){G=wj(c[B>>2]|0)|0;do{if((wj(c[B>>2]|0)|0)!=(G|0)){break}be(a,0);if((Xv(D,0,c[(c[B>>2]|0)+152>>2]&16777215,F)|0)!=0){break}}while((c[C>>2]|0)==0);if((Xv(D,0,c[(c[B>>2]|0)+152>>2]&16777215,F)|0)!=0){break}if((c[C>>2]|0)!=0){break}if((Aj(c[B>>2]|0)|0)==(E|0)){continue}G=(b[x>>1]|0)==-1;H=Bj(c[B>>2]|0)|0;if(G){I=35;break}if((H|0)==(e[x>>1]|0)){I=37;break}}if((I|0)==35){E=Cj(c[B>>2]|0)|0;c[g>>2]=H;c[g+4>>2]=E;pw(2160,g)}else if((I|0)==37){E=Bj(c[B>>2]|0)|0;C=Cj(c[B>>2]|0)|0;c[g>>2]=E;c[g+4>>2]=C;pw(2160,g)}nx();break}if((fw(d,1320)|0)!=0){if((hw(d,w)|0)==0){b[w>>1]=2}if((ew(d)|0)==0){break}C=a+4|0;zj(c[C>>2]|0,e[w>>1]|0);ed(c[C>>2]|0);break}if((fw(d,1360)|0)!=0){c[u>>2]=1;if((fw(d,1360)|0)!=0){do{c[u>>2]=(c[u>>2]|0)+1}while((fw(d,1360)|0)!=0)}iw(d,u)|0;if((ew(d)|0)==0){break}B=a+4|0;C=Aj(c[B>>2]|0)|0;E=a+4680|0;mx(E);b:do{if((c[u>>2]|0)!=0){F=a+28|0;D=c[q>>2]|0;G=v+8|0;do{J=c[B>>2]|0;Ag(J,v,c[J+152>>2]|0);J=c[B>>2]|0;if((c[v>>2]&4|0)==0){K=wj(J)|0;while(1){if((wj(c[B>>2]|0)|0)!=(K|0)){break}be(a,0);if((Xv(F,0,c[(c[B>>2]|0)+152>>2]&16777215,D)|0)!=0){break b}if((c[E>>2]|0)!=0){break b}}if((Aj(c[B>>2]|0)|0)!=(C|0)){K=c[B>>2]|0;L=c[K+380>>2]|0;if((c[K+152>>2]|0)!=(L|0)){do{be(a,0);if((Xv(F,0,c[(c[B>>2]|0)+152>>2]&16777215,D)|0)!=0){break b}if((c[E>>2]|0)!=0){break b}}while((c[(c[B>>2]|0)+152>>2]|0)!=(L|0))}}}else{L=c[G>>2]<<1;K=L+(c[J+152>>2]|0)|0;if((L|0)!=0){do{be(a,0);if((Xv(F,0,c[(c[B>>2]|0)+152>>2]&16777215,D)|0)!=0){break b}if((c[E>>2]|0)!=0){break b}}while((c[(c[B>>2]|0)+152>>2]|0)!=(K|0))}}K=(c[u>>2]|0)+ -1|0;c[u>>2]=K}while((K|0)!=0)}}while(0);nx();ed(c[B>>2]|0);break}if((fw(d,1416)|0)!=0){if((ew(d)|0)==0){break}ae(a);ed(c[a+4>>2]|0);break}if((fw(d,1424)|0)!=0){if((ew(d)|0)==0){break}E=a+4680|0;mx(E);C=a+4|0;D=a+28|0;F=c[q>>2]|0;while(1){G=wj(c[C>>2]|0)|0;do{if((wj(c[C>>2]|0)|0)!=(G|0)){break}be(a,0);if((Xv(D,0,c[(c[C>>2]|0)+152>>2]&16777215,F)|0)!=0){break}}while((c[E>>2]|0)==0);if((Xv(D,0,c[(c[C>>2]|0)+152>>2]&16777215,F)|0)!=0){break}if((c[E>>2]|0)!=0){break}G=c[C>>2]|0;Ag(G,t,c[G+152>>2]|0);if((c[t>>2]&8|0)!=0){I=81;break}}if((I|0)==81){ed(c[C>>2]|0)}nx();break}if((fw(d,1456)|0)!=0){if((dw(d)|0)!=0){ed(c[a+4>>2]|0);break}if((bw(d,s,256)|0)==0){aw(d,2080);break}E=a+4|0;if((Fj(c[E>>2]|0,s,r)|0)!=0){c[g>>2]=s;pw(2104,g);break}if((dw(d)|0)!=0){c[g>>2]=c[r>>2];pw(2128,g);break}if((iw(d,r)|0)==0){aw(d,2136);break}if((ew(d)|0)==0){break}Gj(c[E>>2]|0,s,c[r>>2]|0)|0;ed(c[E>>2]|0);break}if((fw(d,1504)|0)!=0){if((dw(d)|0)==0){dd(a,_v(d)|0);break}else{ed(c[a+4>>2]|0);break}}if((fw(d,1552)|0)!=0){c[g>>2]=1;if((fw(d,1552)|0)!=0){do{c[g>>2]=(c[g>>2]|0)+1}while((fw(d,1552)|0)!=0)}iw(d,g)|0;if((ew(d)|0)==0){break}C=a+4680|0;mx(C);E=a+4|0;if((c[g>>2]|0)!=0){F=a+28|0;D=c[q>>2]|0;B=0;do{G=wj(c[E>>2]|0)|0;do{if((wj(c[E>>2]|0)|0)!=(G|0)){break}be(a,0);if((Xv(F,0,c[(c[E>>2]|0)+152>>2]&16777215,D)|0)!=0){break}}while((c[C>>2]|0)==0);B=B+1|0}while(B>>>0<(c[g>>2]|0)>>>0)}nx();ed(c[E>>2]|0);break}if((fw(d,1592)|0)==0){M=1;i=f;return M|0}if((c[494]|0)==0){N=c[496]|0}else{c[494]=0;B=c[(c[a+4>>2]|0)+152>>2]|0;c[496]=B;N=B}c[m>>2]=N;c[n>>2]=16;if((fw(d,1992)|0)==0){if((iw(d,m)|0)!=0){iw(d,n)|0}if((ew(d)|0)==0){break}if((c[n>>2]|0)==0){O=c[m>>2]|0}else{B=a+4|0;C=o+8|0;D=c[m>>2]|0;F=0;while(1){Ag(c[B>>2]|0,o,D);nd(p,o);c[g>>2]=c[m>>2];c[g+4>>2]=p;pw(2e3,g);G=(c[m>>2]|0)+(c[C>>2]<<1)|0;c[m>>2]=G;K=F+1|0;if(K>>>0<(c[n>>2]|0)>>>0){D=G;F=K}else{O=G;break}}}c[496]=O;break}c[h>>2]=c[m>>2];c[j>>2]=16;if((iw(d,h)|0)!=0){iw(d,j)|0}if((ew(d)|0)!=0){F=c[j>>2]|0;if(F>>>0>256){c[j>>2]=256;P=256}else{P=F}F=c[h>>2]|0;D=(ca(P,-12)|0)+F&-2;if(!(D>>>0>F>>>0)){F=a+4|0;C=l+8|0;B=0;E=0;G=0;K=D;D=5;while(1){do{if((D|0)==0){c[k+(E<<2)>>2]=K;J=E+1&255;if((J|0)==(B|0)){Q=B+1&255;R=B;S=G;T=0;break}else{Q=B;R=J;S=G+1|0;T=0;break}}else{Q=B;R=E;S=G;T=D+ -1|0}}while(0);Ag(c[F>>2]|0,l,K);K=(c[C>>2]<<1)+K|0;if(K>>>0>(c[h>>2]|0)>>>0){break}else{B=Q;E=R;G=S;D=T}}D=c[j>>2]|0;if(S>>>0>D>>>0){U=S+Q-D&255}else{U=Q}if((U|0)!=(R|0)){D=U;do{G=c[k+(D<<2)>>2]|0;Ag(c[F>>2]|0,l,G);nd(s,l);c[g>>2]=G;c[g+4>>2]=s;pw(2e3,g);D=D+1&255}while((D|0)!=(R|0))}}}}else{Yv(d,a+28|0)}}while(0);a=c[A>>2]|0;if((a|0)==0){M=0;i=f;return M|0}Zy(a,1848,1864)|0;M=0;i=f;return M|0}function kd(a,b){a=a|0;b=b|0;var d=0;d=i;Pw(b,1632,12)|0;Ww(b)|0;b=a+4|0;c[(c[b>>2]|0)+68>>2]=a;c[(c[b>>2]|0)+72>>2]=0;c[(c[b>>2]|0)+76>>2]=148;c[(c[b>>2]|0)+80>>2]=149;c[(c[b>>2]|0)+84>>2]=1;i=d;return}function ld(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=i;i=i+32|0;f=e;g=a+4|0;a=Dj(c[g>>2]|0,0)|0;h=c[g>>2]|0;j=a&16777215;k=j+1|0;l=c[h+36>>2]|0;if(k>>>0<l>>>0){m=c[h+32>>2]|0;n=((d[m+j>>0]|0)<<8|(d[m+k>>0]|0))&65535;o=l;p=h}else{l=oc[c[h+12>>2]&31](c[h+4>>2]|0,j)|0;j=c[g>>2]|0;n=l;o=c[j+36>>2]|0;p=j}j=n&65535;n=a+2&16777215;l=n+1|0;if(l>>>0<o>>>0){h=c[p+32>>2]|0;q=((d[h+n>>0]|0)<<8|(d[h+l>>0]|0))&65535;r=o;s=p}else{o=oc[c[p+12>>2]&31](c[p+4>>2]|0,n)|0;n=c[g>>2]|0;q=o;r=c[n+36>>2]|0;s=n}n=q&65535;q=a+4&16777215;o=q+1|0;if(o>>>0<r>>>0){p=c[s+32>>2]|0;t=((d[p+q>>0]|0)<<8|(d[p+o>>0]|0))&65535;u=r;v=s}else{r=oc[c[s+12>>2]&31](c[s+4>>2]|0,q)|0;q=c[g>>2]|0;t=r;u=c[q+36>>2]|0;v=q}q=t&65535;t=a+6&16777215;r=t+1|0;if(r>>>0<u>>>0){s=c[v+32>>2]|0;w=((d[s+t>>0]|0)<<8|(d[s+r>>0]|0))&65535;x=v;y=u}else{u=oc[c[v+12>>2]&31](c[v+4>>2]|0,t)|0;t=c[g>>2]|0;w=u;x=t;y=c[t+36>>2]|0}t=w&65535;w=a+8&16777215;u=w+1|0;if(u>>>0<y>>>0){y=c[x+32>>2]|0;z=((d[y+w>>0]|0)<<8|(d[y+u>>0]|0))&65535;A=z&65535;c[f>>2]=a;B=f+4|0;c[B>>2]=b;C=f+8|0;c[C>>2]=j;D=f+12|0;c[D>>2]=n;E=f+16|0;c[E>>2]=q;F=f+20|0;c[F>>2]=t;G=f+24|0;c[G>>2]=A;Lw(3,1912,f);i=e;return}else{z=oc[c[x+12>>2]&31](c[x+4>>2]|0,w)|0;A=z&65535;c[f>>2]=a;B=f+4|0;c[B>>2]=b;C=f+8|0;c[C>>2]=j;D=f+12|0;c[D>>2]=n;E=f+16|0;c[E>>2]=q;F=f+20|0;c[F>>2]=t;G=f+24|0;c[G>>2]=A;Lw(3,1912,f);i=e;return}}function md(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;i=i+16|0;f=e;g=a+4|0;h=c[g>>2]|0;j=(Dj(h,0)|0)&16777215;k=j+1|0;if(k>>>0<(c[h+36>>2]|0)>>>0){l=c[h+32>>2]|0;m=((d[l+j>>0]|0)<<8|(d[l+k>>0]|0))&65535}else{m=oc[c[h+12>>2]&31](c[h+4>>2]|0,j)|0}switch(b|0){case 0:{ae(a);i=e;return};case 10:{$f(a+2424|0);i=e;return};case 46:case 44:case 43:case 42:case 41:case 40:case 39:case 32:case 26:case 25:{i=e;return};default:{a=Dj(c[g>>2]|0,0)|0;j=Cj(c[g>>2]|0)|0;c[f>>2]=a;c[f+4>>2]=b;c[f+8>>2]=j;c[f+12>>2]=m&65535;Lw(3,1872,f);i=e;return}}}function nd(b,d){b=b|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+272|0;g=f;h=f+16|0;a[b>>0]=0;j=d+8|0;if((c[j>>2]|0)==0){k=0;l=4}else{m=0;do{c[g>>2]=e[d+(m<<1)+12>>1]|0;ab(h|0,2016,g|0)|0;Pz(b|0,h|0)|0;m=m+1|0;n=c[j>>2]|0}while(m>>>0<n>>>0);if(n>>>0<4){k=n;l=4}}if((l|0)==4){while(1){l=0;n=b+(Kz(b|0)|0)|0;a[n+0>>0]=a[2024>>0]|0;a[n+1>>0]=a[2025>>0]|0;a[n+2>>0]=a[2026>>0]|0;a[n+3>>0]=a[2027>>0]|0;a[n+4>>0]=a[2028>>0]|0;a[n+5>>0]=a[2029>>0]|0;k=k+1|0;if((k|0)==4){break}else{l=4}}}l=c[d>>2]|0;do{if((l&1|0)==0){if((l&4|0)!=0){k=b+(Kz(b|0)|0)|0;a[k>>0]=62;a[k+1>>0]=0;break}k=b+(Kz(b|0)|0)|0;if((l&16|0)==0){a[k>>0]=32;a[k+1>>0]=0;break}else{a[k>>0]=60;a[k+1>>0]=0;break}}else{k=b+(Kz(b|0)|0)|0;a[k>>0]=42;a[k+1>>0]=0}}while(0);l=rg(e[d+12>>1]|0)|0;k=(l|0)==0?d+32|0:l;l=c[d+28>>2]|0;if((l|0)==2){c[g>>2]=k;c[g+4>>2]=d+96;c[g+8>>2]=d+160;ab(h|0,2040,g|0)|0}else if((l|0)==1){c[g>>2]=k;c[g+4>>2]=d+96;ab(h|0,2032,g|0)|0}else if((l|0)==3){c[g>>2]=k;c[g+4>>2]=d+96;c[g+8>>2]=d+160;c[g+12>>2]=d+224;ab(h|0,2056,g|0)|0}else if((l|0)==0){Mz(h|0,k|0,(Kz(k|0)|0)+1|0)|0}else{c[h>>2]=2960685}Pz(b|0,h|0)|0;h=d+288|0;if((a[h>>0]|0)==0){i=f;return}d=Kz(b|0)|0;k=b+d|0;if(d>>>0<50){Oz(k|0,32,50-d|0)|0;o=b+50|0}else{o=k}a[o+0>>0]=a[2072>>0]|0;a[o+1>>0]=a[2073>>0]|0;a[o+2>>0]=a[2074>>0]|0;Pz(o|0,h|0)|0;i=f;return}function od(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+16|0;e=d;switch(b|0){case 3:{f=a+2424|0;bg(f,1);bg(f,2);bg(f,3);bg(f,4);g=0;i=d;return g|0};case 1:{Fe(a,2896,2912)|0;g=0;i=d;return g|0};case 2:{Fe(a,2920,2912)|0;g=0;i=d;return g|0};case 4:{c[e>>2]=c[(c[a+4>>2]|0)+152>>2];Lw(2,2936,e);g=0;i=d;return g|0};case 0:{g=0;i=d;return g|0};default:{f=a+4|0;h=c[f>>2]|0;j=a+2628|0;c[j>>2]=c[h+88>>2];k=a+2632|0;c[k>>2]=c[h+120>>2];l=a+2636|0;c[l>>2]=c[h+124>>2];m=a+2640|0;c[m>>2]=c[h+152>>2];if((dg(a+2424|0,b)|0)==0){a=c[f>>2]|0;c[a+88>>2]=c[j>>2];c[a+120>>2]=c[k>>2];c[a+124>>2]=c[l>>2];Hj(a,c[m>>2]|0);g=0;i=d;return g|0}else{c[e>>2]=b;te(2952,e);g=1;i=d;return g|0}}}return 0}function pd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;i=i+16|0;f=e;a:do{switch(d|0){case 2:{Fe(b,2976,2992)|0;break};case 3:{Fe(b,2976,3e3)|0;break};case 4:{Fe(b,2976,3008)|0;break};case 5:{Fe(b,2976,3016)|0;break};case 91:case 53:{g=b+1744|0;h=c[g>>2]|0;do{if((h|0)!=0){if((a[h+280>>0]|0)==0){te(3048,f);Od(c[g>>2]|0,0);break}else{te(3024,f);Od(c[g>>2]|0,1);break}}}while(0);g=b+1752|0;h=c[g>>2]|0;if((h|0)!=0){if((Pc(h)|0)==0){te(3024,f);Oc(c[g>>2]|0,1);break a}else{te(3048,f);Oc(c[g>>2]|0,0);break a}}break};case 39:{Td(b,7,1);Td(b,7,0);break};default:{c[f>>2]=d;Lw(2,3072,f)}}}while(0);i=e;return 0}function qd(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;i=i+16|0;e=d;f=b+20|0;a[f>>0]=0;g=c[b+4>>2]|0;if((g|0)==0){h=4}else{j=Hs(g,0)|0;if((j|0)==0){h=4}else{a[f>>0]=1;c[e>>2]=(c[b>>2]|0)+1;te(3104,e);k=j}}a:do{if((h|0)==4){j=gr(c[b+8>>2]|0,c[b+12>>2]|0)|0;b:do{if((j|0)!=0){c:do{if((Sq(j)|0)==6){l=0;m=c[(c[j+64>>2]|0)+68>>2]|0}else{f=_q(j)|0;if((f|0)==1600){n=2}else if((f|0)==800){n=1}else{break b}f=Kt()|0;if((f|0)==0){break b}else{o=0;p=0}d:while(1){g=o>>>4;q=12-g|0;if((g|0)==12){r=p}else{g=0;s=p;while(1){t=s;u=0;do{v=kt(o,g,u,512)|0;if((v|0)==0){h=16;break d}Pt(f,v,o,g)|0;if((br(j,c[v+24>>2]|0,t,1)|0)!=0){h=17;break d}t=t+1|0;u=u+1|0}while(u>>>0<q>>>0);u=g+1|0;if(u>>>0<n>>>0){g=u;s=t}else{r=t;break}}}s=o+1|0;if(s>>>0<80){o=s;p=r}else{l=f;m=f;break c}}if((h|0)==16){Lt(f);break b}else if((h|0)==17){Lt(f);break b}}}while(0);if((m|0)!=0){s=zs(m)|0;Lt(l);if((s|0)!=0){c[e>>2]=(c[b>>2]|0)+1;te(3136,e);k=s;break a}}}}while(0);c[e>>2]=(c[b>>2]|0)+1;te(3168,e);w=1;i=d;return w|0}}while(0);e=b+16|0;Rs(c[e>>2]|0);c[e>>2]=k;a[b+92>>0]=0;c[b+48>>2]=0;w=0;i=d;return w|0}function rd(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+512|0;f=e;g=d+16|0;if((c[g>>2]|0)==0){h=1;i=e;return h|0}c[f>>2]=(c[d>>2]|0)+1;te(3200,f);a:do{if((a[d+20>>0]|0)==0){j=gr(c[d+8>>2]|0,c[d+12>>2]|0)|0;do{if((j|0)!=0){k=ws(c[g>>2]|0)|0;if((k|0)!=0){if((Sq(j)|0)==6){l=c[j+64>>2]|0;m=l+68|0;Lt(c[m>>2]|0);c[m>>2]=k;a[l+72>>0]=1;break a}l=_q(j)|0;if((l|0)==1600){n=2}else if((l|0)==800){n=1}else{Lt(k);break}l=n>>>0>1?n+ -1|0:0;m=0;o=0;b:while(1){p=m>>>4;q=12-p|0;if((p|0)==12){r=(ca(q,l)|0)+o|0}else{p=0;s=o;while(1){t=0;do{u=St(k,m,p,t,0)|0;if((u|0)==0){Oz(f|0,0,512)|0}else{v=b[u+10>>1]|0;w=v&65535;if((v&65535)<512){Oz(f+w|0,0,512-w|0)|0;x=w}else{x=512}Mz(f|0,c[u+24>>2]|0,x|0)|0}u=t;t=t+1|0;if((cr(j,f,u+s|0,1)|0)!=0){y=27;break b}}while(t>>>0<q>>>0);t=s+q|0;u=p+1|0;if(u>>>0<n>>>0){p=u;s=t}else{r=t;break}}}s=m+1|0;if(s>>>0<80){m=s;o=r}else{y=25;break}}if((y|0)==25){Lt(k);break a}else if((y|0)==27){Lt(k);break}}}}while(0);c[f>>2]=(c[d>>2]|0)+1;te(3264,f);h=1;i=e;return h|0}else{j=c[d+4>>2]|0;if((j|0)!=0){if((Is(j,c[g>>2]|0,0)|0)==0){break}}c[f>>2]=(c[d>>2]|0)+1;te(3224,f);h=1;i=e;return h|0}}while(0);a[d+92>>0]=0;h=0;i=e;return h|0}function sd(d){d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;a[d>>0]=0;a[d+1>>0]=0;a[d+3>>0]=0;a[d+4>>0]=0;a[d+5>>0]=127;a[d+6>>0]=0;f=d+8|0;g=d+48|0;h=f+0|0;j=h+36|0;do{c[h>>2]=0;h=h+4|0}while((h|0)<(j|0));b[f+36>>1]=0;a[f+38>>0]=0;c[g>>2]=80;c[d+52>>2]=1;g=d+56|0;f=d+64|0;h=d+88|0;a[g+0>>0]=0;a[g+1>>0]=0;a[g+2>>0]=0;a[g+3>>0]=0;a[g+4>>0]=0;c[f+0>>2]=0;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=0;c[f+16>>2]=0;c[f+20>>2]=0;c[h>>2]=65e3;c[d+92>>2]=0;c[d+96>>2]=0;c[d+100>>2]=0;c[d+104>>2]=783360;c[d+108>>2]=0;a[d+116>>0]=0;c[d+120>>2]=1;c[d+124>>2]=0;c[d+128>>2]=0;c[d+132>>2]=1;h=d+136|0;f=d+144|0;c[h+0>>2]=0;b[h+4>>1]=0;a[h+6>>0]=0;c[f>>2]=80;c[d+148>>2]=1;f=d+152|0;h=d+160|0;g=d+184|0;a[f+0>>0]=0;a[f+1>>0]=0;a[f+2>>0]=0;a[f+3>>0]=0;a[f+4>>0]=0;c[h+0>>2]=0;c[h+4>>2]=0;c[h+8>>2]=0;c[h+12>>2]=0;c[h+16>>2]=0;c[h+20>>2]=0;c[g>>2]=65e3;c[d+188>>2]=0;c[d+192>>2]=0;c[d+196>>2]=0;c[d+200>>2]=783360;c[d+204>>2]=0;a[d+212>>0]=0;c[d+216>>2]=2;c[d+220>>2]=0;c[d+224>>2]=0;c[d+228>>2]=2;g=d+232|0;h=d+240|0;c[g+0>>2]=0;b[g+4>>1]=0;a[g+6>>0]=0;c[h>>2]=80;c[d+244>>2]=1;h=d+248|0;g=d+256|0;f=d+280|0;a[h+0>>0]=0;a[h+1>>0]=0;a[h+2>>0]=0;a[h+3>>0]=0;a[h+4>>0]=0;c[g+0>>2]=0;c[g+4>>2]=0;c[g+8>>2]=0;c[g+12>>2]=0;c[g+16>>2]=0;c[g+20>>2]=0;c[f>>2]=65e3;c[d+284>>2]=0;c[d+288>>2]=0;c[d+292>>2]=0;c[d+296>>2]=783360;c[d+300>>2]=0;a[d+308>>0]=0;c[d+312>>2]=d+24;a[d+316>>0]=0;c[d+320>>2]=0;c[d+324>>2]=0;i=e;return}function td(a,b,d){a=a|0;b=b|0;d=d|0;c[a+320>>2]=b;c[a+324>>2]=d;return}function ud(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;if(b>>>0>2|d>>>0>2){f=1;i=e;return f|0}c[a+(b*96|0)+52>>2]=d;if((c[a+(b*96|0)+68>>2]|0)>>>0<d>>>0){f=0;i=e;return f|0}vd(a+(b*96|0)+24|0,c[a+(b*96|0)+64>>2]|0,0);f=0;i=e;return f|0}function vd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;if(!((c[a+24>>2]|0)>>>0>b>>>0)){i=e;return}if(!((c[a+28>>2]|0)>>>0>d>>>0)){i=e;return}f=a+16|0;g=c[f>>2]|0;if((g|0)==0){h=Qs()|0;c[f>>2]=h;j=h}else{j=g}g=Us(j,b,d,1)|0;if((g|0)==0){i=e;return}j=g+4|0;if((c[j>>2]|0)==0){if((Ks(g,c[3416+((b>>>0>79?4:b>>>4)<<2)>>2]|0)|0)!=0){i=e;return}}if((c[g>>2]|0)==0){Js(g,5e5)}c[a+40>>2]=b;c[a+44>>2]=d;c[a+48>>2]=g;g=c[j>>2]|0;c[a+56>>2]=g;j=a+52|0;if((c[j>>2]|0)>>>0<g>>>0){i=e;return}c[j>>2]=0;i=e;return}function wd(a,b){a=a|0;b=b|0;c[a+32>>2]=b;c[a+128>>2]=b;c[a+224>>2]=b;return}function xd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=i;if(!(b>>>0<3)){i=e;return}c[a+(b*96|0)+36>>2]=d;i=e;return}function yd(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;if(d>>>0>2){i=f;return}g=b+(d*96|0)+28|0;zz(c[g>>2]|0);c[g>>2]=0;a[b+(d*96|0)+44>>0]=0;if((e|0)==0){i=f;return}d=(Kz(e|0)|0)+1|0;b=yz(d)|0;if((b|0)==0){i=f;return}Mz(b|0,e|0,d|0)|0;c[g>>2]=b;i=f;return}function zd(b,c){b=b|0;c=c|0;var d=0,e=0;d=i;if(c>>>0>2){e=1;i=d;return e|0}e=(a[b+(c*96|0)+45>>0]|0)!=0|0;i=d;return e|0}function Ad(b,c,d){b=b|0;c=c|0;d=d|0;var e=0;e=i;if(c>>>0>2){i=e;return}a[b+(c*96|0)+45>>0]=(d|0)!=0|0;i=e;return}function Bd(b,c,d){b=b|0;c=c|0;d=d|0;var e=0;e=i;if(c>>>0>2){i=e;return}a[b+(c*96|0)+46>>0]=(d|0)!=0|0;i=e;return}function Cd(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;g=e<<24>>24!=0;e=b+2|0;if((d[e>>0]|0|0)==(g&1|0)){i=f;return}a[e>>0]=g&1;if(!((a[b>>0]&32)==0)){i=f;return}e=g?2:0;g=b+(e*96|0)+24|0;c[b+312>>2]=g;vd(g,c[b+(e*96|0)+64>>2]|0,d[b+1>>0]|0);i=f;return}function Dd(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=e<<24>>24!=0;e=b+1|0;h=g&1;if((d[e>>0]|0|0)==(h|0)){i=f;return}a[e>>0]=g&1;g=c[b+312>>2]|0;if((c[g+44>>2]|0)==(h|0)){i=f;return}vd(g,c[g+40>>2]|0,h);i=f;return}function Ed(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=b+20|0;j=c[h>>2]|0;if((f|0)==0){k=j}else{l=f;f=e;e=j;while(1){j=(((d[3304+(a[f>>0]&63)>>0]|0)<<10)+(e*31|0)|0)>>>5;m=l+ -1|0;if((m|0)==0){k=j;break}else{l=m;f=f+1|0;e=j}}}c[h>>2]=k;c[(c[b+312>>2]|0)+88>>2]=k;i=g;return}function Fd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;if(d>>>0>2){i=e;return}f=b+(d*96|0)+24|0;g=b+(d*96|0)+58|0;if((a[g>>0]|0)!=0){i=e;return}if((qd(f)|0)!=0){i=e;return}a[g>>0]=1;vd(f,c[b+(d*96|0)+64>>2]|0,c[b+(d*96|0)+68>>2]|0);i=e;return}function Gd(b,f){b=b|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;if((f&1|0)==0){h=0;i=g;return h|0}Hd(b,f>>>9&15);f=d[b>>0]|0;j=f&192;if((j|0)==128){k=d[b+5>>0]|0;if((e[b+14>>1]|0)>=256){h=k&127;i=g;return h|0}h=(k|128)&255;i=g;return h|0}else if((j|0)==0){if((f&16|0)==0){h=-1;i=g;return h|0}k=b+13|0;l=a[k>>0]|0;a[k>>0]=0;h=l;i=g;return h|0}else if((j|0)==64){j=a[b+4>>0]&31|a[b+3>>0]&96;l=j&255;k=c[b+312>>2]|0;do{switch(((a[b+1>>0]|0)!=0?8:0)|f&7|0){case 3:{m=(a[k+35>>0]|0)!=0|0;n=21;break};case 6:{m=(c[k+28>>2]|0)>>>0>1|0;n=21;break};case 8:{m=(a[k+34>>0]|0)==0|0;n=21;break};case 9:{o=a[k+21>>0]|0;if((a[k+20>>0]|0)==0){p=gr(c[k+8>>2]|0,c[k+12>>2]|0)|0;if((p|0)==0){q=o}else{r=(Uq(p)|0)==0;q=r?o:1}}else{q=o}m=(q|0)==0|0;n=21;break};case 14:case 12:case 7:case 5:case 4:{h=l;i=g;return h|0};case 0:{m=(a[k+32>>0]|0)==0|0;n=21;break};case 1:{o=k+33|0;r=a[o>>0]|0;a[o>>0]=0;m=r<<24>>24==0|0;n=21;break};case 2:{m=(a[k+36>>0]|0)==0|0;n=21;break};case 10:{m=(c[k+40>>2]|0)!=0|0;n=21;break};case 11:{if((c[k+28>>2]|0)==1){r=ca(((65536-(c[k+88>>2]|0)|0)*120|0)>>>15,c[k+60>>2]|0)|0;s=(r>>>0)/((c[k+64>>2]|0)>>>0)|0}else{s=(((c[k+52>>2]|0)*120|0)>>>0)/((c[k+56>>2]|0)>>>0)|0}m=s&1^1;n=21;break};default:{}}}while(0);if((n|0)==21){if((m|0)==0){h=l;i=g;return h|0}}h=(j|128)&255;i=g;return h|0}else{h=0;i=g;return h|0}return 0}function Hd(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+16|0;g=f;do{switch(e&15|0){case 14:{a[b>>0]=a[b>>0]&127;h=b;break};case 3:{a[b>>0]=d[b>>0]|2;h=b;break};case 4:{a[b>>0]=a[b>>0]&251;h=b;break};case 10:{a[b>>0]=a[b>>0]&223;j=(a[b+2>>0]|0)!=0?2:0;k=b+(j*96|0)+24|0;c[b+312>>2]=k;vd(k,c[b+(j*96|0)+64>>2]|0,d[b+1>>0]|0);h=b;break};case 8:{a[b>>0]=a[b>>0]&239;j=b+3|0;a[j>>0]=a[j>>0]&223;h=b;break};case 15:{a[b>>0]=d[b>>0]|128;h=b;break};case 1:{a[b>>0]=d[b>>0]|1;h=b;break};case 5:{a[b>>0]=d[b>>0]|4;h=b;break};case 6:{a[b>>0]=a[b>>0]&247;h=b;break};case 7:{a[b>>0]=d[b>>0]|8;h=b;break};case 9:{a[b>>0]=d[b>>0]|16;j=b+3|0;a[j>>0]=d[j>>0]|32;h=b;break};case 12:{a[b>>0]=a[b>>0]&191;h=b;break};case 13:{a[b>>0]=d[b>>0]|64;h=b;break};case 11:{a[b>>0]=d[b>>0]|32;j=b+120|0;c[b+312>>2]=j;vd(j,c[b+160>>2]|0,d[b+1>>0]|0);h=b;break};case 2:{a[b>>0]=a[b>>0]&253;h=b;break};case 0:{a[b>>0]=a[b>>0]&254;h=b;break};default:{h=b}}}while(0);e=a[h>>0]|0;if((e&8)==0){l=e}else{j=e&255;e=j&4;k=(e|0)!=0;m=e>>>2;e=c[b+312>>2]|0;switch(((a[b+1>>0]|0)!=0?4:0)|j&3|0){case 0:{a[e+32>>0]=m^1;break};case 1:{if((m|0)==0){j=e+40|0;n=c[j>>2]|0;if((a[e+32>>0]|0)==0){if((n|0)==0){o=0}else{p=n+ -1|0;c[j>>2]=p;o=p}}else{p=n+1|0;if(p>>>0<(c[e+24>>2]|0)>>>0){c[j>>2]=p;o=p}else{o=n}}a[e+33>>0]=1;vd(e,o,c[e+44>>2]|0);o=c[j>>2]|0;c[g>>2]=(c[e>>2]|0)+1;c[g+4>>2]=o;pw(3392,g)}break};case 2:{o=e+36|0;j=m^1;if((a[o>>0]|0)==(j|0)){q=0}else{a[o>>0]=j;q=0}while(1){j=q+1|0;if((a[b+(q*96|0)+60>>0]|0)!=0){r=1;break}if(j>>>0<3){q=j}else{r=0;break}}q=b+316|0;if(!((a[q>>0]|0)==r<<24>>24)){a[q>>0]=r;q=c[b+324>>2]|0;if((q|0)!=0){jc[q&255](c[b+320>>2]|0,r)}}break};case 3:{if(k){a[e+34>>0]=0;c[g>>2]=(c[e>>2]|0)+1;te(3368,g);if((a[e+92>>0]|0)!=0){rd(e)|0}}break};case 4:{if(k){a[e+35>>0]=0}break};default:{}}l=a[h>>0]|0}if(!(l<<24>>24>-1)){i=f;return}l=b+5|0;a[l>>0]=d[l>>0]|64;l=b+6|0;if((a[l>>0]|0)==0){i=f;return}a[l>>0]=0;l=c[b+312>>2]|0;b=l+76|0;if((c[b>>2]|0)>>>0>(c[l+56>>2]|0)>>>0){if((a[l+22>>0]|0)!=0){h=l+52|0;Os(c[l+48>>2]|0,c[h>>2]|0)|0;c[h>>2]=0}}c[b>>2]=0;i=f;return}function Id(e,f,g){e=e|0;f=f|0;g=g|0;var h=0;h=i;if((f&1|0)==0){i=h;return}Hd(e,f>>>9&15);f=d[e>>0]|0;if((f&192|0)!=192){i=h;return}if((f&16|0)==0){a[e+4>>0]=g;i=h;return}f=e+6|0;if((a[f>>0]|0)==0){a[f>>0]=1;c[e+8>>2]=0;c[(c[e+312>>2]|0)+76>>2]=0}b[e+14>>1]=g&255|65280;i=h;return}function Jd(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=i;h=c[e+312>>2]|0;if((a[h+36>>0]|0)==0){i=g;return}j=h+84|0;k=(c[j>>2]|0)+(f*5e5|0)|0;f=c[h+80>>2]|0;l=(k>>>0)/(f>>>0)|0;c[j>>2]=(k>>>0)%(f>>>0)|0;f=h+56|0;k=c[f>>2]|0;if((k|0)==0){m=0}else{j=h+52|0;n=(c[j>>2]|0)+l|0;while(1){if(n>>>0<k>>>0){break}else{n=n-k|0}}c[j>>2]=n;m=k}k=c[h+64>>2]|0;if((k|0)!=0){n=h+60|0;j=(c[n>>2]|0)+l|0;c[n>>2]=j;if(!(j>>>0<k>>>0)){c[n>>2]=j-k}}k=e+6|0;a:do{if((a[k>>0]|0)==0){if((d[e>>0]|0)<64){j=c[h+48>>2]|0;if(!((j|0)==0|(m|0)==0)){n=h+68|0;l=c[n>>2]|0;o=c[j+8>>2]|0;j=h+52|0;if((l|0)!=(c[j>>2]|0)){p=e+12|0;q=e+16|0;r=e+13|0;s=a[p>>0]|0;t=128>>>(l&7)&255;u=l>>>3;while(1){l=(s&255)<<1;v=(a[o+u>>0]&t)<<24>>24!=0;a[p>>0]=v&1|l;if(v){c[q>>2]=0}else{v=(c[q>>2]|0)+1|0;c[q>>2]=v;if(v>>>0>7){c[q>>2]=0;a[p>>0]=l|1}}l=(c[n>>2]|0)+1|0;c[n>>2]=l;do{if(l>>>0<(c[f>>2]|0)>>>0){if(t<<24>>24==1){w=l;x=-128;y=u+1|0;break}else{w=l;x=(t&255)>>>1;y=u;break}}else{c[n>>2]=0;w=0;x=-128;y=0}}while(0);l=a[p>>0]|0;if(l<<24>>24<0){a[r>>0]=l;a[p>>0]=0;z=c[n>>2]|0;A=0}else{z=w;A=l}if((z|0)==(c[j>>2]|0)){break}else{s=A;t=x;u=y}}}}}}else{u=h+48|0;t=c[u>>2]|0;if(!((t|0)==0|(m|0)==0)){s=h+72|0;j=c[s>>2]|0;n=c[t+8>>2]|0;t=h+52|0;if((j|0)!=(c[t>>2]|0)){p=e+8|0;r=e+14|0;q=e+12|0;o=h+92|0;l=h+76|0;v=c[p>>2]|0;B=128>>>(j&7);C=j>>>3;b:while(1){j=n+C|0;D=v;E=B;while(1){if((D|0)==0){F=b[r>>1]|0;if((F&65535)<256){break b}G=F&255;a[q>>0]=G;c[p>>2]=8;b[r>>1]=0;H=G}else{H=a[q>>0]|0}G=E&255;if(H<<24>>24<0){I=d[j>>0]|E}else{I=d[j>>0]&(E^255)}a[j>>0]=I;a[o>>0]=1;a[q>>0]=d[q>>0]<<1;D=(c[p>>2]|0)+ -1|0;c[p>>2]=D;J=(c[s>>2]|0)+1|0;c[s>>2]=J;c[l>>2]=(c[l>>2]|0)+1;if(!(J>>>0<(c[f>>2]|0)>>>0)){K=27;break}if((G|0)==1){K=30;break}if((J|0)==(c[t>>2]|0)){break a}else{E=G>>>1}}if((K|0)==27){K=0;c[s>>2]=0;L=0;M=0}else if((K|0)==30){K=0;L=J;M=C+1|0}if((L|0)==(c[t>>2]|0)){break a}else{v=D;B=128;C=M}}C=e+5|0;a[C>>0]=a[C>>0]&191;c[p>>2]=0;a[k>>0]=0;if((c[l>>2]|0)>>>0>(c[f>>2]|0)>>>0){if((a[h+22>>0]|0)!=0){Os(c[u>>2]|0,c[t>>2]|0)|0;c[t>>2]=0}}c[l>>2]=0}}}}while(0);f=c[h+52>>2]|0;c[h+68>>2]=f;c[h+72>>2]=f;i=g;return}function Kd(){var b=0,d=0,e=0,f=0,g=0,h=0;b=i;d=yz(304)|0;if((d|0)==0){e=0;i=b;return e|0}f=d+288|0;a[d+264>>0]=0;g=d+268|0;c[d>>2]=0;c[d+4>>2]=0;h=d+284|0;c[g+0>>2]=0;c[g+4>>2]=0;c[g+8>>2]=0;a[g+12>>0]=0;c[f+0>>2]=0;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=0;c[h>>2]=3440;e=d;i=b;return e|0}function Ld(a,b,d){a=a|0;b=b|0;d=d|0;c[a+288>>2]=b;c[a+292>>2]=d;return}function Md(a,b,d){a=a|0;b=b|0;d=d|0;c[a+296>>2]=b;c[a+300>>2]=d;return}function Nd(a,b,d){a=a|0;b=b|0;d=d|0;c[a+276>>2]=b;c[a+284>>2]=(d|0)==0?3440:5504;return 0}function Od(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=c[b+284>>2]|0;if((d|0)==0){d=c[2036]|0;if((d|0)!=0){g=d;d=8144;do{h=c[f>>2]|0;a:do{if((h|0)!=0){j=h;k=f;while(1){l=k+24|0;if((j|0)==(g|0)){break}j=c[l>>2]|0;if((j|0)==0){break a}else{k=l}}c[k+0>>2]=c[d+0>>2];c[k+4>>2]=c[d+4>>2];c[k+8>>2]=c[d+8>>2];c[k+12>>2]=c[d+12>>2];c[k+16>>2]=c[d+16>>2];c[k+20>>2]=c[d+20>>2]}}while(0);d=d+24|0;g=c[d>>2]|0}while((g|0)!=0)}a[b+280>>0]=1;i=e;return}else{g=c[1898]|0;if((g|0)!=0){d=g;g=7592;do{h=c[f>>2]|0;b:do{if((h|0)!=0){j=h;l=f;while(1){m=l+24|0;if((j|0)==(d|0)){break}j=c[m>>2]|0;if((j|0)==0){break b}else{l=m}}c[l+0>>2]=c[g+0>>2];c[l+4>>2]=c[g+4>>2];c[l+8>>2]=c[g+8>>2];c[l+12>>2]=c[g+12>>2];c[l+16>>2]=c[g+16>>2];c[l+20>>2]=c[g+20>>2]}}while(0);g=g+24|0;d=c[g>>2]|0}while((d|0)!=0)}a[b+280>>0]=0;i=e;return}}function Pd(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;if((f|0)==2){j=71}else{j=(f|0)==3?75:f}f=c[d+284>>2]|0;while(1){k=c[f>>2]|0;l=(k|0)==0;if(l|(k|0)==(j|0)){break}else{f=f+24|0}}if(l){l=Ky(j)|0;c[h>>2]=j;c[h+4>>2]=(l|0)!=0?l:8728;Lw(2,8696,h);i=g;return}if((e|0)==2){h=b[f+14>>1]|0;l=h&65535;if(h<<16>>16==0){i=g;return}h=d+4|0;j=c[h>>2]|0;k=0;while(1){if(j>>>0>255){m=j}else{a[d+((c[d>>2]|0)+j&255)+8>>0]=a[f+k+16>>0]|0;n=(c[h>>2]|0)+1|0;c[h>>2]=n;m=n}k=k+1|0;if((k|0)==(l|0)){break}else{j=m}}i=g;return}else if((e|0)==1){e=b[f+4>>1]|0;m=e&65535;if(e<<16>>16==0){i=g;return}e=d+4|0;j=c[e>>2]|0;l=0;while(1){if(j>>>0>255){o=j}else{a[d+((c[d>>2]|0)+j&255)+8>>0]=a[f+l+6>>0]|0;k=(c[e>>2]|0)+1|0;c[e>>2]=k;o=k}l=l+1|0;if((l|0)==(m|0)){break}else{j=o}}i=g;return}else{i=g;return}}function Qd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e;g=d&255;if((g|0)==22){c[b>>2]=0;c[b+4>>2]=1;a[b+8>>0]=c[b+276>>2]<<1&14|1;c[b+268>>2]=0;c[b+272>>2]=1;i=e;return}else if((g|0)==16){c[b+268>>2]=1958400;c[b+272>>2]=1;i=e;return}else if((g|0)==20){c[b+268>>2]=0;c[b+272>>2]=1;i=e;return}else{c[f>>2]=g;te(8736,f);i=e;return}}function Rd(b,c){b=b|0;c=c|0;a[b+264>>0]=c;return}function Sd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;if((a[b+264>>0]|0)==0){i=e;return}f=b+272|0;if((c[f>>2]|0)==0){i=e;return}g=b+4|0;h=c[g>>2]|0;if((h|0)!=0){j=c[b+292>>2]|0;if((j|0)==0){k=h}else{jc[j&255](c[b+288>>2]|0,a[b+(c[b>>2]|0)+8>>0]|0);k=c[g>>2]|0}c[b>>2]=(c[b>>2]|0)+1&255;c[g>>2]=k+ -1;c[f>>2]=0;c[b+268>>2]=0;i=e;return}k=b+268|0;g=c[k>>2]|0;if(g>>>0>d>>>0){c[k>>2]=g-d;i=e;return}d=c[b+292>>2]|0;if((d|0)!=0){jc[d&255](c[b+288>>2]|0,123)}c[f>>2]=0;i=e;return}function Td(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0;g=i;h=1<<e;if((f|0)==0){f=b+4652|0;e=(d[f>>0]|0)&(h^255);a[f>>0]=e;j=e}else{e=b+4652|0;f=d[e>>0]|0|h;a[e>>0]=f;j=f}f=0;e=j&255;while(1){e=e>>>1;if((e|0)==0){break}else{f=f+1|0}}Wj(c[b+4>>2]|0,f);i=g;return}function Ud(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;if(e<<24>>24==0){i=f;return}if((cg(d+2424|0)|0)!=0){e=d+4|0;g=c[e>>2]|0;if(!((b[g+166>>1]&1792)==1792)){h=(c[g+148>>2]|0)+ -4|0;j=c[g+152>>2]|0;k=h&16777215;l=k+3|0;if(l>>>0<(c[g+36>>2]|0)>>>0){m=g+32|0;a[(c[m>>2]|0)+k>>0]=j>>>24;a[(c[m>>2]|0)+(k+1)>>0]=j>>>16;a[(c[m>>2]|0)+(k+2)>>0]=j>>>8;a[(c[m>>2]|0)+l>>0]=j}else{lc[c[g+28>>2]&31](c[g+4>>2]|0,k,j)}j=c[e>>2]|0;c[j+148>>2]=h;Hj(j,c[d+2468>>2]|0)}}j=d+36|0;Zo(j,0);Zo(j,1);i=f;return}function Vd(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;f=i;i=i+80|0;g=f;h=f+28|0;j=f+40|0;k=f+36|0;l=f+72|0;m=f+24|0;n=f+32|0;o=f+76|0;p=d+3480|0;c[p>>2]=0;q=d+3476|0;c[q>>2]=0;c[d+4632>>2]=0;r=d+4656|0;a[d+4652>>0]=0;a[d+4676>>0]=0;c[d+4680>>2]=0;s=d+4684|0;c[r+0>>2]=0;c[r+4>>2]=0;c[r+8>>2]=0;b[r+12>>1]=0;c[s>>2]=1;r=d+4688|0;c[r>>2]=1;t=d+4696|0;c[t>>2]=0;c[d+4692>>2]=0;u=d+4712|0;v=d+28|0;c[u+0>>2]=0;c[u+4>>2]=0;c[u+8>>2]=0;c[u+12>>2]=0;c[u+16>>2]=0;c[u+20>>2]=0;Vv(v);v=Jx(e,0,10448)|0;Sx((v|0)==0?e:v,9776,h,10456)|0;c[g>>2]=c[h>>2];Nw(2,10472,10480,g);v=c[h>>2]|0;do{if((Fz(v,10456)|0)==0){c[d>>2]=1}else{if((Fz(v,10496)|0)==0){c[d>>2]=2;break}if((Fz(v,10504)|0)==0){c[d>>2]=4;break}else{c[g>>2]=v;Lw(0,10520,g);c[d>>2]=1;break}}}while(0);v=eq()|0;u=d+8|0;c[u>>2]=v;fq(v,d,1,2,3,2,3,4);v=d+12|0;yw(c[u>>2]|0,e,v)|0;zw(c[u>>2]|0,e)|0;c[v>>2]=jq(c[u>>2]|0,0)|0;w=jq(c[u>>2]|0,4194304)|0;x=d+16|0;c[x>>2]=w;y=d+20|0;c[y>>2]=0;z=d+24|0;c[z>>2]=0;A=c[v>>2]|0;do{if((A|0)==0){Lw(0,10344,g)}else{if((w|0)==0){Lw(0,10376,g);break}B=Op(A)|0;c[y>>2]=B;_p(B,6291456);if(($p(c[y>>2]|0)|0)>>>0>2097152){aq(c[y>>2]|0,2097152)}B=Op(c[x>>2]|0)|0;c[z>>2]=B;_p(B,0);c[d+4628>>2]=0;Rx(e,10408,h,1)|0;if((c[h>>2]|0)==0){Nw(2,10416,10424,g);B=c[d>>2]|0;if((B&1|0)!=0){qq(c[u>>2]|0,686,4194304);break}if((B&6|0)!=0){qq(c[u>>2]|0,3324,1464619843)}}}}while(0);z=Jx(e,0,10264)|0;Sx(z,9776,h,8800)|0;Px(z,10272,j,0)|0;z=c[j>>2]|0;c[g>>2]=c[h>>2];c[g+4>>2]=z;Nw(2,10280,10288,g);z=nj()|0;x=d+4|0;c[x>>2]=z;if((z|0)!=0){if(($d(d,c[h>>2]|0)|0)!=0){c[g>>2]=c[h>>2];Lw(0,10312,g)}oj(c[x>>2]|0,c[u>>2]|0,4,5,6,5,6,7);qj(c[x>>2]|0,d,150);rj(c[x>>2]|0,d,7);sj(c[x>>2]|0,0);x=c[j>>2]|0;c[s>>2]=x;c[r>>2]=x}x=Jx(e,0,10152)|0;Ox(x,8904,h,15720448)|0;Ox(x,9312,j,8192)|0;x=c[j>>2]|0;c[g>>2]=c[h>>2];c[g+4>>2]=x;Nw(2,10160,9328,g);x=d+36|0;Qo(x,9);Vo(x,d,151);Ro(x,d,152);So(x,d,153);r=Np(c[h>>2]|0,c[j>>2]|0,0)|0;if((r|0)!=0){Vp(r,x,8,9,10,8,9,10);hq(c[u>>2]|0,r,1)}r=Jx(e,0,10136)|0;Ox(r,8904,h,8388608)|0;Ox(r,9312,j,4194304)|0;r=c[j>>2]|0;c[g>>2]=c[h>>2];c[g+4>>2]=r;Nw(2,10144,9328,g);r=d+128|0;jp(r);kp(r,d,154);qp(r,3672e3,3672e3,3672e3);s=Np(c[h>>2]|0,c[j>>2]|0,0)|0;if((s|0)!=0){Vp(s,d,11,0,0,11,0,0);hq(c[u>>2]|0,s,1)}s=d+3488|0;Nf(s);Qf(s,r,0);s=d+4056|0;Nf(s);Qf(s,r,1);s=Jx(e,0,1e4)|0;if((s|0)!=0){z=s;do{Px(z,10008,h,0)|0;Px(z,10016,j,1)|0;Sx(z,9112,k,0)|0;s=c[j>>2]|0;y=c[k>>2]|0;c[g>>2]=c[h>>2];c[g+4>>2]=s;c[g+8>>2]=(y|0)!=0?y:9168;Nw(2,10032,10040,g);z=Jx(e,z,1e4)|0;y=c[h>>2]|0;if(y>>>0>1){c[g>>2]=y;Lw(0,10072,g)}else{s=c[j>>2]|0;pp(r,y,s,s);s=c[k>>2]|0;if((s|0)!=0){if((Of(d+((c[h>>2]|0)*568|0)+3488|0,s)|0)!=0){c[g>>2]=c[k>>2];Lw(0,10104,g)}}}}while((z|0)!=0)}z=Jx(e,0,9848)|0;Sx(z,9504,h,9856)|0;Rx(z,9872,k,1)|0;Rx(z,9888,l,0)|0;Sx(z,9896,j,0)|0;z=c[k>>2]|0;r=c[j>>2]|0;s=c[l>>2]|0;c[g>>2]=c[h>>2];c[g+4>>2]=z;c[g+8>>2]=(r|0)!=0?r:9960;c[g+12>>2]=s;Nw(2,9904,9912,g);c[d+4672>>2]=xz(c[h>>2]|0)|0;s=d+1428|0;bf(s);cf(s,d,155);df(s,d,156);ef(s,c[k>>2]|0);if((ff(s,c[h>>2]|0)|0)!=0){Lw(0,9968,g)}if((c[l>>2]|0)!=0){a[d+1548>>0]=0;a[d+1549>>0]=6;a[d+1550>>0]=-1;a[d+1551>>0]=-53}r=c[j>>2]|0;if((r|0)==0){gf(s,0,1)}else{hf(s,r)}r=d+1744|0;c[r>>2]=0;if((c[d>>2]&1|0)!=0){s=Jx(e,0,9640)|0;Px(s,9776,h,1)|0;Rx(s,9784,j,0)|0;Rx(s,9656,k,0)|0;s=c[j>>2]|0;z=(c[k>>2]|0)!=0?9760:9768;c[g>>2]=c[h>>2];c[g+4>>2]=s;c[g+8>>2]=z;Nw(2,9792,9808,g);z=Kd()|0;c[r>>2]=z;if((z|0)!=0){Nd(z,c[h>>2]|0,c[j>>2]|0)|0;Od(c[r>>2]|0,c[k>>2]|0);Ld(c[r>>2]|0,x,157);Md(c[r>>2]|0,d,12);Uo(x,c[r>>2]|0,158);To(x,c[r>>2]|0,159)}}r=d+1748|0;c[r>>2]=0;z=d+1756|0;c[z>>2]=0;s=d+1752|0;c[s>>2]=0;do{if((c[d>>2]&6|0)!=0){y=Jx(e,0,9624)|0;Rx(y,9632,h,1)|0;Rx(y,9640,j,1)|0;Rx(y,9656,k,0)|0;Nw(2,9672,9680,g);y=Fc()|0;c[r>>2]=y;if((y|0)==0){Lw(0,9696,g);break}Gc(y,x,160);Hc(c[r>>2]|0,x,8);Ic(c[r>>2]|0,d,161);if((c[h>>2]|0)!=0){Nw(2,9672,9720,g);y=cd()|0;c[z>>2]=y;if((y|0)!=0){Jc(c[r>>2]|0,y)|0}}if((c[j>>2]|0)!=0){c[g>>2]=(c[k>>2]|0)!=0?9760:9768;Nw(2,9672,9728,g);y=Xc()|0;c[s>>2]=y;if((y|0)!=0){Oc(y,c[k>>2]|0);Jc(c[r>>2]|0,c[s>>2]|0)|0}}}}while(0);s=d+3484|0;c[s>>2]=xw(e)|0;r=Jx(e,0,9464)|0;z=d+1760|0;sd(z);td(z,d,162);wd(z,c[s>>2]|0);c[g>>2]=13631488;Nw(2,9472,9480,g);x=Jx(r,0,9376)|0;if((x|0)!=0){y=0;A=x;do{Px(A,9376,m,y)|0;Px(A,9496,n,c[m>>2]|0)|0;Sx(A,9504,o,0)|0;Rx(A,9512,h,0)|0;Rx(A,9528,j,0)|0;Rx(A,9536,l,0)|0;Rx(A,9552,k,0)|0;x=(c[h>>2]|0)!=0?400:800;w=c[j>>2]|0;B=c[k>>2]|0;C=c[n>>2]|0;D=c[o>>2]|0;c[g>>2]=c[m>>2];c[g+4>>2]=x;c[g+8>>2]=w;c[g+12>>2]=B;c[g+16>>2]=C;c[g+20>>2]=(D|0)!=0?D:9168;Nw(2,9472,9568,g);ud(z,(c[m>>2]|0)+ -1|0,(c[h>>2]|0)!=0?1:2)|0;xd(z,(c[m>>2]|0)+ -1|0,c[n>>2]|0);yd(z,(c[m>>2]|0)+ -1|0,c[o>>2]|0);Ad(z,(c[m>>2]|0)+ -1|0,c[j>>2]|0);Bd(z,(c[m>>2]|0)+ -1|0,c[k>>2]|0);if((c[l>>2]|0)!=0){Fd(z,(c[m>>2]|0)+ -1|0)}y=(c[m>>2]|0)+1|0;A=Jx(r,A,9376)|0}while((A|0)!=0)}A=Jx(e,0,9304)|0;if((A|0)!=0){Ox(A,8904,h,5767168)|0;Ox(A,9312,j,524288)|0;r=c[j>>2]|0;c[g>>2]=c[h>>2];c[g+4>>2]=r;Nw(2,9320,9328,g);r=d+2088|0;lf(r);mf(r,c[s>>2]|0);y=Np(c[h>>2]|0,c[j>>2]|0,0)|0;if((y|0)!=0){Vp(y,r,12,13,0,13,14,0);hq(c[u>>2]|0,y,1);y=Jx(A,0,9360)|0;if((y|0)!=0){z=y;do{Px(z,9368,k,0)|0;Px(z,9376,l,0)|0;Sx(z,9384,m,9392)|0;Sx(z,9400,n,9408)|0;y=c[l>>2]|0;o=c[m>>2]|0;D=c[n>>2]|0;c[g>>2]=c[k>>2];c[g+4>>2]=y;c[g+8>>2]=o;c[g+12>>2]=D;Nw(2,9320,9416,g);nf(r,c[k>>2]|0,c[l>>2]|0);of(r,c[k>>2]|0,c[m>>2]|0);pf(r,c[k>>2]|0,c[n>>2]|0);z=Jx(A,z,9360)|0}while((z|0)!=0)}}}z=Jx(e,0,9216)|0;Px(z,9224,k,30)|0;Rx(z,9240,h,0)|0;A=d+2424|0;Yf(A,(z|0)!=0|0);Zf(A,c[u>>2]|0);_f(A,c[s>>2]|0);a[d+2484>>0]=c[h>>2];if((z|0)!=0){if((c[2638]&1|0)==0){c[g>>2]=1;ab(j|0,9256,g|0)|0;Px(z,j,l,c[k>>2]|0)|0;E=c[l>>2]|0}else{s=c[2744]|0;c[l>>2]=s;E=s}ag(A,0,E);E=c[l>>2]|0;c[g>>2]=1;c[g+4>>2]=E;Nw(2,9272,9280,g);if((c[2638]&2|0)==0){c[g>>2]=2;ab(j|0,9256,g|0)|0;Px(z,j,l,c[k>>2]|0)|0;F=c[l>>2]|0}else{E=c[10980>>2]|0;c[l>>2]=E;F=E}ag(A,1,F);F=c[l>>2]|0;c[g>>2]=2;c[g+4>>2]=F;Nw(2,9272,9280,g);if((c[2638]&4|0)==0){c[g>>2]=3;ab(j|0,9256,g|0)|0;Px(z,j,l,c[k>>2]|0)|0;G=c[l>>2]|0}else{F=c[10984>>2]|0;c[l>>2]=F;G=F}ag(A,2,G);G=c[l>>2]|0;c[g>>2]=3;c[g+4>>2]=G;Nw(2,9272,9280,g);if((c[2638]&8|0)==0){c[g>>2]=4;ab(j|0,9256,g|0)|0;Px(z,j,l,c[k>>2]|0)|0;H=c[l>>2]|0}else{z=c[10988>>2]|0;c[l>>2]=z;H=z}ag(A,3,H);H=c[l>>2]|0;c[g>>2]=4;c[g+4>>2]=H;Nw(2,9272,9280,g)}H=d+2644|0;jg(H);if((c[v>>2]|0)!=0){A=Jx(e,0,9096)|0;z=$p(c[v>>2]|0)|0;G=z>>>0<768?0:z+ -768|0;c[h>>2]=G;Ox(A,8904,h,G)|0;Ox(A,9104,j,6e3)|0;Sx(A,9112,k,0)|0;A=c[j>>2]|0;G=c[k>>2]|0;c[g>>2]=c[h>>2];c[g+4>>2]=A;c[g+8>>2]=(G|0)!=0?G:9168;Nw(2,9120,9128,g);G=c[h>>2]|0;A=d+4644|0;c[A>>2]=G;c[d+4648>>2]=G+ -23552;G=Xp(c[v>>2]|0)|0;kg(H,G+(c[A>>2]|0)|0);lg(H,c[j>>2]|0);A=c[k>>2]|0;if((A|0)!=0){if((og(H,A)|0)!=0){c[g>>2]=c[k>>2];Lw(0,9176,g)}}}A=Aw(e,c[2636]|0)|0;c[p>>2]=A;if((A|0)!=0){Vy(A,d,26);Wy(c[p>>2]|0,d,15);Xy(c[p>>2]|0,d,3)}if((c[v>>2]|0)==0){I=c[u>>2]|0;Gw(I,e)|0;J=c[p>>2]|0;Zy(J,8768,8784)|0;K=d+4700|0;c[K>>2]=0;L=d+4704|0;c[L>>2]=0;kx(L)|0;c[t>>2]=0;i=f;return}A=Jx(e,0,8896)|0;H=$p(c[v>>2]|0)|0;v=H>>>0<22784?0:H+ -22784|0;Ox(A,8904,h,v)|0;Px(A,8912,j,512)|0;Px(A,8920,k,342)|0;Ox(A,8928,m,0)|0;Ox(A,8936,n,16777215)|0;Px(A,8944,l,1e3)|0;A=c[j>>2]|0;H=c[k>>2]|0;G=((c[l>>2]|0)>>>0)/10|0;c[g>>2]=c[h>>2];c[g+4>>2]=A;c[g+8>>2]=H;c[g+12>>2]=G;Nw(2,8960,8968,g);g=c[h>>2]|0;h=d+4636|0;c[h>>2]=g;if((v|0)==(g|0)&g>>>0>32767){c[d+4640>>2]=v+ -32768}else{c[d+4640>>2]=g}g=sg(c[j>>2]|0,c[k>>2]|0)|0;c[q>>2]=g;if((g|0)==0){I=c[u>>2]|0;Gw(I,e)|0;J=c[p>>2]|0;Zy(J,8768,8784)|0;K=d+4700|0;c[K>>2]=0;L=d+4704|0;c[L>>2]=0;kx(L)|0;c[t>>2]=0;i=f;return}tg(g,d,163);de(d,c[h>>2]|0);g=c[p>>2]|0;if((g|0)!=0){vg(c[q>>2]|0,g);Uy(c[p>>2]|0,512,342)|0}wg(c[q>>2]|0,c[m>>2]|0,c[n>>2]|0);xg(c[q>>2]|0,((((c[l>>2]|0)*255|0)+500|0)>>>0)/1e3|0);if((ca((c[j>>2]|0)>>>3,c[k>>2]|0)|0)==0){I=c[u>>2]|0;Gw(I,e)|0;J=c[p>>2]|0;Zy(J,8768,8784)|0;K=d+4700|0;c[K>>2]=0;L=d+4704|0;c[L>>2]=0;kx(L)|0;c[t>>2]=0;i=f;return}else{M=0}do{oq(c[u>>2]|0,(c[h>>2]|0)+M|0,-1);M=M+1|0}while(M>>>0<(ca((c[j>>2]|0)>>>3,c[k>>2]|0)|0)>>>0);I=c[u>>2]|0;Gw(I,e)|0;J=c[p>>2]|0;Zy(J,8768,8784)|0;K=d+4700|0;c[K>>2]=0;L=d+4704|0;c[L>>2]=0;kx(L)|0;c[t>>2]=0;i=f;return}function Wd(a){a=a|0;var b=0,d=0;b=i;c[a+4700>>2]=0;d=a+4704|0;c[d>>2]=0;kx(d)|0;c[a+4696>>2]=0;i=b;return}function Xd(a){a=a|0;var b=0,c=0,d=0;b=i;c=yz(4736)|0;if((c|0)==0){d=0}else{Vd(c,a);d=c}i=b;return d|0}function Yd(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=(d|0)!=0;a[b+4676>>0]=f&1;if(f){i=e;return}c[b+4700>>2]=0;f=b+4704|0;c[f>>2]=0;kx(f)|0;c[b+4696>>2]=0;i=e;return}function Zd(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e;if(b>>>0>1){i=e;return}c[a+(b<<2)+4688>>2]=d;d=c[a+4688>>2]|0;b=c[a+4692>>2]|0;if((b|0)==0){g=d}else{g=(d|0)==0|b>>>0<d>>>0?b:d}d=a+4684|0;if((g|0)==(c[d>>2]|0)){i=e;return}c[f>>2]=g;te(8880,f);ef(a+1428|0,(g|0)!=1|0);c[d>>2]=g;g=a+4696|0;c[g>>2]=0;c[a+4700>>2]=0;d=a+4704|0;c[d>>2]=0;kx(d)|0;c[g>>2]=0;i=e;return}function _d(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=c[a+3480>>2]|0;if((f|0)==0){g=1}else{g=Zy(f,b,d)|0}i=e;return g|0}function $d(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;do{if((Fz(b,8800)|0)==0){tj(c[a+4>>2]|0);e=0}else{if((Fz(b,8808)|0)==0){uj(c[a+4>>2]|0);e=0;break}if((Fz(b,8816)|0)==0){vj(c[a+4>>2]|0);e=0}else{e=1}}}while(0);i=d;return e|0}function ae(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+16|0;f=d+4632|0;if((c[f>>2]|0)!=0){i=e;return}c[f>>2]=1;te(8824,e);g=d+4656|0;a[d+4652>>0]=0;c[g+0>>2]=0;c[g+4>>2]=0;c[g+8>>2]=0;b[g+12>>1]=0;do{if((c[d>>2]&1|0)==0){ye(d,0);g=d+16|0;h=c[g>>2]|0;if((h|0)!=0){if((c[h+40>>2]|0)>>>0>7){j=d+4|0;k=c[j>>2]|0;l=dq(h,0)|0;if((c[k+36>>2]|0)>>>0>3){h=k+32|0;a[c[h>>2]>>0]=l>>>24;a[(c[h>>2]|0)+1>>0]=l>>>16;a[(c[h>>2]|0)+2>>0]=l>>>8;a[(c[h>>2]|0)+3>>0]=l}else{lc[c[k+28>>2]&31](c[k+4>>2]|0,0,l)}l=c[j>>2]|0;j=dq(c[g>>2]|0,4)|0;if((c[l+36>>2]|0)>>>0>7){g=l+32|0;a[(c[g>>2]|0)+4>>0]=j>>>24;a[(c[g>>2]|0)+5>>0]=j>>>16;a[(c[g>>2]|0)+6>>0]=j>>>8;a[(c[g>>2]|0)+7>>0]=j;break}else{lc[c[l+28>>2]&31](c[l+4>>2]|0,4,j);break}}}}else{ye(d,1)}}while(0);j=d+36|0;hp(j);a[d+4624>>0]=-9;l=d+4625|0;a[l>>0]=-1;_o(j,-9);$o(j,a[l>>0]|0);eg(d+2424|0);uf(d+2088|0);Ip(d+128|0);l=c[d+1748>>2]|0;if((l|0)!=0){Kc(l)}Xj(c[d+4>>2]|0);c[d+4700>>2]=0;l=d+4704|0;c[l>>2]=0;kx(l)|0;c[d+4696>>2]=0;c[f>>2]=0;i=e;return}function be(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+16|0;g=f;if((e|0)==0){h=c[(c[b+4>>2]|0)+372>>2]|0;j=(h|0)==0?1:h}else{j=e}e=c[b+4684>>2]|0;if((e|0)==0){k=1;l=(c[b+4696>>2]|0)+j|0}else{k=e;l=j}Zj(c[b+4>>2]|0,l);qg(b+2644|0,l);l=b+4712|0;e=l;h=Jz(c[e>>2]|0,c[e+4>>2]|0,j|0,0)|0;e=l;c[e>>2]=h;c[e+4>>2]=G;e=b+4720|0;h=(c[e>>2]|0)+j|0;c[e>>2]=h;j=b+4724|0;l=c[j>>2]|0;if(h>>>0<k>>>0){m=l}else{n=l;l=h;do{n=n+1|0;l=l-k|0}while(!(l>>>0<k>>>0));c[j>>2]=n;c[e>>2]=l;m=n}if(m>>>0<10){i=f;return}n=(m>>>0)/10|0;m=b+36|0;ip(m,n);l=b+1748|0;e=c[l>>2]|0;k=n*10|0;if((e|0)!=0){Mc(e,k)}Jd(b+1760|0,n);c[j>>2]=(c[j>>2]|0)-k;j=b+4728|0;n=(c[j>>2]|0)+k|0;c[j>>2]=n;if(n>>>0<256){i=f;return}zg(c[b+3476>>2]|0,n);Vf(b+3488|0,c[j>>2]|0);Vf(b+4056|0,c[j>>2]|0);n=c[b+1744>>2]|0;if((n|0)!=0){Sd(n,c[j>>2]|0)}n=b+4732|0;k=(c[n>>2]|0)+(c[j>>2]|0)|0;c[n>>2]=k;c[j>>2]=0;if(k>>>0<8192){i=f;return}k=c[b+3480>>2]|0;if((k|0)!=0){gz(k)}if((c[l>>2]|0)==0){l=b+4656|0;k=c[l>>2]|0;if((k+1|0)>>>0>2){j=b+4668|0;e=b+4625|0;h=d[e>>0]|0;o=(a[j>>0]|0)==0?h|16:h&239;h=o&255;a[e>>0]=h;if((k|0)>0){p=(o^16)&255;a[e>>0]=p;q=p;r=k+ -2|0}else{q=h;r=k+2|0}c[l>>2]=r;$o(m,q);Bp(b+128|0,a[j>>0]|0);a[j>>0]=(a[j>>0]|0)==0|0}j=b+4660|0;q=c[j>>2]|0;if((q+1|0)>>>0>2){r=b+4669|0;l=b+4625|0;k=d[l>>0]|0;h=(a[r>>0]|0)==0?k|32:k&223;k=h&255;a[l>>0]=k;if((q|0)>0){s=k;t=q+ -2|0}else{k=(h^32)&255;a[l>>0]=k;s=k;t=q+2|0}c[j>>2]=t;$o(m,s);Cp(b+128|0,a[r>>0]|0);a[r>>0]=(a[r>>0]|0)==0|0}}kf(b+1428|0,c[n>>2]|0);r=b+4700|0;s=(c[r>>2]|0)+(c[n>>2]|0)|0;c[r>>2]=s;if(s>>>0>31333){c[r>>2]=s+ -31334;s=kx(b+4704|0)|0;if(s>>>0<4e3){r=b+4708|0;m=(c[r>>2]|0)+(4e3-s)|0;c[r>>2]=m;if((m|0)>0){t=b+4696|0;c[t>>2]=(c[t>>2]|0)+1;u=m;v=35}else{w=m;x=r}}else{r=b+4708|0;m=(c[r>>2]|0)+(4e3-s)|0;c[r>>2]=m;if((m|0)<0){r=b+4696|0;s=c[r>>2]|0;if((s|0)==0){u=m;v=35}else{c[r>>2]=s+ -1;u=m;v=35}}else{u=m;v=35}}if((v|0)==35){v=b+4708|0;if((u|0)>9999){jx(u)|0;w=c[v>>2]|0;x=v}else{w=u;x=v}}if((w|0)<-1e6){te(8840,g);c[x>>2]=(c[x>>2]|0)+1e6}}c[n>>2]=0;i=f;return}function ce(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+384|0;g=f;if(e<<24>>24==0){i=f;return}e=b+36|0;Yo(e,0);Yo(e,1);pg(b+2644|0);e=b+8|0;h=b+4644|0;j=0;do{k=j;j=j+1|0;a[g+k>>0]=kq(c[e>>2]|0,j+(c[h>>2]|0)|0)|0}while((j|0)!=370);if((c[b>>2]&4|0)==0){Ed(b+1760|0,g,370);i=f;return}j=(d[9008+(a[g>>0]&63)>>0]|0)*370|0;if(j>>>0<370){l=1}else{l=j>>>0>11839?31:(j>>>0)/370|0}j=(((((31-l|0)*223|0)+15|0)>>>0)/30|0)+32|0;l=c[b+3476>>2]|0;if((l|0)==0){i=f;return}if((c[l+28>>2]|0)==(j|0)){i=f;return}xg(l,j);i=f;return}function de(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=a+12|0;do{if(($p(c[e>>2]|0)|0)>>>0>b>>>0){f=(Xp(c[e>>2]|0)|0)+b|0}else{g=jq(c[a+8>>2]|0,b)|0;if((g|0)!=0){h=Xp(g)|0;j=Zp(g)|0;f=h+(j-(c[a+4636>>2]|0))|0;break}ug(c[a+3476>>2]|0,0);i=d;return}}while(0);ug(c[a+3476>>2]|0,f);i=d;return}function ee(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;if((b|0)==3){pd(a,d)|0;i=e;return}f=c[a+1744>>2]|0;if((f|0)!=0){Pd(f,b,d)}f=c[a+1752>>2]|0;if((f|0)==0){i=e;return}Qc(f,b,d);i=e;return}function fe(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0;h=i;j=b+4676|0;if((a[j>>0]|0)!=0){if((g|0)==0){i=h;return}a[j>>0]=0;c[b+4700>>2]=0;j=b+4704|0;c[j>>2]=0;kx(j)|0;c[b+4696>>2]=0;i=h;return}j=c[b+1756>>2]|0;if((j|0)!=0){Yc(j,g,e,f);i=h;return}j=b+4664|0;if(((g&2^2)&(c[j>>2]^g)|0)!=0){Zy(c[b+3480>>2]|0,9072,9088)|0}k=b+4625|0;l=d[k>>0]|0;m=(g&1|0)==0?l|8:l&247;n=m&255;a[k>>0]=n;if((m|0)!=(l|0)){$o(b+36|0,n)}n=b+4656|0;c[n>>2]=(c[n>>2]|0)+e;e=b+4660|0;c[e>>2]=(c[e>>2]|0)+f;c[j>>2]=g;i=h;return}function ge(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+16|0;e=d;f=b<<24>>24!=0;b=f?4:0;c[a+4692>>2]=b;g=c[a+4688>>2]|0;if(f){h=(g|0)==0|b>>>0<g>>>0?b:g}else{h=g}g=a+4684|0;if((h|0)==(c[g>>2]|0)){i=d;return}c[e>>2]=h;te(8880,e);ef(a+1428|0,(h|0)!=1|0);c[g>>2]=h;h=a+4696|0;c[h>>2]=0;c[a+4700>>2]=0;g=a+4704|0;c[g>>2]=0;kx(g)|0;c[h>>2]=0;i=d;return}function he(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0;e=i;f=b+4625|0;g=d[f>>0]|0;h=(c<<24>>24==0?g|8:g&247)&255;a[f>>0]=h;$o(b+36|0,h);i=e;return}function ie(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0;e=i;f=b+4625|0;g=d[f>>0]|0;h=(c<<24>>24==0?g&254:g|1)&255;a[f>>0]=h;$o(b+36|0,h);i=e;return}function je(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=b+4652|0;h=d[g>>0]|0;j=e<<24>>24==0?h&251:h|4;a[g>>0]=j;g=0;h=j;while(1){h=h>>>1;if((h|0)==0){break}else{g=g+1|0}}Wj(c[b+4>>2]|0,g);i=f;return}function ke(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;if((b|0)==2097146){d=tp(a+128|0)|0}else if((b|0)==2097148){d=yp(a+128|0)|0}else if((b|0)==2097150){d=xp(a+128|0)|0}else if((b|0)==2097144){d=up(a+128|0)|0}else{d=-1}i=c;return d|0}function le(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;if((b|0)==4194299){vp(a+128|0,c)}else if((b|0)==4194297){wp(a+128|0,c)}else if((b|0)==4194301){Ap(a+128|0,c)}else if((b|0)==4194303){zp(a+128|0,c)}i=d;return}function me(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=b+4652|0;h=d[g>>0]|0;j=e<<24>>24==0?h&253:h|2;a[g>>0]=j;g=0;h=j;while(1){h=h>>>1;if((h|0)==0){break}else{g=g+1|0}}Wj(c[b+4>>2]|0,g);i=f;return}function ne(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+16|0;f=e;g=b+4624|0;h=a[g>>0]|0;j=d&255;if(h<<24>>24==d<<24>>24){i=e;return}a[g>>0]=d;g=(h^d)&255;do{if((g&16|0)!=0){d=c[b>>2]|0;if((d&1|0)!=0){ye(b,j>>>4&1);break}if((d&6|0)!=0){Cd(b+1760|0,j>>>4&1)}}}while(0);if((g&32|0)!=0){Dd(b+1760|0,j>>>5&1)}if((g&64|0)!=0){if((j&64|0)==0){te(10192,f);k=b+4640|0}else{te(10168,f);k=b+4636|0}de(b,c[k>>2]|0)}if((g&8|0)!=0){if((c[b>>2]&1|0)!=0){k=Xp(c[b+12>>2]|0)|0;if((j&8|0)==0){te(10240,f);l=b+4648|0}else{te(10216,f);l=b+4644|0}kg(b+2644|0,k+(c[l>>2]|0)|0)}}if((g&7|0)==0){i=e;return}mg(b+2644|0,j&7);i=e;return}function oe(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=b+4625|0;g=a[f>>0]|0;h=d&255;if(g<<24>>24==d<<24>>24){i=e;return}a[f>>0]=d;jf(b+1428|0,d);if((g^d)<<24>>24<0){ng(b+2644|0,h>>>7^1)}d=c[b+1748>>2]|0;if((d|0)==0){i=e;return}Lc(d,h>>>4&3);i=e;return}function pe(a,b){a=a|0;b=b|0;var c=0;c=i;if(!(b<<24>>24==0)){ae(a)}i=c;return}function qe(a){a=a|0;c[2642]=1;return}function re(a){a=a|0;lx(0,1);a=c[o>>2]|0;fb(10584,32,1,a|0)|0;Nb(a|0)|0;a=c[2640]|0;if((a|0)==0){kb(1)}if((c[a+4>>2]|0)==0){kb(1)}dd(a,10624);kb(1)}function se(a){a=a|0;var b=0,d=0;b=i;i=i+16|0;d=b;lx(0,1);b=c[o>>2]|0;c[d>>2]=a;hb(b|0,10632,d|0)|0;Nb(b|0)|0;kb(1)}function te(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;i=i+32|0;e=d;f=d+8|0;g=c[2640]|0;if((g|0)==0){h=0}else{h=(Dj(c[g+4>>2]|0,0)|0)&16777215}c[e>>2]=h;Lw(3,10656,e);c[f>>2]=b;Mw(3,a,f);i=d;return}function ue(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,r=0,s=0,t=0;d=i;i=i+16|0;e=d;f=d+8|0;Hw();g=c[o>>2]|0;Iw(g,0,2)|0;h=Hx(0)|0;c[2644]=h;if((h|0)==0){j=1;i=d;return j|0}Tx(10672);Kw(g,3);h=tw(a,b,f,10704)|0;do{if((h|0)==-1){Lw(2,11272,e);k=10688;l=26}else{m=h;n=10688;a:while(1){if((m|0)<0){j=1;l=30;break}do{switch(m|0){case 98:{c[2638]=c[2638]|1;c[2744]=Hb(c[c[f>>2]>>2]|0,0,0)|0;r=n;break};case 108:{Jw(c[c[f>>2]>>2]|0,3)|0;r=n;break};case 82:case 114:{r=n;break};case 0:{l=24;break a;break};case 115:{Ux(10672,11096,c[c[f>>2]>>2]|0,11064)|0;r=n;break};case 116:{c[2636]=c[c[f>>2]>>2];r=n;break};case 118:{Kw(g,3);r=n;break};case 66:{s=Hb(c[c[f>>2]>>2]|0,0,0)|0;if((s|0)==0|s>>>0>3){l=10;break a}t=s+ -1|0;c[2638]=c[2638]|1<<t;c[10976+(t<<2)>>2]=Hb(c[(c[f>>2]|0)+4>>2]|0,0,0)|0;r=n;break};case 99:{r=c[c[f>>2]>>2]|0;break};case 112:{Ux(10672,11072,c[c[f>>2]>>2]|0,11088)|0;r=n;break};case 113:{Kw(g,0);r=n;break};case 86:{l=7;break a;break};case 63:{l=6;break a;break};case 73:{Ux(10672,c[c[f>>2]>>2]|0,11064,0)|0;r=n;break};case 105:{if((ox(c[2644]|0,c[c[f>>2]>>2]|0)|0)==0){r=n}else{l=15;break a}break};case 100:{cx(c[c[f>>2]>>2]|0)|0;r=n;break};default:{j=1;l=30;break a}}}while(0);t=tw(a,b,f,10704)|0;if((t|0)==-1){l=25;break}else{m=t;n=r}}if((l|0)==6){sw(11464,11504,10704);Nb(c[q>>2]|0)|0;j=0;i=d;return j|0}else if((l|0)==7){n=c[q>>2]|0;fb(11368,93,1,n|0)|0;Nb(n|0)|0;j=0;i=d;return j|0}else if((l|0)==10){c[e>>2]=c[b>>2];c[e+4>>2]=s;hb(g|0,10992,e|0)|0;j=1;i=d;return j|0}else if((l|0)==15){n=c[c[f>>2]>>2]|0;c[e>>2]=c[b>>2];c[e+4>>2]=n;hb(g|0,11024,e|0)|0;j=1;i=d;return j|0}else if((l|0)==24){n=c[c[f>>2]>>2]|0;c[e>>2]=c[b>>2];c[e+4>>2]=n;hb(g|0,11112,e|0)|0;j=1;i=d;return j|0}else if((l|0)==25){Lw(2,11272,e);if((r|0)==0){break}else{k=r;l=26;break}}else if((l|0)==30){i=d;return j|0}}}while(0);if((l|0)==26){c[e>>2]=k;Nw(2,11216,11224,e);if((sx(c[2644]|0,k)|0)!=0){Lw(0,11240,e);j=1;i=d;return j|0}}e=Jx(c[2644]|0,0,11144)|0;k=(e|0)==0?c[2644]|0:e;if((Vx(10672,k,1)|0)==0){va(2)|0;tb(0)|0;ex(k)|0;za(2,216)|0;za(11,217)|0;za(15,218)|0;rw(c[p>>2]|0,c[q>>2]|0);c[2640]=Xd(k)|0;Ow(11152);Qw(11152,14,c[2640]|0);Rw(11152,26,c[2640]|0);Sw(11152,c[(c[2640]|0)+8>>2]|0,4);Tw(11152,c[(c[2640]|0)+8>>2]|0,5);Uw(11152,0);jw(c[2640]|0,27,28);kd(c[2640]|0,11152);ae(c[2640]|0);gd(c[2640]|0);kb(1)}else{j=1;i=d;return j|0}return 0}function ve(){var a=0;a=i;lx(0,1);i=a;return}function we(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=(Fj(c[a+4>>2]|0,b,d)|0)!=0|0;i=e;return f|0}function xe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=(Gj(c[a+4>>2]|0,b,d)|0)!=0|0;i=e;return f|0}function ye(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a+4628|0;f=(b|0)!=0;if((c[e>>2]|0)==(f&1|0)){i=d;return}b=a+8|0;g=c[b>>2]|0;if(f){iq(g,c[a+12>>2]|0);hq(c[b>>2]|0,c[a+24>>2]|0,0);hq(c[b>>2]|0,c[a+20>>2]|0,0);pj(c[a+4>>2]|0,0,0);c[e>>2]=1;i=d;return}else{iq(g,c[a+24>>2]|0);iq(c[b>>2]|0,c[a+20>>2]|0);g=a+12|0;hq(c[b>>2]|0,c[g>>2]|0,0);b=c[a+4>>2]|0;a=Xp(c[g>>2]|0)|0;pj(b,a,$p(c[g>>2]|0)|0);c[e>>2]=0;i=d;return}}function ze(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;if(b>>>0<4194304){e=c[a+12>>2]|0;if((e|0)!=0){f=$p(e)|0;if((f|0)!=0){e=(b>>>0)%(f>>>0)|0;if((e|0)!=(b|0)){g=e;h=9}}}}else{if(b>>>0<5767168){e=c[a+16>>2]|0;if((e|0)!=0){f=$p(e)|0;if((f|0)!=0){e=((b>>>0)%(f>>>0)|0)+4194304|0;if((e|0)!=(b|0)){g=e;h=9}}}}}if((h|0)==9){j=kq(c[a+8>>2]|0,g)|0;i=d;return j|0}if((b+ -5767168|0)>>>0<524288){j=0;i=d;return j|0}g=b+ -12582912|0;if(g>>>0<2097152){j=Gd(a+1760|0,g)|0;i=d;return j|0}else{j=(b&15728640|0)==13631488?-86:0;i=d;return j|0}return 0}function Ae(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;if(b>>>0<4194304){e=c[a+12>>2]|0;if((e|0)==0){f=0}else{g=$p(e)|0;if((g|0)==0){f=0}else{e=(b>>>0)%(g>>>0)|0;if((e|0)==(b|0)){f=0}else{h=e;j=9}}}}else{if(b>>>0<5767168){e=c[a+16>>2]|0;if((e|0)==0){f=0}else{g=$p(e)|0;if((g|0)==0){f=0}else{e=((b>>>0)%(g>>>0)|0)+4194304|0;if((e|0)==(b|0)){f=0}else{h=e;j=9}}}}else{f=0}}if((j|0)==9){f=lq(c[a+8>>2]|0,h)|0}i=d;return f|0}function Be(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;if(b>>>0<4194304){e=c[a+12>>2]|0;if((e|0)==0){f=0}else{g=$p(e)|0;if((g|0)==0){f=0}else{e=(b>>>0)%(g>>>0)|0;if((e|0)==(b|0)){f=0}else{h=e;j=9}}}}else{if(b>>>0<5767168){e=c[a+16>>2]|0;if((e|0)==0){f=0}else{g=$p(e)|0;if((g|0)==0){f=0}else{e=((b>>>0)%(g>>>0)|0)+4194304|0;if((e|0)==(b|0)){f=0}else{h=e;j=9}}}}else{f=0}}if((j|0)==9){f=mq(c[a+8>>2]|0,h)|0}i=d;return f|0}function Ce(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;if(b>>>0<4194304){f=c[a+12>>2]|0;if((f|0)==0){i=e;return}g=$p(f)|0;if((g|0)==0){i=e;return}f=(b>>>0)%(g>>>0)|0;if((f|0)==(b|0)){i=e;return}else{h=f;j=9}}else{if(b>>>0<5767168){f=c[a+16>>2]|0;if((f|0)==0){k=b}else{g=$p(f)|0;if((g|0)==0){k=b}else{f=((b>>>0)%(g>>>0)|0)+4194304|0;if((f|0)==(b|0)){k=b}else{h=f;j=9}}}}else{k=b}}if((j|0)==9){oq(c[a+8>>2]|0,h,d);k=h}if(!((k+ -5767168|0)>>>0>524287&k>>>0>12582911&k>>>0<14680064)){i=e;return}Id(a+1760|0,k+ -12582912|0,d);i=e;return}function De(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;if(b>>>0<4194304){f=c[a+12>>2]|0;if((f|0)!=0){g=$p(f)|0;if((g|0)!=0){f=(b>>>0)%(g>>>0)|0;if((f|0)!=(b|0)){h=f;j=9}}}}else{if(b>>>0<5767168){f=c[a+16>>2]|0;if((f|0)!=0){g=$p(f)|0;if((g|0)!=0){f=((b>>>0)%(g>>>0)|0)+4194304|0;if((f|0)!=(b|0)){h=f;j=9}}}}}if((j|0)==9){pq(c[a+8>>2]|0,h,d)}i=e;return}function Ee(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;if(b>>>0<4194304){f=c[a+12>>2]|0;if((f|0)!=0){g=$p(f)|0;if((g|0)!=0){f=(b>>>0)%(g>>>0)|0;if((f|0)!=(b|0)){h=f;j=9}}}}else{if(b>>>0<5767168){f=c[a+16>>2]|0;if((f|0)!=0){g=$p(f)|0;if((g|0)!=0){f=((b>>>0)%(g>>>0)|0)+4194304|0;if((f|0)!=(b|0)){h=f;j=9}}}}}if((j|0)==9){qq(c[a+8>>2]|0,h,d)}i=e;return}function Fe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=(a|0)==0?c[2640]|0:a;if((b|0)==0){g=1;i=e;return g|0}a=(d|0)==0?12248:d;d=12440;h=12256;while(1){j=h+8|0;if((Xw(d,b)|0)!=0){k=5;break}d=c[j>>2]|0;if((d|0)==0){break}else{h=j}}if((k|0)==5){g=gc[c[h+4>>2]&63](f,b,a)|0;i=e;return g|0}h=c[f+3480>>2]|0;if((h|0)!=0){f=Zy(h,b,a)|0;if((f|0)>-1){g=f;i=e;return g|0}}g=1;i=e;return g|0}function Ge(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+16|0;e=b;if(($d(a,d)|0)==0){f=0;i=b;return f|0}c[e>>2]=d;Lw(0,13432,e);f=1;i=b;return f|0}function He(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+16|0;e=b;if((Yw(d,e)|0)==0){Zd(a,0,c[e>>2]|0);f=0}else{f=1}i=b;return f|0}function Ie(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+16|0;e=b;if((Zw(d,e)|0)!=0){f=1;i=b;return f|0}d=(c[e>>2]|0)+(c[a+4684>>2]|0)|0;g=(d|0)<1?1:d;c[e>>2]=g;Zd(a,0,g);f=0;i=b;return f|0}function Je(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;d=i;i=i+16|0;f=d;g=d+8|0;h=d+4|0;c[g>>2]=e;if((Fz(e,13248)|0)==0){Lw(2,13256,f);if((hr(c[b+3484>>2]|0)|0)==0){j=0;i=d;return j|0}Lw(0,13280,f);j=1;i=d;return j|0}e=b+3484|0;b=0;a:while(1){do{if((a[c[g>>2]>>0]|0)==0){j=b;k=11;break a}if((ax(g,h,12864,12872)|0)!=0){break a}c[f>>2]=c[h>>2];Lw(2,13368,f)}while((ir(c[e>>2]|0,c[h>>2]|0,13392,0)|0)==0);c[f>>2]=c[h>>2];Lw(0,13400,f);b=1}if((k|0)==11){i=d;return j|0}c[f>>2]=c[g>>2];Lw(0,13328,f);j=1;i=d;return j|0}function Ke(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+16|0;f=d;g=d+8|0;h=d+4|0;c[g>>2]=e;if((a[e>>0]|0)==0){j=0;i=d;return j|0}e=b+3484|0;while(1){if((ax(g,h,12864,12872)|0)!=0){break}b=gr(c[e>>2]|0,c[h>>2]|0)|0;k=c[h>>2]|0;if((b|0)==0){c[f>>2]=k;Lw(0,13176,f)}else{c[f>>2]=k;Lw(2,13224,f);fr(c[e>>2]|0,b)|0;Qq(b)}if((a[c[g>>2]>>0]|0)==0){j=0;l=9;break}}if((l|0)==9){i=d;return j|0}c[f>>2]=c[g>>2];Lw(0,13136,f);j=1;i=d;return j|0}function Le(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;b=i;e=(uw(c[a+3484>>2]|0,d,1)|0)!=0|0;i=b;return e|0}function Me(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+16|0;e=b;f=b+4|0;if((Yw(d,f)|0)!=0){g=1;i=b;return g|0}d=gr(c[a+3484>>2]|0,c[f>>2]|0)|0;if((d|0)==0){g=0;i=b;return g|0}c[e>>2]=c[f>>2];Lw(2,13104,e);Vq(d,1);g=0;i=b;return g|0}function Ne(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+16|0;e=b;f=b+4|0;if((Yw(d,f)|0)!=0){g=1;i=b;return g|0}d=gr(c[a+3484>>2]|0,c[f>>2]|0)|0;if((d|0)==0){g=0;i=b;return g|0}c[e>>2]=c[f>>2];Lw(2,13072,e);Vq(d,0);g=0;i=b;return g|0}function Oe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;i=i+16|0;e=b;f=b+4|0;if((Yw(d,f)|0)!=0){g=1;i=b;return g|0}d=c[f>>2]|0;if((d|0)==0){Lw(2,12992,e);h=a+1760|0;Ad(h,0,1);Ad(h,1,1);Ad(h,2,1);g=0;i=b;return g|0}else{c[e>>2]=d;Lw(2,13032,e);Ad(a+1760|0,(c[f>>2]|0)+ -1|0,1);g=0;i=b;return g|0}return 0}function Pe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0;b=i;i=i+16|0;e=b;f=b+4|0;if((Yw(d,f)|0)!=0){g=1;i=b;return g|0}d=c[f>>2]|0;if((d|0)==0){Lw(2,12912,e);h=a+1760|0;Ad(h,0,0);Ad(h,1,0);Ad(h,2,0);g=0;i=b;return g|0}else{c[e>>2]=d;Lw(2,12952,e);Ad(a+1760|0,(c[f>>2]|0)+ -1|0,0);g=0;i=b;return g|0}return 0}function Qe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;d=i;i=i+16|0;b=d;e=a+1760|0;a=zd(e,0)|0;c[b>>2]=1;c[b+4>>2]=a;pw(12880,b);a=zd(e,1)|0;c[b>>2]=2;c[b+4>>2]=a;pw(12880,b);a=zd(e,2)|0;c[b>>2]=3;c[b+4>>2]=a;pw(12880,b);i=d;return 0}function Re(a,b,d){a=a|0;b=b|0;d=d|0;d=i;c[a+4680>>2]=2;Vw(11152,1);i=d;return 0}function Se(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+16|0;e=b;if((_w(d,e)|0)==0){Yd(a,c[e>>2]|0);f=0}else{f=1}i=b;return f|0}function Te(b,c,d){b=b|0;c=c|0;d=d|0;d=i;Yd(b,(a[b+4676>>0]|0)==0|0);i=d;return 0}function Ue(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;b=i;i=i+16|0;e=b;if((_w(d,e)|0)!=0){f=1;i=b;return f|0}Zd(a,0,(c[e>>2]|0)!=0|0);f=0;i=b;return f|0}function Ve(a,b,d){a=a|0;b=b|0;d=d|0;d=i;if((c[a+4688>>2]|0)==0){Zd(a,0,1);i=d;return 0}else{Zd(a,0,0);i=d;return 0}return 0}function We(a,b,c){a=a|0;b=b|0;c=c|0;c=i;ae(a);i=c;return 0}function Xe(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+16|0;e=b+4|0;f=b;c[e>>2]=d;if((ax(e,f,12864,12872)|0)!=0){g=1;i=b;return g|0}d=c[f>>2]|0;if(d>>>0>1){g=1;i=b;return g|0}g=(Of(a+(d*568|0)+3488|0,c[e>>2]|0)|0)!=0|0;i=b;return g|0}function Ye(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+16|0;e=b+4|0;f=b;c[e>>2]=d;if((ax(e,f,12864,12872)|0)!=0){g=1;i=b;return g|0}d=c[f>>2]|0;if(d>>>0>1){g=1;i=b;return g|0}g=(Pf(a+(d*568|0)+3488|0,c[e>>2]|0)|0)!=0|0;i=b;return g|0}function Ze(a,b,d){a=a|0;b=b|0;d=d|0;d=i;_d(a,12840,12856)|0;c[a+4680>>2]=1;i=d;return 0}function _e(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;b=i;i=i+16|0;e=b;if((Yw(d,e)|0)!=0){f=1;i=b;return f|0}d=c[e>>2]|0;if(d>>>0>999){g=255}else{g=(d<<8>>>0)/1e3|0}c[e>>2]=g;xg(c[a+3476>>2]|0,g);f=0;i=b;return f|0}function $e(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;d=i;i=i+16|0;f=d;if((a[e>>0]|0)==0){g=b+2424|0;if((a[b+2426>>0]|0)==0){h=0;i=d;return h|0}bg(g,1);bg(g,2);bg(g,3);h=0;i=d;return h|0}if((Yw(e,f)|0)!=0){h=1;i=d;return h|0}if((a[b+2426>>0]|0)==0){e=c[f>>2]|0;Fd(b+1760|0,(e|0)==0?0:e+ -1|0);h=0;i=d;return h|0}else{bg(b+2424|0,c[f>>2]|0);h=0;i=d;return h|0}return 0}function af(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=i;i=i+32|0;e=d;f=0;g=b;while(1){b=e+(f<<2)|0;h=a[g>>0]|0;a:do{if((h+ -48<<24>>24&255)>9){j=h;k=g;while(1){l=k+1|0;if(j<<24>>24==0){m=0;n=k;break a}o=a[l>>0]|0;if((o+ -48<<24>>24&255)>9){j=o;k=l}else{p=o;q=l;r=4;break}}}else{p=h;q=g;r=4}}while(0);if((r|0)==4){r=0;if((p+ -48<<24>>24&255)<10){h=p;k=q;j=0;while(1){l=(h<<24>>24)+ -48+(j*10|0)|0;o=k+1|0;s=a[o>>0]|0;if((s+ -48<<24>>24&255)<10){h=s;k=o;j=l}else{m=l;n=o;break}}}else{m=0;n=q}}c[b>>2]=m;f=f+1|0;if((f|0)==6){break}else{g=n}}n=e+4|0;g=c[n>>2]|0;if((g|0)==0){t=0}else{f=g+ -1|0;c[n>>2]=f;t=f}f=e+8|0;n=c[f>>2]|0;if((n|0)==0){u=0}else{g=n+ -1|0;c[f>>2]=g;u=g}g=c[e>>2]|0;if(g>>>0<1904|t>>>0>11){v=0}else{f=g+ -1904|0;g=f&3;n=((f>>>2)*1461|0)+(g*365|0)+((g|0)!=0)|0;f=(g|0)==0?13512|0:13464;if((t|0)==0){w=n}else{g=0;m=n;while(1){n=(c[f+(g<<2)>>2]|0)+m|0;q=g+1|0;if((q|0)==(t|0)){w=n;break}else{g=q;m=n}}}if((c[f+(t<<2)>>2]|0)>>>0>u>>>0){v=(w+u|0)*86400|0}else{v=0}}u=c[e+12>>2]|0;w=c[e+16>>2]|0;t=c[e+20>>2]|0;if(u>>>0>23|w>>>0>59|t>>>0>59){x=0;y=x+v|0;i=d;return y|0}x=(((u*60|0)+w|0)*60|0)+t|0;y=x+v|0;i=d;return y|0}function bf(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;c[b+304>>2]=0;c[b+308>>2]=0;a[b+312>>0]=0;e=b+283|0;f=b+260|0;g=b+16|0;Oz(b|0,0,258)|0;c[f+0>>2]=0;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=0;c[f+16>>2]=0;f=e+0|0;e=f+18|0;do{a[f>>0]=0;f=f+1|0}while((f|0)<(e|0));a[g>>0]=-88;a[b+19>>0]=34;a[b+30>>0]=100;a[b+8>>0]=24;a[b+9>>0]=-120;a[b+11>>0]=32;i=d;return}function cf(a,b,d){a=a|0;b=b|0;d=d|0;c[a+292>>2]=b;c[a+296>>2]=d;return}function df(a,b,d){a=a|0;b=b|0;d=d|0;c[a+304>>2]=b;c[a+308>>2]=d;return}function ef(a,b){a=a|0;b=b|0;c[a+284>>2]=(b|0)!=0;return}function ff(b,c){b=b|0;c=c|0;var d=0,e=0,f=0;d=i;e=Ib(c|0,13456)|0;if((e|0)==0){f=1}else{c=(ta(b|0,1,256,e|0)|0)==256;zb(e|0)|0;if(c){a[b+256>>0]=-128;a[b+257>>0]=0;f=0}else{f=1}}i=d;return f|0}function gf(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0;f=i;g=gb(0)|0;c[a+260>>2]=g+2082844800;if((e|0)==0){e=((d[a+237>>0]|0)<<8|(d[a+238>>0]|0))<<8;h=e|(d[a+239>>0]|0);c[a+264>>2]=-2082844800-g+b-((e&8388608|0)==0?h:h|-16777216);i=f;return}else{c[a+264>>2]=b;i=f;return}}function hf(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0;e=i;if((b|0)==0){c[a+260>>2]=(gb(0)|0)+2082844800;c[a+264>>2]=0;i=e;return}else{f=af(b)|0;b=gb(0)|0;c[a+260>>2]=b+2082844800;g=((d[a+237>>0]|0)<<8|(d[a+238>>0]|0))<<8;h=g|(d[a+239>>0]|0);c[a+264>>2]=f+ -2082844800-b-((g&8388608|0)==0?h:h|-16777216);i=e;return}}function jf(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;g=b+283|0;h=a[g>>0]|0;j=e&255;a[g>>0]=e;if((j&4|0)!=0){c[b+272>>2]=0;c[b+268>>2]=0;c[b+276>>2]=0;i=f;return}if(((j&2^2)&((h^e)&255)|0)==0){i=f;return}e=b+268|0;h=b+282|0;g=a[h>>0]|0;if((c[e>>2]|0)!=0){k=(g&255)>>>7;a[b+300>>0]=k;l=c[b+296>>2]|0;if((l|0)==0){m=g}else{jc[l&255](c[b+292>>2]|0,k);m=a[h>>0]|0}k=m&255;a[h>>0]=k<<1|k>>>7;k=b+276|0;m=(c[k>>2]|0)+1|0;c[k>>2]=m;if(!(m>>>0>7)){i=f;return}c[k>>2]=0;c[e>>2]=0;c[b+272>>2]=0;i=f;return}k=g&255;g=k<<1;m=g|j&1;j=m&255;a[h>>0]=j;l=b+276|0;n=(c[l>>2]|0)+1|0;c[l>>2]=n;if(!(n>>>0>7)){i=f;return}n=b+272|0;o=c[n>>2]|0;do{if((o|0)==3){if((a[b+256>>0]|0)>=0){a[b+(d[b+280>>0]<<5&224|(d[b+281>>0]|0)>>>2&31)>>0]=j}c[n>>2]=0}else if((o|0)==1){p=a[b+280>>0]|0;q=p&255;do{if(p<<24>>24==53){a[b+256>>0]=g&128}else{if((a[b+256>>0]|0)>=0){if((q&227|0)==1){r=q<<1&24;s=b+260|0;c[s>>2]=c[s>>2]&~(255<<r)|(m&255)<<r;break}if((q&243|0)==33){a[b+(q>>>2&3|8)>>0]=j;break}if(p<<24>>24==49){a[b+257>>0]=j;break}if((q&195|0)==65){a[b+(q>>>2&15|16)>>0]=j}}}}while(0);c[n>>2]=0}else if((o|0)==0){a[b+280>>0]=j;if((g&120|0)==56){c[n>>2]=2;break}if((g&128|0)==0){c[n>>2]=1;break}q=k>>>1;do{if((m&227|0)==129){a[h>>0]=(c[b+260>>2]|0)>>>(q<<3&24)}else{if((m&243|0)==161){a[h>>0]=a[b+(q&3|8)>>0]|0;break}if((m&195|0)==193){a[h>>0]=a[b+(q&15|16)>>0]|0;break}else{a[h>>0]=0;break}}}while(0);c[n>>2]=0;c[e>>2]=1}else if((o|0)==2){a[b+281>>0]=j;q=a[b+280>>0]|0;if(q<<24>>24<0){a[h>>0]=a[b+((q&255)<<5&224|k>>>1&31)>>0]|0;c[n>>2]=0;c[e>>2]=1;break}else{c[n>>2]=3;break}}}while(0);c[l>>2]=0;i=f;return}function kf(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=b+260|0;h=c[g>>2]|0;if((c[b+284>>2]|0)==0){j=b+288|0;k=(c[j>>2]|0)+e|0;c[j>>2]=k;if(k>>>0>7833600){c[j>>2]=k+ -7833600;k=h+1|0;c[g>>2]=k;l=k}else{l=h}k=b+264|0;j=l+(c[k>>2]|0)|0;c[g>>2]=j;c[k>>2]=0;m=j}else{j=(gb(0)|0)+2082844800|0;k=(d[b+237>>0]<<8|d[b+238>>0])<<8;l=k|d[b+239>>0];e=((k&8388608|0)==0?l:l|-16777216)+j+(c[b+264>>2]|0)|0;c[g>>2]=e;m=e}if((m|0)==(h|0)){i=f;return}h=b+312|0;if((a[h>>0]|0)!=1){a[h>>0]=1;m=c[b+308>>2]|0;if((m|0)!=0){jc[m&255](c[b+304>>2]|0,1);if((a[h>>0]|0)==0){i=f;return}}}a[h>>0]=0;h=c[b+308>>2]|0;if((h|0)==0){i=f;return}jc[h&255](c[b+304>>2]|0,0);i=f;return}function lf(b){b=b|0;var d=0,e=0;d=i;a[b+9>>0]=0;a[b+10>>0]=0;a[b+11>>0]=0;c[b+16>>2]=0;c[b+20>>2]=0;c[b+40>>2]=0;c[b+44>>2]=0;e=b;c[e>>2]=0;c[e+4>>2]=0;c[b+48>>2]=4096;c[b+52>>2]=yz(4096)|0;c[b+60>>2]=4080;c[b+64>>2]=4;c[b+68>>2]=0;c[b+72>>2]=0;c[b+76>>2]=0;c[b+108>>2]=0;c[b+140>>2]=0;c[b+172>>2]=0;c[b+204>>2]=0;c[b+236>>2]=0;c[b+268>>2]=0;c[b+300>>2]=0;c[b+332>>2]=0;i=d;return}function mf(a,b){a=a|0;b=b|0;c[a+332>>2]=b;return}function nf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;g=d&7;c[b+(g<<5)+76>>2]=1;c[b+(g<<5)+80>>2]=e;e=b+(g<<5)+84|0;d=e;a[d>>0]=541410128;a[d+1>>0]=2114883;a[d+2>>0]=8261;a[d+3>>0]=32;d=e+4|0;a[d>>0]=538976288;a[d+1>>0]=2105376;a[d+2>>0]=8224;a[d+3>>0]=32;d=b+(g<<5)+92|0;g=13560|0;b=d+16|0;do{a[d>>0]=a[g>>0]|0;d=d+1|0;g=g+1|0}while((d|0)<(b|0));i=f;return}function of(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;f=c&7;c=a[d>>0]|0;if(c<<24>>24==0){a[b+(f<<5)+84>>0]=32;g=d}else{a[b+(f<<5)+84>>0]=c;g=d+1|0}d=a[g>>0]|0;if(d<<24>>24==0){a[b+(f<<5)+85>>0]=32;h=g}else{a[b+(f<<5)+85>>0]=d;h=g+1|0}g=a[h>>0]|0;if(g<<24>>24==0){a[b+(f<<5)+86>>0]=32;j=h}else{a[b+(f<<5)+86>>0]=g;j=h+1|0}h=a[j>>0]|0;if(h<<24>>24==0){a[b+(f<<5)+87>>0]=32;k=j}else{a[b+(f<<5)+87>>0]=h;k=j+1|0}j=a[k>>0]|0;if(j<<24>>24==0){a[b+(f<<5)+88>>0]=32;l=k}else{a[b+(f<<5)+88>>0]=j;l=k+1|0}k=a[l>>0]|0;if(k<<24>>24==0){a[b+(f<<5)+89>>0]=32;m=l}else{a[b+(f<<5)+89>>0]=k;m=l+1|0}l=a[m>>0]|0;if(l<<24>>24==0){a[b+(f<<5)+90>>0]=32;n=m;o=a[n>>0]|0;p=o<<24>>24==0;q=b+(f<<5)+91|0;r=p?32:o;a[q>>0]=r;i=e;return}else{a[b+(f<<5)+90>>0]=l;n=m+1|0;o=a[n>>0]|0;p=o<<24>>24==0;q=b+(f<<5)+91|0;r=p?32:o;a[q>>0]=r;i=e;return}}function pf(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=c&7;c=d;d=0;while(1){g=a[c>>0]|0;if(g<<24>>24==0){a[b+(f<<5)+d+92>>0]=32;h=c}else{a[b+(f<<5)+d+92>>0]=g;h=c+1|0}d=d+1|0;if((d|0)==16){break}else{c=h}}i=e;return}function qf(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+16|0;g=f;h=(c[b+60>>2]&e)>>>(c[b+64>>2]|0);switch(h|0){case 38:case 6:{if((c[b>>2]|0)==5){e=b+40|0;j=c[e>>2]|0;k=c[b+44>>2]|0;if(j>>>0<k>>>0){l=a[(c[b+52>>2]|0)+j>>0]|0;m=j+1|0;c[e>>2]=m;if(m>>>0<k>>>0){n=l}else{c[b>>2]=7;k=b+9|0;a[k>>0]=a[k>>0]&131|108;a[b+5>>0]=0;n=l}}else{n=0}}else{n=0}break};case 1:{n=a[b+6>>0]|0;break};case 4:{n=a[b+9>>0]|0;break};case 32:{if((c[b>>2]|0)==5){l=b+40|0;k=c[l>>2]|0;m=c[b+44>>2]|0;if(k>>>0<m>>>0){e=a[(c[b+52>>2]|0)+k>>0]|0;j=k+1|0;c[l>>2]=j;if(j>>>0<m>>>0){n=e}else{c[b>>2]=7;m=b+9|0;a[m>>0]=a[m>>0]&131|108;a[b+5>>0]=0;n=e}}else{n=0}}else{n=0}break};case 3:{n=(d[b+8>>0]|0)&15;break};case 7:{n=-1;break};case 0:{n=a[b+5>>0]|0;break};case 2:{n=a[b+7>>0]|0;break};case 5:{e=b+11|0;m=d[e>>0]|0;j=((((d[b+9>>0]|0)>>>2^(d[b+8>>0]|0))&7|0)==0?m|8:m&247)&255;a[e>>0]=j;n=j;break};default:{c[g>>2]=h;c[g+4>>2]=255;te(13584,g);n=-1}}i=f;return n|0}function rf(a,b){a=a|0;b=b|0;return 0}function sf(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+16|0;h=g;j=(c[b+60>>2]&e)>>>(c[b+64>>2]|0);switch(j|0){case 7:case 6:{i=g;return};case 2:{e=b+7|0;k=f&255;l=a[e>>0]^f;a[e>>0]=f;e=c[b>>2]|0;do{if((e|0)==0){if(!((f&1&l)<<24>>24==0)){c[b>>2]=1;a[b+5>>0]=a[b+4>>0]|0;m=b+6|0;a[m>>0]=d[m>>0]|0|64}}else if((e|0)==2){if((l&255&(k&1^1)|0)!=0){m=d[b+4>>0]|0;n=m&127;if((n|0)!=0&(m&1|0)==0){m=n;n=0;while(1){o=n+1|0;p=m>>>1;if((p|0)!=0&(p&1|0)==0){m=p;n=o}else{q=o;break}}}else{q=0}c[b+56>>2]=q;n=b+6|0;a[n>>0]=a[n>>0]&247;n=q&7;if((c[b+(n<<5)+76>>2]|0)!=0){m=c[b+(n<<5)+80>>2]|0;if((m|0)!=65535){if((gr(c[b+332>>2]|0,m)|0)!=0){c[b>>2]=4;m=b+9|0;a[m>>0]=a[m>>0]&131|104;c[b+16>>2]=0;c[b+20>>2]=16;break}}}c[b>>2]=0;m=b+9|0;a[m>>0]=a[m>>0]&131}}else if((e|0)==5){if(!((f&2&l)<<24>>24==0)){if((c[b+40>>2]|0)>>>0<(c[b+44>>2]|0)>>>0){m=b+11|0;a[m>>0]=d[m>>0]|0|64}}}else if((e|0)==6){if(!((f&2&l)<<24>>24==0)){if((c[b+40>>2]|0)>>>0<(c[b+44>>2]|0)>>>0){m=b+11|0;a[m>>0]=d[m>>0]|0|64}}}}while(0);if((l&255&(k&2^2)|0)==0){i=g;return}k=b+11|0;a[k>>0]=a[k>>0]&191;i=g;return};case 3:{k=b+8|0;l=a[k>>0]|0;a[k>>0]=f;if((f&2&(l^2))<<24>>24==0){i=g;return}l=c[b>>2]|0;if((l|0)==5){c[b>>2]=7;k=b+9|0;a[k>>0]=a[k>>0]&131|108;a[b+5>>0]=0;i=g;return}else if((l|0)==6){c[b>>2]=7;l=b+9|0;a[l>>0]=a[l>>0]&131|108;a[b+5>>0]=0;i=g;return}else{i=g;return}break};case 4:{a[b+10>>0]=f;i=g;return};case 5:{l=b+11|0;a[l>>0]=d[l>>0]|0|64;i=g;return};case 1:{l=f&255;k=l&159;e=b+6|0;q=(d[e>>0]|0)^k;a[e>>0]=k;switch(c[b>>2]|0){case 1:{if((l&4&q|0)==0){i=g;return}c[b>>2]=2;i=g;return};case 6:{k=l&16;if((q&k|0)!=0){e=b+40|0;m=c[e>>2]|0;if(m>>>0<(c[b+44>>2]|0)>>>0){a[(c[b+52>>2]|0)+m>>0]=a[b+4>>0]|0;c[e>>2]=(c[e>>2]|0)+1}e=b+9|0;a[e>>0]=a[e>>0]&223}if((q&(k^16)|0)==0){i=g;return}if((c[b+40>>2]|0)>>>0<(c[b+44>>2]|0)>>>0){k=b+9|0;a[k>>0]=d[k>>0]|0|32;i=g;return}else{c[b>>2]=7;k=b+9|0;a[k>>0]=a[k>>0]&131|108;a[b+5>>0]=2;i=g;return}break};case 5:{k=l&16;if((q&k|0)!=0){e=b+9|0;a[e>>0]=a[e>>0]&223}if((q&(k^16)|0)==0){i=g;return}k=b+40|0;e=(c[k>>2]|0)+1|0;c[k>>2]=e;if(e>>>0<(c[b+44>>2]|0)>>>0){a[b+5>>0]=a[(c[b+52>>2]|0)+e>>0]|0;e=b+9|0;a[e>>0]=d[e>>0]|0|32;i=g;return}else{c[b>>2]=7;e=b+9|0;a[e>>0]=a[e>>0]&131|108;a[b+5>>0]=0;i=g;return}break};case 7:{e=l&16;if((q&e|0)!=0){k=b+9|0;a[k>>0]=a[k>>0]&223}if((q&(e^16)|0)==0){i=g;return}c[b>>2]=8;e=b+9|0;a[e>>0]=d[e>>0]|0|124;a[b+5>>0]=0;i=g;return};case 4:{e=l&16;if((q&e|0)!=0){k=b+16|0;m=c[k>>2]|0;n=b+20|0;if(m>>>0<(c[n>>2]|0)>>>0){a[b+m+24>>0]=a[b+4>>0]|0;o=(c[k>>2]|0)+1|0;c[k>>2]=o;r=o}else{r=m}a:do{if((r|0)==1){m=a[b+24>>0]|0;o=b+68|0;c[o>>2]=0;c[b+72>>2]=0;k=m&255;do{switch(k|0){case 10:{c[n>>2]=6;c[o>>2]=223;break a;break};case 18:{c[n>>2]=6;c[o>>2]=224;break a;break};case 4:{c[n>>2]=6;c[o>>2]=221;break a;break};case 8:{c[n>>2]=6;c[o>>2]=222;break a;break};case 27:{c[n>>2]=6;c[o>>2]=227;break a;break};case 37:{c[n>>2]=10;c[o>>2]=228;break a;break};case 21:{c[n>>2]=6;c[o>>2]=225;break a;break};case 26:{c[n>>2]=6;c[o>>2]=226;break a;break};case 0:{c[n>>2]=6;c[o>>2]=219;break a;break};case 3:{c[n>>2]=6;c[o>>2]=220;break a;break};case 47:{c[n>>2]=10;c[o>>2]=231;break a;break};case 60:{c[n>>2]=6;c[o>>2]=232;break a;break};case 40:{c[n>>2]=10;c[o>>2]=229;break a;break};case 42:{c[n>>2]=10;c[o>>2]=230;break a;break};default:{c[h>>2]=k;te(13648,h);c[b>>2]=7;m=b+9|0;a[m>>0]=a[m>>0]&131|108;a[b+5>>0]=2;break a}}}while(0)}}while(0);n=b+9|0;a[n>>0]=a[n>>0]&223}if((q&(e^16)|0)==0){i=g;return}if((c[b+16>>2]|0)>>>0<(c[b+20>>2]|0)>>>0){e=b+9|0;a[e>>0]=d[e>>0]|0|32;i=g;return}e=c[b+68>>2]|0;if((e|0)==0){c[b>>2]=7;n=b+9|0;a[n>>0]=a[n>>0]&131|108;a[b+5>>0]=2;i=g;return}else{ic[e&511](b);i=g;return}break};case 8:{e=l&16;if((q&e|0)!=0){l=b+9|0;a[l>>0]=a[l>>0]&223}if((q&(e^16)|0)==0){i=g;return}c[b>>2]=0;e=b+9|0;a[e>>0]=a[e>>0]&131;i=g;return};default:{i=g;return}}break};case 0:{a[b+4>>0]=f;i=g;return};case 32:{if((c[b>>2]|0)!=6){i=g;return}e=b+40|0;q=c[e>>2]|0;l=b+44|0;if(!(q>>>0<(c[l>>2]|0)>>>0)){i=g;return}a[(c[b+52>>2]|0)+q>>0]=f;q=(c[e>>2]|0)+1|0;c[e>>2]=q;if(q>>>0<(c[l>>2]|0)>>>0){i=g;return}l=c[b+72>>2]|0;if((l|0)==0){c[b>>2]=7;q=b+9|0;a[q>>0]=a[q>>0]&131|108;a[b+5>>0]=2;i=g;return}else{ic[l&511](b);i=g;return}break};default:{c[h>>2]=j;c[h+4>>2]=f&255;te(13616,h);i=g;return}}}function tf(a,b,c){a=a|0;b=b|0;c=c|0;return}function uf(b){b=b|0;var d=0;a[b+9>>0]=0;a[b+10>>0]=0;d=b;c[d>>2]=0;c[d+4>>2]=0;a[b+11>>0]=8;a[b+12>>0]=0;c[b+16>>2]=0;c[b+20>>2]=0;c[b+40>>2]=0;c[b+44>>2]=0;c[b+68>>2]=0;c[b+72>>2]=0;return}function vf(b){b=b|0;var d=0;c[b>>2]=7;d=b+9|0;a[d>>0]=a[d>>0]&131|108;a[b+5>>0]=0;return}function wf(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;e=b+52|0;f=(c[e>>2]|0)+0|0;g=f+13|0;do{a[f>>0]=0;f=f+1|0}while((f|0)<(g|0));a[c[e>>2]>>0]=-16;c[b+40>>2]=0;c[b+44>>2]=13;c[b>>2]=5;f=b+9|0;a[f>>0]=a[f>>0]&131|100;a[b+5>>0]=a[c[e>>2]>>0]|0;i=d;return}function xf(b){b=b|0;var d=0;c[b>>2]=7;d=b+9|0;a[d>>0]=a[d>>0]&131|108;a[b+5>>0]=0;return}function yf(b){b=b|0;var c=0,e=0;c=i;e=a[b+28>>0]|0;Lf(b,((d[b+25>>0]|0)<<8&7936|(d[b+26>>0]|0))<<8|(d[b+27>>0]|0),e<<24>>24==0?256:e&255);i=c;return}function zf(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+16|0;e=d;f=a[b+28>>0]|0;g=f<<24>>24==0?256:f&255;f=g<<9;h=b+48|0;do{if((c[h>>2]|0)>>>0<f>>>0){j=b+52|0;k=Az(c[j>>2]|0,f)|0;if((k|0)!=0){c[j>>2]=k;c[h>>2]=f;break}c[e>>2]=g;te(13680,e);c[b>>2]=7;k=b+9|0;a[k>>0]=a[k>>0]&131|108;a[b+5>>0]=2;i=d;return}}while(0);c[b+40>>2]=0;c[b+44>>2]=f;c[b+72>>2]=233;c[b>>2]=6;f=b+9|0;a[f>>0]=a[f>>0]&131|96;i=d;return}function Af(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b+((c[b+56>>2]&7)<<5)+76|0;g=(c[f>>2]|0)==0;h=g?0:f;f=b+52|0;Oz(c[f>>2]|0,0,256)|0;if(!g){g=h+8|0;j=g;k=d[j>>0]|d[j+1>>0]<<8|d[j+2>>0]<<16|d[j+3>>0]<<24;j=g+4|0;g=d[j>>0]|d[j+1>>0]<<8|d[j+2>>0]<<16|d[j+3>>0]<<24;j=(c[f>>2]|0)+8|0;l=j;a[l>>0]=k;a[l+1>>0]=k>>8;a[l+2>>0]=k>>16;a[l+3>>0]=k>>24;k=j+4|0;a[k>>0]=g;a[k+1>>0]=g>>8;a[k+2>>0]=g>>16;a[k+3>>0]=g>>24;g=(c[f>>2]|0)+16|0;k=h+16|0;h=g+16|0;do{a[g>>0]=a[k>>0]|0;g=g+1|0;k=k+1|0}while((g|0)<(h|0))}a[(c[f>>2]|0)+4>>0]=32;c[b+40>>2]=0;k=a[b+28>>0]|0;c[b+44>>2]=(k&255)<36?k&255:36;c[b>>2]=5;k=b+9|0;a[k>>0]=a[k>>0]&131|100;a[b+5>>0]=a[c[f>>2]>>0]|0;i=e;return}function Bf(b){b=b|0;var d=0;c[b+40>>2]=0;c[b+44>>2]=0;c[b>>2]=6;d=b+9|0;a[d>>0]=a[d>>0]&131|96;return}function Cf(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;i=i+16|0;f=e;g=c[b+56>>2]&7;if((c[b+(g<<5)+76>>2]|0)!=0){h=c[b+(g<<5)+80>>2]|0;if((h|0)!=65535){g=gr(c[b+332>>2]|0,h)|0;if((g|0)!=0){h=b+52|0;Oz(c[h>>2]|0,0,512)|0;j=b+40|0;c[j>>2]=0;k=b+44|0;c[k>>2]=0;l=d[b+26>>0]|0;m=l&63;if((m|0)==1){a[c[h>>2]>>0]=1;a[(c[h>>2]|0)+1>>0]=10;c[k>>2]=12}else if((m|0)==3){a[c[h>>2]>>0]=3;a[(c[h>>2]|0)+1>>0]=22;c[k>>2]=24}else if((m|0)==48){a[c[h>>2]>>0]=48;a[(c[h>>2]|0)+1>>0]=33;n=(c[h>>2]|0)+14|0;o=13936|0;p=n+20|0;do{a[n>>0]=a[o>>0]|0;n=n+1|0;o=o+1|0}while((n|0)<(p|0));c[k>>2]=34}else if((m|0)==4){a[c[h>>2]>>0]=4;a[(c[h>>2]|0)+1>>0]=22;a[(c[h>>2]|0)+2>>0]=0;bq(c[h>>2]|0,3,c[g+32>>2]&65535);a[(c[h>>2]|0)+5>>0]=c[g+36>>2];bq(c[h>>2]|0,20,3600);c[k>>2]=32}else{c[f>>2]=l;te(13960,f);if((c[k>>2]|0)==0){c[b>>2]=7;k=b+9|0;a[k>>0]=a[k>>0]&131|108;a[b+5>>0]=2;i=e;return}}c[b>>2]=5;k=b+9|0;a[k>>0]=a[k>>0]&131|100;a[b+5>>0]=a[(c[h>>2]|0)+(c[j>>2]|0)>>0]|0;i=e;return}}}c[b>>2]=7;j=b+9|0;a[j>>0]=a[j>>0]&131|108;a[b+5>>0]=2;i=e;return}function Df(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;i=i+16|0;e=d;f=a[b+28>>0]&3;if((f|0)==2){g=13872}else if((f|0)==0){g=13840}else if((f|0)==3){g=13888}else if((f|0)==1){g=13856}else{g=0}c[e>>2]=c[b+56>>2];c[e+4>>2]=g;te(13904,e);c[b>>2]=7;e=b+9|0;a[e>>0]=a[e>>0]&131|108;a[b+5>>0]=0;i=d;return}function Ef(b){b=b|0;var d=0,e=0,f=0;d=i;e=c[b+56>>2]&7;if((c[b+(e<<5)+76>>2]|0)!=0){f=c[b+(e<<5)+80>>2]|0;if((f|0)!=65535){e=gr(c[b+332>>2]|0,f)|0;if((e|0)!=0){f=_q(e)|0;e=b+52|0;cq(c[e>>2]|0,0,f+ -1|0);cq(c[e>>2]|0,4,512);c[b+40>>2]=0;c[b+44>>2]=8;c[b>>2]=5;f=b+9|0;a[f>>0]=a[f>>0]&131|100;a[b+5>>0]=a[c[e>>2]>>0]|0;i=d;return}}}c[b>>2]=7;e=b+9|0;a[e>>0]=a[e>>0]&131|108;a[b+5>>0]=2;i=d;return}function Ff(a){a=a|0;var b=0;b=i;Lf(a,(((d[a+26>>0]|0)<<8|(d[a+27>>0]|0))<<8|(d[a+28>>0]|0))<<8|(d[a+29>>0]|0),(d[a+31>>0]|0)<<8|(d[a+32>>0]|0));i=b;return}function Gf(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;i=i+16|0;f=e;g=(d[b+31>>0]|0)<<8|(d[b+32>>0]|0);h=g<<9;j=b+48|0;do{if((c[j>>2]|0)>>>0<h>>>0){k=b+52|0;l=Az(c[k>>2]|0,h)|0;if((l|0)!=0){c[k>>2]=l;c[j>>2]=h;break}c[f>>2]=g;te(13680,f);c[b>>2]=7;l=b+9|0;a[l>>0]=a[l>>0]&131|108;a[b+5>>0]=2;i=e;return}}while(0);c[b+40>>2]=0;c[b+44>>2]=h;c[b+72>>2]=234;c[b>>2]=6;h=b+9|0;a[h>>0]=a[h>>0]&131|96;i=e;return}function Hf(b){b=b|0;var d=0,e=0,f=0;d=i;e=c[b+56>>2]&7;if((c[b+(e<<5)+76>>2]|0)!=0){f=c[b+(e<<5)+80>>2]|0;if((f|0)!=65535){if((gr(c[b+332>>2]|0,f)|0)!=0){c[b+40>>2]=0;c[b+44>>2]=0;c[b>>2]=7;f=b+9|0;a[f>>0]=a[f>>0]&131|108;a[b+5>>0]=0;i=d;return}}}c[b>>2]=7;f=b+9|0;a[f>>0]=a[f>>0]&131|108;a[b+5>>0]=2;i=d;return}function If(b){b=b|0;var d=0,e=0,f=0;d=i;e=b+52|0;Oz(c[e>>2]|0,0,512)|0;c[b+40>>2]=0;c[b+44>>2]=4;c[b>>2]=5;f=b+9|0;a[f>>0]=a[f>>0]&131|100;a[b+5>>0]=a[c[e>>2]>>0]|0;i=d;return}function Jf(a){a=a|0;var b=0;b=i;Kf(a,(((d[a+26>>0]|0)<<8|(d[a+27>>0]|0))<<8|(d[a+28>>0]|0))<<8|(d[a+29>>0]|0),(d[a+31>>0]|0)<<8|(d[a+32>>0]|0));i=b;return}function Kf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+16|0;g=f;h=c[b+56>>2]&7;if((c[b+(h<<5)+76>>2]|0)!=0){j=c[b+(h<<5)+80>>2]|0;if((j|0)!=65535){h=gr(c[b+332>>2]|0,j)|0;if((h|0)!=0){j=e<<9;k=b+40|0;l=c[k>>2]|0;if((j|0)!=(l|0)){c[g>>2]=j;c[g+4>>2]=l;te(13712,g);c[b>>2]=7;l=b+9|0;a[l>>0]=a[l>>0]&131|108;a[b+5>>0]=2;i=f;return}if((cr(h,c[b+52>>2]|0,d,e)|0)==0){c[k>>2]=0;c[b+44>>2]=0;c[b+72>>2]=0;c[b>>2]=7;k=b+9|0;a[k>>0]=a[k>>0]&131|108;a[b+5>>0]=0;i=f;return}else{te(13752,g);c[b>>2]=7;g=b+9|0;a[g>>0]=a[g>>0]&131|108;a[b+5>>0]=2;i=f;return}}}}c[b>>2]=7;g=b+9|0;a[g>>0]=a[g>>0]&131|108;a[b+5>>0]=2;i=f;return}function Lf(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f;h=c[b+56>>2]&7;if((c[b+(h<<5)+76>>2]|0)!=0){j=c[b+(h<<5)+80>>2]|0;if((j|0)!=65535){h=gr(c[b+332>>2]|0,j)|0;if((h|0)!=0){j=e<<9;k=b+48|0;l=b+52|0;m=c[l>>2]|0;do{if((c[k>>2]|0)>>>0<j>>>0){n=Az(m,j)|0;if((n|0)!=0){c[l>>2]=n;c[k>>2]=j;o=n;break}c[g>>2]=e;te(13776,g);c[b>>2]=7;n=b+9|0;a[n>>0]=a[n>>0]&131|108;a[b+5>>0]=2;i=f;return}else{o=m}}while(0);if((br(h,o,d,e)|0)==0){c[b+40>>2]=0;c[b+44>>2]=j;c[b>>2]=5;j=b+9|0;a[j>>0]=a[j>>0]&131|100;a[b+5>>0]=a[c[b+52>>2]>>0]|0;i=f;return}else{c[g>>2]=d;c[g+4>>2]=e;te(13808,g);c[b>>2]=7;g=b+9|0;a[g>>0]=a[g>>0]&131|108;a[b+5>>0]=2;i=f;return}}}}c[b>>2]=7;g=b+9|0;a[g>>0]=a[g>>0]&131|108;a[b+5>>0]=2;i=f;return}function Mf(b){b=b|0;var c=0,e=0;c=i;e=a[b+28>>0]|0;Kf(b,((d[b+25>>0]|0)<<8&7936|(d[b+26>>0]|0))<<8|(d[b+27>>0]|0),e<<24>>24==0?256:e&255);i=c;return}function Nf(a){a=a|0;var b=0,d=0;b=i;c[a+300>>2]=0;c[a+304>>2]=0;c[a+564>>2]=0;d=a+0|0;a=d+44|0;do{c[d>>2]=0;d=d+4|0}while((d|0)<(a|0));i=b;return}function Of(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a+564|0;a=c[e>>2]|0;if((a|0)!=0){Pr(a)}a=Vr(b)|0;c[e>>2]=a;i=d;return(a|0)==0|0}function Pf(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=fx(14008,b)|0;b=a+564|0;a=c[b>>2]|0;if((a|0)!=0){Pr(a)}a=Vr(e)|0;c[b>>2]=a;zz(e);i=d;return(a|0)==0|0}function Qf(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;c[a>>2]=b;f=a+4|0;c[f>>2]=d;lp(b,d,a,164);mp(b,d,a,165);np(b,d,a,166);op(b,d,a,1);Dp(c[a>>2]|0,c[f>>2]|0,1);i=e;return}function Rf(a,b){a=a|0;b=b|0;b=i;Xf(a);i=b;return}function Sf(a,b){a=a|0;b=b|0;b=i;Wf(a);i=b;return}function Tf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=a+32|0;f=b&255;if((c[e>>2]|0)==(f|0)){i=d;return}c[e>>2]=b<<24>>24!=0;Tr(c[a+564>>2]|0,f)|0;i=d;return}function Uf(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;h=f>>>1;c[a+12>>2]=b;c[a+16>>2]=d;c[a+20>>2]=e;c[a+24>>2]=h;Ur(c[a+564>>2]|0,b,e,d,h)|0;i=g;return}function Vf(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;Wf(a);Xf(a);Dp(c[a>>2]|0,c[a+4>>2]|0,1);e=a+8|0;f=(c[e>>2]|0)+(b*15|0)|0;c[e>>2]=f;Jp(c[a>>2]|0,f>>>5);c[e>>2]=c[e>>2]&31;i=d;return}function Wf(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=b+304|0;f=c[e>>2]|0;if((f|0)!=0){g=b+300|0;h=Rr(c[b+564>>2]|0,b+(c[g>>2]|0)+308|0,f)|0;c[g>>2]=(c[g>>2]|0)+h;f=c[e>>2]|0;c[e>>2]=f-h;if((f|0)==(h|0)){c[g>>2]=0}if((f|0)!=(h|0)){i=d;return}}h=b+4|0;a:do{if((Hp(c[b>>2]|0,c[h>>2]|0)|0)==0){f=b+300|0;g=b+564|0;while(1){j=Fp(c[b>>2]|0,c[h>>2]|0)|0;a[b+((c[e>>2]|0)+(c[f>>2]|0))+308>>0]=j;j=(c[e>>2]|0)+1|0;c[e>>2]=j;k=c[f>>2]|0;if(!((k+j|0)>>>0<256|(j|0)==0)){l=Rr(c[g>>2]|0,b+k+308|0,j)|0;c[f>>2]=(c[f>>2]|0)+l;j=c[e>>2]|0;c[e>>2]=j-l;if((j|0)==(l|0)){c[f>>2]=0}if((j|0)!=(l|0)){break}}if((Hp(c[b>>2]|0,c[h>>2]|0)|0)!=0){break a}}i=d;return}}while(0);h=c[e>>2]|0;if((h|0)==0){i=d;return}f=b+300|0;g=Rr(c[b+564>>2]|0,b+(c[f>>2]|0)+308|0,h)|0;c[f>>2]=(c[f>>2]|0)+g;h=c[e>>2]|0;c[e>>2]=h-g;if((h|0)!=(g|0)){i=d;return}c[f>>2]=0;i=d;return}function Xf(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;e=b+36|0;f=b+4|0;if((Gp(c[b>>2]|0,c[f>>2]|0)|0)!=0){i=d;return}g=b+40|0;h=b+564|0;while(1){if((c[g>>2]|0)==0){c[e>>2]=0;j=Qr(c[h>>2]|0,b+44|0,256)|0;k=(c[g>>2]|0)+j|0;c[g>>2]=k;if((k|0)==0){l=6;break}}Ep(c[b>>2]|0,c[f>>2]|0,a[b+(c[e>>2]|0)+44>>0]|0);c[e>>2]=(c[e>>2]|0)+1;c[g>>2]=(c[g>>2]|0)+ -1;if((Gp(c[b>>2]|0,c[f>>2]|0)|0)!=0){l=6;break}}if((l|0)==6){i=d;return}}function Yf(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;a[b>>0]=0;a[b+1>>0]=0;a[b+2>>0]=(d|0)!=0|0;d=b+4|0;c[b+64>>2]=0;b=d+0|0;f=b+56|0;do{c[b>>2]=0;b=b+4|0}while((b|0)<(f|0));a[d+56>>0]=0;i=e;return}function Zf(a,b){a=a|0;b=b|0;c[a+4>>2]=b;return}function _f(a,b){a=a|0;b=b|0;c[a+8>>2]=b;return}function $f(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+16|0;e=d;if((a[b+2>>0]|0)==0){i=d;return}f=b+1|0;if((a[f>>0]|0)!=0){i=d;return}a[f>>0]=1;f=b+132|0;c[f>>2]=0;g=b+136|0;c[g>>2]=0;h=b+4|0;if((mq(c[h>>2]|0,16252928)|0)==1346585944){if((mq(c[h>>2]|0,16252936)|0)>>>0<4){j=5}else{c[b+44>>2]=(mq(c[h>>2]|0,16252944)|0)+16252928;c[b+48>>2]=(mq(c[h>>2]|0,16252948)|0)+16252928;c[b+52>>2]=(mq(c[h>>2]|0,16252952)|0)+16252928;k=(mq(c[h>>2]|0,16252940)|0)+16252928|0;c[f>>2]=k;if((k|0)!=0){c[e>>2]=k;Nw(2,14024,14064,e);k=1048576;l=4194304;while(1){m=l+1|0;n=k+ -1|0;if((lq(c[h>>2]|0,l)|0)<<16>>16==1326){if((mq(c[h>>2]|0,l+2|0)|0)==1399811705){o=l+ -18|0;if((lq(c[h>>2]|0,o)|0)<<16>>16==20224){j=14;break}}}if((n|0)==0){j=11;break}else{k=n;l=m}}if((j|0)==11){c[g>>2]=0}else if((j|0)==14){c[g>>2]=o;if((o|0)!=0){c[e>>2]=o;Nw(2,14024,14120,e);o=c[g>>2]|0;if((o|0)==0){i=d;return}if((c[f>>2]|0)==0){i=d;return}l=o;o=b+140|0;b=0;while(1){k=(b<<1)+8|0;m=(lq(c[h>>2]|0,k+l|0)|0)&65535;n=(c[g>>2]|0)+m|0;m=lq(c[h>>2]|0,(c[f>>2]|0)+k|0)|0;k=c[f>>2]|0;a[o>>0]=kq(c[h>>2]|0,n)|0;p=n+1|0;a[o+1>>0]=kq(c[h>>2]|0,p)|0;q=n+2|0;a[o+2>>0]=kq(c[h>>2]|0,q)|0;r=n+3|0;a[o+3>>0]=kq(c[h>>2]|0,r)|0;s=n+4|0;a[o+4>>0]=kq(c[h>>2]|0,s)|0;t=n+5|0;a[o+5>>0]=kq(c[h>>2]|0,t)|0;u=k+(m&65535)|0;nq(c[h>>2]|0,n,78);nq(c[h>>2]|0,p,-7);nq(c[h>>2]|0,q,u>>>24&255);nq(c[h>>2]|0,r,u>>>16&255);nq(c[h>>2]|0,s,u>>>8&255);nq(c[h>>2]|0,t,u&255);u=b+1|0;if((u|0)==5){break}l=c[g>>2]|0;o=o+6|0;b=u}i=d;return}}Nw(0,14024,14096,e);i=d;return}}}else{j=5}if((j|0)==5){c[f>>2]=0}Nw(0,14024,14032,e);i=d;return}function ag(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=i;if(!(b>>>0<4)){i=e;return}c[a+(b<<2)+12>>2]=d;c[a+(b<<2)+28>>2]=d;i=e;return}function bg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;i=i+16|0;f=e;if((a[b>>0]|0)==0){i=e;return}if((d|0)==0|d>>>0>4){i=e;return}g=gr(c[b+8>>2]|0,d)|0;if((g|0)==0){i=e;return}h=b+4|0;b=mq(c[h>>2]|0,308)|0;if(d>>>0<5){j=(d*66|0)+8+b|0}else{j=b}b=j+3|0;if(!((kq(c[h>>2]|0,b)|0)<<24>>24==0)){i=e;return}c[f>>2]=d;Nw(2,14024,14144,f);oq(c[h>>2]|0,b,1);b=(_q(g)|0)>>>0<1600;f=c[h>>2]|0;d=j+18|0;if(b){oq(f,d,0)}else{oq(f,d,-1)}oq(c[h>>2]|0,j+19|0,-1);d=(Uq(g)|0)==0;g=c[h>>2]|0;h=j+2|0;if(d){oq(g,h,0);i=e;return}else{oq(g,h,-1);i=e;return}}function cg(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;if((a[b>>0]|0)==0){e=0;i=d;return e|0}f=b+8|0;g=b+4|0;h=0;j=0;a:while(1){k=j;do{if(!(k>>>0<4)){e=h;break a}l=b+(k<<2)+28|0;m=c[l>>2]|0;if((m|0)!=0){n=m+ -1|0;c[l>>2]=n;if((n|0)==0){bg(b,k+1|0)}}k=k+1|0}while((gr(c[f>>2]|0,k)|0)==0);n=mq(c[g>>2]|0,308)|0;if((k|0)!=0&k>>>0<5){o=(k*66|0)+8+n|0}else{o=n}n=(kq(c[g>>2]|0,o+3|0)|0)<<24>>24==1;h=n?1:h;j=k}i=d;return e|0}function dg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;e=i;i=i+560|0;f=e;g=e+16|0;h=e+20|0;j=e+24|0;k=e+12|0;l=e+40|0;m=e+28|0;switch(d|0){case 16:{a[b>>0]=1;if((cg(b)|0)==0){n=0;i=e;return n|0}c[b+216>>2]=c[b+44>>2];n=0;i=e;return n|0};case 17:{d=b+4|0;o=b+208|0;p=(lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0)&65535;q=lq(c[d>>2]|0,(c[o>>2]|0)+22|0)|0;r=q&65535;if(q<<16>>16==0|(q&65535)>4){c[b+204>>2]=-56;s=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,-56);if(!((s&512)==0)){n=0;i=e;return n|0}s=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,s)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}s=mq(c[d>>2]|0,308)|0;t=(q&65535)<5;if(t){u=(r*66|0)+8+s|0}else{u=s}s=u+3|0;if((kq(c[d>>2]|0,s)|0)<<24>>24==0){c[b+204>>2]=-65;u=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,-65);if(!((u&512)==0)){n=0;i=e;return n|0}u=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,u)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}oq(c[d>>2]|0,s,2);s=p&255;if((s|0)==2){u=(lq(c[d>>2]|0,(c[o>>2]|0)+44|0)|0)&15;if((u|0)==0){v=mq(c[d>>2]|0,(c[b+212>>2]|0)+16|0)|0}else if((u|0)==3){q=mq(c[d>>2]|0,(c[o>>2]|0)+46|0)|0;v=(mq(c[d>>2]|0,(c[b+212>>2]|0)+16|0)|0)+q|0}else if((u|0)==1){v=mq(c[d>>2]|0,(c[o>>2]|0)+46|0)|0}else{v=0}u=mq(c[d>>2]|0,(c[o>>2]|0)+36|0)|0;q=(mq(c[d>>2]|0,(c[o>>2]|0)+32|0)|0)&16777215;w=lq(c[d>>2]|0,(c[o>>2]|0)+44|0)|0;x=gr(c[b+8>>2]|0,r)|0;if((x|0)==0){c[b+204>>2]=-65;y=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,-65);if(!((y&512)==0)){n=0;i=e;return n|0}y=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,y)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}if(!((w&64)==0)){c[b+204>>2]=0;w=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,0);if(!((w&512)==0)){n=0;i=e;return n|0}w=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,w)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}if((v&511|0)==0){if((u&511|0)==0){w=u>>>9;a:do{if((w|0)!=0){y=v>>>9;z=x+64|0;A=b+56|0;B=m+1|0;C=m+2|0;D=m+3|0;E=m+4|0;F=m+5|0;G=m+6|0;H=m+7|0;I=m+8|0;J=m+9|0;K=m+10|0;L=m+11|0;M=0;while(1){N=M+y|0;if((Sq(x)|0)==6){if((ig(_q(x)|0,N,g,h,j)|0)!=0){break}O=c[g>>2]|0;P=c[h>>2]|0;Q=c[j>>2]|0;sq(c[z>>2]|0,m,12,O,P,Q,0)|0;c[k>>2]=512;if((rq(c[z>>2]|0,l,k,O,P,Q,0)|0)!=0){R=34;break}}else{S=m+0|0;T=S+12|0;do{a[S>>0]=0;S=S+1|0}while((S|0)<(T|0));if((br(x,l,N,1)|0)!=0){break}}U=(M<<9)+q|0;V=0;do{oq(c[d>>2]|0,U+V|0,a[l+V>>0]|0);V=V+1|0}while((V|0)!=512);oq(c[d>>2]|0,764,a[m>>0]|0);oq(c[d>>2]|0,765,a[B>>0]|0);oq(c[d>>2]|0,766,a[C>>0]|0);oq(c[d>>2]|0,767,a[D>>0]|0);oq(c[d>>2]|0,768,a[E>>0]|0);oq(c[d>>2]|0,769,a[F>>0]|0);oq(c[d>>2]|0,770,a[G>>0]|0);oq(c[d>>2]|0,771,a[H>>0]|0);oq(c[d>>2]|0,772,a[I>>0]|0);oq(c[d>>2]|0,773,a[J>>0]|0);oq(c[d>>2]|0,774,a[K>>0]|0);oq(c[d>>2]|0,775,a[L>>0]|0);V=c[A>>2]|0;if((V|0)!=0){U=M*12|0;oq(c[d>>2]|0,V+U|0,a[m>>0]|0);oq(c[d>>2]|0,(U|1)+(c[A>>2]|0)|0,a[B>>0]|0);oq(c[d>>2]|0,(U|2)+(c[A>>2]|0)|0,a[C>>0]|0);oq(c[d>>2]|0,(U|3)+(c[A>>2]|0)|0,a[D>>0]|0);oq(c[d>>2]|0,U+4+(c[A>>2]|0)|0,a[E>>0]|0);oq(c[d>>2]|0,U+5+(c[A>>2]|0)|0,a[F>>0]|0);oq(c[d>>2]|0,U+6+(c[A>>2]|0)|0,a[G>>0]|0);oq(c[d>>2]|0,U+7+(c[A>>2]|0)|0,a[H>>0]|0);oq(c[d>>2]|0,U+8+(c[A>>2]|0)|0,a[I>>0]|0);oq(c[d>>2]|0,U+9+(c[A>>2]|0)|0,a[J>>0]|0);oq(c[d>>2]|0,U+10+(c[A>>2]|0)|0,a[K>>0]|0);oq(c[d>>2]|0,U+11+(c[A>>2]|0)|0,a[L>>0]|0)}M=M+1|0;if(!(M>>>0<w>>>0)){break a}}if((R|0)==34){c[f>>2]=O;c[f+4>>2]=P;c[f+8>>2]=Q;te(14504,f)}te(14480,f);c[b+204>>2]=-1;M=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,-1);if(!((M&512)==0)){n=0;i=e;return n|0}M=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,M)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}}while(0);Q=mq(c[d>>2]|0,308)|0;if(t){W=(r*66|0)+8+Q|0}else{W=Q}oq(c[d>>2]|0,W+3|0,2);qq(c[d>>2]|0,(c[o>>2]|0)+40|0,u);W=b+212|0;Q=(mq(c[d>>2]|0,(c[W>>2]|0)+16|0)|0)+u|0;qq(c[d>>2]|0,(c[W>>2]|0)+16|0,Q);c[b+204>>2]=0;Q=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,0);if(!((Q&512)==0)){n=0;i=e;return n|0}Q=mq(c[d>>2]|0,308)|0;c[W>>2]=mq(c[d>>2]|0,Q)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}}te(14456,f);c[b+204>>2]=-50;Q=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,-50);if(!((Q&512)==0)){n=0;i=e;return n|0}Q=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,Q)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}else if((s|0)==3){s=(lq(c[d>>2]|0,(c[o>>2]|0)+44|0)|0)&15;if((s|0)==3){Q=mq(c[d>>2]|0,(c[o>>2]|0)+46|0)|0;X=(mq(c[d>>2]|0,(c[b+212>>2]|0)+16|0)|0)+Q|0}else if((s|0)==0){X=mq(c[d>>2]|0,(c[b+212>>2]|0)+16|0)|0}else if((s|0)==1){X=mq(c[d>>2]|0,(c[o>>2]|0)+46|0)|0}else{X=0}s=mq(c[d>>2]|0,(c[o>>2]|0)+36|0)|0;Q=(mq(c[d>>2]|0,(c[o>>2]|0)+32|0)|0)&16777215;W=gr(c[b+8>>2]|0,r)|0;if((W|0)==0){c[b+204>>2]=-65;r=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,-65);if(!((r&512)==0)){n=0;i=e;return n|0}r=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,r)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}if((Uq(W)|0)!=0){c[b+204>>2]=-44;r=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,-44);if(!((r&512)==0)){n=0;i=e;return n|0}r=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,r)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}if((s&511|0)==0){if((X&511|0)==0){S=m+0|0;T=S+12|0;do{a[S>>0]=0;S=S+1|0}while((S|0)<(T|0));r=(lq(c[d>>2]|0,770)|0)&65535;u=s>>>9;b:do{if((u|0)!=0){t=b+56|0;P=X>>>9;O=m+1|0;w=m+2|0;q=m+3|0;x=m+4|0;k=m+5|0;j=m+6|0;h=m+7|0;g=m+8|0;v=m+9|0;M=m+10|0;L=m+11|0;A=0;while(1){K=(A<<9)+Q|0;J=0;do{a[l+J>>0]=kq(c[d>>2]|0,K+J|0)|0;J=J+1|0}while((J|0)!=512);J=c[t>>2]|0;c:do{if((J|0)==0){pq(c[d>>2]|0,770,A+r&65535);a[m>>0]=kq(c[d>>2]|0,764)|0;a[O>>0]=kq(c[d>>2]|0,765)|0;a[w>>0]=kq(c[d>>2]|0,766)|0;a[q>>0]=kq(c[d>>2]|0,767)|0;a[x>>0]=kq(c[d>>2]|0,768)|0;a[k>>0]=kq(c[d>>2]|0,769)|0;a[j>>0]=kq(c[d>>2]|0,770)|0;a[h>>0]=kq(c[d>>2]|0,771)|0;a[g>>0]=kq(c[d>>2]|0,772)|0;a[v>>0]=kq(c[d>>2]|0,773)|0;a[M>>0]=kq(c[d>>2]|0,774)|0;a[L>>0]=kq(c[d>>2]|0,775)|0}else{K=A*12|0;I=J;H=0;while(1){G=kq(c[d>>2]|0,I+K+H|0)|0;a[m+H>>0]=G;oq(c[d>>2]|0,H+764|0,G);G=H+1|0;if((G|0)==12){break c}I=c[t>>2]|0;H=G}}}while(0);J=A;A=A+1|0;if((hg(W,l,m,J+P|0)|0)!=0){break}if(!(A>>>0<u>>>0)){break b}}te(14432,f);c[b+204>>2]=-1;A=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,-1);if(!((A&512)==0)){n=0;i=e;return n|0}A=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,A)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}}while(0);qq(c[d>>2]|0,(c[o>>2]|0)+40|0,s);u=b+212|0;W=(mq(c[d>>2]|0,(c[u>>2]|0)+16|0)|0)+s|0;qq(c[d>>2]|0,(c[u>>2]|0)+16|0,W);c[b+204>>2]=0;W=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,0);if(!((W&512)==0)){n=0;i=e;return n|0}W=mq(c[d>>2]|0,308)|0;c[u>>2]=mq(c[d>>2]|0,W)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}}te(14400,f);c[b+204>>2]=-50;W=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,-50);if(!((W&512)==0)){n=0;i=e;return n|0}W=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,W)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}else{c[f>>2]=p;te(14360,f);c[b+204>>2]=-17;p=lq(c[d>>2]|0,(c[o>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[o>>2]|0)+16|0,-17);if(!((p&512)==0)){n=0;i=e;return n|0}p=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,p)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}break};case 18:{d=b+4|0;p=b+208|0;o=(lq(c[d>>2]|0,(c[p>>2]|0)+26|0)|0)&65535;do{if((o|0)==1){c[b+204>>2]=-27;lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-27);n=0;i=e;return n|0}else if((o|0)==5){W=lq(c[d>>2]|0,(c[p>>2]|0)+22|0)|0;if(W<<16>>16==0|(W&65535)>4){c[b+204>>2]=-56;u=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-56);if(!((u&512)==0)){n=0;i=e;return n|0}u=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,u)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}u=b+204|0;if((gr(c[b+8>>2]|0,W&65535)|0)==0){c[u>>2]=-64;W=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-64);if(!((W&512)==0)){n=0;i=e;return n|0}W=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,W)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}else{c[u>>2]=0;u=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,0);if(!((u&512)==0)){n=0;i=e;return n|0}u=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,u)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}}else if((o|0)==7){u=lq(c[d>>2]|0,(c[p>>2]|0)+22|0)|0;W=u&65535;if(u<<16>>16==0|(u&65535)>4){c[b+204>>2]=-56;s=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-56);if(!((s&512)==0)){n=0;i=e;return n|0}s=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,s)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}s=mq(c[d>>2]|0,308)|0;if((u&65535)<5){Y=(W*66|0)+8+s|0}else{Y=s}oq(c[d>>2]|0,Y+3|0,0);oq(c[d>>2]|0,Y+2|0,0);oq(c[d>>2]|0,Y+18|0,0);c[b+204>>2]=0;s=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,0);if(!((s&512)==0)){n=0;i=e;return n|0}s=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,s)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}else if((o|0)==8){c[b+56>>2]=(mq(c[d>>2]|0,(c[p>>2]|0)+28|0)|0)&16777215;c[b+204>>2]=0;s=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,0);if(!((s&512)==0)){n=0;i=e;return n|0}s=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,s)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}else if((o|0)==9){c[b+204>>2]=-56;s=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-56);if(!((s&512)==0)){n=0;i=e;return n|0}s=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,s)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}else if((o|0)==6){s=lq(c[d>>2]|0,(c[p>>2]|0)+22|0)|0;W=s&65535;u=lq(c[d>>2]|0,(c[p>>2]|0)+28|0)|0;r=u&65535;if(s<<16>>16==0|(s&65535)>4){c[b+204>>2]=-56;Q=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-56);if(!((Q&512)==0)){n=0;i=e;return n|0}Q=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,Q)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}Q=gr(c[b+8>>2]|0,W)|0;if((Q|0)==0){c[b+204>>2]=-64;X=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-64);if(!((X&512)==0)){n=0;i=e;return n|0}X=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,X)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}if((a[Q+56>>0]|0)!=0){c[b+204>>2]=-44;X=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-44);if(!((X&512)==0)){n=0;i=e;return n|0}X=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,X)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}if(u<<16>>16==0){R=109}else{if(r>>>0>(c[b+64>>2]|0)>>>0){R=109}else{Z=c[b+((r<<1)+ -2<<2)+68>>2]|0}}if((R|0)==109){r=_q(Q)|0;if((Sq(Q)|0)==6){Z=u<<16>>16==1?800:1600}else{Z=r}}if((gg(Q,Z)|0)!=0){c[b+204>>2]=-50;Q=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-50);if(!((Q&512)==0)){n=0;i=e;return n|0}Q=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,Q)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}Q=mq(c[d>>2]|0,308)|0;if((s&65535)<5){_=(W*66|0)+8+Q|0}else{_=Q}pq(c[d>>2]|0,_+18|0,Z&65535);pq(c[d>>2]|0,_+20|0,Z>>>16&65535);c[b+204>>2]=0;Q=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,0);if(!((Q&512)==0)){n=0;i=e;return n|0}Q=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,Q)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}else if((o|0)==21){fg(b);n=0;i=e;return n|0}else if((o|0)==22){fg(b);n=0;i=e;return n|0}else if((o|0)==23){Q=lq(c[d>>2]|0,(c[p>>2]|0)+22|0)|0;if(Q<<16>>16==0|(Q&65535)>4){c[b+204>>2]=-56;W=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-56);if(!((W&512)==0)){n=0;i=e;return n|0}W=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,W)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}else{W=(Q&65535)+ -1|0;qq(c[d>>2]|0,(c[p>>2]|0)+28|0,(W<<3&8|W>>>1&1)<<8|4);c[b+204>>2]=0;W=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,0);if(!((W&512)==0)){n=0;i=e;return n|0}W=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,W)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}}else if((o|0)==21315){W=lq(c[d>>2]|0,(c[p>>2]|0)+22|0)|0;Q=lq(c[d>>2]|0,(c[p>>2]|0)+28|0)|0;s=Q&65535;r=mq(c[d>>2]|0,(c[p>>2]|0)+30|0)|0;u=mq(c[d>>2]|0,(c[p>>2]|0)+34|0)|0;if(W<<16>>16==0|(W&65535)>4){c[b+204>>2]=-56;X=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-56);if(!((X&512)==0)){n=0;i=e;return n|0}X=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,X)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}X=gr(c[b+8>>2]|0,W&65535)|0;if((X|0)==0){c[b+204>>2]=-64;W=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-64);if(!((W&512)==0)){n=0;i=e;return n|0}W=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,W)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}if((a[X+56>>0]|0)!=0){c[b+204>>2]=-44;W=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-44);if(!((W&512)==0)){n=0;i=e;return n|0}W=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,W)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}if(!(Q<<16>>16==0)){if(!(s>>>0>(c[b+64>>2]|0)>>>0)){Q=c[b+((s<<1)+ -2<<2)+68>>2]|0;if(Q>>>0<1120){$=-2}else{if(Q>>>0<1520){$=0}else{if(Q>>>0<2240){$=-1}else{$=Q>>>0<5760?1:253}}}if((gg(X,Q)|0)!=0){c[b+204>>2]=-50;s=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-50);if(!((s&512)==0)){n=0;i=e;return n|0}s=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,s)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}s=r&16777215;S=m+0|0;T=S+12|0;do{a[S>>0]=0;S=S+1|0}while((S|0)<(T|0));d:do{if((Q|0)!=0){e:do{if($>>>0>1){r=m+1|0;W=m+2|0;A=m+3|0;P=m+4|0;t=m+5|0;L=m+6|0;M=m+7|0;v=m+8|0;g=m+9|0;h=m+10|0;j=m+11|0;k=s;x=0;q=u&16777215;while(1){w=0;do{a[l+w>>0]=kq(c[d>>2]|0,w+k|0)|0;w=w+1|0}while((w|0)!=512);a[m>>0]=kq(c[d>>2]|0,q)|0;a[r>>0]=kq(c[d>>2]|0,q+1|0)|0;a[W>>0]=kq(c[d>>2]|0,q+2|0)|0;a[A>>0]=kq(c[d>>2]|0,q+3|0)|0;a[P>>0]=kq(c[d>>2]|0,q+4|0)|0;a[t>>0]=kq(c[d>>2]|0,q+5|0)|0;a[L>>0]=kq(c[d>>2]|0,q+6|0)|0;a[M>>0]=kq(c[d>>2]|0,q+7|0)|0;a[v>>0]=kq(c[d>>2]|0,q+8|0)|0;a[g>>0]=kq(c[d>>2]|0,q+9|0)|0;a[h>>0]=kq(c[d>>2]|0,q+10|0)|0;a[j>>0]=kq(c[d>>2]|0,q+11|0)|0;if((hg(X,l,m,x)|0)!=0){break e}x=x+1|0;if(!(x>>>0<Q>>>0)){break d}else{k=k+512|0;q=q+12|0}}}else{q=s;k=0;while(1){x=0;do{a[l+x>>0]=kq(c[d>>2]|0,x+q|0)|0;x=x+1|0}while((x|0)!=512);if((hg(X,l,m,k)|0)!=0){break e}k=k+1|0;if(!(k>>>0<Q>>>0)){break d}else{q=q+512|0}}}}while(0);c[b+204>>2]=-1;q=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-1);if(!((q&512)==0)){n=0;i=e;return n|0}q=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,q)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}}while(0);c[b+204>>2]=0;Q=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,0);if(!((Q&512)==0)){n=0;i=e;return n|0}Q=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,Q)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}}c[b+204>>2]=-50;Q=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-50);if(!((Q&512)==0)){n=0;i=e;return n|0}Q=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,Q)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}else{c[f>>2]=o;te(14208,f);c[b+204>>2]=-17;Q=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-17);if(!((Q&512)==0)){n=0;i=e;return n|0}Q=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,Q)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}}while(0);break};case 19:{d=b+4|0;p=b+208|0;o=(lq(c[d>>2]|0,(c[p>>2]|0)+26|0)|0)&65535;if((o|0)==6){m=lq(c[d>>2]|0,(c[p>>2]|0)+22|0)|0;l=(lq(c[d>>2]|0,(c[p>>2]|0)+28|0)|0)&65535;$=mq(c[d>>2]|0,(c[p>>2]|0)+30|0)|0;if(m<<16>>16==0|(m&65535)>4){c[b+204>>2]=-56;S=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-56);if(!((S&512)==0)){n=0;i=e;return n|0}S=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,S)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}S=gr(c[b+8>>2]|0,m&65535)|0;if((S|0)==0){c[b+204>>2]=-64;m=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-64);if(!((m&512)==0)){n=0;i=e;return n|0}m=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,m)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}m=_q(S)|0;T=b+68|0;Z=b+64|0;do{if((Sq(S)|0)==6){c[Z>>2]=4;c[T>>2]=800;_=b+72|0;c[_>>2]=-2130050992;c[b+76>>2]=1600;R=b+80|0;c[R>>2]=-2113273776;c[b+84>>2]=1440;Y=b+88|0;c[Y>>2]=-2113339312;c[b+92>>2]=2880;Q=b+96|0;c[Q>>2]=-1844314032;if(m>>>0<1120){c[_>>2]=-1056309168;aa=4;break}if(m>>>0<1520){c[Y>>2]=-1039597488;aa=4;break}if(m>>>0<2240){c[R>>2]=-1039531952;aa=4;break}if((a[b+60>>0]|0)==0){c[Z>>2]=1;c[T>>2]=2880;c[_>>2]=-770572208;aa=1;break}else{c[Q>>2]=-770572208;aa=4;break}}else{c[Z>>2]=1;c[T>>2]=m;c[b+72>>2]=0;aa=1}}while(0);m=l>>>0>aa>>>0?aa:l;T=c[d>>2]|0;if((m|0)==0){ba=T}else{Z=~aa;aa=~l;l=~(Z>>>0>aa>>>0?Z:aa);aa=T;T=0;while(1){Z=(T<<3)+$|0;S=T<<1;qq(aa,Z,c[b+(S<<2)+68>>2]|0);qq(c[d>>2]|0,Z+4|0,c[b+((S|1)<<2)+68>>2]|0);S=T+1|0;Z=c[d>>2]|0;if((S|0)==(l|0)){ba=Z;break}else{aa=Z;T=S}}}pq(ba,(c[p>>2]|0)+28|0,m&65535);c[b+204>>2]=0;m=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,0);if(!((m&512)==0)){n=0;i=e;return n|0}m=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,m)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}else if((o|0)==8){m=lq(c[d>>2]|0,(c[p>>2]|0)+22|0)|0;ba=m&65535;if(m<<16>>16==0|(m&65535)>4){c[b+204>>2]=-56;T=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-56);if(!((T&512)==0)){n=0;i=e;return n|0}T=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,T)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}if((gr(c[b+8>>2]|0,ba)|0)==0){c[b+204>>2]=-64;T=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-64);if(!((T&512)==0)){n=0;i=e;return n|0}T=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,T)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}T=mq(c[d>>2]|0,308)|0;if((m&65535)<5){ca=(ba*66|0)+8+T|0}else{ca=T}T=0;do{ba=T<<1;m=lq(c[d>>2]|0,ba+ca|0)|0;pq(c[d>>2]|0,ba+28+(c[p>>2]|0)|0,m);T=T+1|0}while((T|0)!=11);c[b+204>>2]=0;T=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,0);if(!((T&512)==0)){n=0;i=e;return n|0}T=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,T)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0;n=0;i=e;return n|0}else{c[b+204>>2]=-18;T=lq(c[d>>2]|0,(c[p>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[p>>2]|0)+16|0,-18);if((T&512)==0){T=mq(c[d>>2]|0,308)|0;c[b+212>>2]=mq(c[d>>2]|0,T)|0;c[b+216>>2]=mq(c[d>>2]|0,2300)|0}c[f>>2]=o;te(14168,f);n=0;i=e;return n|0}break};case 20:{n=0;i=e;return n|0};default:{n=1;i=e;return n|0}}return 0}function eg(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=b+1|0;if((a[e>>0]|0)!=0){f=b+136|0;g=c[f>>2]|0;if((g|0)!=0){if((c[b+132>>2]|0)!=0){h=b+4|0;j=g;g=b+140|0;k=0;while(1){l=(lq(c[h>>2]|0,j+8+(k<<1)|0)|0)&65535;m=(c[f>>2]|0)+l|0;nq(c[h>>2]|0,m,a[g>>0]|0);nq(c[h>>2]|0,m+1|0,a[g+1>>0]|0);nq(c[h>>2]|0,m+2|0,a[g+2>>0]|0);nq(c[h>>2]|0,m+3|0,a[g+3>>0]|0);nq(c[h>>2]|0,m+4|0,a[g+4>>0]|0);nq(c[h>>2]|0,m+5|0,a[g+5>>0]|0);m=k+1|0;if((m|0)==5){break}j=c[f>>2]|0;g=g+6|0;k=m}a[e>>0]=0}}}a[b>>0]=0;c[b+28>>2]=c[b+12>>2];c[b+32>>2]=c[b+16>>2];c[b+36>>2]=c[b+20>>2];c[b+40>>2]=c[b+24>>2];i=d;return}function fg(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;b=i;d=a+4|0;e=a+208|0;f=lq(c[d>>2]|0,(c[e>>2]|0)+22|0)|0;if(f<<16>>16==0|(f&65535)>4){c[a+204>>2]=-56;g=lq(c[d>>2]|0,(c[e>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[e>>2]|0)+16|0,-56);if(!((g&512)==0)){i=b;return}g=mq(c[d>>2]|0,308)|0;c[a+212>>2]=mq(c[d>>2]|0,g)|0;c[a+216>>2]=mq(c[d>>2]|0,2300)|0;i=b;return}g=c[a+48>>2]|0;h=c[a+52>>2]|0;j=gr(c[a+8>>2]|0,f&65535)|0;if((j|0)==0){k=g}else{f=_q(j)|0;if((f|0)==2880|(f|0)==1440|(f|0)==1600|(f|0)==800){k=g}else{k=h}}qq(c[d>>2]|0,(c[e>>2]|0)+28|0,k);c[a+204>>2]=0;k=lq(c[d>>2]|0,(c[e>>2]|0)+6|0)|0;pq(c[d>>2]|0,(c[e>>2]|0)+16|0,0);if(!((k&512)==0)){i=b;return}k=mq(c[d>>2]|0,308)|0;c[a+212>>2]=mq(c[d>>2]|0,k)|0;c[a+216>>2]=mq(c[d>>2]|0,2300)|0;i=b;return}function gg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+528|0;f=e;g=e+8|0;if((Sq(b)|0)!=6){if((_q(b)|0)!=(d|0)){h=1;i=e;return h|0}Oz(g|0,0,512)|0;if((d|0)==0){h=0;i=e;return h|0}else{j=0}while(1){cr(b,g,j,1)|0;k=j+1|0;if((k|0)==(d|0)){h=0;break}else{j=k}}i=e;return h|0}j=c[b+64>>2]|0;k=g+0|0;l=k+12|0;do{a[k>>0]=0;k=k+1|0}while((k|0)<(l|0));do{if(d>>>0<1120){m=1;n=9}else{if(d>>>0<1520){o=2}else{if(d>>>0<2240){m=2;n=9;break}o=d>>>0<5760?3:255}vq(j)|0;k=(o|0)==2;if((o&254|0)!=2){h=1;i=e;return h|0}wq(j,k?2:32770);l=k?9:18;k=0;do{p=0;while(1){q=p+1|0;xq(j,k,0,k,0,q,512,0)|0;if(q>>>0<l>>>0){p=q}else{r=0;break}}do{r=r+1|0;xq(j,k,1,k,1,r,512,0)|0}while(r>>>0<l>>>0);k=k+1|0}while((k|0)!=80)}}while(0);if((n|0)==9){vq(j)|0;wq(j,3);n=j+68|0;r=0;o=13;do{o=(((r&15|0)==0)<<31>>31)+o|0;if((o|0)!=0){d=0;do{k=0;do{xq(j,r,d,r,d,k,512,0)|0;l=St(c[n>>2]|0,r,d,k,1)|0;if((l|0)!=0){Ct(l,g,12)|0}k=k+1|0}while((k|0)!=(o|0));d=d+1|0}while(d>>>0<m>>>0)}r=r+1|0}while((r|0)!=80)}c[f>>2]=_q(b)|0;te(14320,f);h=0;i=e;return h|0}function hg(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+32|0;g=f;h=f+24|0;j=f+20|0;k=f+16|0;l=f+12|0;if((Sq(a)|0)!=6){m=(cr(a,b,e,1)|0)!=0|0;i=f;return m|0}if((ig(_q(a)|0,e,h,j,k)|0)!=0){m=1;i=f;return m|0}e=_q(a)|0;if(e>>>0<1120|(e+ -1520|0)>>>0<720){e=a+64|0;n=c[h>>2]|0;o=c[j>>2]|0;p=c[k>>2]|0;uq(c[e>>2]|0,d,12,n,o,p,0)|0;q=e;r=n;s=o;t=p}else{q=a+64|0;r=c[h>>2]|0;s=c[j>>2]|0;t=c[k>>2]|0}c[l>>2]=512;if((tq(c[q>>2]|0,b,l,r,s,t,0)|0)==0){m=0;i=f;return m|0}c[g>>2]=r;c[g+4>>2]=s;c[g+8>>2]=t;te(14248,g);m=1;i=f;return m|0}function ig(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+16|0;h=g;a:do{if(a>>>0<1120){j=1}else{do{if(a>>>0<1520){c[f>>2]=((b>>>0)%9|0)+1;c[e>>2]=((b>>>0)/9|0)&1;k=(b>>>0)/18|0}else{if(a>>>0<2240){j=0;break a}if(a>>>0<5760){c[f>>2]=((b>>>0)%18|0)+1;c[e>>2]=((b>>>0)/18|0)&1;k=(b>>>0)/36|0;break}c[h>>2]=a;c[h+4>>2]=b;te(14280,h);l=1;i=g;return l|0}}while(0);c[d>>2]=k;l=0;i=g;return l|0}}while(0);k=j?1:2;c[d>>2]=0;h=k<<4;a=b;b=0;m=0;n=12;while(1){o=ca(n,h)|0;if(a>>>0<o>>>0){break}p=b+16|0;c[d>>2]=p;q=m+1|0;if(q>>>0<5){a=a-o|0;b=p;m=q;n=n+ -1|0}else{l=1;r=13;break}}if((r|0)==13){i=g;return l|0}c[f>>2]=(a>>>0)%(n>>>0)|0;c[e>>2]=((a>>>0)/(n>>>0)|0)&(j&1^1);j=(a>>>0)/((ca(n,k)|0)>>>0)|0;c[d>>2]=(c[d>>2]|0)+j;l=0;i=g;return l|0}function jg(a){a=a|0;var d=0,e=0;d=i;c[a+756>>2]=0;c[a+760>>2]=0;c[a+764>>2]=0;e=a+768|0;c[a+0>>2]=0;c[a+4>>2]=0;c[a+8>>2]=0;c[a+12>>2]=0;c[e>>2]=8e3;iv(a+772|0);b[a+820>>1]=-32768;c[a+824>>2]=0;c[a+828>>2]=60;i=d;return}function kg(a,b){a=a|0;b=b|0;c[a+4>>2]=b;return}function lg(a,b){a=a|0;b=b|0;var d=0;d=i;c[a+768>>2]=b;kv(a+772|0,b,22255);i=d;return}function mg(a,b){a=a|0;b=b|0;c[a+764>>2]=b;return}function ng(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=(b|0)!=0|0;b=a+760|0;if((c[b>>2]|0)==(e|0)){i=d;return}c[b>>2]=e;i=d;return}function og(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;e=c[a>>2]|0;if((e|0)!=0){pv(e)}e=sv(b)|0;c[a>>2]=e;if((e|0)==0){f=1}else{if((rv(e,1,22255,0)|0)==0){f=0}else{pv(c[a>>2]|0);c[a>>2]=0;f=1}}i=d;return f|0}function pg(a){a=a|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+8192|0;g=f;h=a+4|0;if((c[h>>2]|0)==0){i=f;return}if((c[a>>2]|0)==0){i=f;return}j=a+12|0;k=c[j>>2]|0;a:do{if(k>>>0<370){l=a+760|0;if((c[l>>2]|0)==0){if((c[a+828>>2]|0)>>>0>59&(k|0)==0){break}m=a+820|0;if(!((b[m>>1]|0)==-32768)){c[a+824>>2]=1}n=a+8|0;o=370-k|0;p=k;do{if(!(p>>>0<370)){break}b[a+(p<<1)+16>>1]=-32768;q=(c[n>>2]|0)+1|0;c[n>>2]=q>>>0>369?0:q;p=(c[j>>2]|0)+1|0;c[j>>2]=p;o=o+ -1|0}while((o|0)!=0);b[m>>1]=-32768;break}o=8-(c[a+764>>2]|0)|0;p=a+8|0;n=a+820|0;q=a+824|0;r=370-k|0;s=k;do{if(!(s>>>0<370)){break a}t=c[p>>2]|0;do{if((c[l>>2]|0)==0){u=32768}else{v=d[(c[h>>2]|0)+(t<<1)>>0]<<8;if(v>>>0<32768){u=32768-(((32768-v|0)>>>0)/(o>>>0)|0)|0;break}else{u=(((v+ -32768|0)>>>0)/(o>>>0)|0)+32768|0;break}}}while(0);v=t+1|0;c[p>>2]=v>>>0>369?0:v;v=u&65535;if((u|0)!=(e[n>>1]|0)){b[n>>1]=v;c[q>>2]=1}b[a+(s<<1)+16>>1]=v;s=(c[j>>2]|0)+1|0;c[j>>2]=s;r=r+ -1|0}while((r|0)!=0)}}while(0);u=a+824|0;h=a+828|0;k=c[h>>2]|0;if((c[u>>2]|0)==0){if(k>>>0<60){r=k+1|0;c[h>>2]=r;if(r>>>0<60){w=27}}}else{if(k>>>0>59){k=c[a>>2]|0;Oz(g|0,0,8192)|0;qv(k,g,4096)|0}c[h>>2]=0;w=27}if((w|0)==27){if((c[a+768>>2]|0)==0){x=a+16|0}else{w=a+16|0;lv(a+772|0,w,w,c[j>>2]|0,1,0);x=w}qv(c[a>>2]|0,x,c[j>>2]|0)|0}c[u>>2]=0;c[a+8>>2]=16;c[j>>2]=0;c[a+756>>2]=0;i=f;return}function qg(a,f){a=a|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;h=a+760|0;if((c[h>>2]|0)==0){i=g;return}j=a+4|0;if((c[j>>2]|0)==0){i=g;return}k=a+12|0;l=c[k>>2]|0;if(l>>>0>369){i=g;return}m=a+756|0;n=(c[m>>2]|0)+f|0;c[m>>2]=n;if(!(n>>>0>351)){i=g;return}c[m>>2]=(n>>>0)%352|0;m=8-(c[a+764>>2]|0)|0;f=a+8|0;o=a+820|0;p=a+824|0;q=(n>>>0)/352|0;n=l;while(1){if(!(n>>>0<370)){r=14;break}l=c[f>>2]|0;do{if((c[h>>2]|0)==0){s=32768}else{t=(d[(c[j>>2]|0)+(l<<1)>>0]|0)<<8;if(t>>>0<32768){s=32768-(((32768-t|0)>>>0)/(m>>>0)|0)|0;break}else{s=(((t+ -32768|0)>>>0)/(m>>>0)|0)+32768|0;break}}}while(0);t=l+1|0;c[f>>2]=t>>>0>369?0:t;t=s&65535;if((s|0)!=(e[o>>1]|0|0)){b[o>>1]=t;c[p>>2]=1}b[a+(n<<1)+16>>1]=t;t=(c[k>>2]|0)+1|0;c[k>>2]=t;u=q+ -1|0;if((u|0)==0){r=14;break}else{q=u;n=t}}if((r|0)==14){i=g;return}}function rg(a){a=a|0;var b=0,d=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;a:do{if((a&61440|0)==40960){d=(a&2048|0)==0;f=d?63743:64511;g=d?19344:14536;d=c[g+4>>2]|0;if((d|0)==0){h=0}else{j=d;d=0;while(1){k=d+1|0;if((((e[g+(d<<3)>>1]|0)^a)&f|0)==0){h=j;break a}l=c[g+(k<<3)+4>>2]|0;if((l|0)==0){h=0;break}else{j=l;d=k}}}}else{h=0}}while(0);i=b;return h|0}function sg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=yz(60)|0;if((f|0)==0){g=0;i=e;return g|0}c[f>>2]=0;c[f+44>>2]=0;c[f+4>>2]=b;c[f+8>>2]=d;a[f+12>>0]=0;c[f+16>>2]=8;h=yz(ca((b+7|0)>>>3,d)|0)|0;c[f+20>>2]=h;if((h|0)!=0){h=yz(b*24|0)|0;c[f+24>>2]=h;if((h|0)!=0){c[f+28>>2]=255;a[f+32>>0]=0;a[f+33>>0]=0;a[f+34>>0]=0;a[f+35>>0]=-1;a[f+36>>0]=-1;a[f+37>>0]=-1;c[f+40>>2]=0;a[f+48>>0]=0;c[f+52>>2]=0;c[f+56>>2]=0;g=f;i=e;return g|0}}zz(f);g=0;i=e;return g|0}function tg(a,b,d){a=a|0;b=b|0;d=d|0;c[a+52>>2]=b;c[a+56>>2]=d;return}function ug(a,b){a=a|0;b=b|0;c[a>>2]=b;return}function vg(a,b){a=a|0;b=b|0;var d=0;d=i;c[a+44>>2]=b;if((b|0)==0){i=d;return}Uy(b,c[a+4>>2]|0,c[a+8>>2]|0)|0;i=d;return}function wg(b,c,d){b=b|0;c=c|0;d=d|0;a[b+32>>0]=c>>>16;a[b+35>>0]=d>>>16;a[b+33>>0]=c>>>8;a[b+36>>0]=d>>>8;a[b+34>>0]=c;a[b+37>>0]=d;a[b+12>>0]=1;return}function xg(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=d>>>0>255?255:d;d=b+28|0;if((c[d>>2]|0)==(f|0)){i=e;return}a[b+12>>0]=1;c[d>>2]=f;i=e;return}function yg(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=i;i=i+16|0;f=e+3|0;g=e;h=b+44|0;j=c[h>>2]|0;if((j|0)==0){i=e;return}if((c[b>>2]|0)==0){i=e;return}k=c[b+28>>2]|0;a[f>>0]=((ca(d[b+32>>0]|0,k)|0)>>>0)/255|0;a[g>>0]=((ca(d[b+35>>0]|0,k)|0)>>>0)/255|0;l=f+1|0;a[l>>0]=((ca(d[b+33>>0]|0,k)|0)>>>0)/255|0;m=g+1|0;a[m>>0]=((ca(d[b+36>>0]|0,k)|0)>>>0)/255|0;n=f+2|0;a[n>>0]=((ca(d[b+34>>0]|0,k)|0)>>>0)/255|0;o=g+2|0;a[o>>0]=((ca(d[b+37>>0]|0,k)|0)>>>0)/255|0;k=b+4|0;p=b+8|0;az(j,c[k>>2]|0,c[p>>2]|0);j=c[b+24>>2]|0;q=c[p>>2]|0;a:do{if((q|0)==0){r=b+12|0}else{s=b+16|0;t=b+12|0;u=q;v=c[b+20>>2]|0;w=c[b>>2]|0;x=0;while(1){y=u-x|0;z=c[s>>2]|0;A=y>>>0>z>>>0?z:y;y=((c[k>>2]|0)+7|0)>>>3;B=ca(y,A)|0;if((a[t>>0]|0)==0){if((Dz(v,w,B)|0)==0){C=u}else{D=8}}else{D=8}if((D|0)==8){D=0;Mz(v|0,w|0,B|0)|0;if((B&536870911|0)!=0){E=x+ -1-u|0;F=~z;z=ca(y<<3,~(E>>>0>F>>>0?E:F))|0;F=0;E=0;while(1){if((d[v+(F>>>3)>>0]&128>>>(F&7)|0)==0){a[j+E>>0]=a[g>>0]|0;a[j+(E+1)>>0]=a[m>>0]|0;a[j+(E+2)>>0]=a[o>>0]|0}else{a[j+E>>0]=a[f>>0]|0;a[j+(E+1)>>0]=a[l>>0]|0;a[j+(E+2)>>0]=a[n>>0]|0}F=F+1|0;if((F|0)==(z|0)){break}else{E=E+3|0}}}ez(c[h>>2]|0,j,x,A);C=c[p>>2]|0}E=A+x|0;if(!(E>>>0<C>>>0)){r=t;break a}u=C;v=v+B|0;w=w+B|0;x=E}}}while(0);a[r>>0]=0;fz(c[h>>2]|0);i=e;return}function zg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=b+40|0;g=c[f>>2]|0;h=g+d|0;c[f>>2]=h;if(h>>>0<120384){i=e;return}if(g>>>0<120384){yg(b);g=b+48|0;if((a[g>>0]|0)!=1){a[g>>0]=1;g=c[b+56>>2]|0;if((g|0)!=0){jc[g&255](c[b+52>>2]|0,1)}}}g=c[f>>2]|0;if(!(g>>>0>130239)){i=e;return}h=b+48|0;if((a[h>>0]|0)==0){j=g}else{a[h>>0]=0;h=c[b+56>>2]|0;if((h|0)==0){j=g}else{jc[h&255](c[b+52>>2]|0,0);j=c[f>>2]|0}}c[f>>2]=j+ -130240;i=e;return}function Ag(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;h=i;i=i+16|0;j=h;k=e+36|0;l=e+32|0;m=e+8|0;n=e+4|0;e=0;do{o=e+g&16777215;if(o>>>0<(c[k>>2]|0)>>>0){p=a[(c[l>>2]|0)+o>>0]|0}else{p=oc[c[m>>2]&31](c[n>>2]|0,o)|0}a[j+e>>0]=p;e=e+1|0}while((e|0)!=16);c[f>>2]=0;c[f+4>>2]=g;a[f+288>>0]=0;g=d[j>>0]|0;e=d[j+1>>0]|0;b[f+12>>1]=g<<8|e;p=f+8|0;c[p>>2]=1;jc[c[31144+((e>>>6|g<<2)<<2)>>2]&255](f,j);if((c[p>>2]|0)==0){i=h;return}else{q=0}do{g=q<<1;b[f+(q<<1)+12>>1]=(d[j+g>>0]|0)<<8|(d[j+(g|1)>>0]|0);q=q+1|0}while(q>>>0<(c[p>>2]|0)>>>0);i=h;return}function Bg(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+16|0;h=g;j=(b[e+12>>1]&63)==60;k=e+32|0;a[k+0>>0]=a[37608>>0]|0;a[k+1>>0]=a[37609>>0]|0;a[k+2>>0]=a[37610>>0]|0;a[k+3>>0]=a[37611>>0]|0;a[k+4>>0]=a[37612>>0]|0;a[k+5>>0]=a[37613>>0]|0;c[e+28>>2]=2;k=d[f+3>>0]|0;c[h>>2]=35704;c[h+4>>2]=k;ab(e+96|0,35352,h|0)|0;h=e+8|0;c[h>>2]=(c[h>>2]|0)+1;h=e+160|0;if(j){a[h>>0]=5391171;a[h+1>>0]=21059;a[h+2>>0]=82;a[h+3>>0]=0;i=g;return}else{kj(e,h,f,a[f+1>>0]&63,8);i=g;return}}function Cg(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+16|0;h=g;j=(b[e+12>>1]&63)==60;k=e+32|0;a[k+0>>0]=a[37600>>0]|0;a[k+1>>0]=a[37601>>0]|0;a[k+2>>0]=a[37602>>0]|0;a[k+3>>0]=a[37603>>0]|0;a[k+4>>0]=a[37604>>0]|0;a[k+5>>0]=a[37605>>0]|0;c[e+28>>2]=2;k=(d[f+2>>0]|0)<<8|(d[f+3>>0]|0);c[h>>2]=35704;c[h+4>>2]=k;ab(e+96|0,35256,h|0)|0;h=e+8|0;c[h>>2]=(c[h>>2]|0)+1;h=e+160|0;if(j){a[h+0>>0]=a[35392>>0]|0;a[h+1>>0]=a[35393>>0]|0;a[h+2>>0]=a[35394>>0]|0;c[e>>2]=c[e>>2]|1;i=g;return}else{kj(e,h,f,a[f+1>>0]&63,16);i=g;return}}function Dg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37592>>0]|0;a[h+1>>0]=a[37593>>0]|0;a[h+2>>0]=a[37594>>0]|0;a[h+3>>0]=a[37595>>0]|0;a[h+4>>0]=a[37596>>0]|0;a[h+5>>0]=a[37597>>0]|0;c[b+28>>2]=2;h=(((d[e+2>>0]|0)<<8|(d[e+3>>0]|0))<<8|(d[e+4>>0]|0))<<8|(d[e+5>>0]|0);c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35360,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+2;kj(b,b+160|0,e,a[e+1>>0]&63,32);i=f;return}function Eg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b+8|0;j=c[h>>2]|0;k=a[e+(j<<1)>>0]|0;c[h>>2]=j+1;j=b+32|0;if((k&8)==0){a[j+0>>0]=a[37584>>0]|0;a[j+1>>0]=a[37585>>0]|0;a[j+2>>0]=a[37586>>0]|0;a[j+3>>0]=a[37587>>0]|0;a[j+4>>0]=a[37588>>0]|0;a[j+5>>0]=a[37589>>0]|0;a[j+6>>0]=a[37590>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,8);k=d[e+2>>0]|0;c[g>>2]=(k&128|0)!=0?35288:35296;c[g+4>>2]=k>>>4&7;ab(b+160|0,35280,g|0)|0;l=c[b>>2]|0;m=l|128;c[b>>2]=m;i=f;return}else{a[j+0>>0]=a[37576>>0]|0;a[j+1>>0]=a[37577>>0]|0;a[j+2>>0]=a[37578>>0]|0;a[j+3>>0]=a[37579>>0]|0;a[j+4>>0]=a[37580>>0]|0;a[j+5>>0]=a[37581>>0]|0;a[j+6>>0]=a[37582>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,8);j=d[e+2>>0]|0;c[g>>2]=(j&128|0)!=0?35288:35296;c[g+4>>2]=j>>>4&7;ab(b+160|0,35280,g|0)|0;l=c[b>>2]|0;m=l|128;c[b>>2]=m;i=f;return}}function Fg(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=b[e+12>>1]|0;k=e+32|0;if((j&56)==8){l=k;m=l;a[m>>0]=1163284301;a[m+1>>0]=4544079;a[m+2>>0]=17750;a[m+3>>0]=69;m=l+4|0;a[m>>0]=5713488;a[m+1>>0]=22318;a[m+2>>0]=87;a[m+3>>0]=0;c[e+28>>2]=2;m=(d[f+2>>0]|0)<<8;l=m|(d[f+3>>0]|0);n=(m&32768|0)!=0;c[h>>2]=n?35336:35344;c[h+4>>2]=35704;c[h+8>>2]=(n?0-l|0:l)&65535;c[h+12>>2]=j&7;ab(e+96|0,35320,h|0)|0;j=e+8|0;c[j>>2]=(c[j>>2]|0)+1;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(e+160|0,35264,h|0)|0;i=g;return}else{a[k+0>>0]=a[37464>>0]|0;a[k+1>>0]=a[37465>>0]|0;a[k+2>>0]=a[37466>>0]|0;a[k+3>>0]=a[37467>>0]|0;a[k+4>>0]=a[37468>>0]|0;c[e+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(e+96|0,35264,h|0)|0;kj(e,e+160|0,f,a[f+1>>0]&63,8);i=g;return}}function Gg(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=b[e+12>>1]|0;k=e+32|0;if((j&56)==8){l=k;m=l;a[m>>0]=1163284301;a[m+1>>0]=4544079;a[m+2>>0]=17750;a[m+3>>0]=69;m=l+4|0;a[m>>0]=4992592;a[m+1>>0]=19502;a[m+2>>0]=76;a[m+3>>0]=0;c[e+28>>2]=2;m=(d[f+2>>0]|0)<<8;l=m|(d[f+3>>0]|0);n=(m&32768|0)!=0;c[h>>2]=n?35336:35344;c[h+4>>2]=35704;c[h+8>>2]=(n?0-l|0:l)&65535;c[h+12>>2]=j&7;ab(e+96|0,35320,h|0)|0;j=e+8|0;c[j>>2]=(c[j>>2]|0)+1;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(e+160|0,35264,h|0)|0;i=g;return}else{a[k+0>>0]=a[37456>>0]|0;a[k+1>>0]=a[37457>>0]|0;a[k+2>>0]=a[37458>>0]|0;a[k+3>>0]=a[37459>>0]|0;a[k+4>>0]=a[37460>>0]|0;c[e+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(e+96|0,35264,h|0)|0;kj(e,e+160|0,f,a[f+1>>0]&63,8);i=g;return}}function Hg(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=e+12|0;k=e+32|0;if((b[j>>1]&56)==8){l=k;m=l;a[m>>0]=1163284301;a[m+1>>0]=4544079;a[m+2>>0]=17750;a[m+3>>0]=69;m=l+4|0;a[m>>0]=5713488;a[m+1>>0]=22318;a[m+2>>0]=87;a[m+3>>0]=0;c[e+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(e+96|0,35264,h|0)|0;m=(d[f+2>>0]|0)<<8;l=m|(d[f+3>>0]|0);n=(m&32768|0)!=0;m=b[j>>1]&7;c[h>>2]=n?35336:35344;c[h+4>>2]=35704;c[h+8>>2]=(n?0-l|0:l)&65535;c[h+12>>2]=m;ab(e+160|0,35320,h|0)|0;m=e+8|0;c[m>>2]=(c[m>>2]|0)+1;i=g;return}else{a[k+0>>0]=a[37448>>0]|0;a[k+1>>0]=a[37449>>0]|0;a[k+2>>0]=a[37450>>0]|0;a[k+3>>0]=a[37451>>0]|0;a[k+4>>0]=a[37452>>0]|0;c[e+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(e+96|0,35264,h|0)|0;kj(e,e+160|0,f,a[f+1>>0]&63,8);i=g;return}}function Ig(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=e+12|0;k=e+32|0;if((b[j>>1]&56)==8){l=k;m=l;a[m>>0]=1163284301;a[m+1>>0]=4544079;a[m+2>>0]=17750;a[m+3>>0]=69;m=l+4|0;a[m>>0]=4992592;a[m+1>>0]=19502;a[m+2>>0]=76;a[m+3>>0]=0;c[e+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(e+96|0,35264,h|0)|0;m=(d[f+2>>0]|0)<<8;l=m|(d[f+3>>0]|0);n=(m&32768|0)!=0;m=b[j>>1]&7;c[h>>2]=n?35336:35344;c[h+4>>2]=35704;c[h+8>>2]=(n?0-l|0:l)&65535;c[h+12>>2]=m;ab(e+160|0,35320,h|0)|0;m=e+8|0;c[m>>2]=(c[m>>2]|0)+1;i=g;return}else{a[k+0>>0]=a[37440>>0]|0;a[k+1>>0]=a[37441>>0]|0;a[k+2>>0]=a[37442>>0]|0;a[k+3>>0]=a[37443>>0]|0;a[k+4>>0]=a[37444>>0]|0;c[e+28>>2]=2;c[h>>2]=(d[f>>0]|0)>>>1&7;ab(e+96|0,35264,h|0)|0;kj(e,e+160|0,f,a[f+1>>0]&63,8);i=g;return}}function Jg(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+16|0;h=g;j=(b[e+12>>1]&63)==60;k=e+32|0;a[k+0>>0]=a[37568>>0]|0;a[k+1>>0]=a[37569>>0]|0;a[k+2>>0]=a[37570>>0]|0;a[k+3>>0]=a[37571>>0]|0;a[k+4>>0]=a[37572>>0]|0;a[k+5>>0]=a[37573>>0]|0;a[k+6>>0]=a[37574>>0]|0;c[e+28>>2]=2;k=d[f+3>>0]|0;c[h>>2]=35704;c[h+4>>2]=k;ab(e+96|0,35352,h|0)|0;h=e+8|0;c[h>>2]=(c[h>>2]|0)+1;h=e+160|0;if(j){a[h>>0]=5391171;a[h+1>>0]=21059;a[h+2>>0]=82;a[h+3>>0]=0;i=g;return}else{kj(e,h,f,a[f+1>>0]&63,8);i=g;return}}function Kg(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;i=i+16|0;h=g;j=(b[e+12>>1]&63)==60;k=e+32|0;a[k+0>>0]=a[37560>>0]|0;a[k+1>>0]=a[37561>>0]|0;a[k+2>>0]=a[37562>>0]|0;a[k+3>>0]=a[37563>>0]|0;a[k+4>>0]=a[37564>>0]|0;a[k+5>>0]=a[37565>>0]|0;a[k+6>>0]=a[37566>>0]|0;c[e+28>>2]=2;k=(d[f+2>>0]|0)<<8|(d[f+3>>0]|0);c[h>>2]=35704;c[h+4>>2]=k;ab(e+96|0,35256,h|0)|0;h=e+8|0;c[h>>2]=(c[h>>2]|0)+1;h=e+160|0;if(j){a[h+0>>0]=a[35392>>0]|0;a[h+1>>0]=a[35393>>0]|0;a[h+2>>0]=a[35394>>0]|0;c[e>>2]=c[e>>2]|1;i=g;return}else{kj(e,h,f,a[f+1>>0]&63,16);i=g;return}}function Lg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37552>>0]|0;a[h+1>>0]=a[37553>>0]|0;a[h+2>>0]=a[37554>>0]|0;a[h+3>>0]=a[37555>>0]|0;a[h+4>>0]=a[37556>>0]|0;a[h+5>>0]=a[37557>>0]|0;a[h+6>>0]=a[37558>>0]|0;c[b+28>>2]=2;h=(((d[e+2>>0]|0)<<8|(d[e+3>>0]|0))<<8|(d[e+4>>0]|0))<<8|(d[e+5>>0]|0);c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35360,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+2;kj(b,b+160|0,e,a[e+1>>0]&63,32);i=f;return}function Mg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b+8|0;j=c[h>>2]|0;k=a[e+(j<<1)>>0]|0;c[h>>2]=j+1;j=b+32|0;if((k&8)==0){a[j+0>>0]=a[37544>>0]|0;a[j+1>>0]=a[37545>>0]|0;a[j+2>>0]=a[37546>>0]|0;a[j+3>>0]=a[37547>>0]|0;a[j+4>>0]=a[37548>>0]|0;a[j+5>>0]=a[37549>>0]|0;a[j+6>>0]=a[37550>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);k=d[e+2>>0]|0;c[g>>2]=(k&128|0)!=0?35288:35296;c[g+4>>2]=k>>>4&7;ab(b+160|0,35280,g|0)|0;l=c[b>>2]|0;m=l|128;c[b>>2]=m;i=f;return}else{a[j+0>>0]=a[37536>>0]|0;a[j+1>>0]=a[37537>>0]|0;a[j+2>>0]=a[37538>>0]|0;a[j+3>>0]=a[37539>>0]|0;a[j+4>>0]=a[37540>>0]|0;a[j+5>>0]=a[37541>>0]|0;a[j+6>>0]=a[37542>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,16);j=d[e+2>>0]|0;c[g>>2]=(j&128|0)!=0?35288:35296;c[g+4>>2]=j>>>4&7;ab(b+160|0,35280,g|0)|0;l=c[b>>2]|0;m=l|128;c[b>>2]=m;i=f;return}}function Ng(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37528>>0]|0;a[h+1>>0]=a[37529>>0]|0;a[h+2>>0]=a[37530>>0]|0;a[h+3>>0]=a[37531>>0]|0;a[h+4>>0]=a[37532>>0]|0;a[h+5>>0]=a[37533>>0]|0;a[h+6>>0]=a[37534>>0]|0;c[b+28>>2]=2;h=d[e+3>>0]|0;c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35352,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;kj(b,b+160|0,e,a[e+1>>0]&63,8);i=f;return}function Og(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37520>>0]|0;a[h+1>>0]=a[37521>>0]|0;a[h+2>>0]=a[37522>>0]|0;a[h+3>>0]=a[37523>>0]|0;a[h+4>>0]=a[37524>>0]|0;a[h+5>>0]=a[37525>>0]|0;a[h+6>>0]=a[37526>>0]|0;c[b+28>>2]=2;h=(d[e+2>>0]|0)<<8|(d[e+3>>0]|0);c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35256,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;kj(b,b+160|0,e,a[e+1>>0]&63,16);i=f;return}function Pg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37512>>0]|0;a[h+1>>0]=a[37513>>0]|0;a[h+2>>0]=a[37514>>0]|0;a[h+3>>0]=a[37515>>0]|0;a[h+4>>0]=a[37516>>0]|0;a[h+5>>0]=a[37517>>0]|0;a[h+6>>0]=a[37518>>0]|0;c[b+28>>2]=2;h=(((d[e+2>>0]|0)<<8|(d[e+3>>0]|0))<<8|(d[e+4>>0]|0))<<8|(d[e+5>>0]|0);c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35360,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+2;kj(b,b+160|0,e,a[e+1>>0]&63,32);i=f;return}function Qg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b+8|0;j=c[h>>2]|0;k=a[e+(j<<1)>>0]|0;c[h>>2]=j+1;j=b+32|0;if((k&8)==0){a[j+0>>0]=a[37504>>0]|0;a[j+1>>0]=a[37505>>0]|0;a[j+2>>0]=a[37506>>0]|0;a[j+3>>0]=a[37507>>0]|0;a[j+4>>0]=a[37508>>0]|0;a[j+5>>0]=a[37509>>0]|0;a[j+6>>0]=a[37510>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,32);k=d[e+2>>0]|0;c[g>>2]=(k&128|0)!=0?35288:35296;c[g+4>>2]=k>>>4&7;ab(b+160|0,35280,g|0)|0;l=c[b>>2]|0;m=l|128;c[b>>2]=m;i=f;return}else{a[j+0>>0]=a[37496>>0]|0;a[j+1>>0]=a[37497>>0]|0;a[j+2>>0]=a[37498>>0]|0;a[j+3>>0]=a[37499>>0]|0;a[j+4>>0]=a[37500>>0]|0;a[j+5>>0]=a[37501>>0]|0;a[j+6>>0]=a[37502>>0]|0;c[b+28>>2]=2;kj(b,b+96|0,e,a[e+1>>0]&63,32);j=d[e+2>>0]|0;c[g>>2]=(j&128|0)!=0?35288:35296;c[g+4>>2]=j>>>4&7;ab(b+160|0,35280,g|0)|0;l=c[b>>2]|0;m=l|128;c[b>>2]=m;i=f;return}}function Rg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37488>>0]|0;a[h+1>>0]=a[37489>>0]|0;a[h+2>>0]=a[37490>>0]|0;a[h+3>>0]=a[37491>>0]|0;a[h+4>>0]=a[37492>>0]|0;a[h+5>>0]=a[37493>>0]|0;a[h+6>>0]=a[37494>>0]|0;c[b+28>>2]=2;h=d[e+3>>0]|0;c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35352,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;kj(b,b+160|0,e,a[e+1>>0]&63,8);i=f;return}function Sg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37480>>0]|0;a[h+1>>0]=a[37481>>0]|0;a[h+2>>0]=a[37482>>0]|0;a[h+3>>0]=a[37483>>0]|0;a[h+4>>0]=a[37484>>0]|0;a[h+5>>0]=a[37485>>0]|0;a[h+6>>0]=a[37486>>0]|0;c[b+28>>2]=2;h=(d[e+2>>0]|0)<<8|(d[e+3>>0]|0);c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35256,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+1;kj(b,b+160|0,e,a[e+1>>0]&63,16);i=f;return}function Tg(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[37472>>0]|0;a[h+1>>0]=a[37473>>0]|0;a[h+2>>0]=a[37474>>0]|0;a[h+3>>0]=a[37475>>0]|0;a[h+4>>0]=a[37476>>0]|0;a[h+5>>0]=a[37477>>0]|0;a[h+6>>0]=a[37478>>0]|0;c[b+28>>2]=2;h=(((d[e+2>>0]|0)<<8|(d[e+3>>0]|0))<<8|(d[e+4>>0]|0))<<8|(d[e+5>>0]|0);c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35360,g|0)|0;g=b+8|0;c[g>>2]=(c[g>>2]|0)+2;kj(b,b+160|0,e,a[e+1>>0]&63,32);i=f;return}function Ug(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=b+32|0;a[h+0>>0]=a[35848>>0]|0;a[h+1>>0]=a[35849>>0]|0;a[h+2>>0]=a[35850>>0]|0;c[b+28>>2]=1;h=(d[e>>0]|0)<<8|(d[e+1>>0]|0);c[g>>2]=35704;c[g+4>>2]=h;ab(b+96|0,35256,g|0)|0;i=f;return}



function $m(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,508,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}j=e[h>>1]|0;h=j>>>15;k=(j<<1|h)&65535;j=f+372|0;c[j>>2]=(c[j>>2]|0)+8;co(f,14,k);j=f+166|0;l=e[j>>1]|0;b[j>>1]=(h|0)==0?l&65534:l|1;l=f+156|0;h=c[l>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+h>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[j>>1]=o;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;No(f,k)|0;i=g;return}else{Kj(f);i=g;return}}function an(a){a=a|0;var c=0;c=i;b[a+330>>1]=b[a+160>>1]|0;Tj(a);i=c;return}function bn(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;h=i;j=f+152|0;k=(c[j>>2]|0)+2|0;l=f+160|0;m=e[l>>1]|0;n=(m&128|0)!=0?m|-256:m&255;do{if((n|0)==0){m=f+156|0;o=c[m>>2]|0;if((o&1|0)!=0){Mj(f,o,0,0);i=h;return}p=f+164|0;q=f+162|0;b[q>>1]=b[p>>1]|0;r=o&16777215;o=r+1|0;if(o>>>0<(c[f+36>>2]|0)>>>0){s=c[f+32>>2]|0;t=(d[s+r>>0]<<8|d[s+o>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,r)|0}b[p>>1]=t;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;c[j>>2]=(c[j>>2]|0)+2;m=e[q>>1]|0;u=(m&32768|0)!=0?m|-65536:m;break}Kj(f);i=h;return}else{u=n}}while(0);do{if((g|0)==0){n=f+372|0;c[n>>2]=((b[l>>1]&255)==0?12:8)+(c[n>>2]|0);v=c[f+156>>2]|0}else{n=f+372|0;c[n>>2]=(c[n>>2]|0)+10;n=k+u|0;t=f+156|0;c[t>>2]=n;if((n&1|0)!=0){Mj(f,n,0,0);i=h;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;q=n&16777215;n=q+1|0;if(n>>>0<(c[f+36>>2]|0)>>>0){p=c[f+32>>2]|0;w=(d[p+q>>0]<<8|d[p+n>>0])&65535}else{w=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[m>>1]=w;if((a[f+336>>0]|0)==0){m=(c[t>>2]|0)+2|0;c[t>>2]=m;c[j>>2]=(c[j>>2]|0)+2;v=m;break}Kj(f);i=h;return}}while(0);w=f+156|0;if((v&1|0)!=0){Mj(f,v,0,0);i=h;return}u=f+164|0;b[f+162>>1]=b[u>>1]|0;k=v&16777215;v=k+1|0;if(v>>>0<(c[f+36>>2]|0)>>>0){l=c[f+32>>2]|0;x=(d[l+k>>0]<<8|d[l+v>>0])&65535}else{x=oc[c[f+12>>2]&31](c[f+4>>2]|0,k)|0}b[u>>1]=x;if((a[f+336>>0]|0)==0){x=c[w>>2]|0;c[w>>2]=x+2;c[j>>2]=x+ -2;i=h;return}else{Kj(f);i=h;return}}function cn(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;h=b[e+160>>1]&7;do{if((h|0)==4){j=c[e+156>>2]|0}else if((h|0)==3){k=e+156|0;l=c[k>>2]|0;if((l&1|0)!=0){Mj(e,l,0,0);i=g;return}m=e+164|0;n=e+162|0;b[n>>1]=b[m>>1]|0;o=l&16777215;l=o+1|0;p=e+36|0;if(l>>>0<(c[p>>2]|0)>>>0){q=c[e+32>>2]|0;r=(d[q+o>>0]<<8|d[q+l>>0])&65535}else{r=oc[c[e+12>>2]&31](c[e+4>>2]|0,o)|0}b[m>>1]=r;o=e+336|0;if((a[o>>0]|0)!=0){Kj(e);i=g;return}l=(c[k>>2]|0)+2|0;c[k>>2]=l;q=e+152|0;c[q>>2]=(c[q>>2]|0)+2;if((l&1|0)!=0){Mj(e,l,0,0);i=g;return}b[n>>1]=r;n=l&16777215;l=n+1|0;if(l>>>0<(c[p>>2]|0)>>>0){p=c[e+32>>2]|0;b[m>>1]=d[p+n>>0]<<8|d[p+l>>0]}else{l=oc[c[e+12>>2]&31](c[e+4>>2]|0,n)|0;n=(a[o>>0]|0)==0;b[m>>1]=l;if(!n){Kj(e);i=g;return}}n=(c[k>>2]|0)+2|0;c[k>>2]=n;c[q>>2]=(c[q>>2]|0)+2;j=n}else if((h|0)==2){n=e+156|0;q=c[n>>2]|0;if((q&1|0)!=0){Mj(e,q,0,0);i=g;return}k=e+164|0;b[e+162>>1]=b[k>>1]|0;l=q&16777215;q=l+1|0;if(q>>>0<(c[e+36>>2]|0)>>>0){m=c[e+32>>2]|0;s=(d[m+l>>0]<<8|d[m+q>>0])&65535}else{s=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=s;if((a[e+336>>0]|0)==0){k=(c[n>>2]|0)+2|0;c[n>>2]=k;n=e+152|0;c[n>>2]=(c[n>>2]|0)+2;j=k;break}Kj(e);i=g;return}else{k=e+372|0;c[k>>2]=(c[k>>2]|0)+2;Nj(e);i=g;return}}while(0);s=e+156|0;if((j&1|0)!=0){Mj(e,j,0,0);i=g;return}h=e+164|0;b[e+162>>1]=b[h>>1]|0;r=j&16777215;j=r+1|0;if(j>>>0<(c[e+36>>2]|0)>>>0){k=c[e+32>>2]|0;t=(d[k+r>>0]<<8|d[k+j>>0])&65535}else{t=oc[c[e+12>>2]&31](c[e+4>>2]|0,r)|0}b[h>>1]=t;if((a[e+336>>0]|0)!=0){Kj(e);i=g;return}c[s>>2]=(c[s>>2]|0)+2;s=e+152|0;c[s>>2]=(c[s>>2]|0)+2;if((f|0)==0){f=e+372|0;c[f>>2]=(c[f>>2]|0)+4;i=g;return}else{Qj(e);i=g;return}}function dn(a){a=a|0;var b=0,d=0,e=0;b=i;ak(a);d=0;do{e=c[41928+(d<<2)>>2]|0;if((e|0)!=0){c[a+(d<<2)+400>>2]=e}d=d+1|0}while((d|0)!=1024);c[a+4496>>2]=236;i=b;return}function en(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;g=e+((b[e+160>>1]&7)<<2)+88|0;h=c[g>>2]|0;j=(h&128|0)!=0?h|-256:h&255;h=e+372|0;c[h>>2]=(c[h>>2]|0)+4;eo(e,15,j);h=e+156|0;k=c[h>>2]|0;if((k&1|0)!=0){Mj(e,k,0,0);i=f;return}l=e+164|0;b[e+162>>1]=b[l>>1]|0;m=k&16777215;k=m+1|0;if(k>>>0<(c[e+36>>2]|0)>>>0){n=c[e+32>>2]|0;o=(d[n+m>>0]<<8|d[n+k>>0])&65535}else{o=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[l>>1]=o;if((a[e+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=e+152|0;c[h>>2]=(c[h>>2]|0)+2;c[g>>2]=j;i=f;return}else{Kj(e);i=f;return}}function fn(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;g=i;h=f+160|0;j=(e[h>>1]|0)>>>9&3;k=f+156|0;l=c[k>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;n=f+162|0;b[n>>1]=b[m>>1]|0;o=l&16777215;l=o+1|0;p=f+36|0;if(l>>>0<(c[p>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+o>>0]<<8|d[q+l>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[m>>1]=r;r=f+336|0;if((a[r>>0]|0)!=0){Kj(f);i=g;return}c[k>>2]=(c[k>>2]|0)+2;o=f+152|0;c[o>>2]=(c[o>>2]|0)+2;if(!((b[n>>1]&2047)==0)){l=f+372|0;c[l>>2]=(c[l>>2]|0)+2;Nj(f);i=g;return}l=b[h>>1]&63;if((nc[c[46024+(l<<2)>>2]&63](f,l,2020,8)|0)!=0){i=g;return}if((c[f+340>>2]|0)!=2){l=f+372|0;c[l>>2]=(c[l>>2]|0)+2;Nj(f);i=g;return}l=(j|0)==0;do{if(l){h=f+344|0;q=c[h>>2]|0;s=q&16777215;t=c[p>>2]|0;if(s>>>0<t>>>0){u=a[(c[f+32>>2]|0)+s>>0]|0;v=q;w=t}else{t=oc[c[f+8>>2]&31](c[f+4>>2]|0,s)|0;u=t;v=c[h>>2]|0;w=c[p>>2]|0}h=u&255;t=v+1&16777215;if(t>>>0<w>>>0){x=a[(c[f+32>>2]|0)+t>>0]|0}else{x=oc[c[f+8>>2]&31](c[f+4>>2]|0,t)|0}t=x&255;y=(h&128|0)!=0?h|-256:h;z=(t&128|0)!=0?t|-256:t}else{t=f+344|0;h=c[t>>2]|0;s=h&16777215;if((j|0)!=1){q=s+3|0;A=c[p>>2]|0;if(q>>>0<A>>>0){B=c[f+32>>2]|0;C=((d[B+s>>0]<<8|d[B+(s+1)>>0])<<8|d[B+(s+2)>>0])<<8|d[B+q>>0];D=h;E=A}else{A=oc[c[f+16>>2]&31](c[f+4>>2]|0,s)|0;C=A;D=c[t>>2]|0;E=c[p>>2]|0}A=D+4&16777215;q=A+3|0;if(q>>>0<E>>>0){B=c[f+32>>2]|0;y=C;z=((d[B+A>>0]<<8|d[B+(A+1)>>0])<<8|d[B+(A+2)>>0])<<8|d[B+q>>0];break}else{y=C;z=oc[c[f+16>>2]&31](c[f+4>>2]|0,A)|0;break}}A=s+1|0;q=c[p>>2]|0;if(A>>>0<q>>>0){B=c[f+32>>2]|0;F=(d[B+s>>0]<<8|d[B+A>>0])&65535;G=h;H=q}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,s)|0;F=q;G=c[t>>2]|0;H=c[p>>2]|0}t=F&65535;q=G+2&16777215;s=q+1|0;if(s>>>0<H>>>0){h=c[f+32>>2]|0;I=(d[h+q>>0]<<8|d[h+s>>0])&65535}else{I=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}q=I&65535;y=(t&32768|0)!=0?t|-65536:t;z=(q&32768|0)!=0?q|-65536:q}}while(0);I=b[n>>1]|0;H=I&65535;G=H>>>12&7;do{if((H&32768|0)==0){F=c[f+(G<<2)+88>>2]|0;if(l){J=(F&128|0)!=0?F|-256:F&255;break}if((j|0)==1){J=(F&32768|0)!=0?F|-65536:F&65535}else{J=F}}else{J=c[f+(G<<2)+120>>2]|0}}while(0);G=J^-2147483648;if(G>>>0<(y^-2147483648)>>>0){K=1}else{K=G>>>0>(z^-2147483648)>>>0}G=f+166|0;j=e[G>>1]|0;l=(J|0)==(y|0)|(J|0)==(z|0)?j|4:j&65531;b[G>>1]=K?l|1:l&65534;l=f+372|0;c[l>>2]=(c[l>>2]|0)+14;if(!((I&2048)==0|K^1)){Pj(f);i=g;return}K=c[k>>2]|0;if((K&1|0)!=0){Mj(f,K,0,0);i=g;return}b[n>>1]=b[m>>1]|0;n=K&16777215;K=n+1|0;if(K>>>0<(c[p>>2]|0)>>>0){p=c[f+32>>2]|0;L=(d[p+n>>0]<<8|d[p+K>>0])&65535}else{L=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=L;if((a[r>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;c[o>>2]=(c[o>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function gn(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=f+160|0;k=b[j>>1]&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}k=c[f+(((e[j>>1]|0)>>>9&7)<<2)+88>>2]|0;do{if((k|0)<0){j=f+166|0;b[j>>1]=e[j>>1]|8}else{j=c[h>>2]|0;if((j|0)<0|k>>>0>j>>>0){j=f+166|0;b[j>>1]=b[j>>1]&65527;break}j=f+372|0;c[j>>2]=(c[j>>2]|0)+14;j=f+156|0;l=c[j>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;j=f+152|0;c[j>>2]=(c[j>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}}while(0);Pj(f);i=g;return}function hn(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,4093,8)|0)!=0){i=f;return}if((Jo(e,g)|0)!=0){i=f;return}h=e+372|0;c[h>>2]=(c[h>>2]|0)+8;bo(e,15,a[g>>0]|0);g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function jn(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,4095,16)|0)!=0){i=f;return}if((Ko(e,g)|0)!=0){i=f;return}h=e+372|0;c[h>>2]=(c[h>>2]|0)+8;co(e,15,b[g>>1]|0);g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function kn(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,4095,32)|0)!=0){i=f;return}if((Lo(e,g)|0)!=0){i=f;return}h=e+372|0;c[h>>2]=(c[h>>2]|0)+8;eo(e,15,c[g>>2]|0);g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function ln(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+16|0;h=g;j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;q=f+336|0;if((a[q>>0]|0)!=0){Kj(f);i=g;return}c[j>>2]=(c[j>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;k=e[m>>1]|0;if((k&33544|0)!=0){p=f+372|0;c[p>>2]=(c[p>>2]|0)+2;Nj(f);i=g;return}p=(k&2048|0)!=0;r=k&7;s=b[f+160>>1]&63;if((nc[c[46024+(s<<2)>>2]&63](f,s,4093,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}s=c[h>>2]|0;h=f+((k>>>12&7)<<2)+88|0;t=c[h>>2]|0;if(p){u=(s&-2147483648|0)==0&0==0;v=(t&-2147483648|0)==0&0==0;w=v?t:t;x=v?0:-1;y=u?s:s;z=u?0:-1}else{w=t;x=0;y=s;z=0}s=Yz(w|0,x|0,y|0,z|0)|0;z=G;c[h>>2]=s;do{if((k&1024|0)==0){h=f+166|0;y=e[h>>1]|0;x=(z|0)<0?y|8:y&65523;y=(z|s|0)==0?x|4:x&65531;b[h>>1]=y;if((z|0)==((p&(s|0)<0)<<31>>31|0)){x=y&65533;b[h>>1]=x;A=x;break}else{x=y|2;b[h>>1]=x;A=x;break}}else{c[f+(r<<2)+88>>2]=z;x=f+166|0;h=e[x>>1]|0;y=(z|0)<0?h|8:h&65523;h=((z|s|0)==0?y|4:y&65529)&65533;b[x>>1]=h;A=h}}while(0);s=f+372|0;c[s>>2]=(c[s>>2]|0)+74;b[f+166>>1]=A&65534;A=c[j>>2]|0;if((A&1|0)!=0){Mj(f,A,0,0);i=g;return}b[m>>1]=b[l>>1]|0;m=A&16777215;A=m+1|0;if(A>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;B=(d[o+m>>0]<<8|d[o+A>>0])&65535}else{B=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=B;if((a[q>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[n>>2]=(c[n>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function mn(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0;g=i;i=i+16|0;h=g;j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;q=f+336|0;if((a[q>>0]|0)!=0){Kj(f);i=g;return}c[j>>2]=(c[j>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;k=e[m>>1]|0;if((k&33544|0)!=0){p=f+372|0;c[p>>2]=(c[p>>2]|0)+2;Nj(f);i=g;return}p=(k&2048|0)!=0;r=k>>>12&7;s=k&7;t=b[f+160>>1]&63;if((nc[c[46024+(t<<2)>>2]&63](f,t,4093,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}t=f+(r<<2)+88|0;u=c[t>>2]|0;v=c[h>>2]|0;if((v|0)==0){Oj(f);i=g;return}if(p){if((v|0)<0){w=0-v|0;c[h>>2]=w;x=w}else{x=v}y=x;z=v>>>31;A=u>>>31;B=(u|0)<0?0-u|0:u}else{y=v;z=0;A=0;B=u}do{if((k&1024|0)==0){C=(B>>>0)/(y>>>0)|0;D=(B>>>0)%(y>>>0)|0;E=A;F=27}else{v=c[f+(s<<2)+88>>2]|0;if(p){x=v>>>31;if((v|0)<0){H=x;I=0-u|0;J=((u|0)==0)+~v|0}else{H=x;I=u;J=v}}else{H=A;I=u;J=v}v=Zz(I|0,J|0,y|0,0)|0;x=G;w=_z(I|0,J|0,y|0,0)|0;if(p){if(!(x>>>0>0|(x|0)==0&v>>>0>2147483648)){if(!((v|0)==-2147483648&(x|0)==0&(z|0)==(H|0))){C=v;D=w;E=H;F=27;break}}}else{if(x>>>0<1|(x|0)==1&v>>>0<0){C=v;D=w;E=H;F=27;break}}w=f+166|0;b[w>>1]=e[w>>1]|2}}while(0);if((F|0)==27){F=(z|0)==(E|0)?C:0-C|0;c[t>>2]=F;if((s|0)!=(r|0)){c[f+(s<<2)+88>>2]=(E|0)==0?D:0-D|0}eo(f,15,F)}F=f+372|0;c[F>>2]=(c[F>>2]|0)+144;F=c[j>>2]|0;if((F&1|0)!=0){Mj(f,F,0,0);i=g;return}b[m>>1]=b[l>>1]|0;m=F&16777215;F=m+1|0;if(F>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;K=(d[o+m>>0]<<8|d[o+F>>0])&65535}else{K=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=K;if((a[q>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[n>>2]=(c[n>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function nn(a){a=a|0;var b=0,c=0;b=i;c=e[a+160>>1]|0;if((c&62|0)==58|(c&63|0)==60){cn(a,1);i=b;return}if((c&56|0)==8){_j(a,1);i=b;return}else{$j(a,1);i=b;return}}function on(a){a=a|0;var b=0,c=0;b=i;c=e[a+160>>1]|0;if((c&62|0)==58|(c&63|0)==60){cn(a,0);i=b;return}if((c&56|0)==8){_j(a,0);i=b;return}else{$j(a,0);i=b;return}}function pn(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;if((c&1|0)==0){d=(c&4|0)==0}else{d=0}c=d&1;d=e[a+160>>1]|0;if((d&62|0)==58|(d&63|0)==60){cn(a,c);i=b;return}if((d&56|0)==8){_j(a,c);i=b;return}else{$j(a,c);i=b;return}}function qn(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;if((c&1|0)==0){d=(c&4|0)!=0}else{d=1}c=d&1;d=e[a+160>>1]|0;if((d&62|0)==58|(d&63|0)==60){cn(a,c);i=b;return}if((d&56|0)==8){_j(a,c);i=b;return}else{$j(a,c);i=b;return}}function rn(a){a=a|0;var c=0,d=0,f=0;c=i;d=(b[a+166>>1]&1^1)&65535;f=e[a+160>>1]|0;if((f&62|0)==58|(f&63|0)==60){cn(a,d);i=c;return}if((f&56|0)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function sn(a){a=a|0;var c=0,d=0,f=0;c=i;d=b[a+166>>1]&1;f=e[a+160>>1]|0;if((f&62|0)==58|(f&63|0)==60){cn(a,d);i=c;return}if((f&56|0)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function tn(a){a=a|0;var b=0,c=0,d=0;b=i;c=((e[a+166>>1]|0)>>>2&1^1)&65535;d=e[a+160>>1]|0;if((d&62|0)==58|(d&63|0)==60){cn(a,c);i=b;return}if((d&56|0)==8){_j(a,c);i=b;return}else{$j(a,c);i=b;return}}function un(a){a=a|0;var b=0,c=0,d=0;b=i;c=(e[a+166>>1]|0)>>>2&1;d=e[a+160>>1]|0;if((d&62|0)==58|(d&63|0)==60){cn(a,c);i=b;return}if((d&56|0)==8){_j(a,c);i=b;return}else{$j(a,c);i=b;return}}function vn(a){a=a|0;var b=0,c=0,d=0;b=i;c=((e[a+166>>1]|0)>>>1&1^1)&65535;d=e[a+160>>1]|0;if((d&62|0)==58|(d&63|0)==60){cn(a,c);i=b;return}if((d&56|0)==8){_j(a,c);i=b;return}else{$j(a,c);i=b;return}}function wn(a){a=a|0;var b=0,c=0,d=0;b=i;c=(e[a+166>>1]|0)>>>1&1;d=e[a+160>>1]|0;if((d&62|0)==58|(d&63|0)==60){cn(a,c);i=b;return}if((d&56|0)==8){_j(a,c);i=b;return}else{$j(a,c);i=b;return}}function xn(a){a=a|0;var b=0,c=0,d=0;b=i;c=((e[a+166>>1]|0)>>>3&1^1)&65535;d=e[a+160>>1]|0;if((d&62|0)==58|(d&63|0)==60){cn(a,c);i=b;return}if((d&56|0)==8){_j(a,c);i=b;return}else{$j(a,c);i=b;return}}function yn(a){a=a|0;var b=0,c=0,d=0;b=i;c=(e[a+166>>1]|0)>>>3&1;d=e[a+160>>1]|0;if((d&62|0)==58|(d&63|0)==60){cn(a,c);i=b;return}if((d&56|0)==8){_j(a,c);i=b;return}else{$j(a,c);i=b;return}}function zn(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;d=(c>>>3^c>>>1)&1^1;c=e[a+160>>1]|0;if((c&62|0)==58|(c&63|0)==60){cn(a,d);i=b;return}if((c&56|0)==8){_j(a,d);i=b;return}else{$j(a,d);i=b;return}}function An(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;d=(c>>>3^c>>>1)&1;c=e[a+160>>1]|0;if((c&62|0)==58|(c&63|0)==60){cn(a,d);i=b;return}if((c&56|0)==8){_j(a,d);i=b;return}else{$j(a,d);i=b;return}}function Bn(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;if(((c>>>3^c>>>1)&1|0)==0){d=(c&4|0)==0}else{d=0}c=d&1;d=e[a+160>>1]|0;if((d&62|0)==58|(d&63|0)==60){cn(a,c);i=b;return}if((d&56|0)==8){_j(a,c);i=b;return}else{$j(a,c);i=b;return}}function Cn(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;if(((c>>>3^c>>>1)&1|0)==0){d=(c&4|0)!=0}else{d=1}c=d&1;d=e[a+160>>1]|0;if((d&62|0)==58|(d&63|0)==60){cn(a,c);i=b;return}if((d&56|0)==8){_j(a,c);i=b;return}else{$j(a,c);i=b;return}}function Dn(a){a=a|0;var b=0;b=i;ao(a,1);i=b;return}function En(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b[d+160>>1]&255;if((f|0)==0){g=(c[d+152>>2]|0)+4|0}else if((f|0)==255){g=(c[d+152>>2]|0)+6|0}else{g=(c[d+152>>2]|0)+2|0}f=d+148|0;h=(c[f>>2]|0)+ -4|0;j=h&16777215;k=j+3|0;if(k>>>0<(c[d+36>>2]|0)>>>0){l=d+32|0;a[(c[l>>2]|0)+j>>0]=g>>>24;a[(c[l>>2]|0)+(j+1)>>0]=g>>>16;a[(c[l>>2]|0)+(j+2)>>0]=g>>>8;a[(c[l>>2]|0)+k>>0]=g;c[f>>2]=h;ao(d,1);i=e;return}else{lc[c[d+28>>2]&31](c[d+4>>2]|0,j,g);c[f>>2]=h;ao(d,1);i=e;return}}function Fn(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;if((c&1|0)==0){d=(c&4|0)==0}else{d=0}ao(a,d&1);i=b;return}function Gn(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;if((c&1|0)==0){d=(c&4|0)!=0}else{d=1}ao(a,d&1);i=b;return}function Hn(a){a=a|0;var c=0;c=i;ao(a,(b[a+166>>1]&1^1)&65535);i=c;return}function In(a){a=a|0;var c=0;c=i;ao(a,b[a+166>>1]&1);i=c;return}function Jn(a){a=a|0;var b=0;b=i;ao(a,((e[a+166>>1]|0)>>>2&1^1)&65535);i=b;return}function Kn(a){a=a|0;var b=0;b=i;ao(a,(e[a+166>>1]|0)>>>2&1);i=b;return}function Ln(a){a=a|0;var b=0;b=i;ao(a,((e[a+166>>1]|0)>>>1&1^1)&65535);i=b;return}function Mn(a){a=a|0;var b=0;b=i;ao(a,(e[a+166>>1]|0)>>>1&1);i=b;return}function Nn(a){a=a|0;var b=0;b=i;ao(a,((e[a+166>>1]|0)>>>3&1^1)&65535);i=b;return}function On(a){a=a|0;var b=0;b=i;ao(a,(e[a+166>>1]|0)>>>3&1);i=b;return}function Pn(a){a=a|0;var b=0,c=0;b=i;c=e[a+166>>1]|0;ao(a,(c>>>3^c>>>1)&1^1);i=b;return}function Qn(a){a=a|0;var b=0,c=0;b=i;c=e[a+166>>1]|0;ao(a,(c>>>3^c>>>1)&1);i=b;return}function Rn(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;if(((c>>>3^c>>>1)&1|0)==0){d=(c&4|0)==0}else{d=0}ao(a,d&1);i=b;return}function Sn(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;if(((c>>>3^c>>>1)&1|0)==0){d=(c&4|0)!=0}else{d=1}ao(a,d&1);i=b;return}function Tn(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;if((_n(e,g,2021)|0)!=0){h=e+372|0;c[h>>2]=(c[h>>2]|0)+2;Nj(e);i=f;return}eo(e,15,c[g>>2]<<32-(c[e+352>>2]|0));g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function Un(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;if((_n(f,h,2021)|0)!=0){j=f+372|0;c[j>>2]=(c[j>>2]|0)+2;Nj(f);i=g;return}j=f+162|0;k=(e[j>>1]|0)>>>12&7;l=32-(c[f+352>>2]|0)|0;m=-1>>>l&c[h>>2];c[h>>2]=m;eo(f,15,m<<l);c[f+(k<<2)+88>>2]=m;m=f+156|0;k=c[m>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;b[j>>1]=b[l>>1]|0;j=k&16777215;k=j+1|0;if(k>>>0<(c[f+36>>2]|0)>>>0){h=c[f+32>>2]|0;n=(d[h+j>>0]<<8|d[h+k>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,j)|0}b[l>>1]=n;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function Vn(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;if((_n(e,g,485)|0)!=0){h=e+372|0;c[h>>2]=(c[h>>2]|0)+2;Nj(e);i=f;return}h=c[g>>2]|0;if(($n(e,~h)|0)!=0){g=e+372|0;c[g>>2]=(c[g>>2]|0)+2;Nj(e);i=f;return}eo(e,15,h<<32-(c[e+352>>2]|0));h=e+156|0;g=c[h>>2]|0;if((g&1|0)!=0){Mj(e,g,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=g&16777215;g=k+1|0;if(g>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+g>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=e+152|0;c[h>>2]=(c[h>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function Wn(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;if((_n(f,h,2021)|0)!=0){j=f+372|0;c[j>>2]=(c[j>>2]|0)+2;Nj(f);i=g;return}j=f+162|0;k=(e[j>>1]|0)>>>12&7;l=32-(c[f+352>>2]|0)|0;m=-1>>>l;n=c[h>>2]|0;if((-2147483648>>>l&n|0)==0){o=m&n}else{o=n|~m}c[h>>2]=o;eo(f,15,o<<l);c[f+(k<<2)+88>>2]=o;o=f+156|0;k=c[o>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;b[j>>1]=b[l>>1]|0;j=k&16777215;k=j+1|0;if(k>>>0<(c[f+36>>2]|0)>>>0){h=c[f+32>>2]|0;p=(d[h+j>>0]<<8|d[h+k>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,j)|0}b[l>>1]=p;if((a[f+336>>0]|0)==0){c[o>>2]=(c[o>>2]|0)+2;o=f+152|0;c[o>>2]=(c[o>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function Xn(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;if((_n(e,g,485)|0)!=0){h=e+372|0;c[h>>2]=(c[h>>2]|0)+2;Nj(e);i=f;return}if(($n(e,0)|0)!=0){h=e+372|0;c[h>>2]=(c[h>>2]|0)+2;Nj(e);i=f;return}eo(e,15,c[g>>2]<<32-(c[e+352>>2]|0));g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function Yn(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;if((_n(e,g,485)|0)!=0){h=e+372|0;c[h>>2]=(c[h>>2]|0)+2;Nj(e);i=f;return}if(($n(e,-1)|0)!=0){h=e+372|0;c[h>>2]=(c[h>>2]|0)+2;Nj(e);i=f;return}eo(e,15,c[g>>2]<<32-(c[e+352>>2]|0));g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function Zn(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;if((_n(f,h,2021)|0)!=0){j=f+372|0;c[j>>2]=(c[j>>2]|0)+2;Nj(f);i=g;return}j=f+162|0;k=c[f+(((e[j>>1]|0)>>>12&7)<<2)+88>>2]|0;c[h>>2]=k;if(($n(f,k)|0)!=0){h=f+372|0;c[h>>2]=(c[h>>2]|0)+2;Nj(f);i=g;return}eo(f,15,k<<32-(c[f+352>>2]|0));k=f+156|0;h=c[k>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}l=f+164|0;b[j>>1]=b[l>>1]|0;j=h&16777215;h=j+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+j>>0]<<8|d[m+h>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,j)|0}b[l>>1]=n;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function _n(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;j=e+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(e,k,0,0);l=1;i=h;return l|0}m=e+164|0;n=e+162|0;b[n>>1]=b[m>>1]|0;o=k&16777215;k=o+1|0;p=e+36|0;if(k>>>0<(c[p>>2]|0)>>>0){q=c[e+32>>2]|0;r=(d[q+o>>0]<<8|d[q+k>>0])&65535}else{r=oc[c[e+12>>2]&31](c[e+4>>2]|0,o)|0}b[m>>1]=r;if((a[e+336>>0]|0)!=0){Kj(e);l=1;i=h;return l|0}c[j>>2]=(c[j>>2]|0)+2;j=e+152|0;c[j>>2]=(c[j>>2]|0)+2;j=b[n>>1]|0;n=j&65535;r=n>>>6;if((n&2048|0)==0){s=r&31}else{s=c[e+((r&7)<<2)+88>>2]|0}if((j&32)==0){t=n}else{t=c[e+((n&7)<<2)+88>>2]|0}n=t&31;t=(n|0)==0?32:n;n=b[e+160>>1]&63;if((nc[c[46024+(n<<2)>>2]&63](e,n,g,8)|0)!=0){l=1;i=h;return l|0}c[e+348>>2]=s;g=e+352|0;c[g>>2]=t;n=c[e+340>>2]|0;if((n|0)==1){j=c[e+((c[e+344>>2]&7)<<2)+88>>2]|0;r=s+t&31;if((r|0)==0){u=j}else{u=j>>>(32-r|0)|j<<r}c[f>>2]=u}else if((n|0)==2){n=c[e+344>>2]|0;u=s>>>3;c[f>>2]=0;r=c[g>>2]|0;if((r|0)!=0){g=e+32|0;j=e+8|0;t=e+4|0;m=((s|0)<0?u|-536870912:u)+n|0;n=e+356|0;u=r;r=s;while(1){s=r&7;o=8-s|0;k=o>>>0>u>>>0?u:o;q=o-k|0;o=m&16777215;if(o>>>0<(c[p>>2]|0)>>>0){v=a[(c[g>>2]|0)+o>>0]|0}else{v=oc[c[j>>2]&31](c[t>>2]|0,o)|0}a[n>>0]=v;c[f>>2]=(255<<q&255>>>s&(v&255))>>>q|c[f>>2]<<k;if((u|0)==(k|0)){break}else{m=m+1|0;n=n+1|0;u=u-k|0;r=k+s|0}}}}else{l=1;i=h;return l|0}r=e+372|0;c[r>>2]=(c[r>>2]|0)+18;l=0;i=h;return l|0}function $n(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;g=c[b+340>>2]|0;if((g|0)==2){h=c[b+348>>2]|0;j=h>>>3;k=c[b+352>>2]|0;if((k|0)==0){l=0;i=f;return l|0}m=b+36|0;n=b+32|0;o=b+20|0;p=b+4|0;q=(c[b+344>>2]|0)+((h|0)<0?j|-536870912:j)|0;j=b+356|0;r=k;k=h;while(1){h=k&7;s=8-h|0;t=s>>>0>r>>>0?r:s;u=s-t|0;s=255<<u&255>>>h;v=r-t|0;w=((s^255)&(d[j>>0]|0)|e>>>(v-u|0)&s)&255;s=q&16777215;if(s>>>0<(c[m>>2]|0)>>>0){a[(c[n>>2]|0)+s>>0]=w}else{lc[c[o>>2]&31](c[p>>2]|0,s,w)}if((r|0)==(t|0)){l=0;break}else{q=q+1|0;j=j+1|0;r=v;k=t+h|0}}i=f;return l|0}else if((g|0)==1){g=b+((c[b+344>>2]&7)<<2)+88|0;k=32-(c[b+352>>2]|0)|0;r=-1>>>k;j=k-(c[b+348>>2]|0)&31;if((j|0)==0){x=e;y=r}else{b=32-j|0;x=e>>>b|e<<j;y=r>>>b|r<<j}c[g>>2]=c[g>>2]&~y|y&x;l=0;i=f;return l|0}else{l=1;i=f;return l|0}return 0}function ao(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=i;j=f+152|0;k=(c[j>>2]|0)+2|0;l=f+160|0;m=e[l>>1]|0;n=(m&128|0)!=0?m|-256:m&255;do{if((n|0)==0){m=f+156|0;o=c[m>>2]|0;if((o&1|0)!=0){Mj(f,o,0,0);i=h;return}p=f+164|0;q=f+162|0;b[q>>1]=b[p>>1]|0;r=o&16777215;o=r+1|0;if(o>>>0<(c[f+36>>2]|0)>>>0){s=c[f+32>>2]|0;t=(d[s+r>>0]<<8|d[s+o>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,r)|0}b[p>>1]=t;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;c[j>>2]=(c[j>>2]|0)+2;m=e[q>>1]|0;u=(m&32768|0)!=0?m|-65536:m;break}Kj(f);i=h;return}else{if((n&255|0)==255){m=f+156|0;q=c[m>>2]|0;if((q&1|0)!=0){Mj(f,q,0,0);i=h;return}p=f+164|0;r=f+162|0;b[r>>1]=b[p>>1]|0;o=q&16777215;q=o+1|0;s=f+36|0;if(q>>>0<(c[s>>2]|0)>>>0){v=c[f+32>>2]|0;w=(d[v+o>>0]<<8|d[v+q>>0])&65535}else{w=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[p>>1]=w;o=f+336|0;if((a[o>>0]|0)!=0){Kj(f);i=h;return}q=(c[m>>2]|0)+2|0;c[m>>2]=q;c[j>>2]=(c[j>>2]|0)+2;v=b[r>>1]|0;if((q&1|0)!=0){Mj(f,q,0,0);i=h;return}b[r>>1]=w;x=q&16777215;q=x+1|0;if(q>>>0<(c[s>>2]|0)>>>0){s=c[f+32>>2]|0;b[p>>1]=d[s+x>>0]<<8|d[s+q>>0]}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,x)|0;x=(a[o>>0]|0)==0;b[p>>1]=q;if(!x){Kj(f);i=h;return}}c[m>>2]=(c[m>>2]|0)+2;c[j>>2]=(c[j>>2]|0)+2;u=e[r>>1]|(v&65535)<<16}else{u=n}}}while(0);do{if((g|0)==0){n=f+372|0;c[n>>2]=((b[l>>1]&255)==0?12:8)+(c[n>>2]|0);y=c[f+156>>2]|0}else{n=f+372|0;c[n>>2]=(c[n>>2]|0)+10;n=k+u|0;w=f+156|0;c[w>>2]=n;if((n&1|0)!=0){Mj(f,n,0,0);i=h;return}t=f+164|0;b[f+162>>1]=b[t>>1]|0;v=n&16777215;n=v+1|0;if(n>>>0<(c[f+36>>2]|0)>>>0){r=c[f+32>>2]|0;z=(d[r+v>>0]<<8|d[r+n>>0])&65535}else{z=oc[c[f+12>>2]&31](c[f+4>>2]|0,v)|0}b[t>>1]=z;if((a[f+336>>0]|0)==0){t=(c[w>>2]|0)+2|0;c[w>>2]=t;c[j>>2]=(c[j>>2]|0)+2;y=t;break}Kj(f);i=h;return}}while(0);z=f+156|0;if((y&1|0)!=0){Mj(f,y,0,0);i=h;return}u=f+164|0;b[f+162>>1]=b[u>>1]|0;k=y&16777215;y=k+1|0;if(y>>>0<(c[f+36>>2]|0)>>>0){l=c[f+32>>2]|0;A=(d[l+k>>0]<<8|d[l+y>>0])&65535}else{A=oc[c[f+12>>2]&31](c[f+4>>2]|0,k)|0}b[u>>1]=A;if((a[f+336>>0]|0)==0){A=c[z>>2]|0;c[z>>2]=A+2;c[j>>2]=A+ -2;i=h;return}else{Kj(f);i=h;return}}function bo(a,c,d){a=a|0;c=c|0;d=d|0;var f=0;if(d<<24>>24==0){f=4}else{f=d<<24>>24<0?8:0}d=c&255;c=a+166|0;b[c>>1]=(e[c>>1]|0)&(d^65535)|f&d;return}function co(a,c,d){a=a|0;c=c|0;d=d|0;var f=0;if(d<<16>>16==0){f=4}else{f=d<<16>>16<0?8:0}d=c&255;c=a+166|0;b[c>>1]=(e[c>>1]|0)&(d^65535)|f&d;return}function eo(a,c,d){a=a|0;c=c|0;d=d|0;var f=0;if((d|0)==0){f=4}else{f=d>>31&8}d=c&255;c=a+166|0;b[c>>1]=(e[c>>1]|0)&(d^65535)|f&d;return}function fo(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a+166|0;a=e[h>>1]|0;j=c<<24>>24==0?a|4:a&65531;b[h>>1]=j;a=(d&255)>>>7;d=(f&255)>>>7;if(c<<24>>24>-1){c=(d|a|0)==0?0:17;if((d&a|0)==0){k=c}else{k=(c&65535|2)&65535}}else{c=(d&a|0)==0?8:25;if((d|a|0)==0){k=(c&65535|2)&65535}else{k=c}}b[h>>1]=j&65508|k&65535;i=g;return}function go(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a+166|0;a=e[h>>1]|0;j=c<<16>>16==0?a|4:a&65531;b[h>>1]=j;a=(d&65535)>>>15;d=(f&65535)>>>15;if(c<<16>>16>-1){c=(d|a|0)==0?0:17;if((d&a|0)==0){k=c}else{k=(c&65535|2)&65535}}else{c=(d&a|0)==0?8:25;if((d|a|0)==0){k=(c&65535|2)&65535}else{k=c}}b[h>>1]=j&65508|k&65535;i=g;return}function ho(a,c,d,f){a=a|0;c=c|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=a+166|0;a=e[h>>1]|0;j=(c|0)==0?a|4:a&65531;b[h>>1]=j;a=d>>>31;d=f>>>31;if((c|0)>-1){c=(d|a|0)==0?0:17;if((d&a|0)==0){k=c}else{k=(c&65535|2)&65535}}else{c=(d&a|0)==0?8:25;if((d|a|0)==0){k=(c&65535|2)&65535}else{k=c}}b[h>>1]=j&65508|k&65535;i=g;return}function io(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=(d&255)>>>7;d=(e&255)>>>7;if(c<<24>>24>-1){e=(d|g|0)==0?0:17;if((d&g|0)==0){h=e}else{h=(e&65535|2)&65535}}else{e=(d&g|0)==0?8:25;if((d|g|0)==0){h=(e&65535|2)&65535}else{h=e}}e=a+166|0;a=b[e>>1]&65508|h&65535;b[e>>1]=c<<24>>24==0?a:a&65531;i=f;return}function jo(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=(d&65535)>>>15;d=(e&65535)>>>15;if(c<<16>>16>-1){e=(d|g|0)==0?0:17;if((d&g|0)==0){h=e}else{h=(e&65535|2)&65535}}else{e=(d&g|0)==0?8:25;if((d|g|0)==0){h=(e&65535|2)&65535}else{h=e}}e=a+166|0;a=b[e>>1]&65508|h&65535;b[e>>1]=c<<16>>16==0?a:a&65531;i=f;return}function ko(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=d>>>31;d=e>>>31;if((c|0)>-1){e=(d|g|0)==0?0:17;if((d&g|0)==0){h=e}else{h=(e&65535|2)&65535}}else{e=(d&g|0)==0?8:25;if((d|g|0)==0){h=(e&65535|2)&65535}else{h=e}}e=a+166|0;a=b[e>>1]&65508|h&65535;b[e>>1]=(c|0)==0?a:a&65531;i=f;return}function lo(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=d<<24>>24<0;d=e<<24>>24>-1;if(c<<24>>24>-1){e=g&d?17:0;if(g|d){h=e}else{h=(e&65535|2)&65535}}else{e=g|d?25:8;if(g&d){h=(e&65535|2)&65535}else{h=e}}e=a+166|0;a=b[e>>1]&65520|h&15;b[e>>1]=c<<24>>24==0?a|4:a;i=f;return}function mo(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=d<<16>>16<0;d=e<<16>>16>-1;if(c<<16>>16>-1){e=g&d?17:0;if(g|d){h=e}else{h=(e&65535|2)&65535}}else{e=g|d?25:8;if(g&d){h=(e&65535|2)&65535}else{h=e}}e=a+166|0;a=b[e>>1]&65520|h&15;b[e>>1]=c<<16>>16==0?a|4:a;i=f;return}function no(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=(d|0)<0;d=(e|0)>-1;if((c|0)>-1){e=g&d?17:0;if(g|d){h=e}else{h=(e&65535|2)&65535}}else{e=g|d?25:8;if(g&d){h=(e&65535|2)&65535}else{h=e}}e=a+166|0;a=b[e>>1]&65520|h&15;b[e>>1]=(c|0)==0?a|4:a;i=f;return}function oo(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=d<<24>>24<0;d=e<<24>>24>-1;if(c<<24>>24>-1){e=g&d?17:0;if(g|d){h=e}else{h=(e&65535|2)&65535}}else{e=g|d?25:8;if(g&d){h=(e&65535|2)&65535}else{h=e}}e=a+166|0;a=b[e>>1]&65504|h&31;b[e>>1]=c<<24>>24==0?a|4:a;i=f;return}function po(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=d<<16>>16<0;d=e<<16>>16>-1;if(c<<16>>16>-1){e=g&d?17:0;if(g|d){h=e}else{h=(e&65535|2)&65535}}else{e=g|d?25:8;if(g&d){h=(e&65535|2)&65535}else{h=e}}e=a+166|0;a=b[e>>1]&65504|h&31;b[e>>1]=c<<16>>16==0?a|4:a;i=f;return}function qo(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=(d|0)<0;d=(e|0)>-1;if((c|0)>-1){e=g&d?17:0;if(g|d){h=e}else{h=(e&65535|2)&65535}}else{e=g|d?25:8;if(g&d){h=(e&65535|2)&65535}else{h=e}}e=a+166|0;a=b[e>>1]&65504|h&31;b[e>>1]=(c|0)==0?a|4:a;i=f;return}function ro(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=d<<24>>24<0;d=e<<24>>24>-1;if(c<<24>>24>-1){e=g&d?17:0;if(g|d){h=e}else{h=(e&65535|2)&65535}}else{e=g|d?25:8;if(g&d){h=(e&65535|2)&65535}else{h=e}}e=a+166|0;a=b[e>>1]&65508|h&27;b[e>>1]=c<<24>>24==0?a:a&65531;i=f;return}function so(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=d<<16>>16<0;d=e<<16>>16>-1;if(c<<16>>16>-1){e=g&d?17:0;if(g|d){h=e}else{h=(e&65535|2)&65535}}else{e=g|d?25:8;if(g&d){h=(e&65535|2)&65535}else{h=e}}e=a+166|0;a=b[e>>1]&65508|h&27;b[e>>1]=c<<16>>16==0?a:a&65531;i=f;return}function to(a,c,d,e){a=a|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=(d|0)<0;d=(e|0)>-1;if((c|0)>-1){e=g&d?17:0;if(g|d){h=e}else{h=(e&65535|2)&65535}}else{e=g|d?25:8;if(g&d){h=(e&65535|2)&65535}else{h=e}}e=a+166|0;a=b[e>>1]&65508|h&27;b[e>>1]=(c|0)==0?a:a&65531;i=f;return}function uo(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;e=i;if((d&1|0)==0){Nj(a);f=1;i=e;return f|0}else{c[a+340>>2]=1;c[a+344>>2]=b&7;f=0;i=e;return f|0}return 0}function vo(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;e=i;if((d&2|0)==0){Nj(a);f=1;i=e;return f|0}else{c[a+340>>2]=1;c[a+344>>2]=b&7|8;f=0;i=e;return f|0}return 0}function wo(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;e=i;if((d&4|0)==0){Nj(a);f=1;i=e;return f|0}else{c[a+340>>2]=2;c[a+344>>2]=c[a+((b&7)<<2)+120>>2];f=0;i=e;return f|0}return 0}function xo(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;if((d&8|0)==0){Nj(a);g=1;i=f;return g|0}else{c[a+340>>2]=2;d=a+((b&7)<<2)+120|0;b=c[d>>2]|0;c[a+344>>2]=b;c[d>>2]=b+(e>>>3);g=0;i=f;return g|0}return 0}function yo(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;b=i;if((d&8|0)==0){Nj(a);f=1;i=b;return f|0}else{c[a+340>>2]=2;d=a+148|0;g=c[d>>2]|0;c[a+344>>2]=g;c[d>>2]=g+((e|0)==8?2:e>>>3);f=0;i=b;return f|0}return 0}function zo(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;if((d&16|0)==0){Nj(a);g=1;i=f;return g|0}else{c[a+340>>2]=2;d=a+((b&7)<<2)+120|0;b=(c[d>>2]|0)-(e>>>3)|0;c[a+344>>2]=b;c[d>>2]=b;b=a+372|0;c[b>>2]=(c[b>>2]|0)+2;g=0;i=f;return g|0}return 0}function Ao(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;b=i;if((d&16|0)==0){Nj(a);f=1;i=b;return f|0}else{c[a+340>>2]=2;d=a+148|0;g=(c[d>>2]|0)-((e|0)==8?2:e>>>3)|0;c[a+344>>2]=g;c[d>>2]=g;g=a+372|0;c[g>>2]=(c[g>>2]|0)+2;f=0;i=b;return f|0}return 0}function Bo(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=i;if((h&32|0)==0){Nj(f);k=1;i=j;return k|0}h=f+156|0;l=c[h>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);k=1;i=j;return k|0}m=f+164|0;n=f+162|0;b[n>>1]=b[m>>1]|0;o=l&16777215;l=o+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+o>>0]<<8|d[p+l>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[m>>1]=q;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;c[f+340>>2]=2;h=e[n>>1]|0;c[f+344>>2]=((h&32768|0)!=0?h|-65536:h)+(c[f+((g&7)<<2)+120>>2]|0);g=f+372|0;c[g>>2]=(c[g>>2]|0)+4;k=0;i=j;return k|0}else{Kj(f);k=1;i=j;return k|0}return 0}function Co(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;if((g&64|0)==0){Nj(e);j=1;i=h;return j|0}g=e+156|0;k=c[g>>2]|0;if((k&1|0)!=0){Mj(e,k,0,0);j=1;i=h;return j|0}l=e+164|0;m=e+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;if(k>>>0<(c[e+36>>2]|0)>>>0){o=c[e+32>>2]|0;p=(d[o+n>>0]<<8|d[o+k>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,n)|0}b[l>>1]=p;if((a[e+336>>0]|0)!=0){Kj(e);j=1;i=h;return j|0}c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;c[e+340>>2]=2;g=c[e+((f&7)<<2)+120>>2]|0;f=e+344|0;c[f>>2]=g;p=b[m>>1]|0;do{if((c[e>>2]&4|0)==0){q=0}else{m=p&65535;if((m&256|0)==0){q=m>>>9&3;break}j=Po(e,m)|0;i=h;return j|0}}while(0);m=p&65535;l=((m&128|0)!=0?m|-256:m&255)+g|0;c[f>>2]=l;g=m>>>12&7;if((m&32768|0)==0){r=e+(g<<2)+88|0}else{r=e+(g<<2)+120|0}g=c[r>>2]|0;if((p&2048)==0){s=(g&32768|0)!=0?g|-65536:g&65535}else{s=g}c[f>>2]=l+(s<<q);q=e+372|0;c[q>>2]=(c[q>>2]|0)+6;j=0;i=h;return j|0}function Do(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;j=i;if((h&128|0)==0){Nj(f);k=1;i=j;return k|0}h=f+156|0;g=c[h>>2]|0;if((g&1|0)!=0){Mj(f,g,0,0);k=1;i=j;return k|0}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=g&16777215;g=n+1|0;if(g>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+g>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=p;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;c[f+340>>2]=2;h=e[m>>1]|0;c[f+344>>2]=(h&32768|0)!=0?h|-65536:h;h=f+372|0;c[h>>2]=(c[h>>2]|0)+4;k=0;i=j;return k|0}else{Kj(f);k=1;i=j;return k|0}return 0}function Eo(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;j=i;if((h&256|0)==0){Nj(f);k=1;i=j;return k|0}h=f+156|0;g=c[h>>2]|0;if((g&1|0)!=0){Mj(f,g,0,0);k=1;i=j;return k|0}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=g&16777215;g=n+1|0;o=f+36|0;if(g>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+g>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;n=f+336|0;if((a[n>>0]|0)!=0){Kj(f);k=1;i=j;return k|0}g=(c[h>>2]|0)+2|0;c[h>>2]=g;p=f+152|0;c[p>>2]=(c[p>>2]|0)+2;c[f+340>>2]=2;r=f+344|0;c[r>>2]=e[m>>1]|0;if((g&1|0)!=0){Mj(f,g,0,0);k=1;i=j;return k|0}b[m>>1]=q;q=g&16777215;g=q+1|0;if(g>>>0<(c[o>>2]|0)>>>0){o=c[f+32>>2]|0;b[l>>1]=d[o+q>>0]<<8|d[o+g>>0]}else{g=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0;q=(a[n>>0]|0)==0;b[l>>1]=g;if(!q){Kj(f);k=1;i=j;return k|0}}c[h>>2]=(c[h>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;c[r>>2]=e[m>>1]|c[r>>2]<<16;r=f+372|0;c[r>>2]=(c[r>>2]|0)+8;k=0;i=j;return k|0}function Fo(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=i;if((h&512|0)==0){Nj(f);k=1;i=j;return k|0}c[f+340>>2]=2;h=f+156|0;g=c[h>>2]|0;l=f+344|0;c[l>>2]=g+ -2;if((g&1|0)!=0){Mj(f,g,0,0);k=1;i=j;return k|0}m=f+164|0;n=f+162|0;b[n>>1]=b[m>>1]|0;o=g&16777215;g=o+1|0;if(g>>>0<(c[f+36>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+o>>0]<<8|d[p+g>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[m>>1]=q;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;h=e[n>>1]|0;c[l>>2]=((h&32768|0)!=0?h|-65536:h)+(c[l>>2]|0);l=f+372|0;c[l>>2]=(c[l>>2]|0)+4;k=0;i=j;return k|0}else{Kj(f);k=1;i=j;return k|0}return 0}function Go(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;h=i;if((g&1024|0)==0){Nj(e);j=1;i=h;return j|0}c[e+340>>2]=2;g=e+156|0;f=c[g>>2]|0;k=e+344|0;c[k>>2]=f+ -2;if((f&1|0)!=0){Mj(e,f,0,0);j=1;i=h;return j|0}l=e+164|0;m=e+162|0;b[m>>1]=b[l>>1]|0;n=f&16777215;f=n+1|0;if(f>>>0<(c[e+36>>2]|0)>>>0){o=c[e+32>>2]|0;p=(d[o+n>>0]<<8|d[o+f>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,n)|0}b[l>>1]=p;if((a[e+336>>0]|0)!=0){Kj(e);j=1;i=h;return j|0}c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;g=b[m>>1]|0;do{if((c[e>>2]&4|0)==0){q=0}else{m=g&65535;if((m&256|0)==0){q=m>>>9&3;break}j=Po(e,m)|0;i=h;return j|0}}while(0);m=g&65535;p=((m&128|0)!=0?m|-256:m&255)+(c[k>>2]|0)|0;c[k>>2]=p;l=m>>>12&7;if((m&32768|0)==0){r=e+(l<<2)+88|0}else{r=e+(l<<2)+120|0}l=c[r>>2]|0;if((g&2048)==0){s=(l&32768|0)!=0?l|-65536:l&65535}else{s=l}c[k>>2]=p+(s<<q);q=e+372|0;c[q>>2]=(c[q>>2]|0)+6;j=0;i=h;return j|0}function Ho(f,g,h,j){f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;if((h&2048|0)==0){Nj(f);k=1;i=g;return k|0}h=f+156|0;l=c[h>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);k=1;i=g;return k|0}m=f+164|0;n=f+162|0;b[n>>1]=b[m>>1]|0;o=l&16777215;l=o+1|0;p=f+36|0;if(l>>>0<(c[p>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+o>>0]<<8|d[q+l>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[m>>1]=r;o=f+336|0;if((a[o>>0]|0)!=0){Kj(f);k=1;i=g;return k|0}l=(c[h>>2]|0)+2|0;c[h>>2]=l;q=f+152|0;c[q>>2]=(c[q>>2]|0)+2;c[f+340>>2]=0;s=e[n>>1]|0;t=f+344|0;c[t>>2]=s;if((j|0)==16){u=f+372|0;c[u>>2]=(c[u>>2]|0)+4;k=0;i=g;return k|0}else if((j|0)==32){if((l&1|0)!=0){Mj(f,l,0,0);k=1;i=g;return k|0}b[n>>1]=r;r=l&16777215;l=r+1|0;if(l>>>0<(c[p>>2]|0)>>>0){p=c[f+32>>2]|0;b[m>>1]=d[p+r>>0]<<8|d[p+l>>0]}else{l=oc[c[f+12>>2]&31](c[f+4>>2]|0,r)|0;r=(a[o>>0]|0)==0;b[m>>1]=l;if(!r){Kj(f);k=1;i=g;return k|0}}c[h>>2]=(c[h>>2]|0)+2;c[q>>2]=(c[q>>2]|0)+2;c[t>>2]=e[n>>1]|c[t>>2]<<16;n=f+372|0;c[n>>2]=(c[n>>2]|0)+8;k=0;i=g;return k|0}else{c[t>>2]=s&255;s=f+372|0;c[s>>2]=(c[s>>2]|0)+4;k=0;i=g;return k|0}return 0}function Io(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=i;Nj(a);i=d;return 1}function Jo(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=c[b+340>>2]|0;if((f|0)==0){a[d>>0]=c[b+344>>2];g=0;i=e;return g|0}else if((f|0)==1){h=c[b+344>>2]|0;if(h>>>0<8){a[d>>0]=c[b+((h&7)<<2)+88>>2];g=0;i=e;return g|0}else{Nj(b);g=1;i=e;return g|0}}else if((f|0)==2){f=c[b+344>>2]&16777215;if(f>>>0<(c[b+36>>2]|0)>>>0){j=a[(c[b+32>>2]|0)+f>>0]|0}else{j=oc[c[b+8>>2]&31](c[b+4>>2]|0,f)|0}a[d>>0]=j;j=b+372|0;c[j>>2]=(c[j>>2]|0)+4;if((a[b+336>>0]|0)==0){g=0;i=e;return g|0}Kj(b);g=1;i=e;return g|0}else{Nj(b);g=1;i=e;return g|0}return 0}function Ko(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;h=c[e+340>>2]|0;if((h|0)==2){j=c[e+344>>2]|0;if((j&1|0)!=0){if((c[e>>2]&1|0)==0){Mj(e,j,1,0);k=1;i=g;return k|0}}l=j&16777215;j=l+1|0;if(j>>>0<(c[e+36>>2]|0)>>>0){m=c[e+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[f>>1]=n;n=e+372|0;c[n>>2]=(c[n>>2]|0)+4;if((a[e+336>>0]|0)==0){k=0;i=g;return k|0}Kj(e);k=1;i=g;return k|0}else if((h|0)==0){b[f>>1]=c[e+344>>2];k=0;i=g;return k|0}else if((h|0)==1){h=c[e+344>>2]|0;do{if(h>>>0<8){o=c[e+((h&7)<<2)+88>>2]&65535}else{if(h>>>0<16){o=c[e+((h&7)<<2)+120>>2]|0;break}Nj(e);k=1;i=g;return k|0}}while(0);b[f>>1]=o;k=0;i=g;return k|0}else{Nj(e);k=1;i=g;return k|0}return 0}function Lo(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=c[b+340>>2]|0;if((g|0)==2){h=c[b+344>>2]|0;if((h&1|0)!=0){if((c[b>>2]&1|0)==0){Mj(b,h,1,0);j=1;i=f;return j|0}}k=h&16777215;h=k+3|0;if(h>>>0<(c[b+36>>2]|0)>>>0){l=c[b+32>>2]|0;m=((d[l+k>>0]<<8|d[l+(k+1)>>0])<<8|d[l+(k+2)>>0])<<8|d[l+h>>0]}else{m=oc[c[b+16>>2]&31](c[b+4>>2]|0,k)|0}c[e>>2]=m;m=b+372|0;c[m>>2]=(c[m>>2]|0)+8;if((a[b+336>>0]|0)==0){j=0;i=f;return j|0}Kj(b);j=1;i=f;return j|0}else if((g|0)==1){m=c[b+344>>2]|0;do{if(m>>>0<8){n=b+((m&7)<<2)+88|0}else{if(m>>>0<16){n=b+((m&7)<<2)+120|0;break}Nj(b);j=1;i=f;return j|0}}while(0);c[e>>2]=c[n>>2];j=0;i=f;return j|0}else if((g|0)==0){c[e>>2]=c[b+344>>2];j=0;i=f;return j|0}else{Nj(b);j=1;i=f;return j|0}return 0}function Mo(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;f=c[b+340>>2]|0;if((f|0)==0){Nj(b);g=1;i=e;return g|0}else if((f|0)==2){h=c[b+344>>2]&16777215;if(h>>>0<(c[b+36>>2]|0)>>>0){a[(c[b+32>>2]|0)+h>>0]=d}else{lc[c[b+20>>2]&31](c[b+4>>2]|0,h,d)}h=b+372|0;c[h>>2]=(c[h>>2]|0)+4;if((a[b+336>>0]|0)==0){g=0;i=e;return g|0}Kj(b);g=1;i=e;return g|0}else if((f|0)==1){f=c[b+344>>2]|0;if(f>>>0<8){h=b+((f&7)<<2)+88|0;c[h>>2]=c[h>>2]&-256|d&255;g=0;i=e;return g|0}else{Nj(b);g=1;i=e;return g|0}}else{Nj(b);g=1;i=e;return g|0}return 0}function No(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=c[b+340>>2]|0;if((f|0)==1){g=c[b+344>>2]|0;if(g>>>0<8){h=b+((g&7)<<2)+88|0;c[h>>2]=c[h>>2]&-65536|d&65535;j=0;i=e;return j|0}if(g>>>0<16){h=d&65535;c[b+((g&7)<<2)+120>>2]=(h&32768|0)==0?h:h|-65536;j=0;i=e;return j|0}else{Nj(b);j=1;i=e;return j|0}}else if((f|0)==2){h=c[b+344>>2]|0;if((h&1|0)!=0){if((c[b>>2]&1|0)==0){Mj(b,h,1,1);j=1;i=e;return j|0}}g=h&16777215;h=g+1|0;if(h>>>0<(c[b+36>>2]|0)>>>0){k=b+32|0;a[(c[k>>2]|0)+g>>0]=(d&65535)>>>8;a[(c[k>>2]|0)+h>>0]=d}else{lc[c[b+24>>2]&31](c[b+4>>2]|0,g,d)}d=b+372|0;c[d>>2]=(c[d>>2]|0)+4;if((a[b+336>>0]|0)==0){j=0;i=e;return j|0}Kj(b);j=1;i=e;return j|0}else if((f|0)==0){Nj(b);j=1;i=e;return j|0}else{Nj(b);j=1;i=e;return j|0}return 0}function Oo(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=c[b+340>>2]|0;if((f|0)==1){g=c[b+344>>2]|0;if(g>>>0<8){c[b+((g&7)<<2)+88>>2]=d;h=0;i=e;return h|0}if(g>>>0<16){c[b+((g&7)<<2)+120>>2]=d;h=0;i=e;return h|0}else{Nj(b);h=1;i=e;return h|0}}else if((f|0)==2){g=c[b+344>>2]|0;if((g&1|0)!=0){if((c[b>>2]&1|0)==0){Mj(b,g,1,1);h=1;i=e;return h|0}}j=g&16777215;g=j+3|0;if(g>>>0<(c[b+36>>2]|0)>>>0){k=b+32|0;a[(c[k>>2]|0)+j>>0]=d>>>24;a[(c[k>>2]|0)+(j+1)>>0]=d>>>16;a[(c[k>>2]|0)+(j+2)>>0]=d>>>8;a[(c[k>>2]|0)+g>>0]=d}else{lc[c[b+28>>2]&31](c[b+4>>2]|0,j,d)}d=b+372|0;c[d>>2]=(c[d>>2]|0)+8;if((a[b+336>>0]|0)==0){h=0;i=e;return h|0}Kj(b);h=1;i=e;return h|0}else if((f|0)==0){Nj(b);h=1;i=e;return h|0}else{Nj(b);h=1;i=e;return h|0}return 0}function Po(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;j=(g&64|0)!=0;if((g&128|0)!=0){c[f+344>>2]=0}k=g>>>9&3;if(j){l=0}else{m=g>>>12&7;if((g&32768|0)==0){n=f+(m<<2)+88|0}else{n=f+(m<<2)+120|0}m=c[n>>2]|0;if((g&2048|0)==0){l=(m&32768|0)!=0?m|-65536:m&65535}else{l=m}}m=g>>>4&3;do{if((m|0)==3){n=f+156|0;o=c[n>>2]|0;if((o&1|0)!=0){Mj(f,o,0,0);p=1;i=h;return p|0}q=f+164|0;r=f+162|0;b[r>>1]=b[q>>1]|0;s=o&16777215;o=s+1|0;t=f+36|0;if(o>>>0<(c[t>>2]|0)>>>0){u=c[f+32>>2]|0;v=(d[u+s>>0]<<8|d[u+o>>0])&65535}else{v=oc[c[f+12>>2]&31](c[f+4>>2]|0,s)|0}b[q>>1]=v;s=f+336|0;if((a[s>>0]|0)!=0){Kj(f);p=1;i=h;return p|0}o=(c[n>>2]|0)+2|0;c[n>>2]=o;u=f+152|0;c[u>>2]=(c[u>>2]|0)+2;w=b[r>>1]|0;if((o&1|0)!=0){Mj(f,o,0,0);p=1;i=h;return p|0}b[r>>1]=v;x=o&16777215;o=x+1|0;if(o>>>0<(c[t>>2]|0)>>>0){t=c[f+32>>2]|0;b[q>>1]=d[t+x>>0]<<8|d[t+o>>0]}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,x)|0;x=(a[s>>0]|0)==0;b[q>>1]=o;if(!x){Kj(f);p=1;i=h;return p|0}}c[n>>2]=(c[n>>2]|0)+2;c[u>>2]=(c[u>>2]|0)+2;y=e[r>>1]|(w&65535)<<16}else if((m|0)==0){Nj(f);p=1;i=h;return p|0}else if((m|0)==2){w=f+156|0;r=c[w>>2]|0;if((r&1|0)!=0){Mj(f,r,0,0);p=1;i=h;return p|0}u=f+164|0;n=f+162|0;b[n>>1]=b[u>>1]|0;x=r&16777215;r=x+1|0;if(r>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;z=(d[o+x>>0]<<8|d[o+r>>0])&65535}else{z=oc[c[f+12>>2]&31](c[f+4>>2]|0,x)|0}b[u>>1]=z;if((a[f+336>>0]|0)==0){c[w>>2]=(c[w>>2]|0)+2;w=f+152|0;c[w>>2]=(c[w>>2]|0)+2;w=e[n>>1]|0;y=(w&32768|0)!=0?w|-65536:w;break}Kj(f);p=1;i=h;return p|0}else{y=0}}while(0);if((g&7|0)==0){z=f+344|0;c[z>>2]=y+(l<<k)+(c[z>>2]|0);p=0;i=h;return p|0}z=g&3;do{if((z|0)==0){Nj(f);p=1;i=h;return p|0}else if((z|0)==3){m=f+156|0;v=c[m>>2]|0;if((v&1|0)!=0){Mj(f,v,0,0);p=1;i=h;return p|0}w=f+164|0;n=f+162|0;b[n>>1]=b[w>>1]|0;u=v&16777215;v=u+1|0;x=f+36|0;if(v>>>0<(c[x>>2]|0)>>>0){r=c[f+32>>2]|0;A=(d[r+u>>0]<<8|d[r+v>>0])&65535}else{A=oc[c[f+12>>2]&31](c[f+4>>2]|0,u)|0}b[w>>1]=A;u=f+336|0;if((a[u>>0]|0)!=0){Kj(f);p=1;i=h;return p|0}v=(c[m>>2]|0)+2|0;c[m>>2]=v;r=f+152|0;c[r>>2]=(c[r>>2]|0)+2;o=b[n>>1]|0;if((v&1|0)!=0){Mj(f,v,0,0);p=1;i=h;return p|0}b[n>>1]=A;q=v&16777215;v=q+1|0;if(v>>>0<(c[x>>2]|0)>>>0){x=c[f+32>>2]|0;b[w>>1]=d[x+q>>0]<<8|d[x+v>>0]}else{v=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0;q=(a[u>>0]|0)==0;b[w>>1]=v;if(!q){Kj(f);p=1;i=h;return p|0}}c[m>>2]=(c[m>>2]|0)+2;c[r>>2]=(c[r>>2]|0)+2;B=e[n>>1]|(o&65535)<<16}else if((z|0)==2){o=f+156|0;n=c[o>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);p=1;i=h;return p|0}r=f+164|0;m=f+162|0;b[m>>1]=b[r>>1]|0;q=n&16777215;n=q+1|0;if(n>>>0<(c[f+36>>2]|0)>>>0){v=c[f+32>>2]|0;C=(d[v+q>>0]<<8|d[v+n>>0])&65535}else{C=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[r>>1]=C;if((a[f+336>>0]|0)==0){c[o>>2]=(c[o>>2]|0)+2;o=f+152|0;c[o>>2]=(c[o>>2]|0)+2;o=e[m>>1]|0;B=(o&32768|0)!=0?o|-65536:o;break}Kj(f);p=1;i=h;return p|0}else{B=0}}while(0);if((g&4|0)==0){g=f+344|0;C=y+(l<<k)+(c[g>>2]|0)&16777215;z=C+3|0;if(z>>>0<(c[f+36>>2]|0)>>>0){A=c[f+32>>2]|0;D=((d[A+C>>0]<<8|d[A+(C+1)>>0])<<8|d[A+(C+2)>>0])<<8|d[A+z>>0]}else{D=oc[c[f+16>>2]&31](c[f+4>>2]|0,C)|0}c[g>>2]=D+B;p=0;i=h;return p|0}if(j){Nj(f);p=1;i=h;return p|0}j=f+344|0;D=(c[j>>2]|0)+y&16777215;y=D+3|0;if(y>>>0<(c[f+36>>2]|0)>>>0){g=c[f+32>>2]|0;E=((d[g+D>>0]<<8|d[g+(D+1)>>0])<<8|d[g+(D+2)>>0])<<8|d[g+y>>0]}else{E=oc[c[f+16>>2]&31](c[f+4>>2]|0,D)|0}c[j>>2]=B+(l<<k)+E;p=0;i=h;return p|0}function Qo(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;c[b>>2]=d;c[b+48>>2]=0;c[b+52>>2]=0;a[b+56>>0]=0;c[b+60>>2]=0;c[b+64>>2]=0;a[b+68>>0]=0;d=b+72|0;f=b+4|0;b=f+41|0;do{a[f>>0]=0;f=f+1|0}while((f|0)<(b|0));c[d+0>>2]=0;c[d+4>>2]=0;c[d+8>>2]=0;c[d+12>>2]=0;a[d+16>>0]=0;i=e;return}function Ro(a,b,d){a=a|0;b=b|0;d=d|0;c[a+36>>2]=b;c[a+40>>2]=d;return}function So(a,b,d){a=a|0;b=b|0;d=d|0;c[a+48>>2]=b;c[a+52>>2]=d;return}function To(a,b,d){a=a|0;b=b|0;d=d|0;c[a+60>>2]=b;c[a+64>>2]=d;return}function Uo(a,b,d){a=a|0;b=b|0;d=d|0;c[a+72>>2]=b;c[a+76>>2]=d;return}function Vo(a,b,d){a=a|0;b=b|0;d=d|0;c[a+80>>2]=b;c[a+84>>2]=d;return}function Wo(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;if(!((a[b+12>>0]&28)==28)){f=0;i=e;return f|0}g=b+10|0;h=d[g>>0]|0;j=h>>>7;k=j&255;a[g>>0]=h<<1|j;j=b+11|0;h=(d[j>>0]|0)+1&7;a[j>>0]=h;if((h|0)!=0){f=k;i=e;return f|0}h=b+14|0;j=d[h>>0]|0;g=j&123|4;l=(g&d[b+15>>0]|0)==0?g:j|132;a[h>>0]=l;h=l>>>7&255;l=b+88|0;if((a[l>>0]|0)==h<<24>>24){f=k;i=e;return f|0}a[l>>0]=h;l=c[b+84>>2]|0;if((l|0)==0){f=k;i=e;return f|0}jc[l&255](c[b+80>>2]|0,h);f=k;i=e;return f|0}function Xo(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;if(!((a[b+12>>0]&28)==12)){i=f;return}g=b+10|0;a[g>>0]=d[g>>0]<<1|e<<24>>24!=0;e=b+11|0;g=(d[e>>0]|0)+1&7;a[e>>0]=g;e=b+14|0;if((g|0)==0){g=d[e>>0]|0;h=g&123|4;j=b+15|0;k=(h&d[j>>0]|0)==0?h:g|132;a[e>>0]=k;g=k>>>7&255;k=b+88|0;if((a[k>>0]|0)==g<<24>>24){l=j;m=k}else{a[k>>0]=g;h=c[b+84>>2]|0;if((h|0)==0){l=j;m=k}else{jc[h&255](c[b+80>>2]|0,g);l=j;m=k}}}else{l=b+15|0;m=b+88|0}k=d[e>>0]|0;j=k&111|16;g=(j&d[l>>0]|0)==0?j:k|144;a[e>>0]=g;e=g>>>7&255;if((a[m>>0]|0)==e<<24>>24){i=f;return}a[m>>0]=e;m=c[b+84>>2]|0;if((m|0)==0){i=f;return}jc[m&255](c[b+80>>2]|0,e);i=f;return}function Yo(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=b+32|0;h=(a[g>>0]|0)!=0;j=e<<24>>24!=0;a[g>>0]=j&1;if(!(h^j)){i=f;return}if((j&1|0)!=(a[b+13>>0]&1|0)){i=f;return}j=b+14|0;h=d[j>>0]|0;g=h&125|2;e=(g&d[b+15>>0]|0)==0?g:h|130;a[j>>0]=e;j=e>>>7&255;e=b+88|0;if((a[e>>0]|0)==j<<24>>24){i=f;return}a[e>>0]=j;e=c[b+84>>2]|0;if((e|0)==0){i=f;return}jc[e&255](c[b+80>>2]|0,j);i=f;return}function Zo(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=b+33|0;h=a[g>>0]|0;j=e<<24>>24!=0;a[g>>0]=j&1;g=d[b+13>>0]|0;if((g&8|0)!=0){i=f;return}if(!(h<<24>>24!=0^j)){i=f;return}if(j^(g&4|0)!=0){i=f;return}g=b+14|0;j=d[g>>0]|0;h=j&126|1;e=(h&d[b+15>>0]|0)==0?h:j|129;a[g>>0]=e;g=e>>>7&255;e=b+88|0;if((a[e>>0]|0)==g<<24>>24){i=f;return}a[e>>0]=g;e=c[b+84>>2]|0;if((e|0)==0){i=f;return}jc[e&255](c[b+80>>2]|0,g);i=f;return}function _o(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;a[b+6>>0]=d;f=a[b+8>>0]|0;g=c[b+40>>2]|0;if((g|0)==0){i=e;return}jc[g&255](c[b+36>>2]|0,(a[b+4>>0]&f&255|(f&255^255)&(d&255))&255);i=e;return}function $o(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;a[b+7>>0]=d;f=a[b+9>>0]|0;g=c[b+52>>2]|0;if((g|0)==0){i=e;return}jc[g&255](c[b+48>>2]|0,(a[b+5>>0]&f&255|(f&255^255)&(d&255))&255);i=e;return}function ap(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;if(!((a[b+12>>0]&28)==12)){i=f;return}a[b+10>>0]=e;a[b+11>>0]=0;e=b+14|0;g=d[e>>0]|0;h=g&123|4;j=(h&d[b+15>>0]|0)==0?h:g|132;a[e>>0]=j;e=j>>>7&255;j=b+88|0;if((a[j>>0]|0)==e<<24>>24){i=f;return}a[j>>0]=e;j=c[b+84>>2]|0;if((j|0)==0){i=f;return}jc[j&255](c[b+80>>2]|0,e);i=f;return}function bp(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;do{switch(g>>>(c[f>>2]|0)|0){case 1:{j=f+14|0;k=a[j>>0]&124;l=(d[f+15>>0]&k|0)==0?k:k|128;a[j>>0]=l;j=l>>>7&255;l=f+88|0;if(!((a[l>>0]|0)==j<<24>>24)){a[l>>0]=j;l=c[f+84>>2]|0;if((l|0)!=0){jc[l&255](c[f+80>>2]|0,j)}}j=a[f+8>>0]|0;m=(d[f+6>>0]&(j&255^255)|j&a[f+4>>0]&255)&255;i=h;return m|0};case 10:{j=f+14|0;l=a[j>>0]&123;k=(d[f+15>>0]&l|0)==0?l:l|128;a[j>>0]=k;j=k>>>7&255;k=f+88|0;if(!((a[k>>0]|0)==j<<24>>24)){a[k>>0]=j;k=c[f+84>>2]|0;if((k|0)!=0){jc[k&255](c[f+80>>2]|0,j)}}a[f+11>>0]=0;m=a[f+10>>0]|0;i=h;return m|0};case 6:{m=b[f+16>>1]&255;i=h;return m|0};case 13:{m=a[f+14>>0]|0;i=h;return m|0};case 2:{m=a[f+9>>0]|0;i=h;return m|0};case 11:{m=a[f+12>>0]|0;i=h;return m|0};case 12:{m=a[f+13>>0]|0;i=h;return m|0};case 4:{j=f+14|0;k=a[j>>0]&63;l=(d[f+15>>0]&k|0)==0?k:k|128;a[j>>0]=l;j=l>>>7&255;l=f+88|0;if(!((a[l>>0]|0)==j<<24>>24)){a[l>>0]=j;l=c[f+84>>2]|0;if((l|0)!=0){jc[l&255](c[f+80>>2]|0,j)}}m=b[f+18>>1]&255;i=h;return m|0};case 9:{m=(e[f+26>>1]|0)>>>8&255;i=h;return m|0};case 8:{j=f+14|0;l=a[j>>0]&95;k=(d[f+15>>0]&l|0)==0?l:l|128;a[j>>0]=k;j=k>>>7&255;k=f+88|0;if(!((a[k>>0]|0)==j<<24>>24)){a[k>>0]=j;k=c[f+84>>2]|0;if((k|0)!=0){jc[k&255](c[f+80>>2]|0,j)}}m=b[f+26>>1]&255;i=h;return m|0};case 7:{m=(e[f+16>>1]|0)>>>8&255;i=h;return m|0};case 15:{j=a[f+8>>0]|0;m=(d[f+6>>0]&(j&255^255)|j&a[f+4>>0]&255)&255;i=h;return m|0};case 5:{m=(e[f+18>>1]|0)>>>8&255;i=h;return m|0};case 0:{j=f+14|0;k=a[j>>0]&103;l=(d[f+15>>0]&k|0)==0?k:k|128;a[j>>0]=l;j=l>>>7&255;l=f+88|0;if(!((a[l>>0]|0)==j<<24>>24)){a[l>>0]=j;l=c[f+84>>2]|0;if((l|0)!=0){jc[l&255](c[f+80>>2]|0,j)}}j=a[f+9>>0]|0;m=(d[f+7>>0]&(j&255^255)|j&a[f+5>>0]&255)&255;i=h;return m|0};case 3:{m=a[f+8>>0]|0;i=h;return m|0};case 14:{m=(d[f+15>>0]|128)&255;i=h;return m|0};default:{m=-86;i=h;return m|0}}}while(0);return 0}function cp(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=(bp(a,b)|0)&255;i=c;return d|0}function dp(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=(bp(a,b)|0)&255;i=c;return d|0}function ep(e,f,g){e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=i;do{switch(f>>>(c[e>>2]|0)|0){case 1:{a[e+4>>0]=g;j=a[e+8>>0]|0;k=c[e+40>>2]|0;if((k|0)!=0){jc[k&255](c[e+36>>2]|0,(d[e+6>>0]&(j&255^255)|j&g&255)&255)}j=e+14|0;k=a[j>>0]&124;l=(d[e+15>>0]&k|0)==0?k:k|128;a[j>>0]=l;j=l>>>7&255;l=e+88|0;if((a[l>>0]|0)==j<<24>>24){i=h;return}a[l>>0]=j;l=c[e+84>>2]|0;if((l|0)==0){i=h;return}jc[l&255](c[e+80>>2]|0,j);i=h;return};case 7:{j=e+16|0;b[j>>1]=b[j>>1]&255|(g&255)<<8;i=h;return};case 4:{j=e+16|0;b[j>>1]=b[j>>1]&65280|g&255;i=h;return};case 8:{j=e+24|0;b[j>>1]=b[j>>1]&65280|g&255;i=h;return};case 14:{j=g&255;l=j&127;if((j&128|0)==0){j=e+15|0;k=d[j>>0]&(l^127);a[j>>0]=k;m=k}else{k=e+15|0;j=d[k>>0]|l;a[k>>0]=j;m=j}j=e+14|0;k=d[j>>0]|0;l=k&127;n=(l&m|0)==0?l:k|128;a[j>>0]=n;j=n>>>7&255;n=e+88|0;if((a[n>>0]|0)==j<<24>>24){i=h;return}a[n>>0]=j;n=c[e+84>>2]|0;if((n|0)==0){i=h;return}jc[n&255](c[e+80>>2]|0,j);i=h;return};case 15:{a[e+4>>0]=g;j=a[e+8>>0]|0;n=c[e+40>>2]|0;if((n|0)!=0){jc[n&255](c[e+36>>2]|0,(d[e+6>>0]&(j&255^255)|j&g&255)&255)}j=e+14|0;n=a[j>>0]&124;k=(d[e+15>>0]&n|0)==0?n:n|128;a[j>>0]=k;j=k>>>7&255;k=e+88|0;if((a[k>>0]|0)==j<<24>>24){i=h;return}a[k>>0]=j;k=c[e+84>>2]|0;if((k|0)==0){i=h;return}jc[k&255](c[e+80>>2]|0,j);i=h;return};case 12:{a[e+13>>0]=g;j=d[e+12>>0]|0;if((j&28|0)==0){o=(g&-32)<<24>>24!=-64|0}else{if((j&16|0)==0){o=1}else{o=a[e+10>>0]&1}}j=e+68|0;if(o<<24>>24==(a[j>>0]|0)){i=h;return}a[j>>0]=o;j=c[e+64>>2]|0;if((j|0)==0){i=h;return}jc[j&255](c[e+60>>2]|0,o);i=h;return};case 13:{j=e+14|0;k=d[j>>0]&(g&255^127);n=k&127;l=(n&d[e+15>>0]|0)==0?n:k|128;a[j>>0]=l;j=l>>>7&255;l=e+88|0;if((a[l>>0]|0)==j<<24>>24){i=h;return}a[l>>0]=j;l=c[e+84>>2]|0;if((l|0)==0){i=h;return}jc[l&255](c[e+80>>2]|0,j);i=h;return};case 0:{a[e+5>>0]=g;j=a[e+9>>0]|0;l=c[e+52>>2]|0;if((l|0)!=0){jc[l&255](c[e+48>>2]|0,(d[e+7>>0]&(j&255^255)|j&g&255)&255)}j=e+14|0;l=a[j>>0]&103;k=(d[e+15>>0]&l|0)==0?l:l|128;a[j>>0]=k;j=k>>>7&255;k=e+88|0;if((a[k>>0]|0)==j<<24>>24){i=h;return}a[k>>0]=j;k=c[e+84>>2]|0;if((k|0)==0){i=h;return}jc[k&255](c[e+80>>2]|0,j);i=h;return};case 10:{j=e+14|0;k=a[j>>0]&123;l=e+15|0;n=(d[l>>0]&k|0)==0?k:k|128;a[j>>0]=n;k=n>>>7&255;n=e+88|0;if(!((a[n>>0]|0)==k<<24>>24)){a[n>>0]=k;p=c[e+84>>2]|0;if((p|0)!=0){jc[p&255](c[e+80>>2]|0,k)}}a[e+10>>0]=g;a[e+11>>0]=0;if(!((a[e+12>>0]&28)==28)){i=h;return}k=c[e+76>>2]|0;if((k|0)==0){i=h;return}jc[k&255](c[e+72>>2]|0,g);k=d[j>>0]|0;p=k&123|4;q=(p&d[l>>0]|0)==0?p:k|132;a[j>>0]=q;j=q>>>7&255;if((a[n>>0]|0)==j<<24>>24){i=h;return}a[n>>0]=j;n=c[e+84>>2]|0;if((n|0)==0){i=h;return}jc[n&255](c[e+80>>2]|0,j);i=h;return};case 5:{j=e+16|0;n=(b[j>>1]&255|(g&255)<<8)&65535;b[j>>1]=n;b[e+18>>1]=n;if((a[e+12>>0]&64)==0){c[e+20>>2]=1}n=e+14|0;j=a[n>>0]&63;q=(d[e+15>>0]&j|0)==0?j:j|128;a[n>>0]=q;n=q>>>7&255;q=e+88|0;if((a[q>>0]|0)==n<<24>>24){i=h;return}a[q>>0]=n;q=c[e+84>>2]|0;if((q|0)==0){i=h;return}jc[q&255](c[e+80>>2]|0,n);i=h;return};case 6:{n=e+16|0;b[n>>1]=b[n>>1]&65280|g&255;i=h;return};case 2:{a[e+9>>0]=g;n=c[e+52>>2]|0;if((n|0)==0){i=h;return}jc[n&255](c[e+48>>2]|0,(a[e+5>>0]&g&255|d[e+7>>0]&(g&255^255))&255);i=h;return};case 3:{a[e+8>>0]=g;n=c[e+40>>2]|0;if((n|0)==0){i=h;return}jc[n&255](c[e+36>>2]|0,(a[e+4>>0]&g&255|d[e+6>>0]&(g&255^255))&255);i=h;return};case 11:{a[e+12>>0]=g;if((g&28)==0){a[e+11>>0]=0}n=g&255;if((n&28|0)==0){r=(a[e+13>>0]&-32)<<24>>24!=-64|0}else{if((n&16|0)==0){r=1}else{r=a[e+10>>0]&1}}n=e+68|0;if(r<<24>>24==(a[n>>0]|0)){i=h;return}a[n>>0]=r;n=c[e+64>>2]|0;if((n|0)==0){i=h;return}jc[n&255](c[e+60>>2]|0,r);i=h;return};case 9:{n=e+24|0;q=(b[n>>1]&255|(g&255)<<8)&65535;b[n>>1]=q;b[e+26>>1]=q;if((a[e+12>>0]&32)==0){c[e+28>>2]=1}q=e+14|0;n=a[q>>0]&95;j=(d[e+15>>0]&n|0)==0?n:n|128;a[q>>0]=j;q=j>>>7&255;j=e+88|0;if((a[j>>0]|0)==q<<24>>24){i=h;return}a[j>>0]=q;j=c[e+84>>2]|0;if((j|0)==0){i=h;return}jc[j&255](c[e+80>>2]|0,q);i=h;return};default:{i=h;return}}}while(0)}function fp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;ep(a,b,c&255);i=d;return}function gp(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=i;ep(a,b,c&255);i=d;return}function hp(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;a[b+4>>0]=0;f=b+5|0;a[f>>0]=0;g=b+14|0;h=b+15|0;j=b+40|0;k=b+8|0;l=k+24|0;do{a[k>>0]=0;k=k+1|0}while((k|0)<(l|0));k=c[j>>2]|0;if((k|0)==0){m=0}else{jc[k&255](c[b+36>>2]|0,a[b+6>>0]|0);m=a[b+9>>0]|0}k=c[b+52>>2]|0;if((k|0)!=0){jc[k&255](c[b+48>>2]|0,(a[f>>0]&m&255|d[b+7>>0]&(m&255^255))&255)}m=d[g>>0]|0;f=m&127;k=(d[h>>0]&f|0)==0?f:m|128;a[g>>0]=k;g=k>>>7&255;k=b+88|0;if((a[k>>0]|0)==g<<24>>24){i=e;return}a[k>>0]=g;k=c[b+84>>2]|0;if((k|0)==0){i=e;return}jc[k&255](c[b+80>>2]|0,g);i=e;return}function ip(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;h=e+18|0;j=b[h>>1]|0;k=j&65535;do{if(k>>>0>f>>>0|j<<16>>16==0){b[h>>1]=k-f}else{if((a[e+12>>0]&64)==0){b[h>>1]=k-f;l=e+20|0;if((c[l>>2]|0)==0){break}c[l>>2]=0;l=e+14|0;m=d[l>>0]|0;n=m&63|64;o=(n&d[e+15>>0]|0)==0?n:m|192;a[l>>0]=o;l=o>>>7&255;o=e+88|0;if((a[o>>0]|0)==l<<24>>24){break}a[o>>0]=l;o=c[e+84>>2]|0;if((o|0)==0){break}jc[o&255](c[e+80>>2]|0,l);break}l=f-k|0;o=e+14|0;m=d[o>>0]|0;n=m&63|64;p=(n&d[e+15>>0]|0)==0?n:m|192;a[o>>0]=p;o=p>>>7&255;p=e+88|0;if(!((a[p>>0]|0)==o<<24>>24)){a[p>>0]=o;p=c[e+84>>2]|0;if((p|0)!=0){jc[p&255](c[e+80>>2]|0,o)}}o=b[e+16>>1]|0;if(o<<16>>16==0){q=l&65535;r=0}else{p=o&65535;q=(l>>>0)%(p>>>0)|0;r=p}b[h>>1]=r-q}}while(0);q=e+26|0;r=b[q>>1]|0;h=r&65535;if(h>>>0>f>>>0|r<<16>>16==0){b[q>>1]=h-f;i=g;return}if(!((a[e+12>>0]&32)==0)){i=g;return}b[q>>1]=h-f;f=e+28|0;if((c[f>>2]|0)==0){i=g;return}c[f>>2]=0;f=e+14|0;h=d[f>>0]|0;q=h&95|32;r=(q&d[e+15>>0]|0)==0?q:h|160;a[f>>0]=r;f=r>>>7&255;r=e+88|0;if((a[r>>0]|0)==f<<24>>24){i=g;return}a[r>>0]=f;r=c[e+84>>2]|0;if((r|0)==0){i=g;return}jc[r&255](c[e+80>>2]|0,f);i=g;return}function jp(b){b=b|0;var d=0,e=0;d=i;c[b>>2]=0;c[b+1284>>2]=0;a[b+38>>0]=1;a[b+39>>0]=1;c[b+56>>2]=0;c[b+60>>2]=16384;c[b+64>>2]=0;c[b+68>>2]=1;c[b+72>>2]=0;c[b+76>>2]=1;c[b+80>>2]=0;c[b+84>>2]=0;c[b+88>>2]=0;c[b+348>>2]=0;c[b+352>>2]=0;e=b+612|0;c[e+0>>2]=0;c[e+4>>2]=0;c[e+8>>2]=0;c[e+12>>2]=0;c[e+16>>2]=0;c[e+20>>2]=0;c[e+24>>2]=0;c[e+28>>2]=0;a[b+678>>0]=1;a[b+679>>0]=1;c[b+696>>2]=0;c[b+700>>2]=16384;c[b+704>>2]=0;c[b+708>>2]=1;c[b+712>>2]=0;c[b+716>>2]=1;c[b+720>>2]=0;c[b+724>>2]=0;c[b+728>>2]=0;c[b+988>>2]=0;c[b+992>>2]=0;e=b+1252|0;c[e+0>>2]=0;c[e+4>>2]=0;c[e+8>>2]=0;c[e+12>>2]=0;c[e+16>>2]=0;c[e+20>>2]=0;c[e+24>>2]=0;c[e+28>>2]=0;c[b+1288>>2]=0;c[b+1292>>2]=0;a[b+1296>>0]=0;i=d;return}function kp(a,b,d){a=a|0;b=b|0;d=d|0;c[a+1288>>2]=b;c[a+1292>>2]=d;return}function lp(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=i;if(!(b>>>0<2)){i=f;return}c[a+(b*640|0)+612>>2]=d;c[a+(b*640|0)+616>>2]=e;i=f;return}function mp(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=i;if(!(b>>>0<2)){i=f;return}c[a+(b*640|0)+620>>2]=d;c[a+(b*640|0)+624>>2]=e;i=f;return}function np(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=i;if(!(b>>>0<2)){i=f;return}c[a+(b*640|0)+628>>2]=d;c[a+(b*640|0)+632>>2]=e;i=f;return}function op(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=i;if(!(b>>>0<2)){i=f;return}c[a+(b*640|0)+636>>2]=d;c[a+(b*640|0)+640>>2]=e;i=f;return}function pp(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;f=i;if(b>>>0>1){i=f;return}c[a+(b*640|0)+64>>2]=0;c[a+(b*640|0)+68>>2]=(d|0)==0?1:d;c[a+(b*640|0)+72>>2]=0;c[a+(b*640|0)+76>>2]=(e|0)==0?1:e;i=f;return}function qp(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a+1284>>2]=b;c[a+80>>2]=d;c[a+720>>2]=e;return}function rp(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0;h=i;j=e&1;a:do{switch(f|0){case 9:{e=b+13|0;k=a[e>>0]|0;a[e>>0]=g;a[b+653>>0]=g;l=g&8;if(!(((k^8)&l)<<24>>24==0)){if(l<<24>>24==0){l=b+1296|0;if((a[l>>0]|0)!=0){a[l>>0]=0;l=c[b+1292>>2]|0;if((l|0)!=0){jc[l&255](c[b+1288>>2]|0,0)}}}else{l=(a[b+23>>0]|0)!=0|0;k=b+1296|0;if(!((a[k>>0]|0)==l<<24>>24)){a[k>>0]=l;k=c[b+1292>>2]|0;if((k|0)!=0){jc[k&255](c[b+1288>>2]|0,l)}}}if((a[e>>0]&8)==0){e=b+1296|0;if((a[e>>0]|0)==0){m=63;break a}a[e>>0]=0;e=c[b+1292>>2]|0;if((e|0)==0){m=63;break a}jc[e&255](c[b+1288>>2]|0,0);m=63;break a}else{e=(a[b+23>>0]|0)!=0|0;l=b+1296|0;if((a[l>>0]|0)==e<<24>>24){m=63;break a}a[l>>0]=e;l=c[b+1292>>2]|0;if((l|0)==0){m=63;break a}jc[l&255](c[b+1288>>2]|0,e);m=63;break a}}break};case 5:{e=b+(j*640|0)+9|0;l=a[e>>0]|0;a[e>>0]=g;if(!(((l^g)&2)==0)){l=c[b+(j*640|0)+632>>2]|0;if((l|0)!=0){jc[l&255](c[b+(j*640|0)+628>>2]|0,(g&255)>>>1&1)}}Mp(b,j);m=63;break};case 4:{a[b+(j*640|0)+8>>0]=g;Mp(b,j);break};case 8:{a[b+(j*640|0)+12>>0]=g;l=b+(j*640|0)+20|0;a[l>>0]=a[l>>0]&251;a[b+(j*640|0)+38>>0]=0;l=b+23|0;e=d[l>>0]&((j|0)==0?239:253)&255;a[l>>0]=e;if((a[b+13>>0]&8)==0){l=b+1296|0;if((a[l>>0]|0)!=0){a[l>>0]=0;l=c[b+1292>>2]|0;if((l|0)!=0){jc[l&255](c[b+1288>>2]|0,0)}}}else{l=e<<24>>24!=0|0;e=b+1296|0;if(!((a[e>>0]|0)==l<<24>>24)){a[e>>0]=l;e=c[b+1292>>2]|0;if((e|0)!=0){jc[e&255](c[b+1288>>2]|0,l)}}}Lp(b,j);m=63;break};case 3:{a[b+(j*640|0)+7>>0]=g;if(!((g&16)==0)){l=b+(j*640|0)+20|0;a[l>>0]=d[l>>0]|16;m=63}break};case 13:{a[b+(j*640|0)+17>>0]=g;Mp(b,j);break};case 11:{a[b+(j*640|0)+15>>0]=g;break};case 12:{a[b+(j*640|0)+16>>0]=g;Mp(b,j);break};case 14:{a[b+(j*640|0)+18>>0]=g;Mp(b,j);break};case 1:{a[b+(j*640|0)+5>>0]=g;if((a[b+13>>0]&8)==0){l=b+1296|0;if((a[l>>0]|0)==0){break a}a[l>>0]=0;l=c[b+1292>>2]|0;if((l|0)==0){m=63;break a}jc[l&255](c[b+1288>>2]|0,0);m=63;break a}else{l=(a[b+23>>0]|0)!=0|0;e=b+1296|0;if((a[e>>0]|0)==l<<24>>24){m=63;break a}a[e>>0]=l;e=c[b+1292>>2]|0;if((e|0)==0){m=63;break a}jc[e&255](c[b+1288>>2]|0,l);m=63;break a}break};case 0:{a[b+(j*640|0)+4>>0]=g;l=g&255;e=l&7;c[b>>2]=e;k=l>>>3&7;if((k|0)==1){c[b>>2]=e|8;i=h;return}else if((k|0)==2){e=b+23|0;l=d[e>>0]&((j|0)==0?247:254)&255;a[e>>0]=l;a[b+(j*640|0)+36>>0]=0;if(!((a[b+13>>0]&8)==0)){e=l<<24>>24!=0|0;l=b+1296|0;if((a[l>>0]|0)==e<<24>>24){m=63;break a}a[l>>0]=e;l=c[b+1292>>2]|0;if((l|0)==0){m=63;break a}jc[l&255](c[b+1288>>2]|0,e);m=63;break a}e=b+1296|0;if((a[e>>0]|0)==0){i=h;return}a[e>>0]=0;e=c[b+1292>>2]|0;if((e|0)==0){m=63;break a}jc[e&255](c[b+1288>>2]|0,0);m=63;break a}else if((k|0)==5){k=b+23|0;e=d[k>>0]&((j|0)==0?239:253)&255;a[k>>0]=e;if((a[b+13>>0]&8)==0){k=b+1296|0;if((a[k>>0]|0)==0){m=63;break a}a[k>>0]=0;k=c[b+1292>>2]|0;if((k|0)==0){m=63;break a}jc[k&255](c[b+1288>>2]|0,0);m=63;break a}else{k=e<<24>>24!=0|0;e=b+1296|0;if((a[e>>0]|0)==k<<24>>24){m=63;break a}a[e>>0]=k;e=c[b+1292>>2]|0;if((e|0)==0){m=63;break a}jc[e&255](c[b+1288>>2]|0,k);m=63;break a}}else{i=h;return}break};case 15:{a[b+(j*640|0)+19>>0]=g;a[b+(j*640|0)+35>>0]=g;break};case 2:{a[b+6>>0]=g;a[b+646>>0]=g;a[b+22>>0]=g;a[b+662>>0]=g;break};case 10:{a[b+(j*640|0)+14>>0]=g;break};default:{a[(f&15)+(b+(j*640|0))+4>>0]=g;m=63}}}while(0);if((m|0)==63){if((f|0)==0){i=h;return}}c[b>>2]=0;i=h;return}function sp(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;h=e&1;do{if((f|0)==2){e=a[b+22>>0]|0;if((h|0)==0){j=e}else{k=d[b+23>>0]|0;if((k&32|0)==0){if((k&16|0)==0){if((k&8|0)==0){if((k&4|0)==0){if((k&2|0)==0){l=(k&1|0)==0?51:33}else{l=0}}else{l=18}}else{l=45}}else{l=12}}else{l=30}k=e&255;if((a[b+13>>0]&16)==0){j=((l&255)<<1&14|k&241)&255;break}else{j=((l&255)<<1|k)&112;break}}}else if((f|0)==0){k=a[b+(h*640|0)+36>>0]|0;j=((k&255^255)&d[b+(h*640|0)+20>>0]|a[b+(h*640|0)+37>>0]&k&255)&255}else if((f|0)==3){if((h|0)==0){j=a[b+23>>0]|0}else{j=0}}else if((f|0)==8){k=b+(h*640|0)+28|0;e=a[k>>0]|0;m=b+(h*640|0)+20|0;a[m>>0]=a[m>>0]&254;n=b+(h*640|0)+39|0;a[n>>0]=1;o=(h|0)==0;p=b+23|0;q=d[p>>0]&(o?223:251)&255;a[p>>0]=q;r=b+13|0;if((a[r>>0]&8)==0){s=b+1296|0;if((a[s>>0]|0)!=0){a[s>>0]=0;s=c[b+1292>>2]|0;if((s|0)!=0){jc[s&255](c[b+1288>>2]|0,0)}}}else{s=q<<24>>24!=0|0;q=b+1296|0;if(!((a[q>>0]|0)==s<<24>>24)){a[q>>0]=s;q=c[b+1292>>2]|0;if((q|0)!=0){jc[q&255](c[b+1288>>2]|0,s)}}}s=b+(h*640|0)+352|0;q=c[s>>2]|0;if((c[b+(h*640|0)+348>>2]|0)==(q|0)){j=e}else{t=b+(h*640|0)+64|0;u=c[t>>2]|0;if((u|0)==0){j=e}else{if((a[n>>0]|0)==0){j=e}else{c[t>>2]=u+ -1;a[k>>0]=a[b+(h*640|0)+q+356>>0]|0;c[s>>2]=q+1&255;q=c[b+(h*640|0)+616>>2]|0;if((q|0)!=0){jc[q&255](c[b+(h*640|0)+612>>2]|0,1)}a[m>>0]=d[m>>0]|1;a[n>>0]=0;if((a[b+(h*640|0)+5>>0]&24)==16){a[p>>0]=d[p>>0]|(o?32:4)}if((a[r>>0]&8)==0){r=b+1296|0;if((a[r>>0]|0)==0){j=e;break}a[r>>0]=0;r=c[b+1292>>2]|0;if((r|0)==0){j=e;break}jc[r&255](c[b+1288>>2]|0,0);j=e;break}else{r=(a[p>>0]|0)!=0|0;p=b+1296|0;if((a[p>>0]|0)==r<<24>>24){j=e;break}a[p>>0]=r;p=c[b+1292>>2]|0;if((p|0)==0){j=e;break}jc[p&255](c[b+1288>>2]|0,r);j=e;break}}}}}else{j=a[(f&15)+(b+(h*640|0))+20>>0]|0}}while(0);c[b>>2]=0;i=g;return j|0}function tp(a){a=a|0;var b=0,d=0;b=i;d=sp(a,0,c[a>>2]|0)|0;i=b;return d|0}function up(a){a=a|0;var b=0,d=0;b=i;d=sp(a,1,c[a>>2]|0)|0;i=b;return d|0}function vp(a,b){a=a|0;b=b|0;var d=0;d=i;rp(a,0,c[a>>2]|0,b);i=d;return}function wp(a,b){a=a|0;b=b|0;var d=0;d=i;rp(a,1,c[a>>2]|0,b);i=d;return}function xp(a){a=a|0;var b=0,c=0;b=i;c=sp(a,0,8)|0;i=b;return c|0}function yp(a){a=a|0;var b=0,c=0;b=i;c=sp(a,1,8)|0;i=b;return c|0}function zp(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;a[b+12>>0]=e;e=b+20|0;a[e>>0]=a[e>>0]&251;a[b+38>>0]=0;e=b+23|0;g=d[e>>0]&239;a[e>>0]=g;if((a[b+13>>0]&8)==0){e=b+1296|0;if((a[e>>0]|0)!=0){a[e>>0]=0;e=c[b+1292>>2]|0;if((e|0)!=0){jc[e&255](c[b+1288>>2]|0,0)}}}else{e=g<<24>>24!=0|0;g=b+1296|0;if(!((a[g>>0]|0)==e<<24>>24)){a[g>>0]=e;g=c[b+1292>>2]|0;if((g|0)!=0){jc[g&255](c[b+1288>>2]|0,e)}}}Lp(b,0);c[b>>2]=0;i=f;return}function Ap(b,e){b=b|0;e=e|0;var f=0,g=0;f=i;a[b+652>>0]=e;e=b+660|0;a[e>>0]=a[e>>0]&251;a[b+678>>0]=0;e=b+23|0;g=d[e>>0]&253;a[e>>0]=g;if((a[b+13>>0]&8)==0){e=b+1296|0;if((a[e>>0]|0)!=0){a[e>>0]=0;e=c[b+1292>>2]|0;if((e|0)!=0){jc[e&255](c[b+1288>>2]|0,0)}}}else{e=g<<24>>24!=0|0;g=b+1296|0;if(!((a[g>>0]|0)==e<<24>>24)){a[g>>0]=e;g=c[b+1292>>2]|0;if((g|0)!=0){jc[g&255](c[b+1288>>2]|0,e)}}}Lp(b,1);c[b>>2]=0;i=f;return}function Bp(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=b+20|0;h=a[g>>0]|0;j=h&255;k=(e<<24>>24==0?j|8:j&247)&255;a[g>>0]=k;g=a[b+19>>0]|0;if((g&-6&(k^h))<<24>>24==0){i=f;return}if(!((a[b+5>>0]&1)==0)){h=b+23|0;a[h>>0]=d[h>>0]|8;a[b+36>>0]=g;a[b+37>>0]=k}if((a[b+13>>0]&8)==0){k=b+1296|0;if((a[k>>0]|0)==0){i=f;return}a[k>>0]=0;k=c[b+1292>>2]|0;if((k|0)==0){i=f;return}jc[k&255](c[b+1288>>2]|0,0);i=f;return}else{k=(a[b+23>>0]|0)!=0|0;g=b+1296|0;if((a[g>>0]|0)==k<<24>>24){i=f;return}a[g>>0]=k;g=c[b+1292>>2]|0;if((g|0)==0){i=f;return}jc[g&255](c[b+1288>>2]|0,k);i=f;return}}function Cp(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;g=b+660|0;h=a[g>>0]|0;j=h&255;k=(e<<24>>24==0?j|8:j&247)&255;a[g>>0]=k;g=a[b+659>>0]|0;if((g&-6&(k^h))<<24>>24==0){i=f;return}if(!((a[b+645>>0]&1)==0)){h=b+23|0;a[h>>0]=d[h>>0]|1;a[b+676>>0]=g;a[b+677>>0]=k}if((a[b+13>>0]&8)==0){k=b+1296|0;if((a[k>>0]|0)==0){i=f;return}a[k>>0]=0;k=c[b+1292>>2]|0;if((k|0)==0){i=f;return}jc[k&255](c[b+1288>>2]|0,0);i=f;return}else{k=(a[b+23>>0]|0)!=0|0;g=b+1296|0;if((a[g>>0]|0)==k<<24>>24){i=f;return}a[g>>0]=k;g=c[b+1292>>2]|0;if((g|0)==0){i=f;return}jc[g&255](c[b+1288>>2]|0,k);i=f;return}}function Dp(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;h=e&1;e=b+(h*640|0)+20|0;j=a[e>>0]|0;k=j&255;l=(f<<24>>24==0?k|32:k&223)&255;a[e>>0]=l;e=a[b+(h*640|0)+19>>0]|0;if((e&-6&(l^j))<<24>>24==0){i=g;return}if(!((a[b+(h*640|0)+5>>0]&1)==0)){j=b+23|0;a[j>>0]=d[j>>0]|((h|0)==0?8:1);a[b+(h*640|0)+36>>0]=e;a[b+(h*640|0)+37>>0]=l}if((a[b+13>>0]&8)==0){l=b+1296|0;if((a[l>>0]|0)==0){i=g;return}a[l>>0]=0;l=c[b+1292>>2]|0;if((l|0)==0){i=g;return}jc[l&255](c[b+1288>>2]|0,0);i=g;return}else{l=(a[b+23>>0]|0)!=0|0;h=b+1296|0;if((a[h>>0]|0)==l<<24>>24){i=g;return}a[h>>0]=l;h=c[b+1292>>2]|0;if((h|0)==0){i=g;return}jc[h&255](c[b+1288>>2]|0,l);i=g;return}}function Ep(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=d&1;d=b+(g*640|0)+348|0;h=c[d>>2]|0;if((h+1&255|0)==(c[b+(g*640|0)+352>>2]|0)){i=f;return}a[b+(g*640|0)+h+356>>0]=e;c[d>>2]=(c[d>>2]|0)+1&255;i=f;return}function Fp(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=d&1;d=b+(f*640|0)+88|0;g=c[d>>2]|0;if((c[b+(f*640|0)+84>>2]|0)==(g|0)){h=0;i=e;return h|0}j=a[b+(f*640|0)+g+92>>0]|0;c[d>>2]=g+1&255;h=j;i=e;return h|0}function Gp(a,b){a=a|0;b=b|0;var d=0;d=b&1;return((c[a+(d*640|0)+348>>2]|0)+1&255|0)==(c[a+(d*640|0)+352>>2]|0)|0}function Hp(a,b){a=a|0;b=b|0;var d=0;d=b&1;return(c[a+(d*640|0)+84>>2]|0)==(c[a+(d*640|0)+88>>2]|0)|0}function Ip(b){b=b|0;var e=0,f=0;e=i;c[b>>2]=0;f=0;do{a[b+f+20>>0]=0;a[b+f+4>>0]=0;a[b+f+660>>0]=0;a[b+f+644>>0]=0;f=f+1|0}while((f|0)!=16);f=b+20|0;a[f>>0]=d[f>>0]|4;f=b+21|0;a[f>>0]=d[f>>0]|1;a[b+36>>0]=0;f=b+40|0;c[b+84>>2]=0;c[b+88>>2]=0;c[b+348>>2]=0;c[b+352>>2]=0;c[f+0>>2]=0;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=0;f=b+660|0;a[f>>0]=d[f>>0]|4;f=b+661|0;a[f>>0]=d[f>>0]|1;a[b+676>>0]=0;f=b+680|0;c[b+724>>2]=0;c[b+728>>2]=0;c[b+988>>2]=0;c[b+992>>2]=0;c[f+0>>2]=0;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=0;f=c[b+632>>2]|0;if((f|0)!=0){jc[f&255](c[b+628>>2]|0,0)}f=c[b+1272>>2]|0;if((f|0)!=0){jc[f&255](c[b+1268>>2]|0,0)}f=b+1296|0;if((a[f>>0]|0)==0){i=e;return}a[f>>0]=0;f=c[b+1292>>2]|0;if((f|0)==0){i=e;return}jc[f&255](c[b+1288>>2]|0,0);i=e;return}function Jp(a,b){a=a|0;b=b|0;var c=0;c=i;Kp(a,0,b);Kp(a,1,b);i=c;return}function Kp(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0;g=i;h=b+(e*640|0)+56|0;j=c[h>>2]|0;if(j>>>0>f>>>0){c[h>>2]=j-f;i=g;return}k=f-j|0;j=c[b+(e*640|0)+60>>2]|0;if(k>>>0>j>>>0){l=(k>>>0)%(j>>>0)|0}else{l=k}c[h>>2]=j-l;l=c[b+(e*640|0)+68>>2]|0;j=b+(e*640|0)+64|0;c[j>>2]=l;c[b+(e*640|0)+72>>2]=c[b+(e*640|0)+76>>2];h=b+(e*640|0)+352|0;k=c[h>>2]|0;do{if(!((c[b+(e*640|0)+348>>2]|0)==(k|0)|(l|0)==0)){f=b+(e*640|0)+39|0;if((a[f>>0]|0)!=0){c[j>>2]=l+ -1;a[b+(e*640|0)+28>>0]=a[b+(e*640|0)+k+356>>0]|0;c[h>>2]=k+1&255;m=c[b+(e*640|0)+616>>2]|0;if((m|0)!=0){jc[m&255](c[b+(e*640|0)+612>>2]|0,1)}m=b+(e*640|0)+20|0;a[m>>0]=d[m>>0]|1;a[f>>0]=0;if((a[b+(e*640|0)+5>>0]&24)==16){f=b+23|0;a[f>>0]=d[f>>0]|((e|0)==0?32:4)}if((a[b+13>>0]&8)==0){f=b+1296|0;if((a[f>>0]|0)==0){break}a[f>>0]=0;f=c[b+1292>>2]|0;if((f|0)==0){break}jc[f&255](c[b+1288>>2]|0,0);break}else{f=(a[b+23>>0]|0)!=0|0;m=b+1296|0;if((a[m>>0]|0)==f<<24>>24){break}a[m>>0]=f;m=c[b+1292>>2]|0;if((m|0)==0){break}jc[m&255](c[b+1288>>2]|0,f);break}}}}while(0);Lp(b,e);i=g;return}function Lp(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=b+(e*640|0)+72|0;h=c[g>>2]|0;if((h|0)==0){i=f;return}j=b+(e*640|0)+84|0;k=c[j>>2]|0;if((k+1&255|0)==(c[b+(e*640|0)+88>>2]|0)){i=f;return}l=b+(e*640|0)+38|0;if((a[l>>0]|0)!=0){m=b+(e*640|0)+20|0;a[m>>0]=d[m>>0]|64;i=f;return}c[g>>2]=h+ -1;h=a[b+(e*640|0)+12>>0]|0;a[b+(e*640|0)+k+92>>0]=h;c[j>>2]=(c[j>>2]|0)+1&255;j=c[b+(e*640|0)+624>>2]|0;if((j|0)!=0){jc[j&255](c[b+(e*640|0)+620>>2]|0,h)}h=b+(e*640|0)+20|0;a[h>>0]=d[h>>0]|4;a[l>>0]=1;if(!((a[b+(e*640|0)+5>>0]&2)==0)){l=b+23|0;a[l>>0]=d[l>>0]|((e|0)==0?16:2)}if((a[b+13>>0]&8)==0){e=b+1296|0;if((a[e>>0]|0)==0){i=f;return}a[e>>0]=0;e=c[b+1292>>2]|0;if((e|0)==0){i=f;return}jc[e&255](c[b+1288>>2]|0,0);i=f;return}else{e=(a[b+23>>0]|0)!=0|0;l=b+1296|0;if((a[l>>0]|0)==e<<24>>24){i=f;return}a[l>>0]=e;l=c[b+1292>>2]|0;if((l|0)==0){i=f;return}jc[l&255](c[b+1288>>2]|0,e);i=f;return}}function Mp(a,b){a=a|0;b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;f=(d[a+(b*640|0)+9>>0]|0)>>>5&3;if((f|0)==0){g=5}else if((f|0)==2){g=6}else if((f|0)==1){g=7}else if((f|0)==3){g=8}else{g=0}c[a+(b*640|0)+48>>2]=g;f=d[a+(b*640|0)+8>>0]|0;h=f&3;if((h|0)==1|(h|0)==0){j=h}else if((h|0)==3){j=2}else if((h|0)==2){j=0}else{j=0}c[a+(b*640|0)+44>>2]=j;h=f>>>2&3;if((h|0)==1){k=2}else if((h|0)==2){k=3}else if((h|0)==3){k=4}else{k=0}c[a+(b*640|0)+52>>2]=k;h=f>>>6;if((h|0)==2){l=64}else if((h|0)==0){l=2}else if((h|0)==3){l=128}else if((h|0)==1){l=32}else{l=0}h=(k|0)==0;f=d[a+(b*640|0)+18>>0]|0;if((f&1|0)==0){c[a+(b*640|0)+60>>2]=16384;m=0}else{if((f&2|0)==0){n=a+(b*640|0)+80|0}else{n=a+1284|0}f=c[n>>2]|0;n=ca(((d[a+(b*640|0)+17>>0]|0)<<8|(d[a+(b*640|0)+16>>0]|0))+2|0,h?2:l)|0;l=ca(n,g+1+k|0)|0;c[a+(b*640|0)+60>>2]=l+((j|0)==0?0:n);m=(f>>>0)/(n>>>0)|0}c[a+(b*640|0)+40>>2]=m;n=c[a+(b*640|0)+640>>2]|0;if((n|0)==0){i=e;return}hc[n&1](c[a+(b*640|0)+636>>2]|0,m,j,g,k);i=e;return}function Np(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=yz(48)|0;if((g|0)==0){h=0;i=f;return h|0}if((e|0)==0){c[g+44>>2]=0;j=0}else{e=yz(d+16|0)|0;c[g+44>>2]=e;if((e|0)==0){zz(g);h=0;i=f;return h|0}else{j=e}}e=g+24|0;c[g+0>>2]=0;c[g+4>>2]=0;c[g+8>>2]=0;c[g+12>>2]=0;c[g+16>>2]=0;c[g+20>>2]=0;c[e>>2]=g;a[g+28>>0]=1;a[g+29>>0]=0;a[g+30>>0]=(j|0)!=0|0;c[g+32>>2]=b;c[g+36>>2]=b+ -1+d;c[g+40>>2]=d;h=g;i=f;return h|0}function Op(b){b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=yz(48)|0;if((e|0)==0){f=0;i=d;return f|0}g=e+0|0;h=b+0|0;b=g+48|0;do{c[g>>2]=c[h>>2];g=g+4|0;h=h+4|0}while((g|0)<(b|0));a[e+30>>0]=0;a[e+28>>0]=1;f=e;i=d;return f|0}function Pp(a,b){a=a|0;b=b|0;return 0}function Qp(a,b){a=a|0;b=b|0;return 0}function Rp(a,b){a=a|0;b=b|0;return 0}function Sp(a,b,c){a=a|0;b=b|0;c=c|0;return}function Tp(a,b,c){a=a|0;b=b|0;c=c|0;return}function Up(a,b,c){a=a|0;b=b|0;c=c|0;return}function Vp(a,b,d,e,f,g,h,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0;k=i;c[a+24>>2]=b;c[a>>2]=d;b=a+4|0;c[b>>2]=e;l=a+8|0;c[l>>2]=f;m=a+12|0;c[m>>2]=g;n=a+16|0;c[n>>2]=h;o=a+20|0;c[o>>2]=j;if((c[a+44>>2]|0)!=0){i=k;return}if((d|0)==0){c[a>>2]=15}if((e|0)==0){c[b>>2]=16}if((f|0)==0){c[l>>2]=17}if((g|0)==0){c[m>>2]=16}if((h|0)==0){c[n>>2]=17}if((j|0)!=0){i=k;return}c[o>>2]=18;i=k;return}function Wp(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=c[a+44>>2]|0;if((e|0)==0){i=d;return}Oz(e|0,b|0,c[a+40>>2]|0)|0;i=d;return}function Xp(a){a=a|0;return c[a+44>>2]|0}function Yp(b,c){b=b|0;c=c|0;a[b+29>>0]=(c|0)!=0|0;return}function Zp(a){a=a|0;return c[a+32>>2]|0}function _p(a,b){a=a|0;b=b|0;c[a+32>>2]=b;c[a+36>>2]=b+ -1+(c[a+40>>2]|0);return}function $p(a){a=a|0;return c[a+40>>2]|0}function aq(a,b){a=a|0;b=b|0;c[a+40>>2]=b;c[a+36>>2]=b+ -1+(c[a+32>>2]|0);return}function bq(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c>>0]=(d&65535)>>>8;a[b+(c+1)>>0]=d;return}function cq(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c>>0]=d>>>24;a[b+(c+1)>>0]=d>>>16;a[b+(c+2)>>0]=d>>>8;a[b+(c+3)>>0]=d;return}function dq(a,b){a=a|0;b=b|0;var e=0;e=c[a+44>>2]|0;return(((d[e+b>>0]|0)<<8|(d[e+(b+1)>>0]|0))<<8|(d[e+(b+2)>>0]|0))<<8|(d[e+(b+3)>>0]|0)|0}function eq(){var a=0,b=0,d=0,e=0,f=0,g=0;a=i;b=yz(56)|0;if((b|0)==0){d=0;i=a;return d|0}e=b+52|0;f=b+0|0;g=f+52|0;do{c[f>>2]=0;f=f+4|0}while((f|0)<(g|0));c[e>>2]=-1;d=b;i=a;return d|0}function fq(a,b,d,e,f,g,h,i){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;c[a+24>>2]=b;c[a+28>>2]=d;c[a+32>>2]=e;c[a+36>>2]=f;c[a+40>>2]=g;c[a+44>>2]=h;c[a+48>>2]=i;return}function gq(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+32|0;f=e;if((c[b>>2]|0)==0){i=e;return}g=b+4|0;h=0;do{j=c[(c[g>>2]|0)+(h<<3)>>2]|0;k=c[j+32>>2]|0;l=c[j+36>>2]|0;m=c[j+40>>2]|0;n=(a[j+29>>0]|0)!=0|0;c[f>>2]=h;c[f+4>>2]=k;c[f+8>>2]=l;c[f+12>>2]=m;c[f+16>>2]=n;hb(d|0,46280,f|0)|0;h=h+1|0}while(h>>>0<(c[b>>2]|0)>>>0);i=e;return}function hq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;if((b|0)==0){i=e;return}f=a+4|0;g=Az(c[f>>2]|0,(c[a>>2]<<3)+8|0)|0;if((g|0)==0){i=e;return}c[f>>2]=g;f=c[a>>2]|0;c[a>>2]=f+1;c[g+(f<<3)>>2]=b;c[g+(f<<3)+4>>2]=(d|0)!=0;d=a+8|0;c[d+0>>2]=0;c[d+4>>2]=0;c[d+8>>2]=0;c[d+12>>2]=0;i=e;return}function iq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;e=c[a+4>>2]|0;f=c[a>>2]|0;if((f|0)==0){g=0}else{h=f;f=0;j=0;while(1){k=e+(f<<3)|0;if((c[k>>2]|0)==(b|0)){l=h;m=j}else{n=k;k=c[n+4>>2]|0;o=e+(j<<3)|0;c[o>>2]=c[n>>2];c[o+4>>2]=k;l=c[a>>2]|0;m=j+1|0}k=f+1|0;if(k>>>0<l>>>0){h=l;f=k;j=m}else{g=m;break}}}c[a>>2]=g;g=a+8|0;c[g+0>>2]=0;c[g+4>>2]=0;c[g+8>>2]=0;c[g+12>>2]=0;i=d;return}function jq(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=b+8|0;g=c[f>>2]|0;if((g|0)!=0){h=c[g>>2]|0;if((a[h+28>>0]|0)!=0){if(!((c[h+32>>2]|0)>>>0>d>>>0)){if(!((c[h+36>>2]|0)>>>0<d>>>0)){j=h;i=e;return j|0}}}}h=c[b>>2]|0;if((h|0)==0){j=0;i=e;return j|0}g=0;k=c[b+4>>2]|0;while(1){l=c[k>>2]|0;if((a[l+28>>0]|0)!=0){if(!((c[l+32>>2]|0)>>>0>d>>>0)){if(!((c[l+36>>2]|0)>>>0<d>>>0)){break}}}b=g+1|0;if(b>>>0<h>>>0){g=b;k=k+8|0}else{j=0;m=12;break}}if((m|0)==12){i=e;return j|0}c[f>>2]=k;j=l;i=e;return j|0}function kq(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=b+12|0;g=c[f>>2]|0;if((g|0)==0){h=5}else{j=c[g>>2]|0;if((a[j+28>>0]|0)==0){h=5}else{g=c[j+32>>2]|0;if(g>>>0>d>>>0){h=5}else{if((c[j+36>>2]|0)>>>0<d>>>0){h=5}else{k=j;l=g;h=12}}}}a:do{if((h|0)==5){g=c[b>>2]|0;if((g|0)!=0){j=0;m=c[b+4>>2]|0;while(1){n=c[m>>2]|0;if((a[n+28>>0]|0)!=0){o=c[n+32>>2]|0;if(!(o>>>0>d>>>0)){if(!((c[n+36>>2]|0)>>>0<d>>>0)){break}}}j=j+1|0;if(!(j>>>0<g>>>0)){break a}else{m=m+8|0}}c[f>>2]=m;k=n;l=o;h=12}}}while(0);if((h|0)==12){if((k|0)!=0){h=d-l|0;l=c[k>>2]|0;if((l|0)==0){p=a[(c[k+44>>2]|0)+h>>0]|0;i=e;return p|0}else{p=oc[l&31](c[k+24>>2]|0,h)|0;i=e;return p|0}}}h=c[b+28>>2]|0;if((h|0)==0){p=c[b+52>>2]&255;i=e;return p|0}else{p=oc[h&31](c[b+24>>2]|0,d)|0;i=e;return p|0}return 0}function lq(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;g=b+12|0;h=c[g>>2]|0;if((h|0)==0){j=5}else{k=c[h>>2]|0;if((a[k+28>>0]|0)==0){j=5}else{h=c[k+32>>2]|0;if(h>>>0>e>>>0){j=5}else{l=c[k+36>>2]|0;if(l>>>0<e>>>0){j=5}else{m=k;n=l;o=h;j=12}}}}a:do{if((j|0)==5){h=c[b>>2]|0;if((h|0)!=0){l=0;k=c[b+4>>2]|0;while(1){p=c[k>>2]|0;if((a[p+28>>0]|0)!=0){q=c[p+32>>2]|0;if(!(q>>>0>e>>>0)){r=c[p+36>>2]|0;if(!(r>>>0<e>>>0)){break}}}l=l+1|0;if(!(l>>>0<h>>>0)){break a}else{k=k+8|0}}c[g>>2]=k;m=p;n=r;o=q;j=12}}}while(0);if((j|0)==12){if((m|0)!=0){j=e+1|0;if(j>>>0>n>>>0){n=((kq(b,e)|0)&255)<<8;s=(n|(kq(b,j)|0)&255)&65535;i=f;return s|0}j=e-o|0;o=c[m+4>>2]|0;if((o|0)==0){n=c[m+44>>2]|0;s=(d[n+j>>0]<<8|d[n+(j+1)>>0])&65535;i=f;return s|0}else{s=oc[o&31](c[m+24>>2]|0,j)|0;i=f;return s|0}}}j=c[b+32>>2]|0;if((j|0)==0){s=c[b+52>>2]&65535;i=f;return s|0}else{s=oc[j&31](c[b+24>>2]|0,e)|0;i=f;return s|0}return 0}function mq(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;g=b+12|0;h=c[g>>2]|0;if((h|0)==0){j=5}else{k=c[h>>2]|0;if((a[k+28>>0]|0)==0){j=5}else{h=c[k+32>>2]|0;if(h>>>0>e>>>0){j=5}else{l=c[k+36>>2]|0;if(l>>>0<e>>>0){j=5}else{m=k;n=l;o=h;j=12}}}}a:do{if((j|0)==5){h=c[b>>2]|0;if((h|0)!=0){l=0;k=c[b+4>>2]|0;while(1){p=c[k>>2]|0;if((a[p+28>>0]|0)!=0){q=c[p+32>>2]|0;if(!(q>>>0>e>>>0)){r=c[p+36>>2]|0;if(!(r>>>0<e>>>0)){break}}}l=l+1|0;if(!(l>>>0<h>>>0)){break a}else{k=k+8|0}}c[g>>2]=k;m=p;n=r;o=q;j=12}}}while(0);if((j|0)==12){if((m|0)!=0){j=e+3|0;if(j>>>0>n>>>0){n=((kq(b,e)|0)&255)<<24;q=((kq(b,e+1|0)|0)&255)<<16|n;n=q|((kq(b,e+2|0)|0)&255)<<8;s=n|(kq(b,j)|0)&255;i=f;return s|0}j=e-o|0;o=c[m+8>>2]|0;if((o|0)==0){n=c[m+44>>2]|0;s=d[n+(j+1)>>0]<<16|d[n+j>>0]<<24|d[n+(j+2)>>0]<<8|d[n+(j+3)>>0];i=f;return s|0}else{s=oc[o&31](c[m+24>>2]|0,j)|0;i=f;return s|0}}}j=c[b+36>>2]|0;if((j|0)==0){s=c[b+52>>2]|0;i=f;return s|0}else{s=oc[j&31](c[b+24>>2]|0,e)|0;i=f;return s|0}return 0}function nq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=b+8|0;h=c[g>>2]|0;if((h|0)==0){j=5}else{k=c[h>>2]|0;if((a[k+28>>0]|0)==0){j=5}else{h=c[k+32>>2]|0;if(h>>>0>d>>>0){j=5}else{if((c[k+36>>2]|0)>>>0<d>>>0){j=5}else{l=k;m=h;j=12}}}}a:do{if((j|0)==5){h=c[b>>2]|0;if((h|0)!=0){k=0;n=c[b+4>>2]|0;while(1){o=c[n>>2]|0;if((a[o+28>>0]|0)!=0){p=c[o+32>>2]|0;if(!(p>>>0>d>>>0)){if(!((c[o+36>>2]|0)>>>0<d>>>0)){break}}}k=k+1|0;if(!(k>>>0<h>>>0)){break a}else{n=n+8|0}}c[g>>2]=n;l=o;m=p;j=12}}}while(0);if((j|0)==12){if((l|0)!=0){j=d-m|0;m=c[l+12>>2]|0;if((m|0)==0){a[(c[l+44>>2]|0)+j>>0]=e;i=f;return}else{lc[m&31](c[l+24>>2]|0,j,e);i=f;return}}}j=c[b+40>>2]|0;if((j|0)==0){i=f;return}lc[j&31](c[b+24>>2]|0,d,e);i=f;return}function oq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=b+16|0;h=c[g>>2]|0;if((h|0)==0){j=5}else{k=c[h>>2]|0;if((a[k+28>>0]|0)==0){j=5}else{h=c[k+32>>2]|0;if(h>>>0>d>>>0){j=5}else{if((c[k+36>>2]|0)>>>0<d>>>0){j=5}else{l=k;m=h;j=12}}}}a:do{if((j|0)==5){h=c[b>>2]|0;if((h|0)!=0){k=0;n=c[b+4>>2]|0;while(1){o=c[n>>2]|0;if((a[o+28>>0]|0)!=0){p=c[o+32>>2]|0;if(!(p>>>0>d>>>0)){if(!((c[o+36>>2]|0)>>>0<d>>>0)){break}}}k=k+1|0;if(!(k>>>0<h>>>0)){break a}else{n=n+8|0}}c[g>>2]=n;l=o;m=p;j=12}}}while(0);if((j|0)==12){if((l|0)!=0){if((a[l+29>>0]|0)!=0){i=f;return}j=d-m|0;m=c[l+12>>2]|0;if((m|0)==0){a[(c[l+44>>2]|0)+j>>0]=e;i=f;return}else{lc[m&31](c[l+24>>2]|0,j,e);i=f;return}}}j=c[b+40>>2]|0;if((j|0)==0){i=f;return}lc[j&31](c[b+24>>2]|0,d,e);i=f;return}function pq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;g=b+16|0;h=c[g>>2]|0;if((h|0)==0){j=5}else{k=c[h>>2]|0;if((a[k+28>>0]|0)==0){j=5}else{h=c[k+32>>2]|0;if(h>>>0>d>>>0){j=5}else{l=c[k+36>>2]|0;if(l>>>0<d>>>0){j=5}else{m=k;n=l;o=h;j=12}}}}a:do{if((j|0)==5){h=c[b>>2]|0;if((h|0)!=0){l=0;k=c[b+4>>2]|0;while(1){p=c[k>>2]|0;if((a[p+28>>0]|0)!=0){q=c[p+32>>2]|0;if(!(q>>>0>d>>>0)){r=c[p+36>>2]|0;if(!(r>>>0<d>>>0)){break}}}l=l+1|0;if(!(l>>>0<h>>>0)){break a}else{k=k+8|0}}c[g>>2]=k;m=p;n=r;o=q;j=12}}}while(0);if((j|0)==12){if((m|0)!=0){j=d+1|0;if(j>>>0>n>>>0){oq(b,d,(e&65535)>>>8&255);oq(b,j,e&255);i=f;return}if((a[m+29>>0]|0)!=0){i=f;return}j=d-o|0;o=c[m+16>>2]|0;if((o|0)==0){n=m+44|0;a[(c[n>>2]|0)+j>>0]=(e&65535)>>>8;a[(c[n>>2]|0)+(j+1)>>0]=e;i=f;return}else{lc[o&31](c[m+24>>2]|0,j,e);i=f;return}}}j=c[b+44>>2]|0;if((j|0)==0){i=f;return}lc[j&31](c[b+24>>2]|0,d,e);i=f;return}function qq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;g=b+16|0;h=c[g>>2]|0;if((h|0)==0){j=5}else{k=c[h>>2]|0;if((a[k+28>>0]|0)==0){j=5}else{h=c[k+32>>2]|0;if(h>>>0>d>>>0){j=5}else{l=c[k+36>>2]|0;if(l>>>0<d>>>0){j=5}else{m=k;n=l;o=h;j=12}}}}a:do{if((j|0)==5){h=c[b>>2]|0;if((h|0)!=0){l=0;k=c[b+4>>2]|0;while(1){p=c[k>>2]|0;if((a[p+28>>0]|0)!=0){q=c[p+32>>2]|0;if(!(q>>>0>d>>>0)){r=c[p+36>>2]|0;if(!(r>>>0<d>>>0)){break}}}l=l+1|0;if(!(l>>>0<h>>>0)){break a}else{k=k+8|0}}c[g>>2]=k;m=p;n=r;o=q;j=12}}}while(0);if((j|0)==12){if((m|0)!=0){j=d+3|0;if(j>>>0>n>>>0){oq(b,d,e>>>24&255);oq(b,d+1|0,e>>>16&255);oq(b,d+2|0,e>>>8&255);oq(b,j,e&255);i=f;return}if((a[m+29>>0]|0)!=0){i=f;return}j=d-o|0;o=c[m+20>>2]|0;if((o|0)==0){n=m+44|0;a[(c[n>>2]|0)+j>>0]=e>>>24;a[(c[n>>2]|0)+(j+1)>>0]=e>>>16;a[(c[n>>2]|0)+(j+2)>>0]=e>>>8;a[(c[n>>2]|0)+(j+3)>>0]=e;i=f;return}else{lc[o&31](c[m+24>>2]|0,j,e);i=f;return}}}j=c[b+48>>2]|0;if((j|0)==0){i=f;return}lc[j&31](c[b+24>>2]|0,d,e);i=f;return}function rq(a,b,d,f,g,h,j){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;l=c[a+68>>2]|0;if((l|0)==0){c[d>>2]=0;m=1;i=k;return m|0}a=St(l,f,g,h,j)|0;if((a|0)==0){c[d>>2]=0;m=1;i=k;return m|0}j=a+20|0;h=ot(a,c[j>>2]|0)|0;if((h|0)==0){c[j>>2]=0;n=a}else{n=h}h=c[d>>2]|0;g=e[n+10>>1]|0;if(h>>>0>g>>>0){c[d>>2]=g;o=g;p=32}else{o=h;p=0}if((o|0)!=0){Mz(b|0,c[n+24>>2]|0,o|0)|0}o=c[n+12>>2]|0;n=o<<2;b=o>>>2&2|p|n&4|n&8|n&16;if((c[a>>2]|0)==0){m=b;i=k;return m|0}c[j>>2]=(c[j>>2]|0)+1;m=b;i=k;return m|0}function sq(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0;j=i;Oz(b|0,0,d|0)|0;k=c[a+68>>2]|0;if((k|0)==0){l=0;i=j;return l|0}a=St(k,e,f,g,h)|0;if((a|0)==0){l=0;i=j;return l|0}h=a+20|0;g=ot(a,c[h>>2]|0)|0;if((g|0)==0){c[h>>2]=0;m=a}else{m=g}l=Dt(m,b,d)|0;i=j;return l|0}function tq(b,d,f,g,h,j,k){b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0;l=i;m=c[b+68>>2]|0;if((m|0)==0){c[f>>2]=0;n=1;i=l;return n|0}if((a[b+56>>0]|0)!=0){n=64;i=l;return n|0}o=St(m,g,h,j,k)|0;if((o|0)==0){c[f>>2]=0;n=1;i=l;return n|0}k=o+12|0;if((c[k>>2]&8|0)!=0){n=2;i=l;return n|0}a[b+72>>0]=1;b=c[f>>2]|0;j=e[o+10>>1]|0;if(b>>>0>j>>>0){c[f>>2]=j;p=j;q=32}else{p=b;q=0}if((p|0)!=0){Mz(c[o+24>>2]|0,d|0,p|0)|0}c[k>>2]=c[k>>2]&-3;k=c[o>>2]|0;if((k|0)==0){n=q;i=l;return n|0}lt(k);c[o>>2]=0;c[o+20>>2]=0;n=q;i=l;return n|0}function uq(b,d,e,f,g,h,j){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0;k=i;l=c[b+68>>2]|0;if((l|0)==0){m=0}else{if((a[b+56>>0]|0)==0){n=St(l,f,g,h,j)|0;if((n|0)==0){m=0}else{a[b+72>>0]=1;m=Ct(n,d,e)|0}}else{m=0}}i=k;return m|0}function vq(b){b=b|0;var d=0,e=0,f=0;d=i;e=c[b+68>>2]|0;if((e|0)==0){f=1}else{if((a[b+56>>0]|0)==0){Mt(e);c[b+28>>2]=0;a[b+72>>0]=1;f=0}else{f=1}}i=d;return f|0}function wq(a,b){a=a|0;b=b|0;c[a+76>>2]=b;return}function xq(b,d,e,f,g,h,j,k){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0;l=i;m=c[b+68>>2]|0;do{if((m|0)==0){n=1}else{if((a[b+56>>0]|0)==0){o=Qt(m,d,e,1)|0;if((o|0)==0){n=1}else{a[b+72>>0]=1;p=kt(f,g,h,j)|0;if((p|0)==0){n=1}else{qt(p,k);if((Gt(o,p)|0)==0){tt(p,c[b+76>>2]|0);o=b+28|0;c[o>>2]=(c[o>>2]|0)+1;n=0;break}else{lt(p);n=1;break}}}}else{n=1}}}while(0);i=l;return n|0}function yq(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;h=i;j=yz(88)|0;if((j|0)==0){k=0;i=h;return k|0}Pq(j,j,0,0,0,0);Tq(j,6);Vq(j,g);c[j+4>>2]=237;c[j+8>>2]=16;c[j+12>>2]=17;c[j+20>>2]=29;a[j+72>>0]=0;c[j+76>>2]=2;c[j+80>>2]=f;c[j+84>>2]=0;g=ft(d,f)|0;c[j+68>>2]=g;if((g|0)==0){zq(j);k=0;i=h;return k|0}f=b[g>>1]|0;d=f&65535;if(f<<16>>16==0){k=j;i=h;return k|0}f=c[g+4>>2]|0;g=0;l=0;m=0;while(1){n=c[f+(g<<2)>>2]|0;o=b[n+2>>1]|0;p=o&65535;m=p+m|0;if(o<<16>>16==0){q=l}else{o=c[n+4>>2]|0;n=l;r=0;while(1){s=(e[(c[o+(r<<2)>>2]|0)+2>>1]|0)+n|0;t=r+1|0;if((t|0)==(p|0)){q=s;break}else{n=s;r=t}}}g=g+1|0;if((g|0)==(d|0)){break}else{l=q}}if((m|0)==0|(q|0)==0){k=j;i=h;return k|0}l=(((((m>>>0)/(d>>>0)|0)>>>1)+m|0)>>>0)/(d>>>0)|0;g=(((((q>>>0)/(m>>>0)|0)>>>1)+q|0)>>>0)/(m>>>0)|0;if((Xq(j,q,d,l,g)|0)!=0){k=j;i=h;return k|0}Yq(j,d,l,g);k=j;i=h;return k|0}function zq(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;i=i+16|0;e=d;f=c[b+64>>2]|0;do{if((a[f+72>>0]|0)!=0){g=c[o>>2]|0;h=b+24|0;c[e>>2]=c[h>>2];hb(g|0,46352,e|0)|0;j=f+84|0;if((c[j>>2]|0)!=0){k=f+68|0;if((c[k>>2]|0)!=0){if((Uq(f)|0)==0){if((it(c[j>>2]|0,c[k>>2]|0,c[f+80>>2]|0)|0)==0){break}}}}c[e>>2]=c[h>>2];hb(g|0,46392,e|0)|0}}while(0);e=c[f+68>>2]|0;if((e|0)==0){l=f+84|0;m=c[l>>2]|0;zz(m);zz(f);i=d;return}Lt(e);l=f+84|0;m=c[l>>2]|0;zz(m);zz(f);i=d;return}function Aq(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;i=i+16|0;g=f+12|0;h=f+8|0;j=f+4|0;k=f;l=c[a+64>>2]|0;a=l+68|0;if((e|0)==0){m=0;i=f;return m|0}else{n=e;o=d;p=b}while(1){if((Tt(c[a>>2]|0,o,g,h,j)|0)!=0){m=1;q=5;break}c[k>>2]=512;b=(rq(l,p,k,c[g>>2]|0,c[h>>2]|0,c[j>>2]|0,1)|0)==0;if(!(b&(c[k>>2]|0)==512)){m=1;q=5;break}b=n+ -1|0;if((b|0)==0){m=0;q=5;break}else{n=b;o=o+1|0;p=p+512|0}}if((q|0)==5){i=f;return m|0}return 0}function Bq(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;i=i+16|0;j=h+8|0;k=h+4|0;l=h;if((a[d+56>>0]|0)!=0){m=1;i=h;return m|0}n=c[d+64>>2]|0;d=n+68|0;o=n+56|0;if((g|0)==0){m=0;i=h;return m|0}p=n+72|0;n=g;g=f;f=e;while(1){if((Tt(c[d>>2]|0,g,j,k,l)|0)!=0){m=1;q=16;break}e=c[d>>2]|0;if((e|0)==0){m=1;q=16;break}if((a[o>>0]|0)!=0){m=1;q=16;break}r=St(e,c[j>>2]|0,c[k>>2]|0,c[l>>2]|0,1)|0;if((r|0)==0){m=1;q=16;break}e=r+12|0;if((c[e>>2]&8|0)!=0){m=1;q=16;break}a[p>>0]=1;s=b[r+10>>1]|0;if((s&65535)<512){if(s<<16>>16==0){t=0;u=32}else{v=s&65535;w=32;q=11}}else{v=512;w=0;q=11}if((q|0)==11){q=0;Mz(c[r+24>>2]|0,f|0,v|0)|0;t=v;u=w}c[e>>2]=c[e>>2]&-3;e=c[r>>2]|0;if((e|0)!=0){lt(e);c[r>>2]=0;c[r+20>>2]=0}if(!((u|0)==0&(t|0)==512)){m=1;q=16;break}r=n+ -1|0;if((r|0)==0){m=0;q=16;break}else{n=r;g=g+1|0;f=f+512|0}}if((q|0)==16){i=h;return m|0}return 0}function Cq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0;e=i;f=c[b+64>>2]|0;if((Fz(d,46344)|0)==0){d=f+84|0;if((c[d>>2]|0)==0){g=1}else{b=f+68|0;if((c[b>>2]|0)==0){g=1}else{if((Uq(f)|0)==0){if((it(c[d>>2]|0,c[b>>2]|0,c[f+80>>2]|0)|0)==0){a[f+72>>0]=0;g=0}else{g=1}}else{g=1}}}}else{g=1}i=e;return g|0}function Dq(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;e=i;if((b|0)==0){f=gt(a)|0;if((f|0)==0){g=et(a)|0;if((g|0)==0){h=0;i=e;return h|0}else{j=g}}else{j=f}}else{j=b}if((d|0)==0){b=Ib(a|0,46336)|0;if((b|0)==0){k=1;l=Ib(a|0,46328)|0;m=8}else{n=0;o=b}}else{k=d;l=Ib(a|0,46328)|0;m=8}if((m|0)==8){if((l|0)==0){h=0;i=e;return h|0}else{n=k;o=l}}l=yq(o,j,n)|0;zb(o|0)|0;if((l|0)==0){h=0;i=e;return h|0}o=c[l+64>>2]|0;n=yz((Kz(a|0)|0)+1|0)|0;c[o+84>>2]=n;if((n|0)!=0){Rz(n|0,a|0)|0}Wq(l,a);h=l;i=e;return h|0}function Eq(a){a=a|0;var b=0,c=0;b=i;c=gt(a)|0;i=b;return c|0}function Fq(a,b){a=a|0;b=b|0;return(((d[a+b>>0]|0)<<8|(d[a+(b+1)>>0]|0))<<8|(d[a+(b+2)>>0]|0))<<8|(d[a+(b+3)>>0]|0)|0}function Gq(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c>>0]=d>>>24;a[b+(c+1)>>0]=d>>>16;a[b+(c+2)>>0]=d>>>8;a[b+(c+3)>>0]=d;return}function Hq(a,b){a=a|0;b=b|0;return(((d[a+(b+3)>>0]|0)<<8|(d[a+(b+2)>>0]|0))<<8|(d[a+(b+1)>>0]|0))<<8|(d[a+b>>0]|0)|0}function Iq(a,b){a=a|0;b=b|0;var c=0,e=0,f=0;c=i;e=Nz(d[a+(b+7)>>0]|0|0,0,8)|0;f=Nz(e|(d[a+(b+6)>>0]|0)|0,G|0,8)|0;e=Nz(f|(d[a+(b+5)>>0]|0)|0,G|0,8)|0;f=Nz(e|(d[a+(b+4)>>0]|0)|0,G|0,8)|0;e=Nz(f|(d[a+(b+3)>>0]|0)|0,G|0,8)|0;f=Nz(e|(d[a+(b+2)>>0]|0)|0,G|0,8)|0;e=Nz(f|(d[a+(b+1)>>0]|0)|0,G|0,8)|0;i=c;return e|(d[a+b>>0]|0)|0}function Jq(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c>>0]=d;a[b+(c+1)>>0]=d>>>8;a[b+(c+2)>>0]=d>>>16;a[b+(c+3)>>0]=d>>>24;return}function Kq(b,c,d,e){b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=i;a[b+c>>0]=d;g=Lz(d|0,e|0,8)|0;a[b+(c+1)>>0]=g;g=Lz(d|0,e|0,16)|0;a[b+(c+2)>>0]=g;g=Lz(d|0,e|0,24)|0;a[b+(c+3)>>0]=g;a[b+(c+4)>>0]=e;g=Lz(d|0,e|0,40)|0;a[b+(c+5)>>0]=g;g=Lz(d|0,e|0,48)|0;a[b+(c+6)>>0]=g;g=Lz(d|0,e|0,56)|0;a[b+(c+7)>>0]=g;i=f;return}function Lq(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;if(d>>>0>0|(d|0)==0&c>>>0>2147483647){h=1}else{if((xb(a|0,c|0,0)|0)==0){c=ta(b|0,1,e|0,a|0)|0;if(0<f>>>0|0==(f|0)&c>>>0<e>>>0){a=Iz(e|0,f|0,c|0,0)|0;Oz(b+c|0,0,a|0)|0;h=0}else{h=0}}else{h=1}}i=g;return h|0}function Mq(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=i;if(d>>>0>0|(d|0)==0&c>>>0>2147483647){h=1}else{if((xb(a|0,c|0,0)|0)==0){h=((fb(b|0,1,e|0,a|0)|0)!=(e|0)|0!=(f|0))&1}else{h=1}}i=g;return h|0}function Nq(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;if((xb(a|0,0,2)|0)==0){e=La(a|0)|0;if((e|0)==-1){f=1}else{a=b;c[a>>2]=e;c[a+4>>2]=((e|0)<0)<<31>>31;f=0}}else{f=1}i=d;return f|0}function Oq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;c=i;Nb(a|0)|0;d=(wb(Rb(a|0)|0,b|0)|0)!=0|0;i=c;return d|0}function Pq(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=i;k=(e|0)==0;c[b+0>>2]=0;c[b+4>>2]=0;c[b+8>>2]=0;c[b+12>>2]=0;c[b+16>>2]=0;c[b+20>>2]=0;c[b+24>>2]=0;if(k){k=ca(ca(g,f)|0,h)|0;if((k|0)==0){l=0;m=f;n=g;o=h}else{p=k;q=3}}else{p=e;q=3}do{if((q|0)==3){if((f|0)==0){e=(h|0)==0?63:h;k=(g|0)==0?16:g;l=p;m=(p>>>0)/((ca(e,k)|0)>>>0)|0;n=k;o=e;break}e=(h|0)==0;if((g|0)==0){k=e?63:h;l=p;m=f;n=(p>>>0)/((ca(k,f)|0)>>>0)|0;o=k;break}if(e){l=p;m=f;n=g;o=(p>>>0)/((ca(g,f)|0)>>>0)|0}else{l=p;m=f;n=g;o=h}}}while(0);c[b+28>>2]=l;c[b+32>>2]=m;c[b+36>>2]=n;c[b+40>>2]=o;c[b+44>>2]=m;c[b+48>>2]=n;c[b+52>>2]=o;a[b+56>>0]=0;c[b+60>>2]=0;c[b+64>>2]=d;i=j;return}function Qq(a){a=a|0;var b=0,d=0;b=i;if((a|0)!=0){zz(c[a+60>>2]|0);d=c[a+4>>2]|0;if((d|0)!=0){ic[d&511](a)}}i=b;return}function Rq(a,b){a=a|0;b=b|0;c[a+24>>2]=b;return}function Sq(a){a=a|0;return c[a>>2]|0}function Tq(a,b){a=a|0;b=b|0;c[a>>2]=b;return}function Uq(b){b=b|0;return(a[b+56>>0]|0)!=0|0}function Vq(b,c){b=b|0;c=c|0;a[b+56>>0]=(c|0)!=0|0;return}function Wq(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a+60|0;a=c[e>>2]|0;if((a|0)!=0){zz(a)}if((b|0)==0){c[e>>2]=0;i=d;return}a=yz((Kz(b|0)|0)+1|0)|0;c[e>>2]=a;if((a|0)==0){i=d;return}Rz(a|0,b|0)|0;i=d;return}function Xq(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;if((b|0)==0){h=ca(ca(e,d)|0,f)|0;if((h|0)==0){j=1;i=g;return j|0}else{k=h}}else{k=b}do{if((d|0)==0){b=(f|0)==0?63:f;h=(e|0)==0?16:e;l=b;m=(k>>>0)/((ca(b,h)|0)>>>0)|0;n=h}else{h=(f|0)==0;if((e|0)==0){b=h?63:f;l=b;m=d;n=(k>>>0)/((ca(b,d)|0)>>>0)|0;break}if(h){l=(k>>>0)/((ca(e,d)|0)>>>0)|0;m=d;n=e}else{l=f;m=d;n=e}}}while(0);c[a+28>>2]=k;c[a+32>>2]=m;c[a+36>>2]=n;c[a+40>>2]=l;j=0;i=g;return j|0}function Yq(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;c[a+44>>2]=b;c[a+48>>2]=d;c[a+52>>2]=e;return}function Zq(a){a=a|0;return c[a+24>>2]|0}function _q(a){a=a|0;return c[a+28>>2]|0}function $q(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;e=i;i=i+512|0;f=e;g=b+8|0;h=c[g>>2]|0;a:do{if((h|0)!=0){if((nc[h&63](b,f,0,1)|0)==0){if((a[f+510>>0]|0)==85){if((a[f+511>>0]|0)==-86){j=0;k=0;l=0;m=0;while(1){n=l<<4;do{if((a[f+(n+446)>>0]&127)==0){o=d[f+(n+448)>>0]|0;p=o<<2&768|d[f+(n+449)>>0];q=a[f+(n+447)>>0]|0;r=o&63;o=((d[f+(n+457)>>0]<<8|d[f+(n+456)>>0])<<8|d[f+(n+455)>>0])<<8|d[f+(n+454)>>0];s=d[f+(n+452)>>0]|0;t=s<<2&768|d[f+(n+453)>>0];u=a[f+(n+451)>>0]|0;v=s&63;s=((d[f+(n+461)>>0]<<8|d[f+(n+460)>>0])<<8|d[f+(n+459)>>0])<<8|d[f+(n+458)>>0];if((r|0)==0|(v|0)==0|(o|0)==0|(s|0)==0){w=j;x=k;y=m}else{z=r+ -1|0;r=v+ -1|0;v=o+ -1+s|0;if(o>>>0>z>>>0&v>>>0>r>>>0){s=v-r|0;r=u&255;u=Yz(r|0,0,p|0,0)|0;v=G;A=Yz(t|0,0,q&255|0,0)|0;q=G;if((u|0)==(A|0)&(v|0)==(q|0)){w=j;x=k;y=m}else{B=Yz(t|0,0,o-z|0,0)|0;z=G;o=Yz(s|0,0,p|0,0)|0;p=G;C=Iz(u|0,v|0,A|0,q|0)|0;q=G;A=Iz(o|0,p|0,B|0,z|0)|0;z=Wz(A|0,G|0,C|0,q|0)|0;q=Yz(z|0,0,t|0,0)|0;t=G;if((q|0)==0&(t|0)==0){D=j}else{C=Yz(z|0,0,r|0,0)|0;r=Iz(s|0,0,C|0,G|0)|0;C=Wz(r|0,G|0,q|0,t|0)|0;if((C|0)==0){w=0;x=k;y=m;break}if((z|0)==0){w=C;x=k;y=m;break}else{D=C}}if(!((k|0)==0|(k|0)==(D|0))){break a}if((m|0)==0|(m|0)==(z|0)){w=D;x=D;y=z}else{break a}}}else{w=j;x=k;y=m}}}else{w=j;x=k;y=m}}while(0);l=l+1|0;if(!(l>>>0<4)){break}else{j=w;k=x;m=y}}if(!((x|0)==0|(y|0)==0)){m=b+28|0;k=c[m>>2]|0;j=ca(y,x)|0;l=(k>>>0)/(j>>>0)|0;if((k|0)==0){n=ca(l,j)|0;if((n|0)==0){i=e;return 0}else{E=n}}else{E=k}if((l|0)==0){F=(E>>>0)/(j>>>0)|0}else{F=l}c[m>>2]=E;c[b+32>>2]=F;c[b+36>>2]=x;c[b+40>>2]=y;i=e;return 0}}}}}}while(0);y=c[g>>2]|0;if((y|0)!=0){if((nc[y&63](b,f,0,1)|0)==0){if((a[f+510>>0]|0)==85){if((a[f+511>>0]|0)==-86){if((d[f+12>>0]<<8|d[f+11>>0]|0)==512){y=d[f+27>>0]<<8|d[f+26>>0];x=y&65535;F=d[f+25>>0]<<8|d[f+24>>0];E=F&65535;if(!(x<<16>>16==0|(x&65535)>255)){if(!(E<<16>>16==0|(E&65535)>255)){E=b+28|0;x=c[E>>2]|0;w=ca(F,y)|0;D=(x>>>0)/(w>>>0)|0;if((x|0)==0){h=ca(D,w)|0;if((h|0)==0){i=e;return 0}else{H=h}}else{H=x}do{if((D|0)==0){x=(F|0)==0?63:F;h=(y|0)==0?16:y;I=x;J=(H>>>0)/((ca(x,h)|0)>>>0)|0;K=h}else{h=(F|0)==0;if((y|0)==0){x=h?63:F;I=x;J=D;K=(H>>>0)/((ca(D,x)|0)>>>0)|0;break}if(h){I=(H>>>0)/((ca(D,y)|0)>>>0)|0;J=D;K=y}else{I=F;J=D;K=y}}}while(0);c[E>>2]=H;c[b+32>>2]=J;c[b+36>>2]=K;c[b+40>>2]=I;i=e;return 0}}}}}}}I=c[g>>2]|0;if((I|0)!=0){if((nc[I&63](b,f,0,1)|0)==0){if((d[f+508>>0]<<8|d[f+509>>0]|0)==55998){I=0;g=0;while(1){L=d[f+g>>0]<<8^I;M=d[f+(g|1)>>0]|0;g=g+2|0;if(!(g>>>0<512)){break}else{I=L^M}}if((L|0)==(M|0)){if((((d[f+128>>0]<<8|d[f+129>>0])<<8|d[f+130>>0])<<8|d[f+131>>0]|0)==1){if(!(((d[f+140>>0]<<8|d[f+141>>0])&65535)>8)){M=d[f+422>>0]<<8|d[f+423>>0];L=d[f+436>>0]<<8|d[f+437>>0];I=d[f+438>>0]<<8|d[f+439>>0];f=b+28|0;g=c[f>>2]|0;if((g|0)==0){K=ca(ca(L,M)|0,I)|0;if((K|0)==0){i=e;return 0}else{N=K}}else{N=g}do{if((M|0)==0){g=(I|0)==0?63:I;K=(L|0)==0?16:L;O=g;P=(N>>>0)/((ca(g,K)|0)>>>0)|0;Q=K}else{K=(I|0)==0;if((L|0)==0){g=K?63:I;O=g;P=M;Q=(N>>>0)/((ca(g,M)|0)>>>0)|0;break}if(K){O=(N>>>0)/((ca(L,M)|0)>>>0)|0;P=M;Q=L}else{O=I;P=M;Q=L}}}while(0);c[f>>2]=N;c[b+32>>2]=P;c[b+36>>2]=Q;c[b+40>>2]=O;i=e;return 0}}}}}}O=b+28|0;Q=c[O>>2]|0;do{switch(Q|0){case 320:{c[O>>2]=320;c[b+32>>2]=40;c[b+36>>2]=1;c[b+40>>2]=8;i=e;return 0};case 360:{c[O>>2]=360;c[b+32>>2]=40;c[b+36>>2]=1;c[b+40>>2]=9;i=e;return 0};case 640:{c[O>>2]=640;c[b+32>>2]=40;c[b+36>>2]=2;c[b+40>>2]=8;i=e;return 0};case 720:{c[O>>2]=720;c[b+32>>2]=40;c[b+36>>2]=2;c[b+40>>2]=9;i=e;return 0};case 800:{c[O>>2]=800;c[b+32>>2]=40;c[b+36>>2]=2;c[b+40>>2]=10;i=e;return 0};case 1440:{c[O>>2]=1440;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=9;i=e;return 0};case 1600:{c[O>>2]=1600;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=10;i=e;return 0};case 2400:{c[O>>2]=2400;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=15;i=e;return 0};case 2880:{c[O>>2]=2880;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=18;i=e;return 0};case 5760:{c[O>>2]=5760;c[b+32>>2]=80;c[b+36>>2]=2;c[b+40>>2]=36;i=e;return 0};default:{P=b+32|0;N=c[P>>2]|0;f=b+36|0;L=c[f>>2]|0;M=b+40|0;I=c[M>>2]|0;if((Q|0)==0){K=ca(ca(L,N)|0,I)|0;if((K|0)==0){i=e;return 0}else{R=K}}else{R=Q}do{if((N|0)==0){K=(I|0)==0?63:I;g=(L|0)==0?16:L;S=K;T=(R>>>0)/((ca(K,g)|0)>>>0)|0;U=g}else{g=(I|0)==0;if((L|0)==0){K=g?63:I;S=K;T=N;U=(R>>>0)/((ca(K,N)|0)>>>0)|0;break}if(g){S=(R>>>0)/((ca(L,N)|0)>>>0)|0;T=N;U=L}else{S=I;T=N;U=L}}}while(0);c[O>>2]=R;c[P>>2]=T;c[f>>2]=U;c[M>>2]=S;i=e;return 0}}}while(0);return 0}function ar(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=i;do{if((wr(a)|0)==0){if((Gr(a)|0)!=0){f=Br(a,d)|0;break}if((or(a)|0)!=0){f=nr(a,d)|0;break}g=Eq(a)|0;if((g|0)!=0){f=Dq(a,g,d)|0;break}g=et(a)|0;if((g|0)==0|(g|0)==12){f=Jr(a,b,c,d)|0;break}else{f=Dq(a,g,d)|0;break}}else{f=vr(a,d)|0}}while(0);i=e;return f|0}function br(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=c[a+8>>2]|0;if((g|0)==0){h=1;i=f;return h|0}h=nc[g&63](a,b,d,e)|0;i=f;return h|0}function cr(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=c[a+12>>2]|0;if((g|0)==0){h=1;i=f;return h|0}h=nc[g&63](a,b,d,e)|0;i=f;return h|0}function dr(){var a=0,b=0,d=0;a=i;b=yz(8)|0;if((b|0)==0){d=0}else{c[b>>2]=0;c[b+4>>2]=0;d=b}i=a;return d|0}function er(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=c[a>>2]|0;f=c[a+4>>2]|0;do{if((e|0)==0){g=1}else{h=c[b+24>>2]|0;j=0;while(1){k=j+1|0;if((c[(c[f+(j<<2)>>2]|0)+24>>2]|0)==(h|0)){l=1;m=8;break}if(k>>>0<e>>>0){j=k}else{m=5;break}}if((m|0)==5){g=e+1|0;break}else if((m|0)==8){i=d;return l|0}}}while(0);m=Az(f,g<<2)|0;if((m|0)==0){l=1;i=d;return l|0}c[m+(c[a>>2]<<2)>>2]=b;c[a>>2]=g;c[a+4>>2]=m;l=0;i=d;return l|0}function fr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;e=c[a>>2]|0;if((e|0)==0){f=0;g=0;c[a>>2]=f;i=d;return g|0}h=a+4|0;j=0;k=0;l=0;while(1){m=c[h>>2]|0;n=c[m+(j<<2)>>2]|0;if((n|0)==(b|0)){o=k;p=1}else{c[m+(k<<2)>>2]=n;o=k+1|0;p=l}n=j+1|0;if(n>>>0<e>>>0){j=n;k=o;l=p}else{f=o;g=p;break}}c[a>>2]=f;i=d;return g|0}function gr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;e=c[a>>2]|0;a:do{if((e|0)==0){f=0}else{g=c[a+4>>2]|0;h=0;while(1){j=c[g+(h<<2)>>2]|0;k=h+1|0;if((c[j+24>>2]|0)==(b|0)){f=j;break a}if(k>>>0<e>>>0){h=k}else{f=0;break}}}}while(0);i=d;return f|0}function hr(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;d=c[a>>2]|0;if((d|0)==0){e=0;i=b;return e|0}f=a+4|0;g=d;d=0;h=0;while(1){j=c[(c[f>>2]|0)+(d<<2)>>2]|0;k=c[j+20>>2]|0;if((k|0)==0){l=g;m=h}else{n=(gc[k&63](j,46424,46432)|0)==0;l=c[a>>2]|0;m=n?h:1}n=d+1|0;if(n>>>0<l>>>0){g=l;d=n;h=m}else{e=m;break}}i=b;return e|0}function ir(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=c[a>>2]|0;a:do{if((g|0)==0){h=1}else{j=c[a+4>>2]|0;k=0;while(1){l=c[j+(k<<2)>>2]|0;m=k+1|0;if((c[l+24>>2]|0)==(b|0)){break}if(m>>>0<g>>>0){k=m}else{h=1;break a}}if((l|0)==0){h=1}else{k=c[l+20>>2]|0;if((k|0)==0){h=1}else{h=gc[k&63](l,d,(e|0)==0?46432:e)|0}}}}while(0);i=f;return h|0}function jr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;d=i;i=i+32|0;e=d;if((Lq(a,e,0,0,23,0)|0)!=0){f=0;i=d;return f|0}if((Dz(e,46440,7)|0)!=0){f=0;i=d;return f|0}g=Hq(e,15)|0;h=Hq(e,7)|0;j=Hq(e,11)|0;k=Hq(e,19)|0;if(k>>>0<23){f=0;i=d;return f|0}e=yz(80)|0;if((e|0)==0){f=0;i=d;return f|0}Pq(e,e,0,g,h,j);Tq(e,4);Vq(e,b);c[e+4>>2]=238;c[e+8>>2]=18;c[e+12>>2]=19;b=e+72|0;c[b>>2]=k;c[b+4>>2]=0;c[e+68>>2]=a;f=e;i=d;return f|0}function kr(a){a=a|0;var b=0,d=0;b=i;d=c[a+64>>2]|0;zb(c[d+68>>2]|0)|0;zz(d);i=b;return}function lr(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){g=1;i=f;return g|0}h=c[a+64>>2]|0;a=h+72|0;j=c[a>>2]|0;k=c[a+4>>2]|0;a=Nz(d|0,0,9)|0;d=Jz(j|0,k|0,a|0,G|0)|0;a=G;k=Nz(e|0,0,9)|0;g=(Lq(c[h+68>>2]|0,b,d,a,k,G)|0)!=0|0;i=f;return g|0}function mr(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;if((a[b+56>>0]|0)!=0){h=1;i=g;return h|0}if((f+e|0)>>>0>(c[b+28>>2]|0)>>>0){h=1;i=g;return h|0}j=c[b+64>>2]|0;b=j+72|0;k=c[b>>2]|0;l=c[b+4>>2]|0;b=Nz(e|0,0,9)|0;e=Jz(k|0,l|0,b|0,G|0)|0;b=G;l=Nz(f|0,0,9)|0;f=j+68|0;if((Mq(c[f>>2]|0,d,e,b,l,G)|0)!=0){h=1;i=g;return h|0}Nb(c[f>>2]|0)|0;h=0;i=g;return h|0}function nr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;c=i;if((b|0)==0){d=Ib(a|0,46456)|0;if((d|0)==0){e=1;f=Ib(a|0,46448)|0;g=5}else{h=0;j=d}}else{e=b;f=Ib(a|0,46448)|0;g=5}if((g|0)==5){if((f|0)==0){k=0;i=c;return k|0}else{h=e;j=f}}f=jr(j,h)|0;if((f|0)==0){zb(j|0)|0;k=0;i=c;return k|0}else{Wq(f,a);k=f;i=c;return k|0}return 0}function or(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=i;i=i+16|0;c=b;d=Ib(a|0,46448)|0;if((d|0)==0){e=0;i=b;return e|0}if((Lq(d,c,0,0,8,0)|0)==0){f=(Dz(c,46440,7)|0)==0|0}else{f=0}zb(d|0)|0;e=f;i=b;return e|0}function pr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+32|0;e=d;if((ta(e|0,1,32,a|0)|0)!=32){f=0;i=d;return f|0}if((Fq(e,0)|0)!=1346981191){f=0;i=d;return f|0}if((Fq(e,4)|0)!=0){f=0;i=d;return f|0}if((Fq(e,28)|0)!=512){f=0;i=d;return f|0}g=Fq(e,12)|0;h=Fq(e,16)|0;j=Fq(e,20)|0;k=Fq(e,24)|0;l=yz(80)|0;if((l|0)==0){f=0;i=d;return f|0}Pq(l,l,g,h,j,k);Tq(l,3);Vq(l,b);c[l+68>>2]=a;c[l+4>>2]=239;c[l+8>>2]=20;c[l+12>>2]=21;c[l+16>>2]=22;c[l+20>>2]=30;c[l+72>>2]=Fq(e,8)|0;c[l+76>>2]=Fq(e,28)|0;f=l;i=d;return f|0}function qr(a){a=a|0;var b=0,d=0;b=i;d=c[a+64>>2]|0;a=c[d+68>>2]|0;if((a|0)!=0){zb(a|0)|0}zz(d);i=b;return}function rr(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;g=c[a+64>>2]|0;if((e+d|0)>>>0>(c[g+28>>2]|0)>>>0){h=1;i=f;return h|0}a=c[g+72>>2]|0;j=Nz(d|0,0,9)|0;d=Jz(a|0,0,j|0,G|0)|0;j=G;a=Nz(e|0,0,9)|0;h=(Lq(c[g+68>>2]|0,b,d,j,a,G)|0)!=0|0;i=f;return h|0}function sr(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0;g=i;h=c[b+64>>2]|0;if((a[b+56>>0]|0)!=0){j=1;i=g;return j|0}if((f+e|0)>>>0>(c[b+28>>2]|0)>>>0){j=1;i=g;return j|0}b=c[h+72>>2]|0;k=Nz(e|0,0,9)|0;e=Jz(b|0,0,k|0,G|0)|0;k=G;b=Nz(f|0,0,9)|0;f=h+68|0;if((Mq(c[f>>2]|0,d,e,k,b,G)|0)!=0){j=1;i=g;return j|0}Nb(c[f>>2]|0)|0;j=0;i=g;return j|0}function tr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 1}function ur(a,b,c){a=a|0;b=b|0;c=c|0;c=i;a=(Fz(b,46480)|0)!=0|0;i=c;return a|0}function vr(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;c=i;if((b|0)==0){d=Ib(a|0,46472)|0;if((d|0)==0){e=1;f=Ib(a|0,46464)|0;g=5}else{h=0;j=d}}else{e=b;f=Ib(a|0,46464)|0;g=5}if((g|0)==5){if((f|0)==0){k=0;i=c;return k|0}else{h=e;j=f}}f=pr(j,h)|0;if((f|0)==0){zb(j|0)|0;k=0;i=c;return k|0}else{Wq(f,a);k=f;i=c;return k|0}return 0}function wr(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=i;i=i+16|0;c=b;d=Ib(a|0,46464)|0;if((d|0)==0){e=0;i=b;return e|0}if((Lq(d,c,0,0,4,0)|0)==0){f=(Fq(c,0)|0)==1346981191|0}else{f=0}zb(d|0)|0;e=f;i=b;return e|0}function xr(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;i=i+16|0;f=e;g=yz(4280)|0;if((g|0)==0){h=0;i=e;return h|0}j=g+4276|0;c[j>>2]=b;c[g+68>>2]=0;k=g+4264|0;c[k>>2]=0;l=g+4268|0;c[l>>2]=0;m=g+4272|0;c[m>>2]=0;n=g+152|0;do{if((Lq(b,n,0,0,4096,0)|0)==0){if((Hq(n,0)|0)==4474193){p=g+4248|0;a[p>>0]=0;q=g+72|0;c[q>>2]=Hq(n,4)|0;r=g+76|0;c[r>>2]=Hq(n,8)|0;s=Hq(n,12)|0;c[g+80>>2]=s;t=c[q>>2]|0;u=t+ -1|0;if((u&t|0)==0){v=c[r>>2]|0;if(!((v+ -1&v|0)!=0|(s|0)==0)){s=g+128|0;c[s>>2]=ca(v,t)|0;t=g+136|0;v=t;c[v>>2]=u;c[v+4>>2]=0;v=Iq(n,16)|0;u=g+88|0;r=u;c[r>>2]=v;c[r+4>>2]=G;r=Iq(n,24)|0;v=g+96|0;c[v>>2]=r;c[v+4>>2]=G;v=Iq(n,32)|0;r=G;w=g+104|0;x=w;c[x>>2]=v;c[x+4>>2]=r;x=u;u=c[x+4>>2]|0;y=c[x>>2]&-6;if(!((y|0)==0&(u|0)==0)){x=c[o>>2]|0;z=f;c[z>>2]=y;c[z+4>>2]=u;hb(x|0,46520,f|0)|0;break}if(!((v|0)==0&(r|0)==0)){a[p>>0]=1;r=w;c[r>>2]=0;c[r+4>>2]=0;Kq(n,32,0,0)}r=Iq(n,40)|0;w=g+112|0;v=w;c[v>>2]=r;c[v+4>>2]=G;v=g+4256|0;c[v>>2]=0;c[v+4>>2]=0;v=Iq(n,48)|0;r=g+120|0;x=r;c[x>>2]=v;c[x+4>>2]=G;x=w;u=t;if((c[u>>2]&c[x>>2]|0)==0&(c[u+4>>2]&c[x+4>>2]|0)==0){if((v&511|0)==0&0==0){v=g+144|0;if((Nq(c[j>>2]|0,v)|0)==0){x=v;u=c[q>>2]|0;z=Jz(c[x>>2]|0,c[x+4>>2]|0,-1,-1)|0;x=Jz(z|0,G|0,u|0,0)|0;u=t;t=G&~c[u+4>>2];z=v;c[z>>2]=x&~c[u>>2];c[z+4>>2]=t;do{if((a[p>>0]|0)!=0&(d|0)==0){if((Mq(c[j>>2]|0,n,0,0,4096,0)|0)==0){Nb(c[j>>2]|0)|0;break}zz(g);h=0;i=e;return h|0}}while(0);p=r;t=Lz(c[p>>2]|0,c[p+4>>2]|0,9)|0;Pq(g,g,t,0,0,0);Tq(g,7);Vq(g,d);c[g+4>>2]=240;c[g+8>>2]=23;c[g+12>>2]=24;t=c[s>>2]|0;p=yz(t)|0;c[k>>2]=p;if((p|0)!=0){z=yz(t)|0;c[l>>2]=z;if((z|0)!=0){z=yz(c[q>>2]|0)|0;c[m>>2]=z;if((z|0)!=0){z=w;if((Lq(c[j>>2]|0,p,c[z>>2]|0,c[z+4>>2]|0,t,0)|0)==0){$q(g)|0;h=g;i=e;return h|0}t=c[g+64>>2]|0;z=c[t+68>>2]|0;if((z|0)!=0){Qq(z)}zz(c[t+4272>>2]|0);zz(c[t+4268>>2]|0);zz(c[t+4264>>2]|0);zb(c[t+4276>>2]|0)|0;zz(t);h=0;i=e;return h|0}}}t=c[g+64>>2]|0;z=c[t+68>>2]|0;if((z|0)!=0){Qq(z)}zz(c[t+4272>>2]|0);zz(c[t+4268>>2]|0);zz(c[t+4264>>2]|0);zb(c[t+4276>>2]|0)|0;zz(t);h=0;i=e;return h|0}}}}}}}}while(0);zz(g);h=0;i=e;return h|0}function yr(a){a=a|0;var b=0,d=0;b=i;d=c[a+64>>2]|0;a=c[d+68>>2]|0;if((a|0)!=0){Qq(a)}zz(c[d+4272>>2]|0);zz(c[d+4268>>2]|0);zz(c[d+4264>>2]|0);zb(c[d+4276>>2]|0)|0;zz(d);i=b;return}function zr(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;i=i+16|0;g=f;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){h=1;i=f;return h|0}j=c[a+64>>2]|0;a=j+72|0;k=j+4276|0;if((e|0)==0){h=0;i=f;return h|0}l=j+68|0;m=b;b=e;e=d;a:while(1){d=(c[a>>2]|0)>>>9;n=d-((e>>>0)%(d>>>0)|0)|0;d=n>>>0>b>>>0?b:n;n=Nz(e|0,0,9)|0;o=g;c[o>>2]=n;c[o+4>>2]=G;if((Hr(j,g,0)|0)!=0){h=1;p=12;break}o=g;n=c[o>>2]|0;q=c[o+4>>2]|0;do{if((n|0)==0&(q|0)==0){o=c[l>>2]|0;if((o|0)==0){r=d<<9;Oz(m|0,0,r|0)|0;s=r;break}if((br(o,m,e,d)|0)!=0){h=1;p=12;break a}s=d<<9}else{o=d<<9;if((Lq(c[k>>2]|0,m,n,q,o,0)|0)==0){s=o}else{h=1;p=12;break a}}}while(0);if((b|0)==(d|0)){h=0;p=12;break}else{m=m+s|0;b=b-d|0;e=d+e|0}}if((p|0)==12){i=f;return h|0}return 0}function Ar(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;f=i;i=i+16|0;g=f;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){h=1;i=f;return h|0}j=c[a+64>>2]|0;a=j+72|0;k=j+4276|0;if((e|0)==0){h=0;i=f;return h|0}else{l=b;m=e;n=d}while(1){d=(c[a>>2]|0)>>>9;e=d-((n>>>0)%(d>>>0)|0)|0;d=e>>>0>m>>>0?m:e;e=Nz(n|0,0,9)|0;b=g;c[b>>2]=e;c[b+4>>2]=G;if((Hr(j,g,1)|0)!=0){h=1;o=6;break}b=g;e=d<<9;if((Mq(c[k>>2]|0,l,c[b>>2]|0,c[b+4>>2]|0,e,0)|0)!=0){h=1;o=6;break}if((m|0)==(d|0)){h=0;o=6;break}else{l=l+e|0;m=m-d|0;n=d+n|0}}if((o|0)==6){i=f;return h|0}return 0}function Br(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0;c=i;if((b|0)==0){d=Ib(a|0,46496)|0;if((d|0)==0){e=1;f=Ib(a|0,46488)|0;g=5}else{h=0;j=d}}else{e=b;f=Ib(a|0,46488)|0;g=5}if((g|0)==5){if((f|0)==0){k=0;i=c;return k|0}else{h=e;j=f}}f=xr(j,h)|0;if((f|0)==0){zb(j|0)|0;k=0;i=c;return k|0}else{Wq(f,a);k=f;i=c;return k|0}return 0}function Cr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=Ib(b|0,46496)|0;if((e|0)==0){if((c[a>>2]|0)==7){f=c[(c[a+64>>2]|0)+72>>2]|0}else{f=0}g=c[a+28>>2]|0;h=Ib(b|0,46504)|0;if((h|0)==0){j=0;i=d;return j|0}k=Fr(h,g,f)|0;zb(h|0)|0;if((k|0)!=0){j=0;i=d;return j|0}}else{zb(e|0)|0}e=Ib(b|0,46496)|0;if((e|0)==0){k=Ib(b|0,46488)|0;if((k|0)==0){j=0;i=d;return j|0}else{l=1;m=k}}else{l=0;m=e}e=xr(m,l)|0;if((e|0)==0){zb(m|0)|0;j=0;i=d;return j|0}Wq(e,b);m=c[e+64>>2]|0;c[m+68>>2]=a;c[e+16>>2]=25;c[e+20>>2]=31;c[e+24>>2]=c[a+24>>2];l=m+152|0;k=Iq(l,16)|0;h=G;f=(c[a>>2]|0)==1;g=f?5:1;f?0:0;Kq(l,16,g|k,h);h=a+60|0;k=c[h>>2]|0;if((k|0)==0){n=0}else{n=Kz(k|0)|0}k=n>>>0>1024?0:n;Jq(l,56,64);Jq(l,60,k);if((k|0)!=0){Mz(m+216|0,c[h>>2]|0,k|0)|0}k=m+4276|0;if((Mq(c[k>>2]|0,l,0,0,4096,0)|0)==0){Nb(c[k>>2]|0)|0}Xq(e,c[a+28>>2]|0,c[a+32>>2]|0,c[a+36>>2]|0,c[a+40>>2]|0)|0;Yq(e,c[a+44>>2]|0,c[a+48>>2]|0,c[a+52>>2]|0);Wq(e,b);j=e;i=d;return j|0}function Dr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 1}function Er(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;d=i;if((Fz(b,46512)|0)!=0){e=1;i=d;return e|0}b=c[a+64>>2]|0;a=b+68|0;if((c[a>>2]|0)==0){e=1;i=d;return e|0}f=b+128|0;g=c[f>>2]|0;h=g>>>3;j=b+72|0;k=(c[j>>2]|0)>>>9;do{if((h|0)==0){l=b+4276|0;m=b+4264|0;n=g}else{o=b+4264|0;p=ca(k,h)|0;q=b+136|0;r=b+4256|0;s=b+4276|0;t=b+4268|0;u=b+4272|0;v=0;w=0;a:while(1){x=w<<3;y=Iq(c[o>>2]|0,x)|0;z=G;if((y|0)==0&(z|0)==0){A=v+p|0}else{B=q;C=y&~c[B>>2];y=z&~c[B+4>>2];B=r;if((c[B>>2]|0)==(C|0)&(c[B+4>>2]|0)==(y|0)){D=v;E=0}else{if((Lq(c[s>>2]|0,c[t>>2]|0,C,y,c[f>>2]|0,0)|0)!=0){e=1;F=21;break}B=r;c[B>>2]=C;c[B+4>>2]=y;D=v;E=0}while(1){y=Iq(c[t>>2]|0,E<<3)|0;B=G;if((y|0)==0&(B|0)==0){H=D+k|0}else{C=q;if((Lq(c[s>>2]|0,c[u>>2]|0,y&~c[C>>2],B&~c[C+4>>2],c[j>>2]|0,0)|0)!=0){e=1;F=21;break a}C=D+k|0;B=c[a>>2]|0;y=c[B+28>>2]|0;if((cr(B,c[u>>2]|0,D,C>>>0>y>>>0?y-D|0:k)|0)==0){H=C}else{e=1;F=21;break a}}E=E+1|0;if(!(E>>>0<h>>>0)){break}else{D=H}}Kq(c[o>>2]|0,x,0,0);A=H}C=w+1|0;if(C>>>0<h>>>0){v=A;w=C}else{F=18;break}}if((F|0)==18){l=s;m=o;n=c[f>>2]|0;break}else if((F|0)==21){i=d;return e|0}}}while(0);F=b+112|0;A=F;if((Mq(c[l>>2]|0,c[m>>2]|0,c[A>>2]|0,c[A+4>>2]|0,n,0)|0)!=0){e=1;i=d;return e|0}Nb(c[l>>2]|0)|0;n=F;F=Jz(c[f>>2]|0,0,c[n>>2]|0,c[n+4>>2]|0)|0;n=G;f=b+144|0;c[f>>2]=F;c[f+4>>2]=n;Oq(c[l>>2]|0,F,n)|0;e=0;i=d;return e|0}function Fr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=i;e=Nz(b|0,0,9)|0;b=G;if(c>>>0<4097){f=4096}else{if(c>>>0>134217727){f=134217728}else{g=(c<<1)+ -1|0;while(1){c=g+ -1&g;if((c|0)==0){f=g;break}else{g=c}}}}g=f>>>3;c=Nz(g|0,0,1)|0;h=G;j=Yz(c|0,h|0,c|0,h|0)|0;h=Yz(j|0,G|0,f|0,0)|0;j=G;if(j>>>0<b>>>0|(j|0)==(b|0)&h>>>0<e>>>0){c=2;while(1){k=c<<1;l=Yz(k|0,0,g|0,0)|0;m=G;n=Yz(l|0,m|0,l|0,m|0)|0;m=Yz(n|0,G|0,f|0,0)|0;n=G;if((n>>>0<b>>>0|(n|0)==(b|0)&m>>>0<e>>>0)&k>>>0<16){c=k}else{o=n;p=m;q=k;break}}}else{o=j;p=h;q=2}h=o>>>0<b>>>0|(o|0)==(b|0)&p>>>0<e>>>0;if(h&f>>>0<134217728){p=f;while(1){o=p<<1;j=Yz(p>>>2&536870911|0,0,q|0,0)|0;c=G;g=Yz(j|0,c|0,o|0,0)|0;k=Yz(g|0,G|0,j|0,c|0)|0;c=G;j=c>>>0<b>>>0|(c|0)==(b|0)&k>>>0<e>>>0;if(j&o>>>0<134217728){p=o}else{r=j;s=o;break}}}else{r=h;s=f}if(r){t=1;i=d;return t|0}r=yz(s)|0;if((r|0)==0){t=1;i=d;return t|0}Oz(r|0,0,s|0)|0;Jq(r,0,4474193);Jq(r,4,s);Jq(r,8,q);Jq(r,12,1);Kq(r,16,0,0);Kq(r,24,0,0);Kq(r,32,0,0);Kq(r,40,s,0);Kq(r,48,e,b);if((Mq(a,r,0,0,s,0)|0)!=0){zz(r);t=1;i=d;return t|0}Oz(r|0,0,s|0)|0;b=q|1;a:do{if((b|0)!=1){q=1;while(1){e=Yz(q|0,0,s|0,0)|0;q=q+1|0;if((Mq(a,r,e,G,s,0)|0)!=0){break}if(!(q>>>0<b>>>0)){break a}}zz(r);t=1;i=d;return t|0}}while(0);zz(r);t=0;i=d;return t|0}function Gr(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;b=i;i=i+16|0;c=b;d=Ib(a|0,46488)|0;if((d|0)==0){e=0;i=b;return e|0}if((Lq(d,c,0,0,4,0)|0)==0){f=(Hq(c,0)|0)==4474193|0}else{f=0}zb(d|0)|0;e=f;i=b;return e|0}function Hr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;e=i;f=a+72|0;g=c[f>>2]|0;h=ca(g>>>3,c[a+76>>2]|0)|0;j=b;k=Zz(c[j>>2]|0,c[j+4>>2]|0,g|0,0)|0;g=G;j=Zz(k|0,g|0,h|0,0)|0;l=_z(k|0,g|0,h|0,0)|0;g=a+4264|0;k=j<<3;m=Iq((c[g>>2]|0)+k|0,0)|0;n=G;o=b;p=c[o>>2]|0;q=c[o+4>>2]|0;o=a+136|0;r=o;s=c[r>>2]|0;t=c[r+4>>2]|0;r=s&p;t&q;if(!(j>>>0<h>>>0)){u=1;i=e;return u|0}if((m|0)==0&(n|0)==0){if((d|0)==0){h=b;c[h>>2]=0;c[h+4>>2]=0;u=0;i=e;return u|0}h=a+144|0;j=h;v=a+128|0;w=Jz(c[v>>2]|0,0,c[j>>2]|0,c[j+4>>2]|0)|0;j=G;x=a+68|0;y=c[x>>2]|0;if((y|0)==0){Oz(c[a+4272>>2]|0,0,c[f>>2]|0)|0}else{z=Lz((s^-512)&p|0,(t^511)&q|0,9)|0;q=c[f>>2]|0;p=q>>>9;A=a+4272|0;if((p+z|0)>>>0>(c[y+28>>2]|0)>>>0){Oz(c[A>>2]|0,0,q|0)|0;q=c[x>>2]|0;B=q;C=(c[q+28>>2]|0)-z|0}else{B=y;C=p}if((br(B,c[A>>2]|0,z,C)|0)!=0){u=1;i=e;return u|0}}C=a+4276|0;if((Mq(c[C>>2]|0,c[a+4272>>2]|0,w,j,c[f>>2]|0,0)|0)!=0){u=1;i=e;return u|0}z=a+4268|0;Oz(c[z>>2]|0,0,c[v>>2]|0)|0;Kq((c[z>>2]|0)+(l<<3)|0,0,w,j);A=h;B=c[A>>2]|0;p=c[A+4>>2]|0;if((Mq(c[C>>2]|0,c[z>>2]|0,B,p,c[v>>2]|0,0)|0)!=0){u=1;i=e;return u|0}Nb(c[C>>2]|0)|0;z=a+4256|0;c[z>>2]=B;c[z+4>>2]=p;p=h;Kq((c[g>>2]|0)+k|0,0,c[p>>2]|0,c[p+4>>2]|0);p=a+112|0;if((Mq(c[C>>2]|0,c[g>>2]|0,c[p>>2]|0,c[p+4>>2]|0,c[v>>2]|0,0)|0)!=0){u=1;i=e;return u|0}Nb(c[C>>2]|0)|0;C=Jz(w|0,j|0,r|0,0)|0;v=b;c[v>>2]=C;c[v+4>>2]=G;v=Jz(c[f>>2]|0,0,w|0,j|0)|0;j=h;c[j>>2]=v;c[j+4>>2]=G;u=0;i=e;return u|0}j=m&~s;s=n&~t;t=a+4256|0;n=t;do{if((c[n>>2]|0)==(j|0)&(c[n+4>>2]|0)==(s|0)){D=a+4268|0}else{m=a+4268|0;if((Lq(c[a+4276>>2]|0,c[m>>2]|0,j,s,c[a+128>>2]|0,0)|0)==0){v=t;c[v>>2]=j;c[v+4>>2]=s;D=m;break}else{u=1;i=e;return u|0}}}while(0);n=l<<3;l=Iq((c[D>>2]|0)+n|0,0)|0;m=G;if(!((l|0)==0&(m|0)==0)){v=o;h=Jz(l&~c[v>>2]|0,m&~c[v+4>>2]|0,r|0,0)|0;v=b;c[v>>2]=h;c[v+4>>2]=G;u=0;i=e;return u|0}if((d|0)==0){d=b;c[d>>2]=0;c[d+4>>2]=0;u=0;i=e;return u|0}d=a+68|0;v=c[d>>2]|0;if((v|0)==0){Oz(c[a+4272>>2]|0,0,c[f>>2]|0)|0}else{h=b;m=o;o=Lz((c[m>>2]^-512)&c[h>>2]|0,(c[m+4>>2]^511)&c[h+4>>2]|0,9)|0;h=c[f>>2]|0;m=h>>>9;l=a+4272|0;if((o+m|0)>>>0>(c[v+28>>2]|0)>>>0){Oz(c[l>>2]|0,0,h|0)|0;h=c[d>>2]|0;E=h;F=(c[h+28>>2]|0)-o|0}else{E=v;F=m}if((br(E,c[l>>2]|0,o,F)|0)!=0){u=1;i=e;return u|0}}F=a+4276|0;o=a+144|0;l=o;if((Mq(c[F>>2]|0,c[a+4272>>2]|0,c[l>>2]|0,c[l+4>>2]|0,c[f>>2]|0,0)|0)!=0){u=1;i=e;return u|0}l=o;Kq((c[D>>2]|0)+n|0,0,c[l>>2]|0,c[l+4>>2]|0);if((Mq(c[F>>2]|0,c[D>>2]|0,j,s,c[a+128>>2]|0,0)|0)!=0){u=1;i=e;return u|0}Nb(c[F>>2]|0)|0;F=t;c[F>>2]=j;c[F+4>>2]=s;s=o;F=Jz(c[s>>2]|0,c[s+4>>2]|0,r|0,0)|0;r=b;c[r>>2]=F;c[r+4>>2]=G;r=o;F=Jz(c[r>>2]|0,c[r+4>>2]|0,c[f>>2]|0,0)|0;f=o;c[f>>2]=F;c[f+4>>2]=G;u=0;i=e;return u|0}function Ir(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;i=i+16|0;g=f;if((Nq(a,g)|0)!=0){h=0;i=f;return h|0}j=g;k=c[j>>2]|0;l=c[j+4>>2]|0;if(!(l>>>0>d>>>0|(l|0)==(d|0)&k>>>0>b>>>0)){h=0;i=f;return h|0}j=Iz(k|0,l|0,b|0,d|0)|0;l=Lz(j|0,G|0,9)|0;j=G;k=g;c[k>>2]=l;c[k+4>>2]=j;if((l|0)==0&(j|0)==0){h=0;i=f;return h|0}j=yz(80)|0;if((j|0)==0){h=0;i=f;return h|0}Pq(j,j,l,0,0,0);Tq(j,1);Vq(j,e);c[j+4>>2]=241;c[j+8>>2]=26;c[j+12>>2]=27;e=j+72|0;c[e>>2]=b;c[e+4>>2]=d;c[j+68>>2]=a;$q(j)|0;h=j;i=f;return h|0}function Jr(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;if((d|0)==0){f=Ib(a|0,46568)|0;if((f|0)==0){g=1;h=Ib(a|0,46560)|0;j=5}else{k=0;l=f}}else{g=d;h=Ib(a|0,46560)|0;j=5}if((j|0)==5){if((h|0)==0){m=0;i=e;return m|0}else{k=g;l=h}}h=Ir(l,b,c,k)|0;if((h|0)==0){zb(l|0)|0;m=0;i=e;return m|0}else{Wq(h,a);m=h;i=e;return m|0}return 0}function Kr(a){a=a|0;var b=0,d=0;b=i;d=c[a+64>>2]|0;zb(c[d+68>>2]|0)|0;zz(d);i=b;return}function Lr(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0;f=i;if((e+d|0)>>>0>(c[a+28>>2]|0)>>>0){g=1;i=f;return g|0}h=c[a+64>>2]|0;a=h+72|0;j=c[a>>2]|0;k=c[a+4>>2]|0;a=Nz(d|0,0,9)|0;d=Jz(j|0,k|0,a|0,G|0)|0;a=G;k=Nz(e|0,0,9)|0;g=(Lq(c[h+68>>2]|0,b,d,a,k,G)|0)!=0|0;i=f;return g|0}function Mr(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;if((a[b+56>>0]|0)!=0){h=1;i=g;return h|0}if((f+e|0)>>>0>(c[b+28>>2]|0)>>>0){h=1;i=g;return h|0}j=c[b+64>>2]|0;b=j+72|0;k=c[b>>2]|0;l=c[b+4>>2]|0;b=Nz(e|0,0,9)|0;e=Jz(k|0,l|0,b|0,G|0)|0;b=G;l=Nz(f|0,0,9)|0;f=j+68|0;if((Mq(c[f>>2]|0,d,e,b,l,G)|0)!=0){h=1;i=g;return h|0}Nb(c[f>>2]|0)|0;h=0;i=g;return h|0}function Nr(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+16|0;f=e;g=b+28|0;h=c[g>>2]|0;j=b+48|0;if((h|0)==0){c[g>>2]=0;c[j>>2]=0;i=e;return}k=b+52|0;l=(c[j>>2]|0)!=0?46816:46824;m=b+32|0;b=h;while(1){h=b>>>0<16;n=h?b:16;o=c[k>>2]|0;p=d[m>>0]|0;c[f>>2]=l;c[f+4>>2]=p;hb(o|0,46808,f|0)|0;if(n>>>0>1){o=1;do{p=c[k>>2]|0;c[f>>2]=d[m+o>>0]|0;hb(p|0,46832,f|0)|0;o=o+1|0}while((o|0)!=(n|0))}o=c[k>>2]|0;if(h){p=o;q=n;while(1){fb(46840,3,1,p|0)|0;r=q+1|0;s=c[k>>2]|0;if(r>>>0<16){p=s;q=r}else{t=s;break}}}else{t=o}fb(46848,2,1,t|0)|0;if((n|0)!=0){q=0;do{p=a[m+q>>0]|0;$b(((p+ -32<<24>>24&255)>94?46:p&255)|0,c[k>>2]|0)|0;q=q+1|0}while((q|0)!=(n|0))}$b(10,c[k>>2]|0)|0;if((b|0)==(n|0)){break}else{m=m+n|0;b=b-n|0}}Nb(c[k>>2]|0)|0;c[g>>2]=0;c[j>>2]=0;i=e;return}function Or(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;c[a>>2]=b;b=a+4|0;e=a+48|0;c[b+0>>2]=0;c[b+4>>2]=0;c[b+8>>2]=0;c[b+12>>2]=0;c[b+16>>2]=0;c[b+20>>2]=0;c[b+24>>2]=0;c[e+0>>2]=0;c[e+4>>2]=0;c[e+8>>2]=0;c[e+12>>2]=0;c[e+16>>2]=0;c[e+20>>2]=0;c[e+24>>2]=0;c[e+28>>2]=0;i=d;return}function Pr(a){a=a|0;var b=0,d=0;b=i;if((a|0)==0){i=b;return}d=a+52|0;if((c[d>>2]|0)!=0){Nr(a);zb(c[d>>2]|0)|0}d=c[a+56>>2]|0;if((d|0)==0){i=b;return}ic[d&511](a);i=b;return}function Qr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;if((a|0)==0){f=0;i=e;return f|0}g=c[a+60>>2]|0;if((g|0)==0){f=0;i=e;return f|0}h=gc[g&63](a,b,d)|0;if((c[a+52>>2]|0)==0|(h|0)==0){f=h;i=e;return f|0}d=a+28|0;g=a+48|0;if((c[d>>2]|0)==0){j=b;k=h}else{if((c[g>>2]|0)==0){j=b;k=h}else{Nr(a);j=b;k=h}}while(1){b=c[d>>2]|0;l=16-b|0;m=k>>>0<l>>>0?k:l;Mz(a+b+32|0,j|0,m|0)|0;b=m+(c[d>>2]|0)|0;c[d>>2]=b;c[g>>2]=0;if(b>>>0>15){Nr(a)}if((k|0)==(m|0)){f=h;break}j=j+m|0;k=k-m|0}i=e;return f|0}function Rr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;if((a|0)==0){f=d;i=e;return f|0}g=c[a+64>>2]|0;if((g|0)==0){f=d;i=e;return f|0}h=gc[g&63](a,b,d)|0;if((c[a+52>>2]|0)==0|(h|0)==0){f=h;i=e;return f|0}d=a+28|0;g=a+48|0;if((c[d>>2]|0)==0){j=b;k=h}else{if((c[g>>2]|0)==1){j=b;k=h}else{Nr(a);j=b;k=h}}while(1){b=c[d>>2]|0;l=16-b|0;m=k>>>0<l>>>0?k:l;Mz(a+b+32|0,j|0,m|0)|0;b=m+(c[d>>2]|0)|0;c[d>>2]=b;c[g>>2]=1;if(b>>>0>15){Nr(a)}if((k|0)==(m|0)){f=h;break}j=j+m|0;k=k-m|0}i=e;return f|0}function Sr(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e;g=a+52|0;if((c[g>>2]|0)==0|(b|0)==(d|0)){i=e;return}Nr(a);a=d^b;if((a&512|0)!=0){b=c[g>>2]|0;c[f>>2]=46744;c[f+4>>2]=d>>>9&1;hb(b|0,46792,f|0)|0}if((a&1|0)!=0){b=c[g>>2]|0;c[f>>2]=46752;c[f+4>>2]=d&1;hb(b|0,46792,f|0)|0}if((a&2|0)!=0){b=c[g>>2]|0;c[f>>2]=46760;c[f+4>>2]=d>>>1&1;hb(b|0,46792,f|0)|0}if((a&256|0)!=0){b=c[g>>2]|0;c[f>>2]=46768;c[f+4>>2]=d>>>8&1;hb(b|0,46792,f|0)|0}if((a&1024|0)!=0){b=c[g>>2]|0;c[f>>2]=46776;c[f+4>>2]=d>>>10&1;hb(b|0,46792,f|0)|0}if((a&2048|0)==0){i=e;return}a=c[g>>2]|0;c[f>>2]=46784;c[f+4>>2]=d>>>11&1;hb(a|0,46792,f|0)|0;i=e;return}function Tr(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;if((a|0)==0){e=1}else{f=a+24|0;g=c[f>>2]|0;if((g|0)==(b|0)){e=0}else{Sr(a,g,b);c[f>>2]=b;f=c[a+72>>2]|0;if((f|0)==0){e=0}else{e=oc[f&31](a,b)|0}}}i=d;return e|0}function Ur(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+16|0;h=g;if((a|0)==0){j=1;i=g;return j|0}k=a+4|0;l=a+8|0;if((c[k>>2]|0)==(b|0)){if((c[l>>2]|0)==(d|0)){if((c[a+12>>2]|0)==(e|0)){if((c[a+16>>2]|0)==(f|0)){j=0;i=g;return j|0}}}}c[k>>2]=b;c[l>>2]=d;m=a+12|0;c[m>>2]=e;n=a+16|0;c[n>>2]=f;o=a+52|0;if((c[o>>2]|0)!=0){Nr(a);p=c[m>>2]|0;if((p|0)==0){q=46696}else if((p|0)==2){q=46712}else if((p|0)==1){q=46704}else{q=46720}p=c[o>>2]|0;m=c[l>>2]|0;l=c[n>>2]|0;c[h>>2]=c[k>>2];c[h+4>>2]=m;c[h+8>>2]=q;c[h+12>>2]=l;hb(p|0,46728,h|0)|0;Nb(c[o>>2]|0)|0}o=c[a+76>>2]|0;if((o|0)==0){j=1;i=g;return j|0}j=pc[o&3](a,b,d,e,f)|0;i=g;return j|0}function Vr(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;e=c[11656]|0;if((e|0)==0){f=0;i=d;return f|0}else{g=e;h=0}while(1){e=a[g>>0]|0;a:do{if(e<<24>>24==0){j=b;k=6}else{l=e;m=g;n=b;while(1){if(!(l<<24>>24==(a[n>>0]|0))){break}o=m+1|0;p=n+1|0;q=a[o>>0]|0;if(q<<24>>24==0){j=p;k=6;break a}else{l=q;m=o;n=p}}if(l<<24>>24==0){j=n;k=6}}}while(0);if((k|0)==6){k=0;e=a[j>>0]|0;if(e<<24>>24==0|e<<24>>24==58){break}}e=h+1|0;m=c[46624+(e<<3)>>2]|0;if((m|0)==0){f=0;k=13;break}else{g=m;h=e}}if((k|0)==13){i=d;return f|0}k=kc[c[46628+(h<<3)>>2]&15](b)|0;if((k|0)==0){f=0;i=d;return f|0}h=Hv(b,46688)|0;if((h|0)==0){f=k;i=d;return f|0}b=k+52|0;if((c[b>>2]|0)!=0){Nr(k);zb(c[b>>2]|0)|0}c[b>>2]=Ib(h|0,46680)|0;zz(h);f=k;i=d;return f|0}function Wr(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;e=yz(388)|0;if((e|0)==0){f=0;i=d;return f|0}Or(e,e);c[e+56>>2]=242;c[e+60>>2]=32;c[e+64>>2]=33;c[e+68>>2]=18;c[e+72>>2]=19;c[e+76>>2]=1;g=e+80|0;c[g>>2]=0;c[e+84>>2]=0;c[e+88>>2]=0;a[e+348>>0]=0;a[e+349>>0]=0;c[e+352>>2]=0;c[e+356>>2]=0;c[e+360>>2]=0;h=Hv(b,46896)|0;if((h|0)!=0){if((Fz(h,46912)|0)==0){j=0}else{if((Fz(h,46928)|0)==0){j=1}else{zz(h);zz(e);f=0;i=d;return f|0}}c[g>>2]=j;zz(h)}c[e+364>>2]=Kv(b,46936,1)|0;h=Kv(b,46944,1)|0;j=e+368|0;c[j>>2]=h;c[e+372>>2]=0;if((h|0)==0){c[j>>2]=1}c[e+376>>2]=Kv(b,46952,1)|0;j=Kv(b,46960,1)|0;b=e+380|0;c[b>>2]=j;c[e+384>>2]=0;if((j|0)==0){c[b>>2]=1}b=c[11714]|0;j=b+1|0;if(!(j>>>0<8)){f=e;i=d;return f|0}c[11714]=j;c[46864+(b<<2)>>2]=e;f=e;i=d;return f|0}function Xr(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0;b=i;d=c[a>>2]|0;a=c[11714]|0;if((a|0)==0){e=0;c[11714]=e;zz(d);i=b;return}else{f=0;g=0}while(1){h=c[46864+(f<<2)>>2]|0;if((h|0)==(d|0)){j=g}else{c[46864+(g<<2)>>2]=h;j=g+1|0}h=f+1|0;if(h>>>0<a>>>0){f=h;g=j}else{e=j;break}}c[11714]=e;zz(d);i=b;return}function Yr(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=c[b>>2]|0;b=g+84|0;h=c[b>>2]|0;j=g+88|0;k=c[j>>2]|0;if((h|0)==(k|0)){if((c[g+352>>2]|0)==0){if((c[g+356>>2]|0)==0){l=0;i=f;return l|0}}bs(g);m=c[b>>2]|0;n=c[j>>2]|0}else{m=h;n=k}if((m|0)==(n|0)){l=0;i=f;return l|0}k=m-n|0;m=k&255;h=m>>>0>e>>>0?e:m;if((h|0)==0){l=0;i=f;return l|0}m=~e;e=(k|-256)^255;k=~(e>>>0<m>>>0?m:e);e=n;n=0;while(1){a[d+n>>0]=a[g+(e+92)>>0]|0;m=(c[j>>2]|0)+1&255;c[j>>2]=m;b=n+1|0;if((b|0)==(k|0)){l=h;break}else{e=m;n=b}}i=f;return l|0}function Zr(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function _r(a,b){a=a|0;b=b|0;c[b>>2]=1792;return 0}function $r(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=c[b>>2]|0;b=d&1;g=d&2;d=f+348|0;do{if(!((c[f+80>>2]|0)!=0|(g|0)==0|(b|0)==0)){if((a[d>>0]|0)!=0){if((a[f+349>>0]|0)!=0){break}}c[f+352>>2]=0;c[f+356>>2]=0;c[f+372>>2]=0;c[f+384>>2]=0;c[f+84>>2]=1;c[f+88>>2]=0;a[f+92>>0]=77}}while(0);a[d>>0]=b;a[f+349>>0]=g>>>1;i=e;return 0}function as(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return 0}function bs(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=i;e=c[b+80>>2]|0;if((e|0)==0){f=b+84|0;g=c[f>>2]|0;if((256-(g-(c[b+88>>2]|0)&255)|0)>>>0<3){i=d;return}h=b+352|0;j=c[h>>2]|0;if((j|0)<-127){k=-127}else{k=(j|0)>127?127:j}c[h>>2]=j-k;j=b+356|0;h=c[j>>2]|0;if((h|0)<-127){l=-127}else{l=(h|0)>127?127:h}c[j>>2]=h-l;h=c[b+360>>2]|0;a[b+g+92>>0]=k>>>6&3|l>>>4&12|h<<3&16|h<<5&32|64;h=(c[f>>2]|0)+1&255;c[f>>2]=h;a[b+h+92>>0]=k&63;k=(c[f>>2]|0)+1&255;c[f>>2]=k;a[b+k+92>>0]=l&63;c[f>>2]=(c[f>>2]|0)+1&255;i=d;return}else if((e|0)==1){e=b+84|0;f=c[e>>2]|0;if((256-(f-(c[b+88>>2]|0)&255)|0)>>>0<5){i=d;return}l=c[b+360>>2]|0;k=l>>>1;a[b+f+92>>0]=(k&1|l<<2&4|k&2)^135;k=(c[e>>2]|0)+1&255;c[e>>2]=k;l=b+352|0;f=b+356|0;h=c[l>>2]|0;if((h|0)<-127){m=-127}else{m=(h|0)>127?127:h}c[l>>2]=h-m;a[b+k+92>>0]=m;m=(c[e>>2]|0)+1&255;c[e>>2]=m;k=c[f>>2]|0;if((k|0)<-127){n=-127}else{n=(k|0)>127?127:k}c[f>>2]=k-n;a[b+m+92>>0]=0-n;n=(c[e>>2]|0)+1&255;c[e>>2]=n;m=c[l>>2]|0;if((m|0)<-127){o=-127}else{o=(m|0)>127?127:m}c[l>>2]=m-o;a[b+n+92>>0]=o;o=(c[e>>2]|0)+1&255;c[e>>2]=o;n=c[f>>2]|0;if((n|0)<-127){p=-127}else{p=(n|0)>127?127:n}c[f>>2]=n-p;a[b+o+92>>0]=0-p;c[e>>2]=(c[e>>2]|0)+1&255;i=d;return}else{i=d;return}}function cs(a){a=a|0;var b=0,d=0;a=i;b=yz(80)|0;if((b|0)==0){d=0;i=a;return d|0}Or(b,b);c[b+56>>2]=243;c[b+60>>2]=34;c[b+64>>2]=35;c[b+68>>2]=20;c[b+72>>2]=21;c[b+76>>2]=2;d=b;i=a;return d|0}function ds(a){a=a|0;var b=0;b=i;zz(c[a>>2]|0);i=b;return}function es(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function fs(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function gs(a,b){a=a|0;b=b|0;c[b>>2]=1792;return 0}function hs(a,b){a=a|0;b=b|0;return 0}function is(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return 0}function js(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;b=i;i=i+16|0;d=b;e=yz(100)|0;if((e|0)==0){f=0;i=b;return f|0}Or(e,e);c[e+56>>2]=244;c[e+60>>2]=36;c[e+64>>2]=37;g=e+80|0;c[g>>2]=0;h=e+84|0;c[h>>2]=0;j=e+88|0;c[j>>2]=0;k=e+92|0;c[k>>2]=-1;l=e+96|0;c[l>>2]=-1;m=Hv(a,46968)|0;c[g>>2]=m;do{if((m|0)==0){c[h>>2]=Hv(a,46976)|0;n=Hv(a,46984)|0;c[j>>2]=n;o=c[g>>2]|0;if((o|0)==0){p=c[h>>2]|0;if((p|0)==0){if((n|0)==0){if((Gz(a,47008,6)|0)!=0){f=e;i=b;return f|0}c[k>>2]=0;c[l>>2]=1;f=e;i=b;return f|0}else{q=n}}else{if((Fz(p,46992)|0)==0){c[k>>2]=0;r=n}else{c[d>>2]=0;n=sb(p|0,256,d|0)|0;c[k>>2]=n;if((n|0)<0){break}r=c[j>>2]|0}if((r|0)==0){f=e;i=b;return f|0}else{q=r}}if((Fz(q,46992)|0)==0){c[l>>2]=1;f=e;i=b;return f|0}if((Fz(q,47e3)|0)==0){c[l>>2]=2;f=e;i=b;return f|0}else{c[d>>2]=420;n=sb(q|0,833,d|0)|0;c[l>>2]=n;if((n|0)<0){break}else{f=e}i=b;return f|0}}else{s=o;t=4}}else{s=m;t=4}}while(0);if((t|0)==4){if((Fz(s,46992)|0)==0){c[k>>2]=0;c[l>>2]=1;f=e;i=b;return f|0}if((Fz(s,47e3)|0)==0){c[k>>2]=0;c[l>>2]=2;f=e;i=b;return f|0}c[d>>2]=420;t=sb(s|0,834,d|0)|0;c[k>>2]=t;if((t|0)>=0){c[l>>2]=t;f=e;i=b;return f|0}}ks(e);f=0;i=b;return f|0}function ks(a){a=a|0;var b=0,d=0,e=0;b=i;d=c[a>>2]|0;a=d+96|0;e=c[a>>2]|0;if((e|0)>2){Ga(e|0)|0}e=c[d+92>>2]|0;if((e|0)>2){if((e|0)!=(c[a>>2]|0)){Ga(e|0)|0}}e=c[d+88>>2]|0;if((e|0)!=0){zz(e)}e=c[d+84>>2]|0;if((e|0)!=0){zz(e)}e=c[d+80>>2]|0;if((e|0)==0){zz(d);i=b;return}zz(e);zz(d);i=b;return}function ls(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;i=i+16|0;g=f;h=(c[a>>2]|0)+92|0;a=c[h>>2]|0;if((a|0)<0){i=f;return 0}c[g>>2]=a;b[g+4>>1]=1;if((bb(g|0,1,0)|0)<0){i=f;return 0}if((b[g+6>>1]&5)==0){i=f;return 0}else{g=db(c[h>>2]|0,d|0,((e|0)<0?2147483647:e)|0)|0;i=f;return((g|0)>0?g:0)|0}return 0}function ms(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f;h=(c[a>>2]|0)+96|0;a=c[h>>2]|0;if((a|0)<0){j=e;i=f;return j|0}c[g>>2]=a;b[g+4>>1]=4;if((bb(g|0,1,0)|0)<0){j=0;i=f;return j|0}if((b[g+6>>1]&5)==0){j=0;i=f;return j|0}else{j=Ka(c[h>>2]|0,d|0,((e|0)<0?2147483647:e)|0)|0;i=f;return((j|0)>0?j:0)|0}return 0}function ns(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;i=i+64|0;d=b;e=yz(92)|0;if((e|0)==0){f=0;i=b;return f|0}Or(e,e);c[e+56>>2]=245;c[e+60>>2]=38;c[e+64>>2]=39;g=e+84|0;c[g>>2]=0;h=e+88|0;c[h>>2]=Hv(a,47016)|0;a=Ia(258)|0;j=e+80|0;c[j>>2]=a;if((a|0)>=0){if((Xa(a|0)|0)==0){if((pb(a|0)|0)==0){k=jb(a|0)|0;if((k|0)!=0){if(!((Kz(k|0)|0)>>>0>255)){a=xz(k)|0;c[g>>2]=a;k=c[o>>2]|0;c[d>>2]=a;hb(k|0,47064,d|0)|0;a=c[j>>2]|0;l=Sa(a|0,1,d|0)|0;if(!((l|0)==-1)){c[d>>2]=l|2048;Sa(a|0,4,d|0)|0}a=c[j>>2]|0;if((Ea(a|0,d|0)|0)==0){c[d>>2]=c[d>>2]&-449;j=d+12|0;c[j>>2]=c[j>>2]&-25;if((Tb(a|0,0,d|0)|0)==0){Kb(a|0,2)|0}}a=c[h>>2]|0;if((a|0)==0){f=e;i=b;return f|0}if((Db(c[g>>2]|0,a|0)|0)==0){f=e;i=b;return f|0}a=c[h>>2]|0;c[d>>2]=c[g>>2];c[d+4>>2]=a;hb(k|0,47024,d|0)|0;f=e;i=b;return f|0}}}}}d=c[e>>2]|0;e=d+88|0;k=c[e>>2]|0;if((k|0)!=0){Ya(k|0)|0;zz(c[e>>2]|0)}e=c[d+84>>2]|0;if((e|0)!=0){zz(e)}e=c[d+80>>2]|0;if((e|0)>-1){Ga(e|0)|0}zz(d);f=0;i=b;return f|0}function os(a){a=a|0;var b=0,d=0,e=0;b=i;d=c[a>>2]|0;a=d+88|0;e=c[a>>2]|0;if((e|0)!=0){Ya(e|0)|0;zz(c[a>>2]|0)}a=c[d+84>>2]|0;if((a|0)!=0){zz(a)}a=c[d+80>>2]|0;if(!((a|0)>-1)){zz(d);i=b;return}Ga(a|0)|0;zz(d);i=b;return}function ps(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=c[(c[a>>2]|0)+80>>2]|0;if((f|0)<0){i=e;return 0}else{a=db(f|0,b|0,((d|0)<0?2147483647:d)|0)|0;i=e;return((a|0)>0?a:0)|0}return 0}function qs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;f=c[(c[a>>2]|0)+80>>2]|0;if((f|0)<0){i=e;return d|0}else{a=Ka(f|0,b|0,((d|0)<0?2147483647:d)|0)|0;i=e;return((a|0)>0?a:0)|0}return 0}function rs(a){a=a|0;var b=0,d=0,e=0,f=0,g=0;b=i;d=yz(92)|0;if((d|0)==0){e=0;i=b;return e|0}Or(d,d);c[d+56>>2]=246;c[d+60>>2]=40;c[d+64>>2]=41;f=d+88|0;c[f>>2]=0;g=d+80|0;c[g>>2]=Hv(a,47080)|0;c[d+84>>2]=Iv(a,47088,1)|0;a=c[g>>2]|0;if((a|0)==0){e=d;i=b;return e|0}if((Fz(a,47096)|0)==0){c[f>>2]=c[q>>2];e=d;i=b;return e|0}g=Ib(a|0,47104)|0;c[f>>2]=g;if((g|0)!=0){e=d;i=b;return e|0}g=c[d>>2]|0;d=c[g+80>>2]|0;if((d|0)!=0){zz(d)}d=c[g+88>>2]|0;if(!((d|0)==0|(d|0)==(c[p>>2]|0)|(d|0)==(c[q>>2]|0)|(d|0)==(c[o>>2]|0))){zb(d|0)|0}zz(g);e=0;i=b;return e|0}function ss(a){a=a|0;var b=0,d=0;b=i;d=c[a>>2]|0;a=c[d+80>>2]|0;if((a|0)!=0){zz(a)}a=c[d+88>>2]|0;if((a|0)==0|(a|0)==(c[p>>2]|0)|(a|0)==(c[q>>2]|0)|(a|0)==(c[o>>2]|0)){zz(d);i=b;return}zb(a|0)|0;zz(d);i=b;return}function ts(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function us(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=c[a>>2]|0;a=f+88|0;g=c[a>>2]|0;if((g|0)==0){h=d}else{j=fb(b|0,1,d|0,g|0)|0;if((c[f+84>>2]|0)==0){h=j}else{Nb(c[a>>2]|0)|0;h=j}}i=e;return h|0}



function Kk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=f+160|0;k=b[j>>1]&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=e[h>>1]|0;c[f+(((e[j>>1]|0)>>>9&7)<<2)+120>>2]=(k&32768|0)!=0?k|-65536:k;k=f+372|0;c[k>>2]=(c[k>>2]|0)+4;k=f+156|0;j=c[k>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}h=f+164|0;b[f+162>>1]=b[h>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[h>>1]=n;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function Lk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+16|0;g=f;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,509,8)|0)!=0){i=f;return}if((Jo(e,g)|0)!=0){i=f;return}h=d[g>>0]|0;g=e+166|0;j=b[g>>1]|0;k=j&65535;l=0-((k>>>4&1)+h)|0;if((l&255|0)==0){m=j}else{j=k&65531;b[g>>1]=j;m=j}j=e+372|0;c[j>>2]=(c[j>>2]|0)+8;j=l&128;k=m&65535;m=(j|0)==0?k&65527:k|8;k=(j&h|0)==0?m&65533:m|2;b[g>>1]=((h|l)&128|0)==0?k&65518:k|17;k=e+156|0;h=c[k>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}g=e+164|0;b[e+162>>1]=b[g>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){j=c[e+32>>2]|0;n=(d[j+m>>0]<<8|d[j+h>>0])&65535}else{n=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[g>>1]=n;if((a[e+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=e+152|0;c[k>>2]=(c[k>>2]|0)+2;Mo(e,l&255)|0;i=f;return}else{Kj(e);i=f;return}}function Mk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,509,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}j=e[h>>1]|0;h=f+166|0;k=b[h>>1]|0;l=k&65535;m=0-((l>>>4&1)+j)|0;if((m&65535|0)==0){n=k}else{k=l&65531;b[h>>1]=k;n=k}k=f+372|0;c[k>>2]=(c[k>>2]|0)+8;k=m&32768;l=n&65535;n=(k|0)==0?l&65527:l|8;l=(k&j|0)==0?n&65533:n|2;b[h>>1]=((j|m)&32768|0)==0?l&65518:l|17;l=f+156|0;j=c[l>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}h=f+164|0;b[f+162>>1]=b[h>>1]|0;n=j&16777215;j=n+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){k=c[f+32>>2]|0;o=(d[k+n>>0]<<8|d[k+j>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[h>>1]=o;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;No(f,m&65535)|0;i=g;return}else{Kj(f);i=g;return}}function Nk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+16|0;g=f;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,509,32)|0)!=0){i=f;return}if((Lo(e,g)|0)!=0){i=f;return}h=c[g>>2]|0;g=0-h|0;j=e+166|0;k=b[j>>1]|0;l=k&65535;m=l>>>4&1;n=g-m|0;if((m|0)==(g|0)){o=k}else{k=l&65531;b[j>>1]=k;o=k}k=e+372|0;c[k>>2]=(c[k>>2]|0)+10;k=o&65535;o=(n|0)<0?k|8:k&65527;k=(h&n|0)<0?o|2:o&65533;b[j>>1]=(h|n|0)<0?k|17:k&65518;k=e+156|0;h=c[k>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;o=h&16777215;h=o+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;p=(d[l+o>>0]<<8|d[l+h>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,o)|0}b[j>>1]=p;if((a[e+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=e+152|0;c[k>>2]=(c[k>>2]|0)+2;Oo(e,n)|0;i=f;return}else{Kj(e);i=f;return}}function Ok(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+16|0;g=f;if((c[e>>2]&2|0)!=0){if((a[e+334>>0]|0)==0){Rj(e);i=f;return}}h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,509,16)|0)!=0){i=f;return}if((Ko(e,g)|0)!=0){i=f;return}b[g>>1]=b[e+166>>1]&42783;h=e+372|0;c[h>>2]=(c[h>>2]|0)+4;h=e+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;b[e+162>>1]=b[k>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[e+36>>2]|0)>>>0){m=c[e+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=n;if((a[e+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=e+152|0;c[h>>2]=(c[h>>2]|0)+2;No(e,b[g>>1]|0)|0;i=f;return}else{Kj(e);i=f;return}}function Pk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=f+160|0;k=b[j>>1]&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=c[f+(((e[j>>1]|0)>>>9&7)<<2)+88>>2]|0;do{if((k&32768|0)==0){j=e[h>>1]|0;if((j&32768|0)!=0|(k&65535)>>>0>j>>>0){j=f+166|0;b[j>>1]=b[j>>1]&65527;j=f+372|0;c[j>>2]=(c[j>>2]|0)+14;break}j=f+372|0;c[j>>2]=(c[j>>2]|0)+14;j=f+156|0;l=c[j>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;j=f+152|0;c[j>>2]=(c[j>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else{j=f+166|0;b[j>>1]=e[j>>1]|8;j=f+372|0;c[j>>2]=(c[j>>2]|0)+14}}while(0);Pj(f);i=g;return}function Qk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=b[e+160>>1]&63;if((nc[c[46024+(g<<2)>>2]&63](e,g,509,8)|0)!=0){i=f;return}if((Jo(e,f)|0)!=0){i=f;return}g=e+372|0;c[g>>2]=(c[g>>2]|0)+4;g=e+166|0;b[g>>1]=b[g>>1]&65520|4;g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;Mo(e,0)|0;i=f;return}else{Kj(e);i=f;return}}function Rk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=b[e+160>>1]&63;if((nc[c[46024+(g<<2)>>2]&63](e,g,509,16)|0)!=0){i=f;return}if((Ko(e,f)|0)!=0){i=f;return}g=e+372|0;c[g>>2]=(c[g>>2]|0)+4;g=e+166|0;b[g>>1]=b[g>>1]&65520|4;g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;No(e,0)|0;i=f;return}else{Kj(e);i=f;return}}function Sk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=b[e+160>>1]&63;if((nc[c[46024+(g<<2)>>2]&63](e,g,509,32)|0)!=0){i=f;return}if((Lo(e,f)|0)!=0){i=f;return}g=e+372|0;c[g>>2]=(c[g>>2]|0)+6;g=e+166|0;b[g>>1]=b[g>>1]&65520|4;g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;Oo(e,0)|0;i=f;return}else{Kj(e);i=f;return}}function Tk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+16|0;g=f;if((c[e>>2]&2|0)==0){Nj(e);h=e+372|0;c[h>>2]=(c[h>>2]|0)+2;i=f;return}h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,509,16)|0)!=0){i=f;return}if((Ko(e,g)|0)!=0){i=f;return}b[g>>1]=b[e+166>>1]&31;h=e+372|0;c[h>>2]=(c[h>>2]|0)+4;h=e+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;b[e+162>>1]=b[k>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[e+36>>2]|0)>>>0){m=c[e+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=n;if((a[e+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=e+152|0;c[h>>2]=(c[h>>2]|0)+2;No(e,b[g>>1]|0)|0;i=f;return}else{Kj(e);i=f;return}}function Uk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,509,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}j=d[h>>0]|0;h=0-j|0;k=f+372|0;c[k>>2]=(c[k>>2]|0)+4;k=h&128;l=f+166|0;m=e[l>>1]|0;n=(k|0)==0?m&65527:m|8;m=((k&j|0)==0?n&65529:n|2)&65531;n=(h&255|0)==0?m|4:m;b[l>>1]=((j|h)&128|0)==0?n&65518:n|17;n=f+156|0;j=c[n>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;m=j&16777215;j=m+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){k=c[f+32>>2]|0;o=(d[k+m>>0]<<8|d[k+j>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=o;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;Mo(f,h&255)|0;i=g;return}else{Kj(f);i=g;return}}function Vk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,509,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}j=e[h>>1]|0;h=0-j|0;k=f+372|0;c[k>>2]=(c[k>>2]|0)+4;k=h&32768;l=f+166|0;m=e[l>>1]|0;n=(k|0)==0?m&65527:m|8;m=((k&j|0)==0?n&65529:n|2)&65531;n=(h&65535|0)==0?m|4:m;b[l>>1]=((j|h)&32768|0)==0?n&65518:n|17;n=f+156|0;j=c[n>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;m=j&16777215;j=m+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){k=c[f+32>>2]|0;o=(d[k+m>>0]<<8|d[k+j>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=o;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;No(f,h&65535)|0;i=g;return}else{Kj(f);i=g;return}}function Wk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,509,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}j=c[h>>2]|0;h=0-j|0;k=f+372|0;c[k>>2]=(c[k>>2]|0)+6;k=f+166|0;l=e[k>>1]|0;m=(h|0)<0?l|8:l&65527;l=((j&h|0)<0?m|2:m&65529)&65531;m=(j|0)==0?l|4:l;b[k>>1]=(j|h|0)<0?m|17:m&65518;m=f+156|0;j=c[m>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+l>>0]<<8|d[n+j>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[k>>1]=o;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;Oo(f,h)|0;i=g;return}else{Kj(f);i=g;return}}function Xk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,4093,16)|0)!=0){i=f;return}if((Ko(e,g)|0)!=0){i=f;return}h=e+372|0;c[h>>2]=(c[h>>2]|0)+12;h=e+166|0;b[h>>1]=b[h>>1]&65280|b[g>>1]&31;g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function Yk(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+16|0;g=f;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,509,8)|0)!=0){i=f;return}if((Jo(e,g)|0)!=0){i=f;return}h=(d[g>>0]^255)&255;g=e+372|0;c[g>>2]=(c[g>>2]|0)+4;bo(e,15,h);g=e+156|0;j=c[g>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;b[e+162>>1]=b[k>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[e+36>>2]|0)>>>0){m=c[e+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=n;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;Mo(e,h)|0;i=f;return}else{Kj(e);i=f;return}}function Zk(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,509,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}j=(e[h>>1]^65535)&65535;h=f+372|0;c[h>>2]=(c[h>>2]|0)+4;co(f,15,j);h=f+156|0;k=c[h>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;m=k&16777215;k=m+1|0;if(k>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+k>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=o;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;No(f,j)|0;i=g;return}else{Kj(f);i=g;return}}function _k(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+16|0;g=f;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,509,32)|0)!=0){i=f;return}if((Lo(e,g)|0)!=0){i=f;return}h=~c[g>>2];g=e+372|0;c[g>>2]=(c[g>>2]|0)+6;eo(e,15,h);g=e+156|0;j=c[g>>2]|0;if((j&1|0)!=0){Mj(e,j,0,0);i=f;return}k=e+164|0;b[e+162>>1]=b[k>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[e+36>>2]|0)>>>0){m=c[e+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[e+12>>2]&31](c[e+4>>2]|0,l)|0}b[k>>1]=n;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;Oo(e,h)|0;i=f;return}else{Kj(e);i=f;return}}function $k(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;if((a[f+334>>0]|0)==0){Rj(f);i=g;return}j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,4093,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}j=f+372|0;c[j>>2]=(c[j>>2]|0)+12;Ij(f,e[h>>1]&42783);h=f+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[k>>1]=n;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function al(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;i=i+16|0;g=f;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,509,8)|0)!=0){i=f;return}if((Jo(e,g)|0)!=0){i=f;return}h=e+166|0;j=b[h>>1]|0;k=0-(((j&65535)>>>4&1)+(d[g>>0]|0))|0;if((k&15|0)==0){l=k}else{l=(k&65535)+ -6|0}if((l&240|0)==0){m=l}else{m=(l&65535)+ -96|0}l=j&65535;j=(m&65280|0)==0?l&65518:l|17;b[h>>1]=(m&255|0)==0?j:j&65531;j=e+372|0;c[j>>2]=(c[j>>2]|0)+6;j=e+156|0;h=c[j>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}l=e+164|0;b[e+162>>1]=b[l>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){g=c[e+32>>2]|0;n=(d[g+k>>0]<<8|d[g+h>>0])&65535}else{n=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[l>>1]=n;if((a[e+336>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;j=e+152|0;c[j>>2]=(c[j>>2]|0)+2;Mo(e,m&255)|0;i=f;return}else{Kj(e);i=f;return}}function bl(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=e[f+160>>1]|0;if((h&56|0)==0){j=f+((h&7)<<2)+88|0;k=c[j>>2]|0;l=k<<16|k>>>16;k=f+372|0;c[k>>2]=(c[k>>2]|0)+4;eo(f,15,l);c[j>>2]=l;l=f+156|0;j=c[l>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;m=j&16777215;j=m+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+j>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[k>>1]=o;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}l=h&63;if((nc[c[46024+(l<<2)>>2]&63](f,l,2020,32)|0)!=0){i=g;return}if((c[f+340>>2]|0)!=2){Nj(f);i=g;return}l=f+372|0;c[l>>2]=(c[l>>2]|0)+12;l=c[f+344>>2]|0;h=f+148|0;o=(c[h>>2]|0)+ -4|0;k=o&16777215;m=k+3|0;j=f+36|0;if(m>>>0<(c[j>>2]|0)>>>0){n=f+32|0;a[(c[n>>2]|0)+k>>0]=l>>>24;a[(c[n>>2]|0)+(k+1)>>0]=l>>>16;a[(c[n>>2]|0)+(k+2)>>0]=l>>>8;a[(c[n>>2]|0)+m>>0]=l}else{lc[c[f+28>>2]&31](c[f+4>>2]|0,k,l)}c[h>>2]=o;o=f+156|0;h=c[o>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[j>>2]|0)>>>0){j=c[f+32>>2]|0;p=(d[j+k>>0]<<8|d[j+h>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,k)|0}b[l>>1]=p;if((a[f+336>>0]|0)==0){c[o>>2]=(c[o>>2]|0)+2;o=f+152|0;c[o>>2]=(c[o>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function cl(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=i;h=f+160|0;j=e[h>>1]|0;k=j>>>3&7;if((k|0)==0){l=f+((j&7)<<2)+88|0;j=c[l>>2]|0;m=(j&128|0)!=0?j|65280:j&255;j=f+372|0;c[j>>2]=(c[j>>2]|0)+4;co(f,15,m&65535);c[l>>2]=c[l>>2]&-65536|m&65535;m=f+156|0;l=c[m>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[j>>1]=p;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else if((k|0)==4){k=f+156|0;m=c[k>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}p=f+164|0;j=f+162|0;b[j>>1]=b[p>>1]|0;n=m&16777215;m=n+1|0;l=f+36|0;if(m>>>0<(c[l>>2]|0)>>>0){o=c[f+32>>2]|0;q=(d[o+n>>0]<<8|d[o+m>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[p>>1]=q;q=f+336|0;if((a[q>>0]|0)!=0){Kj(f);i=g;return}c[k>>2]=(c[k>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;m=b[j>>1]|0;o=c[f+((b[h>>1]&7)<<2)+120>>2]|0;if(m<<16>>16==0){r=0}else{if((c[f>>2]&1|0)==0){if((o&1|0)==0){r=m}else{Mj(f,o,1,1);i=g;return}}else{r=m}}m=f+32|0;s=f+372|0;t=f+24|0;u=f+4|0;v=o;o=0;w=r;while(1){if((w&1)==0){x=v}else{r=v+ -2|0;if(o>>>0<8){y=c[f+((7-o&7)<<2)+120>>2]&65535}else{y=c[f+((15-o&7)<<2)+88>>2]|0}z=y&65535;A=r&16777215;B=A+1|0;if(B>>>0<(c[l>>2]|0)>>>0){a[(c[m>>2]|0)+A>>0]=(z&65535)>>>8;a[(c[m>>2]|0)+B>>0]=y}else{lc[c[t>>2]&31](c[u>>2]|0,A,z)}c[s>>2]=(c[s>>2]|0)+4;x=r}o=o+1|0;if((o|0)==16){break}else{v=x;w=(w&65535)>>>1}}c[f+((b[h>>1]&7)<<2)+120>>2]=x;c[s>>2]=(c[s>>2]|0)+8;s=c[k>>2]|0;if((s&1|0)!=0){Mj(f,s,0,0);i=g;return}b[j>>1]=b[p>>1]|0;j=s&16777215;s=j+1|0;if(s>>>0<(c[l>>2]|0)>>>0){l=c[m>>2]|0;C=(d[l+j>>0]<<8|d[l+s>>0])&65535}else{C=oc[c[f+12>>2]&31](c[u>>2]|0,j)|0}b[p>>1]=C;if((a[q>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;c[n>>2]=(c[n>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else{n=f+156|0;k=c[n>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}q=f+164|0;C=f+162|0;b[C>>1]=b[q>>1]|0;p=k&16777215;k=p+1|0;j=f+36|0;if(k>>>0<(c[j>>2]|0)>>>0){u=c[f+32>>2]|0;D=(d[u+p>>0]<<8|d[u+k>>0])&65535}else{D=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[q>>1]=D;D=f+336|0;if((a[D>>0]|0)!=0){Kj(f);i=g;return}c[n>>2]=(c[n>>2]|0)+2;p=f+152|0;c[p>>2]=(c[p>>2]|0)+2;k=b[C>>1]|0;u=b[h>>1]&63;if((nc[c[46024+(u<<2)>>2]&63](f,u,484,16)|0)!=0){i=g;return}if((c[f+340>>2]|0)!=2){Nj(f);i=g;return}u=c[f+344>>2]|0;if(k<<16>>16==0){E=0}else{if((c[f>>2]&1|0)==0){if((u&1|0)==0){E=k}else{Mj(f,u,1,1);i=g;return}}else{E=k}}k=f+32|0;h=f+372|0;s=f+24|0;l=f+4|0;m=u;u=0;x=E;while(1){if((x&1)==0){F=m}else{E=u&7;if(u>>>0<8){G=c[f+(E<<2)+88>>2]&65535}else{G=c[f+(E<<2)+120>>2]|0}E=G&65535;w=m&16777215;v=w+1|0;if(v>>>0<(c[j>>2]|0)>>>0){a[(c[k>>2]|0)+w>>0]=(E&65535)>>>8;a[(c[k>>2]|0)+v>>0]=G}else{lc[c[s>>2]&31](c[l>>2]|0,w,E)}c[h>>2]=(c[h>>2]|0)+4;F=m+2|0}u=u+1|0;if((u|0)==16){break}else{m=F;x=(x&65535)>>>1}}c[h>>2]=(c[h>>2]|0)+8;h=c[n>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}b[C>>1]=b[q>>1]|0;C=h&16777215;h=C+1|0;if(h>>>0<(c[j>>2]|0)>>>0){j=c[k>>2]|0;H=(d[j+C>>0]<<8|d[j+h>>0])&65535}else{H=oc[c[f+12>>2]&31](c[l>>2]|0,C)|0}b[q>>1]=H;if((a[D>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}}function dl(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=i;h=f+160|0;j=e[h>>1]|0;k=j>>>3&7;if((k|0)==4){l=f+156|0;m=c[l>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}n=f+164|0;o=f+162|0;b[o>>1]=b[n>>1]|0;p=m&16777215;m=p+1|0;q=f+36|0;if(m>>>0<(c[q>>2]|0)>>>0){r=c[f+32>>2]|0;s=(d[r+p>>0]<<8|d[r+m>>0])&65535}else{s=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[n>>1]=s;s=f+336|0;if((a[s>>0]|0)!=0){Kj(f);i=g;return}c[l>>2]=(c[l>>2]|0)+2;p=f+152|0;c[p>>2]=(c[p>>2]|0)+2;m=b[o>>1]|0;r=c[f+((b[h>>1]&7)<<2)+120>>2]|0;if(m<<16>>16==0){t=0}else{if((c[f>>2]&1|0)==0){if((r&1|0)==0){t=m}else{Mj(f,r,1,1);i=g;return}}else{t=m}}m=f+32|0;u=f+372|0;v=f+28|0;w=f+4|0;x=r;r=0;y=t;while(1){if((y&1)==0){z=x}else{t=x+ -4|0;if(r>>>0<8){A=f+((7-r&7)<<2)+120|0}else{A=f+((15-r&7)<<2)+88|0}B=c[A>>2]|0;C=t&16777215;D=C+3|0;if(D>>>0<(c[q>>2]|0)>>>0){a[(c[m>>2]|0)+C>>0]=B>>>24;a[(c[m>>2]|0)+(C+1)>>0]=B>>>16;a[(c[m>>2]|0)+(C+2)>>0]=B>>>8;a[(c[m>>2]|0)+D>>0]=B}else{lc[c[v>>2]&31](c[w>>2]|0,C,B)}c[u>>2]=(c[u>>2]|0)+8;z=t}r=r+1|0;if((r|0)==16){break}else{x=z;y=(y&65535)>>>1}}c[f+((b[h>>1]&7)<<2)+120>>2]=z;c[u>>2]=(c[u>>2]|0)+8;u=c[l>>2]|0;if((u&1|0)!=0){Mj(f,u,0,0);i=g;return}b[o>>1]=b[n>>1]|0;o=u&16777215;u=o+1|0;if(u>>>0<(c[q>>2]|0)>>>0){q=c[m>>2]|0;E=(d[q+o>>0]<<8|d[q+u>>0])&65535}else{E=oc[c[f+12>>2]&31](c[w>>2]|0,o)|0}b[n>>1]=E;if((a[s>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;c[p>>2]=(c[p>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else if((k|0)==0){k=f+((j&7)<<2)+88|0;j=c[k>>2]|0;p=(j&32768|0)!=0?j|-65536:j&65535;j=f+372|0;c[j>>2]=(c[j>>2]|0)+4;eo(f,15,p);c[k>>2]=p;p=f+156|0;k=c[p>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;l=k&16777215;k=l+1|0;if(k>>>0<(c[f+36>>2]|0)>>>0){s=c[f+32>>2]|0;F=(d[s+l>>0]<<8|d[s+k>>0])&65535}else{F=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[j>>1]=F;if((a[f+336>>0]|0)==0){c[p>>2]=(c[p>>2]|0)+2;p=f+152|0;c[p>>2]=(c[p>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else{p=f+156|0;F=c[p>>2]|0;if((F&1|0)!=0){Mj(f,F,0,0);i=g;return}j=f+164|0;l=f+162|0;b[l>>1]=b[j>>1]|0;k=F&16777215;F=k+1|0;s=f+36|0;if(F>>>0<(c[s>>2]|0)>>>0){E=c[f+32>>2]|0;G=(d[E+k>>0]<<8|d[E+F>>0])&65535}else{G=oc[c[f+12>>2]&31](c[f+4>>2]|0,k)|0}b[j>>1]=G;G=f+336|0;if((a[G>>0]|0)!=0){Kj(f);i=g;return}c[p>>2]=(c[p>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;F=b[l>>1]|0;E=b[h>>1]&63;if((nc[c[46024+(E<<2)>>2]&63](f,E,484,32)|0)!=0){i=g;return}if((c[f+340>>2]|0)!=2){Nj(f);i=g;return}E=c[f+344>>2]|0;if(F<<16>>16==0){H=0}else{if((c[f>>2]&1|0)==0){if((E&1|0)==0){H=F}else{Mj(f,E,1,1);i=g;return}}else{H=F}}F=f+32|0;h=f+372|0;n=f+28|0;o=f+4|0;w=E;E=0;u=H;while(1){if((u&1)==0){I=w}else{H=E&7;if(E>>>0<8){J=f+(H<<2)+88|0}else{J=f+(H<<2)+120|0}H=c[J>>2]|0;q=w&16777215;m=q+3|0;if(m>>>0<(c[s>>2]|0)>>>0){a[(c[F>>2]|0)+q>>0]=H>>>24;a[(c[F>>2]|0)+(q+1)>>0]=H>>>16;a[(c[F>>2]|0)+(q+2)>>0]=H>>>8;a[(c[F>>2]|0)+m>>0]=H}else{lc[c[n>>2]&31](c[o>>2]|0,q,H)}c[h>>2]=(c[h>>2]|0)+8;I=w+4|0}E=E+1|0;if((E|0)==16){break}else{w=I;u=(u&65535)>>>1}}c[h>>2]=(c[h>>2]|0)+8;h=c[p>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}b[l>>1]=b[j>>1]|0;l=h&16777215;h=l+1|0;if(h>>>0<(c[s>>2]|0)>>>0){s=c[F>>2]|0;K=(d[s+l>>0]<<8|d[s+h>>0])&65535}else{K=oc[c[f+12>>2]&31](c[o>>2]|0,l)|0}b[j>>1]=K;if((a[G>>0]|0)==0){c[p>>2]=(c[p>>2]|0)+2;c[k>>2]=(c[k>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}}function el(a){a=a|0;var d=0;d=i;ic[c[a+(((b[a+160>>1]&65535)>>>3&7)<<2)+4496>>2]&511](a);i=d;return}function fl(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,509,8)|0)!=0){i=f;return}if((Jo(e,g)|0)!=0){i=f;return}h=e+372|0;c[h>>2]=(c[h>>2]|0)+8;bo(e,15,a[g>>0]|0);g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function gl(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,509,16)|0)!=0){i=f;return}if((Ko(e,g)|0)!=0){i=f;return}h=e+372|0;c[h>>2]=(c[h>>2]|0)+8;co(e,15,b[g>>1]|0);g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function hl(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+16|0;g=f;h=b[e+160>>1]&63;if((nc[c[46024+(h<<2)>>2]&63](e,h,509,32)|0)!=0){i=f;return}if((Lo(e,g)|0)!=0){i=f;return}h=e+372|0;c[h>>2]=(c[h>>2]|0)+8;eo(e,15,c[g>>2]|0);g=e+156|0;h=c[g>>2]|0;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}j=e+164|0;b[e+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[e+36>>2]|0)>>>0){l=c[e+32>>2]|0;m=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{m=oc[c[e+12>>2]&31](c[e+4>>2]|0,k)|0}b[j>>1]=m;if((a[e+336>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;g=e+152|0;c[g>>2]=(c[g>>2]|0)+2;i=f;return}else{Kj(e);i=f;return}}function il(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]|0;if(!(j<<16>>16==19196)){k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,509,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}k=a[h>>0]|0;h=f+372|0;c[h>>2]=(c[h>>2]|0)+8;bo(f,15,k);h=f+156|0;j=c[h>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;m=j&16777215;j=m+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+j>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=o;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;Mo(f,(k&255|128)&255)|0;i=g;return}else{Kj(f);i=g;return}}k=c[f+64>>2]|0;if((k|0)!=0){h=f+152|0;o=c[h>>2]|0;l=f+164|0;if((oc[k&31](c[f+60>>2]|0,e[l>>1]|0)|0)==0){if((c[h>>2]|0)==(o|0)){o=f+156|0;k=c[o>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}m=f+162|0;b[m>>1]=b[l>>1]|0;j=k&16777215;k=j+1|0;n=f+36|0;if(k>>>0<(c[n>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+j>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,j)|0}b[l>>1]=q;j=f+336|0;if((a[j>>0]|0)!=0){Kj(f);i=g;return}k=(c[o>>2]|0)+2|0;c[o>>2]=k;p=(c[h>>2]|0)+2|0;c[h>>2]=p;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}b[m>>1]=q;q=k&16777215;m=q+1|0;do{if(m>>>0<(c[n>>2]|0)>>>0){r=c[f+32>>2]|0;b[l>>1]=d[r+q>>0]<<8|d[r+m>>0];s=k;t=p}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0;u=(a[j>>0]|0)==0;b[l>>1]=r;if(u){s=c[o>>2]|0;t=c[h>>2]|0;break}Kj(f);i=g;return}}while(0);c[o>>2]=s+2;c[h>>2]=t+2}t=f+372|0;c[t>>2]=(c[t>>2]|0)+8;i=g;return}}Nj(f);i=g;return}function jl(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;g=i;h=f+160|0;j=(e[h>>1]|0)>>>3&7;if((j|0)==3){k=f+156|0;l=c[k>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;n=f+162|0;b[n>>1]=b[m>>1]|0;o=l&16777215;l=o+1|0;p=f+36|0;if(l>>>0<(c[p>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+o>>0]<<8|d[q+l>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[m>>1]=r;r=f+336|0;if((a[r>>0]|0)!=0){Kj(f);i=g;return}c[k>>2]=(c[k>>2]|0)+2;o=f+152|0;c[o>>2]=(c[o>>2]|0)+2;l=b[n>>1]|0;q=c[f+((b[h>>1]&7)<<2)+120>>2]|0;if(l<<16>>16==0){s=0}else{if((c[f>>2]&1|0)==0){if((q&1|0)==0){s=l}else{Mj(f,q,1,0);i=g;return}}else{s=l}}l=f+32|0;t=f+372|0;u=f+12|0;v=f+4|0;w=q;q=0;x=s;while(1){if((x&1)==0){y=w}else{s=w&16777215;z=s+1|0;if(z>>>0<(c[p>>2]|0)>>>0){A=c[l>>2]|0;B=(d[A+s>>0]<<8|d[A+z>>0])&65535}else{B=oc[c[u>>2]&31](c[v>>2]|0,s)|0}s=B&65535;z=(s&32768|0)!=0?s|-65536:s;s=q&7;if(q>>>0<8){c[f+(s<<2)+88>>2]=z}else{c[f+(s<<2)+120>>2]=z}c[t>>2]=(c[t>>2]|0)+4;y=w+2|0}q=q+1|0;if((q|0)==16){break}else{w=y;x=(x&65535)>>>1}}c[f+((b[h>>1]&7)<<2)+120>>2]=y;c[t>>2]=(c[t>>2]|0)+12;t=c[k>>2]|0;if((t&1|0)!=0){Mj(f,t,0,0);i=g;return}b[n>>1]=b[m>>1]|0;n=t&16777215;t=n+1|0;if(t>>>0<(c[p>>2]|0)>>>0){p=c[l>>2]|0;C=(d[p+n>>0]<<8|d[p+t>>0])&65535}else{C=oc[c[u>>2]&31](c[v>>2]|0,n)|0}b[m>>1]=C;if((a[r>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;c[o>>2]=(c[o>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==0){Nj(f);j=f+372|0;c[j>>2]=(c[j>>2]|0)+2;i=g;return}else{j=f+156|0;o=c[j>>2]|0;if((o&1|0)!=0){Mj(f,o,0,0);i=g;return}k=f+164|0;r=f+162|0;b[r>>1]=b[k>>1]|0;C=o&16777215;o=C+1|0;m=f+36|0;if(o>>>0<(c[m>>2]|0)>>>0){n=c[f+32>>2]|0;D=(d[n+C>>0]<<8|d[n+o>>0])&65535}else{D=oc[c[f+12>>2]&31](c[f+4>>2]|0,C)|0}b[k>>1]=D;D=f+336|0;if((a[D>>0]|0)!=0){Kj(f);i=g;return}c[j>>2]=(c[j>>2]|0)+2;C=f+152|0;c[C>>2]=(c[C>>2]|0)+2;o=b[r>>1]|0;n=b[h>>1]&63;if((nc[c[46024+(n<<2)>>2]&63](f,n,2028,16)|0)!=0){i=g;return}if((c[f+340>>2]|0)!=2){Nj(f);i=g;return}n=c[f+344>>2]|0;if(o<<16>>16==0){E=0}else{if((c[f>>2]&1|0)==0){if((n&1|0)==0){E=o}else{Mj(f,n,1,0);i=g;return}}else{E=o}}o=f+32|0;h=f+372|0;v=f+12|0;u=f+4|0;t=n;n=0;p=E;while(1){if((p&1)==0){F=t}else{E=t&16777215;l=E+1|0;if(l>>>0<(c[m>>2]|0)>>>0){y=c[o>>2]|0;G=(d[y+E>>0]<<8|d[y+l>>0])&65535}else{G=oc[c[v>>2]&31](c[u>>2]|0,E)|0}E=G&65535;l=(E&32768|0)!=0?E|-65536:E;E=n&7;if(n>>>0<8){c[f+(E<<2)+88>>2]=l}else{c[f+(E<<2)+120>>2]=l}c[h>>2]=(c[h>>2]|0)+4;F=t+2|0}n=n+1|0;if((n|0)==16){break}else{t=F;p=(p&65535)>>>1}}c[h>>2]=(c[h>>2]|0)+12;h=c[j>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}b[r>>1]=b[k>>1]|0;r=h&16777215;h=r+1|0;if(h>>>0<(c[m>>2]|0)>>>0){m=c[o>>2]|0;H=(d[m+r>>0]<<8|d[m+h>>0])&65535}else{H=oc[c[v>>2]&31](c[u>>2]|0,r)|0}b[k>>1]=H;if((a[D>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[C>>2]=(c[C>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}}function kl(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=i;h=f+160|0;j=(e[h>>1]|0)>>>3&7;if((j|0)==0){Nj(f);k=f+372|0;c[k>>2]=(c[k>>2]|0)+2;i=g;return}else if((j|0)==3){j=f+156|0;k=c[j>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}l=f+164|0;m=f+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=f+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[l>>1]=q;q=f+336|0;if((a[q>>0]|0)!=0){Kj(f);i=g;return}c[j>>2]=(c[j>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;k=b[m>>1]|0;p=c[f+((b[h>>1]&7)<<2)+120>>2]|0;if(k<<16>>16==0){r=0}else{if((c[f>>2]&1|0)==0){if((p&1|0)==0){r=k}else{Mj(f,p,1,0);i=g;return}}else{r=k}}k=f+32|0;s=f+372|0;t=f+16|0;u=f+4|0;v=p;p=0;w=r;while(1){if((w&1)==0){x=v}else{r=v&16777215;y=r+3|0;if(y>>>0<(c[o>>2]|0)>>>0){z=c[k>>2]|0;A=((d[z+r>>0]<<8|d[z+(r+1)>>0])<<8|d[z+(r+2)>>0])<<8|d[z+y>>0]}else{A=oc[c[t>>2]&31](c[u>>2]|0,r)|0}r=p&7;if(p>>>0<8){c[f+(r<<2)+88>>2]=A}else{c[f+(r<<2)+120>>2]=A}c[s>>2]=(c[s>>2]|0)+8;x=v+4|0}p=p+1|0;if((p|0)==16){break}else{v=x;w=(w&65535)>>>1}}c[f+((b[h>>1]&7)<<2)+120>>2]=x;c[s>>2]=(c[s>>2]|0)+12;s=c[j>>2]|0;if((s&1|0)!=0){Mj(f,s,0,0);i=g;return}b[m>>1]=b[l>>1]|0;m=s&16777215;s=m+1|0;if(s>>>0<(c[o>>2]|0)>>>0){o=c[k>>2]|0;B=(d[o+m>>0]<<8|d[o+s>>0])&65535}else{B=oc[c[f+12>>2]&31](c[u>>2]|0,m)|0}b[l>>1]=B;if((a[q>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;c[n>>2]=(c[n>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else{n=f+156|0;j=c[n>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}q=f+164|0;B=f+162|0;b[B>>1]=b[q>>1]|0;l=j&16777215;j=l+1|0;m=f+36|0;if(j>>>0<(c[m>>2]|0)>>>0){u=c[f+32>>2]|0;C=(d[u+l>>0]<<8|d[u+j>>0])&65535}else{C=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[q>>1]=C;C=f+336|0;if((a[C>>0]|0)!=0){Kj(f);i=g;return}c[n>>2]=(c[n>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;j=b[B>>1]|0;u=b[h>>1]&63;if((nc[c[46024+(u<<2)>>2]&63](f,u,2028,32)|0)!=0){i=g;return}if((c[f+340>>2]|0)!=2){Nj(f);i=g;return}u=c[f+344>>2]|0;if(j<<16>>16==0){D=0}else{if((c[f>>2]&1|0)==0){if((u&1|0)==0){D=j}else{Mj(f,u,1,0);i=g;return}}else{D=j}}j=f+32|0;h=f+372|0;s=f+16|0;o=f+4|0;k=u;u=0;x=D;while(1){if((x&1)==0){E=k}else{D=k&16777215;w=D+3|0;if(w>>>0<(c[m>>2]|0)>>>0){v=c[j>>2]|0;F=((d[v+D>>0]<<8|d[v+(D+1)>>0])<<8|d[v+(D+2)>>0])<<8|d[v+w>>0]}else{F=oc[c[s>>2]&31](c[o>>2]|0,D)|0}D=u&7;if(u>>>0<8){c[f+(D<<2)+88>>2]=F}else{c[f+(D<<2)+120>>2]=F}c[h>>2]=(c[h>>2]|0)+8;E=k+4|0}u=u+1|0;if((u|0)==16){break}else{k=E;x=(x&65535)>>>1}}c[h>>2]=(c[h>>2]|0)+12;h=c[n>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}b[B>>1]=b[q>>1]|0;B=h&16777215;h=B+1|0;if(h>>>0<(c[m>>2]|0)>>>0){m=c[j>>2]|0;G=(d[m+B>>0]<<8|d[m+h>>0])&65535}else{G=oc[c[f+12>>2]&31](c[o>>2]|0,B)|0}b[q>>1]=G;if((a[C>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;c[l>>2]=(c[l>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}}function ll(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0;g=i;h=f+160|0;j=e[h>>1]|0;do{switch(j|0){case 20080:{if((a[f+334>>0]|0)==0){Rj(f);i=g;return}k=f+372|0;l=c[k>>2]|0;if((c[f>>2]&8|0)==0){c[k>>2]=l+132;Xj(f);i=g;return}c[k>>2]=l+4;l=f+156|0;k=c[l>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=k&16777215;k=n+1|0;if(k>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+k>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}break};case 20083:{l=f+334|0;if((a[l>>0]|0)==0){Rj(f);i=g;return}m=f+148|0;n=c[m>>2]|0;k=n&16777215;o=k+1|0;q=f+36|0;r=c[q>>2]|0;if(o>>>0<r>>>0){s=c[f+32>>2]|0;t=(d[s+k>>0]<<8|d[s+o>>0])&65535;u=r}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,k)|0;t=r;u=c[q>>2]|0}r=n+2&16777215;k=r+3|0;if(k>>>0<u>>>0){o=c[f+32>>2]|0;v=((d[o+r>>0]<<8|d[o+(r+1)>>0])<<8|d[o+(r+2)>>0])<<8|d[o+k>>0]}else{v=oc[c[f+16>>2]&31](c[f+4>>2]|0,r)|0}if((c[f>>2]&2|0)!=0){r=n+6&16777215;k=r+1|0;if(k>>>0<(c[q>>2]|0)>>>0){o=c[f+32>>2]|0;w=(d[o+r>>0]<<8|d[o+k>>0])&65535}else{w=oc[c[f+12>>2]&31](c[f+4>>2]|0,r)|0}r=(w&65535)>>>12;if(!((r|0)==8|(r|0)==0)){Uj(f);i=g;return}}Ij(f,t);r=f+152|0;c[r>>2]=v;k=f+156|0;c[k>>2]=v;do{if((c[f>>2]&2|0)==0){o=n+6|0;if((a[l>>0]|0)==0){c[f+172>>2]=o;break}else{c[m>>2]=o;break}}else{o=n+8|0;if((a[l>>0]|0)==0){c[f+172>>2]=o;break}else{c[m>>2]=o;break}}}while(0);m=f+372|0;c[m>>2]=(c[m>>2]|0)+20;if((v&1|0)!=0){Mj(f,v,0,0);i=g;return}m=f+164|0;l=f+162|0;b[l>>1]=b[m>>1]|0;n=v&16777215;o=n+1|0;if(o>>>0<(c[q>>2]|0)>>>0){s=c[f+32>>2]|0;x=(d[s+n>>0]<<8|d[s+o>>0])&65535}else{x=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=x;n=f+336|0;if((a[n>>0]|0)!=0){Kj(f);i=g;return}o=(c[k>>2]|0)+2|0;c[k>>2]=o;c[r>>2]=(c[r>>2]|0)+2;if((o&1|0)!=0){Mj(f,o,0,0);i=g;return}b[l>>1]=x;l=o&16777215;s=l+1|0;do{if(s>>>0<(c[q>>2]|0)>>>0){y=c[f+32>>2]|0;b[m>>1]=d[y+l>>0]<<8|d[y+s>>0];z=o}else{y=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0;A=(a[n>>0]|0)==0;b[m>>1]=y;if(A){z=c[k>>2]|0;break}Kj(f);i=g;return}}while(0);c[k>>2]=z+2;c[r>>2]=v;i=g;return};case 20084:{if((c[f>>2]&2|0)==0){Nj(f);m=f+372|0;c[m>>2]=(c[m>>2]|0)+2;i=g;return}m=f+156|0;n=c[m>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);i=g;return}l=f+164|0;o=f+162|0;b[o>>1]=b[l>>1]|0;s=n&16777215;n=s+1|0;q=f+36|0;if(n>>>0<(c[q>>2]|0)>>>0){A=c[f+32>>2]|0;B=(d[A+s>>0]<<8|d[A+n>>0])&65535}else{B=oc[c[f+12>>2]&31](c[f+4>>2]|0,s)|0}b[l>>1]=B;s=f+336|0;if((a[s>>0]|0)!=0){Kj(f);i=g;return}c[m>>2]=(c[m>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;A=e[o>>1]|0;y=f+148|0;C=c[y>>2]|0;D=C&16777215;E=D+3|0;if(E>>>0<(c[q>>2]|0)>>>0){F=c[f+32>>2]|0;G=((d[F+D>>0]<<8|d[F+(D+1)>>0])<<8|d[F+(D+2)>>0])<<8|d[F+E>>0]}else{G=oc[c[f+16>>2]&31](c[f+4>>2]|0,D)|0}c[m>>2]=G;c[y>>2]=C+4+((A&32768|0)!=0?A|-65536:A);A=f+372|0;c[A>>2]=(c[A>>2]|0)+16;if((G&1|0)!=0){Mj(f,G,0,0);i=g;return}b[o>>1]=b[l>>1]|0;A=G&16777215;C=A+1|0;if(C>>>0<(c[q>>2]|0)>>>0){y=c[f+32>>2]|0;H=(d[y+A>>0]<<8|d[y+C>>0])&65535}else{H=oc[c[f+12>>2]&31](c[f+4>>2]|0,A)|0}b[l>>1]=H;if((a[s>>0]|0)!=0){Kj(f);i=g;return}A=(c[m>>2]|0)+2|0;c[m>>2]=A;c[n>>2]=(c[n>>2]|0)+2;if((A&1|0)!=0){Mj(f,A,0,0);i=g;return}b[o>>1]=H;o=A&16777215;C=o+1|0;do{if(C>>>0<(c[q>>2]|0)>>>0){y=c[f+32>>2]|0;b[l>>1]=d[y+o>>0]<<8|d[y+C>>0];I=A}else{y=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0;D=(a[s>>0]|0)==0;b[l>>1]=y;if(D){I=c[m>>2]|0;break}Kj(f);i=g;return}}while(0);c[m>>2]=I+2;c[n>>2]=I+ -2;i=g;return};case 20091:{if((c[f>>2]&2|0)==0){Nj(f);l=f+372|0;c[l>>2]=(c[l>>2]|0)+2;i=g;return}l=f+334|0;if((a[l>>0]|0)==0){Rj(f);i=g;return}s=f+156|0;o=c[s>>2]|0;if((o&1|0)!=0){Mj(f,o,0,0);i=g;return}A=f+164|0;C=f+162|0;b[C>>1]=b[A>>1]|0;q=o&16777215;o=q+1|0;r=f+36|0;if(o>>>0<(c[r>>2]|0)>>>0){k=c[f+32>>2]|0;J=(d[k+q>>0]<<8|d[k+o>>0])&65535}else{J=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[A>>1]=J;q=f+336|0;if((a[q>>0]|0)!=0){Kj(f);i=g;return}o=(c[s>>2]|0)+2|0;c[s>>2]=o;k=f+152|0;D=(c[k>>2]|0)+2|0;c[k>>2]=D;y=e[C>>1]|0;E=y>>>12;F=E&7;if((E&8|0)==0){K=f+(F<<2)+88|0}else{K=f+(F<<2)+120|0}F=c[K>>2]|0;a:do{switch(y&4095|0){case 0:{c[f+180>>2]=F&3;break};case 1:{c[f+184>>2]=F&3;break};case 2:{if((c[f>>2]&4|0)!=0){c[f+188>>2]=F;break a}Nj(f);E=f+372|0;c[E>>2]=(c[E>>2]|0)+2;i=g;return};case 2048:{if((a[l>>0]|0)==0){c[f+148>>2]=F;break a}else{c[f+168>>2]=F;break a}break};case 2049:{c[f+176>>2]=F;break};case 2050:{if((c[f>>2]&4|0)!=0){c[f+188>>2]=F;break a}Nj(f);E=f+372|0;c[E>>2]=(c[E>>2]|0)+2;i=g;return};default:{Nj(f);i=g;return}}}while(0);F=f+372|0;c[F>>2]=(c[F>>2]|0)+10;if((o&1|0)!=0){Mj(f,o,0,0);i=g;return}b[C>>1]=J;F=o&16777215;l=F+1|0;do{if(l>>>0<(c[r>>2]|0)>>>0){y=c[f+32>>2]|0;b[A>>1]=d[y+F>>0]<<8|d[y+l>>0];L=o;M=D}else{y=oc[c[f+12>>2]&31](c[f+4>>2]|0,F)|0;n=(a[q>>0]|0)==0;b[A>>1]=y;if(n){L=c[s>>2]|0;M=c[k>>2]|0;break}Kj(f);i=g;return}}while(0);c[s>>2]=L+2;c[k>>2]=M+2;i=g;return};case 20081:{A=f+372|0;c[A>>2]=(c[A>>2]|0)+4;A=f+156|0;q=c[A>>2]|0;if((q&1|0)!=0){Mj(f,q,0,0);i=g;return}F=f+164|0;b[f+162>>1]=b[F>>1]|0;D=q&16777215;q=D+1|0;if(q>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;N=(d[o+D>>0]<<8|d[o+q>>0])&65535}else{N=oc[c[f+12>>2]&31](c[f+4>>2]|0,D)|0}b[F>>1]=N;if((a[f+336>>0]|0)==0){c[A>>2]=(c[A>>2]|0)+2;A=f+152|0;c[A>>2]=(c[A>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}break};case 20090:{if((c[f>>2]&2|0)==0){Nj(f);A=f+372|0;c[A>>2]=(c[A>>2]|0)+2;i=g;return}A=f+334|0;if((a[A>>0]|0)==0){Rj(f);i=g;return}F=f+156|0;D=c[F>>2]|0;if((D&1|0)!=0){Mj(f,D,0,0);i=g;return}q=f+164|0;o=f+162|0;b[o>>1]=b[q>>1]|0;l=D&16777215;D=l+1|0;r=f+36|0;if(D>>>0<(c[r>>2]|0)>>>0){C=c[f+32>>2]|0;O=(d[C+l>>0]<<8|d[C+D>>0])&65535}else{O=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[q>>1]=O;l=f+336|0;if((a[l>>0]|0)!=0){Kj(f);i=g;return}c[F>>2]=(c[F>>2]|0)+2;D=f+152|0;c[D>>2]=(c[D>>2]|0)+2;C=e[o>>1]|0;n=C>>>12;b:do{switch(C&4095|0){case 2048:{P=c[((a[A>>0]|0)==0?f+148|0:f+168|0)>>2]|0;break};case 2049:{P=c[f+176>>2]|0;break};case 2050:{if((c[f>>2]&4|0)!=0){P=c[f+176>>2]|0;break b}Nj(f);y=f+372|0;c[y>>2]=(c[y>>2]|0)+2;i=g;return};case 0:{P=c[f+180>>2]&3;break};case 1:{P=c[f+184>>2]&3;break};case 2:{if((c[f>>2]&4|0)!=0){P=c[f+176>>2]|0;break b}Nj(f);y=f+372|0;c[y>>2]=(c[y>>2]|0)+2;i=g;return};default:{Nj(f);i=g;return}}}while(0);A=n&7;if((n&8|0)==0){c[f+(A<<2)+88>>2]=P}else{c[f+(A<<2)+120>>2]=P}A=f+372|0;c[A>>2]=(c[A>>2]|0)+12;A=c[F>>2]|0;if((A&1|0)!=0){Mj(f,A,0,0);i=g;return}b[o>>1]=b[q>>1]|0;C=A&16777215;A=C+1|0;if(A>>>0<(c[r>>2]|0)>>>0){k=c[f+32>>2]|0;Q=(d[k+C>>0]<<8|d[k+A>>0])&65535}else{Q=oc[c[f+12>>2]&31](c[f+4>>2]|0,C)|0}b[q>>1]=Q;if((a[l>>0]|0)==0){c[F>>2]=(c[F>>2]|0)+2;c[D>>2]=(c[D>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}break};case 20085:{C=f+148|0;A=c[C>>2]|0;k=A&16777215;s=k+3|0;y=f+36|0;if(s>>>0<(c[y>>2]|0)>>>0){m=c[f+32>>2]|0;R=((d[m+k>>0]<<8|d[m+(k+1)>>0])<<8|d[m+(k+2)>>0])<<8|d[m+s>>0]}else{R=oc[c[f+16>>2]&31](c[f+4>>2]|0,k)|0}k=f+156|0;c[k>>2]=R;c[C>>2]=A+4;A=f+372|0;c[A>>2]=(c[A>>2]|0)+16;if((R&1|0)!=0){Mj(f,R,0,0);i=g;return}A=f+164|0;C=f+162|0;b[C>>1]=b[A>>1]|0;s=R&16777215;m=s+1|0;if(m>>>0<(c[y>>2]|0)>>>0){E=c[f+32>>2]|0;S=(d[E+s>>0]<<8|d[E+m>>0])&65535}else{S=oc[c[f+12>>2]&31](c[f+4>>2]|0,s)|0}b[A>>1]=S;s=f+336|0;if((a[s>>0]|0)!=0){Kj(f);i=g;return}m=(c[k>>2]|0)+2|0;c[k>>2]=m;E=f+152|0;c[E>>2]=(c[E>>2]|0)+2;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}b[C>>1]=S;C=m&16777215;T=C+1|0;do{if(T>>>0<(c[y>>2]|0)>>>0){U=c[f+32>>2]|0;b[A>>1]=d[U+C>>0]<<8|d[U+T>>0];V=m}else{U=oc[c[f+12>>2]&31](c[f+4>>2]|0,C)|0;W=(a[s>>0]|0)==0;b[A>>1]=U;if(W){V=c[k>>2]|0;break}Kj(f);i=g;return}}while(0);c[k>>2]=V+2;c[E>>2]=V+ -2;i=g;return};case 20087:{A=f+148|0;s=c[A>>2]|0;C=s&16777215;m=C+1|0;T=f+36|0;y=c[T>>2]|0;if(m>>>0<y>>>0){D=c[f+32>>2]|0;X=(d[D+C>>0]<<8|d[D+m>>0])&65535;Y=y}else{y=oc[c[f+12>>2]&31](c[f+4>>2]|0,C)|0;X=y;Y=c[T>>2]|0}y=f+166|0;b[y>>1]=b[y>>1]&65280|X&31;y=s+2&16777215;C=y+3|0;if(C>>>0<Y>>>0){m=c[f+32>>2]|0;Z=((d[m+y>>0]<<8|d[m+(y+1)>>0])<<8|d[m+(y+2)>>0])<<8|d[m+C>>0]}else{Z=oc[c[f+16>>2]&31](c[f+4>>2]|0,y)|0}y=f+156|0;c[y>>2]=Z;c[A>>2]=s+6;s=f+372|0;c[s>>2]=(c[s>>2]|0)+20;if((Z&1|0)!=0){Mj(f,Z,0,0);i=g;return}s=f+164|0;A=f+162|0;b[A>>1]=b[s>>1]|0;C=Z&16777215;m=C+1|0;if(m>>>0<(c[T>>2]|0)>>>0){D=c[f+32>>2]|0;_=(d[D+C>>0]<<8|d[D+m>>0])&65535}else{_=oc[c[f+12>>2]&31](c[f+4>>2]|0,C)|0}b[s>>1]=_;C=f+336|0;if((a[C>>0]|0)!=0){Kj(f);i=g;return}m=(c[y>>2]|0)+2|0;c[y>>2]=m;D=f+152|0;c[D>>2]=(c[D>>2]|0)+2;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}b[A>>1]=_;A=m&16777215;F=A+1|0;do{if(F>>>0<(c[T>>2]|0)>>>0){l=c[f+32>>2]|0;b[s>>1]=d[l+A>>0]<<8|d[l+F>>0];$=m}else{l=oc[c[f+12>>2]&31](c[f+4>>2]|0,A)|0;q=(a[C>>0]|0)==0;b[s>>1]=l;if(q){$=c[y>>2]|0;break}Kj(f);i=g;return}}while(0);c[y>>2]=$+2;c[D>>2]=$+ -2;i=g;return};case 20086:{s=f+156|0;C=c[s>>2]|0;if((C&1|0)!=0){Mj(f,C,0,0);i=g;return}A=f+164|0;b[f+162>>1]=b[A>>1]|0;m=C&16777215;C=m+1|0;if(C>>>0<(c[f+36>>2]|0)>>>0){F=c[f+32>>2]|0;aa=(d[F+m>>0]<<8|d[F+C>>0])&65535}else{aa=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[A>>1]=aa;if((a[f+336>>0]|0)!=0){Kj(f);i=g;return}c[s>>2]=(c[s>>2]|0)+2;s=f+152|0;c[s>>2]=(c[s>>2]|0)+2;if((b[f+166>>1]&2)==0){s=f+372|0;c[s>>2]=(c[s>>2]|0)+4;i=g;return}else{Qj(f);i=g;return}break};case 20082:{if((a[f+334>>0]|0)==0){Rj(f);i=g;return}s=f+156|0;A=c[s>>2]|0;if((A&1|0)!=0){Mj(f,A,0,0);i=g;return}m=f+164|0;C=f+162|0;b[C>>1]=b[m>>1]|0;F=A&16777215;A=F+1|0;T=f+36|0;if(A>>>0<(c[T>>2]|0)>>>0){E=c[f+32>>2]|0;ba=(d[E+F>>0]<<8|d[E+A>>0])&65535}else{ba=oc[c[f+12>>2]&31](c[f+4>>2]|0,F)|0}b[m>>1]=ba;F=f+336|0;if((a[F>>0]|0)!=0){Kj(f);i=g;return}c[s>>2]=(c[s>>2]|0)+2;A=f+152|0;c[A>>2]=(c[A>>2]|0)+2;Ij(f,b[C>>1]|0);E=f+372|0;c[E>>2]=(c[E>>2]|0)+4;E=f+335|0;a[E>>0]=d[E>>0]|1;E=c[s>>2]|0;if((E&1|0)!=0){Mj(f,E,0,0);i=g;return}b[C>>1]=b[m>>1]|0;C=E&16777215;E=C+1|0;if(E>>>0<(c[T>>2]|0)>>>0){T=c[f+32>>2]|0;ca=(d[T+C>>0]<<8|d[T+E>>0])&65535}else{ca=oc[c[f+12>>2]&31](c[f+4>>2]|0,C)|0}b[m>>1]=ca;if((a[F>>0]|0)==0){c[s>>2]=(c[s>>2]|0)+2;c[A>>2]=(c[A>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}break};default:{switch(j>>>3&7|0){case 1:case 0:{A=f+156|0;s=c[A>>2]|0;if((s&1|0)!=0){Mj(f,s,0,0);i=g;return}F=f+164|0;b[f+162>>1]=b[F>>1]|0;m=s&16777215;s=m+1|0;if(s>>>0<(c[f+36>>2]|0)>>>0){C=c[f+32>>2]|0;da=(d[C+m>>0]<<8|d[C+s>>0])&65535}else{da=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[F>>1]=da;if((a[f+336>>0]|0)==0){c[A>>2]=(c[A>>2]|0)+2;A=f+152|0;c[A>>2]=(c[A>>2]|0)+2;Vj(f,b[h>>1]&15);i=g;return}else{Kj(f);i=g;return}break};case 2:{A=f+156|0;F=c[A>>2]|0;if((F&1|0)!=0){Mj(f,F,0,0);i=g;return}m=f+164|0;s=f+162|0;b[s>>1]=b[m>>1]|0;C=F&16777215;F=C+1|0;E=f+36|0;if(F>>>0<(c[E>>2]|0)>>>0){T=c[f+32>>2]|0;ea=(d[T+C>>0]<<8|d[T+F>>0])&65535}else{ea=oc[c[f+12>>2]&31](c[f+4>>2]|0,C)|0}b[m>>1]=ea;C=f+336|0;if((a[C>>0]|0)!=0){Kj(f);i=g;return}c[A>>2]=(c[A>>2]|0)+2;F=f+152|0;c[F>>2]=(c[F>>2]|0)+2;T=b[h>>1]&7;k=e[s>>1]|0;q=f+372|0;c[q>>2]=(c[q>>2]|0)+16;q=f+148|0;l=(c[q>>2]|0)+ -4|0;c[q>>2]=l;r=f+(T<<2)+120|0;T=c[r>>2]|0;o=l&16777215;l=o+3|0;if(l>>>0<(c[E>>2]|0)>>>0){n=f+32|0;a[(c[n>>2]|0)+o>>0]=T>>>24;a[(c[n>>2]|0)+(o+1)>>0]=T>>>16;a[(c[n>>2]|0)+(o+2)>>0]=T>>>8;a[(c[n>>2]|0)+l>>0]=T}else{lc[c[f+28>>2]&31](c[f+4>>2]|0,o,T)}c[r>>2]=c[q>>2];c[q>>2]=(c[q>>2]|0)+((k&32768|0)!=0?k|-65536:k);k=c[A>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}b[s>>1]=b[m>>1]|0;s=k&16777215;k=s+1|0;if(k>>>0<(c[E>>2]|0)>>>0){E=c[f+32>>2]|0;fa=(d[E+s>>0]<<8|d[E+k>>0])&65535}else{fa=oc[c[f+12>>2]&31](c[f+4>>2]|0,s)|0}b[m>>1]=fa;if((a[C>>0]|0)==0){c[A>>2]=(c[A>>2]|0)+2;c[F>>2]=(c[F>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}break};case 5:{if((a[f+334>>0]|0)==0){Rj(f);i=g;return}c[f+((j&7)<<2)+120>>2]=c[f+168>>2];F=f+372|0;c[F>>2]=(c[F>>2]|0)+4;F=f+156|0;A=c[F>>2]|0;if((A&1|0)!=0){Mj(f,A,0,0);i=g;return}C=f+164|0;b[f+162>>1]=b[C>>1]|0;m=A&16777215;A=m+1|0;if(A>>>0<(c[f+36>>2]|0)>>>0){s=c[f+32>>2]|0;ga=(d[s+m>>0]<<8|d[s+A>>0])&65535}else{ga=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[C>>1]=ga;if((a[f+336>>0]|0)==0){c[F>>2]=(c[F>>2]|0)+2;F=f+152|0;c[F>>2]=(c[F>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}break};case 4:{if((a[f+334>>0]|0)==0){Rj(f);i=g;return}c[f+168>>2]=c[f+((j&7)<<2)+120>>2];F=f+372|0;c[F>>2]=(c[F>>2]|0)+4;F=f+156|0;C=c[F>>2]|0;if((C&1|0)!=0){Mj(f,C,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;A=C&16777215;C=A+1|0;if(C>>>0<(c[f+36>>2]|0)>>>0){s=c[f+32>>2]|0;ha=(d[s+A>>0]<<8|d[s+C>>0])&65535}else{ha=oc[c[f+12>>2]&31](c[f+4>>2]|0,A)|0}b[m>>1]=ha;if((a[f+336>>0]|0)==0){c[F>>2]=(c[F>>2]|0)+2;F=f+152|0;c[F>>2]=(c[F>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}break};case 3:{F=f+((j&7)<<2)+120|0;m=c[F>>2]|0;if((c[f>>2]&1|0)==0){if((m&1|0)!=0){Mj(f,m,1,0);i=g;return}}A=f+372|0;c[A>>2]=(c[A>>2]|0)+12;A=f+148|0;c[A>>2]=m;C=m&16777215;m=C+3|0;s=f+36|0;if(m>>>0<(c[s>>2]|0)>>>0){k=c[f+32>>2]|0;ia=((d[k+C>>0]<<8|d[k+(C+1)>>0])<<8|d[k+(C+2)>>0])<<8|d[k+m>>0]}else{ia=oc[c[f+16>>2]&31](c[f+4>>2]|0,C)|0}c[F>>2]=ia;c[A>>2]=(c[A>>2]|0)+4;A=f+156|0;F=c[A>>2]|0;if((F&1|0)!=0){Mj(f,F,0,0);i=g;return}C=f+164|0;b[f+162>>1]=b[C>>1]|0;m=F&16777215;F=m+1|0;if(F>>>0<(c[s>>2]|0)>>>0){s=c[f+32>>2]|0;ja=(d[s+m>>0]<<8|d[s+F>>0])&65535}else{ja=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[C>>1]=ja;if((a[f+336>>0]|0)==0){c[A>>2]=(c[A>>2]|0)+2;A=f+152|0;c[A>>2]=(c[A>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}break};default:{Nj(f);A=f+372|0;c[A>>2]=(c[A>>2]|0)+2;i=g;return}}}}}while(0)}function ml(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;g=b[e+160>>1]&63;if((nc[c[46024+(g<<2)>>2]&63](e,g,2020,32)|0)!=0){i=f;return}if((c[e+340>>2]|0)!=2){Nj(e);i=f;return}g=e+372|0;c[g>>2]=(c[g>>2]|0)+16;g=e+156|0;h=c[g>>2]|0;j=e+344|0;k=c[j>>2]|0;c[g>>2]=k;if((k&1|0)!=0){Mj(e,k,0,0);i=f;return}l=e+164|0;m=e+162|0;b[m>>1]=b[l>>1]|0;n=k&16777215;k=n+1|0;o=e+36|0;if(k>>>0<(c[o>>2]|0)>>>0){p=c[e+32>>2]|0;q=(d[p+n>>0]<<8|d[p+k>>0])&65535}else{q=oc[c[e+12>>2]&31](c[e+4>>2]|0,n)|0}b[l>>1]=q;q=e+336|0;if((a[q>>0]|0)!=0){Kj(e);i=f;return}c[g>>2]=(c[g>>2]|0)+2;n=e+152|0;c[n>>2]=(c[n>>2]|0)+2;k=h+ -2|0;h=e+148|0;p=(c[h>>2]|0)+ -4|0;r=p&16777215;s=r+3|0;if(s>>>0<(c[o>>2]|0)>>>0){t=e+32|0;a[(c[t>>2]|0)+r>>0]=k>>>24;a[(c[t>>2]|0)+(r+1)>>0]=k>>>16;a[(c[t>>2]|0)+(r+2)>>0]=k>>>8;a[(c[t>>2]|0)+s>>0]=k}else{lc[c[e+28>>2]&31](c[e+4>>2]|0,r,k)}c[h>>2]=p;p=c[g>>2]|0;if((p&1|0)!=0){Mj(e,p,0,0);i=f;return}b[m>>1]=b[l>>1]|0;m=p&16777215;p=m+1|0;if(p>>>0<(c[o>>2]|0)>>>0){o=c[e+32>>2]|0;u=(d[o+m>>0]<<8|d[o+p>>0])&65535}else{u=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[l>>1]=u;if((a[q>>0]|0)==0){c[g>>2]=(c[g>>2]|0)+2;c[n>>2]=c[j>>2];i=f;return}else{Kj(e);i=f;return}}function nl(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=b[e+160>>1]&63;if((nc[c[46024+(g<<2)>>2]&63](e,g,2020,32)|0)!=0){i=f;return}if((c[e+340>>2]|0)!=2){Nj(e);i=f;return}g=e+372|0;c[g>>2]=(c[g>>2]|0)+8;g=e+344|0;h=c[g>>2]|0;j=e+156|0;c[j>>2]=h;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}k=e+164|0;l=e+162|0;b[l>>1]=b[k>>1]|0;m=h&16777215;h=m+1|0;n=e+36|0;if(h>>>0<(c[n>>2]|0)>>>0){o=c[e+32>>2]|0;p=(d[o+m>>0]<<8|d[o+h>>0])&65535}else{p=oc[c[e+12>>2]&31](c[e+4>>2]|0,m)|0}b[k>>1]=p;m=e+336|0;if((a[m>>0]|0)!=0){Kj(e);i=f;return}h=(c[j>>2]|0)+2|0;c[j>>2]=h;o=e+152|0;c[o>>2]=(c[o>>2]|0)+2;if((h&1|0)!=0){Mj(e,h,0,0);i=f;return}b[l>>1]=p;p=h&16777215;h=p+1|0;if(h>>>0<(c[n>>2]|0)>>>0){n=c[e+32>>2]|0;b[k>>1]=d[n+p>>0]<<8|d[n+h>>0]}else{h=oc[c[e+12>>2]&31](c[e+4>>2]|0,p)|0;p=(a[m>>0]|0)==0;b[k>>1]=h;if(!p){Kj(e);i=f;return}}c[j>>2]=(c[j>>2]|0)+2;c[o>>2]=c[g>>2];i=f;return}function ol(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j>>>9&7;l=j&63;if((nc[c[46024+(l<<2)>>2]&63](f,l,509,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}l=(k|0)==0?8:k&255;k=a[h>>0]|0;h=(k&255)+(l&255)&255;j=f+372|0;c[j>>2]=(c[j>>2]|0)+8;fo(f,h,l,k);k=f+156|0;l=c[k>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;m=l&16777215;l=m+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+l>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[j>>1]=o;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;Mo(f,h)|0;i=g;return}else{Kj(f);i=g;return}}function pl(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;if((j&56|0)==8){k=j>>>9&7;l=f+((j&7)<<2)+120|0;m=c[l>>2]|0;n=f+372|0;c[n>>2]=(c[n>>2]|0)+8;n=f+156|0;o=c[n>>2]|0;if((o&1|0)!=0){Mj(f,o,0,0);i=g;return}p=f+164|0;b[f+162>>1]=b[p>>1]|0;q=o&16777215;o=q+1|0;if(o>>>0<(c[f+36>>2]|0)>>>0){r=c[f+32>>2]|0;s=(d[r+q>>0]<<8|d[r+o>>0])&65535}else{s=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[p>>1]=s;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;c[l>>2]=m+((k|0)==0?8:k);i=g;return}else{Kj(f);i=g;return}}k=j>>>9&7;m=j&63;if((nc[c[46024+(m<<2)>>2]&63](f,m,509,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}m=(k|0)==0?8:k&65535;k=b[h>>1]|0;h=(k&65535)+(m&65535)&65535;j=f+372|0;c[j>>2]=(c[j>>2]|0)+8;go(f,h,m,k);k=f+156|0;m=c[k>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;l=m&16777215;m=l+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;t=(d[n+l>>0]<<8|d[n+m>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[j>>1]=t;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;No(f,h)|0;i=g;return}else{Kj(f);i=g;return}}function ql(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;if((j&56|0)==8){k=j>>>9&7;l=f+((j&7)<<2)+120|0;m=c[l>>2]|0;n=f+372|0;c[n>>2]=(c[n>>2]|0)+12;n=f+156|0;o=c[n>>2]|0;if((o&1|0)!=0){Mj(f,o,0,0);i=g;return}p=f+164|0;b[f+162>>1]=b[p>>1]|0;q=o&16777215;o=q+1|0;if(o>>>0<(c[f+36>>2]|0)>>>0){r=c[f+32>>2]|0;s=(d[r+q>>0]<<8|d[r+o>>0])&65535}else{s=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[p>>1]=s;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;c[l>>2]=m+((k|0)==0?8:k);i=g;return}else{Kj(f);i=g;return}}k=j>>>9&7;m=j&63;if((nc[c[46024+(m<<2)>>2]&63](f,m,509,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}m=(k|0)==0?8:k;k=c[h>>2]|0;h=k+m|0;j=f+372|0;c[j>>2]=(c[j>>2]|0)+12;ho(f,h,m,k);k=f+156|0;m=c[k>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;l=m&16777215;m=l+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;t=(d[n+l>>0]<<8|d[n+m>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[j>>1]=t;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;Oo(f,h)|0;i=g;return}else{Kj(f);i=g;return}}function rl(a){a=a|0;var c=0;c=i;if((b[a+160>>1]&56)==8){_j(a,1);i=c;return}else{$j(a,1);i=c;return}}function sl(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j>>>9&7;l=j&63;if((nc[c[46024+(l<<2)>>2]&63](f,l,509,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}l=(k|0)==0?8:k&255;k=a[h>>0]|0;h=(k&255)-(l&255)&255;j=f+372|0;c[j>>2]=(c[j>>2]|0)+8;oo(f,h,l,k);k=f+156|0;l=c[k>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;m=l&16777215;l=m+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+l>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[j>>1]=o;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;Mo(f,h)|0;i=g;return}else{Kj(f);i=g;return}}function tl(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;if((j&56|0)==8){k=j>>>9&7;l=f+((j&7)<<2)+120|0;m=c[l>>2]|0;n=f+372|0;c[n>>2]=(c[n>>2]|0)+8;n=f+156|0;o=c[n>>2]|0;if((o&1|0)!=0){Mj(f,o,0,0);i=g;return}p=f+164|0;b[f+162>>1]=b[p>>1]|0;q=o&16777215;o=q+1|0;if(o>>>0<(c[f+36>>2]|0)>>>0){r=c[f+32>>2]|0;s=(d[r+q>>0]<<8|d[r+o>>0])&65535}else{s=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[p>>1]=s;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;c[l>>2]=m-((k|0)==0?8:k);i=g;return}else{Kj(f);i=g;return}}k=j>>>9&7;m=j&63;if((nc[c[46024+(m<<2)>>2]&63](f,m,509,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}m=(k|0)==0?8:k&65535;k=b[h>>1]|0;h=(k&65535)-(m&65535)&65535;j=f+372|0;c[j>>2]=(c[j>>2]|0)+8;po(f,h,m,k);k=f+156|0;m=c[k>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;l=m&16777215;m=l+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;t=(d[n+l>>0]<<8|d[n+m>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[j>>1]=t;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;No(f,h)|0;i=g;return}else{Kj(f);i=g;return}}function ul(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;if((j&56|0)==8){k=j>>>9&7;l=f+((j&7)<<2)+120|0;m=c[l>>2]|0;n=f+372|0;c[n>>2]=(c[n>>2]|0)+12;n=f+156|0;o=c[n>>2]|0;if((o&1|0)!=0){Mj(f,o,0,0);i=g;return}p=f+164|0;b[f+162>>1]=b[p>>1]|0;q=o&16777215;o=q+1|0;if(o>>>0<(c[f+36>>2]|0)>>>0){r=c[f+32>>2]|0;s=(d[r+q>>0]<<8|d[r+o>>0])&65535}else{s=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[p>>1]=s;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;c[l>>2]=m-((k|0)==0?8:k);i=g;return}else{Kj(f);i=g;return}}k=j>>>9&7;m=j&63;if((nc[c[46024+(m<<2)>>2]&63](f,m,509,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}m=(k|0)==0?8:k;k=c[h>>2]|0;h=k-m|0;j=f+372|0;c[j>>2]=(c[j>>2]|0)+12;qo(f,h,m,k);k=f+156|0;m=c[k>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;l=m&16777215;m=l+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;t=(d[n+l>>0]<<8|d[n+m>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[j>>1]=t;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;Oo(f,h)|0;i=g;return}else{Kj(f);i=g;return}}function vl(a){a=a|0;var c=0;c=i;if((b[a+160>>1]&56)==8){_j(a,0);i=c;return}else{$j(a,0);i=c;return}}function wl(a){a=a|0;var c=0,d=0,f=0;c=i;d=e[a+166>>1]|0;if((d&1|0)==0){f=(d&4|0)==0}else{f=0}d=f&1;if((b[a+160>>1]&56)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function xl(a){a=a|0;var c=0,d=0,f=0;c=i;d=e[a+166>>1]|0;if((d&1|0)==0){f=(d&4|0)!=0}else{f=1}d=f&1;if((b[a+160>>1]&56)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function yl(a){a=a|0;var c=0,d=0;c=i;d=(b[a+166>>1]&1^1)&65535;if((b[a+160>>1]&56)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function zl(a){a=a|0;var c=0,d=0;c=i;d=b[a+166>>1]&1;if((b[a+160>>1]&56)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function Al(a){a=a|0;var c=0,d=0;c=i;d=((e[a+166>>1]|0)>>>2&1^1)&65535;if((b[a+160>>1]&56)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function Bl(a){a=a|0;var c=0,d=0;c=i;d=(e[a+166>>1]|0)>>>2&1;if((b[a+160>>1]&56)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function Cl(a){a=a|0;var c=0,d=0;c=i;d=((e[a+166>>1]|0)>>>1&1^1)&65535;if((b[a+160>>1]&56)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function Dl(a){a=a|0;var c=0,d=0;c=i;d=(e[a+166>>1]|0)>>>1&1;if((b[a+160>>1]&56)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function El(a){a=a|0;var c=0,d=0;c=i;d=((e[a+166>>1]|0)>>>3&1^1)&65535;if((b[a+160>>1]&56)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function Fl(a){a=a|0;var c=0,d=0;c=i;d=(e[a+166>>1]|0)>>>3&1;if((b[a+160>>1]&56)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function Gl(a){a=a|0;var c=0,d=0,f=0;c=i;d=e[a+166>>1]|0;f=(d>>>3^d>>>1)&1^1;if((b[a+160>>1]&56)==8){_j(a,f);i=c;return}else{$j(a,f);i=c;return}}function Hl(a){a=a|0;var c=0,d=0,f=0;c=i;d=e[a+166>>1]|0;f=(d>>>3^d>>>1)&1;if((b[a+160>>1]&56)==8){_j(a,f);i=c;return}else{$j(a,f);i=c;return}}function Il(a){a=a|0;var c=0,d=0,f=0;c=i;d=e[a+166>>1]|0;if(((d>>>3^d>>>1)&1|0)==0){f=(d&4|0)==0}else{f=0}d=f&1;if((b[a+160>>1]&56)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function Jl(a){a=a|0;var c=0,d=0,f=0;c=i;d=e[a+166>>1]|0;if(((d>>>3^d>>>1)&1|0)==0){f=(d&4|0)!=0}else{f=1}d=f&1;if((b[a+160>>1]&56)==8){_j(a,d);i=c;return}else{$j(a,d);i=c;return}}function Kl(a){a=a|0;var b=0;b=i;bn(a,1);i=b;return}function Ll(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=((b[d+160>>1]&255)!=0?2:4)+(c[d+152>>2]|0)|0;g=d+148|0;h=(c[g>>2]|0)+ -4|0;j=h&16777215;k=j+3|0;if(k>>>0<(c[d+36>>2]|0)>>>0){l=d+32|0;a[(c[l>>2]|0)+j>>0]=f>>>24;a[(c[l>>2]|0)+(j+1)>>0]=f>>>16;a[(c[l>>2]|0)+(j+2)>>0]=f>>>8;a[(c[l>>2]|0)+k>>0]=f;c[g>>2]=h;bn(d,1);i=e;return}else{lc[c[d+28>>2]&31](c[d+4>>2]|0,j,f);c[g>>2]=h;bn(d,1);i=e;return}}function Ml(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;if((c&1|0)==0){d=(c&4|0)==0}else{d=0}bn(a,d&1);i=b;return}function Nl(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;if((c&1|0)==0){d=(c&4|0)!=0}else{d=1}bn(a,d&1);i=b;return}function Ol(a){a=a|0;var c=0;c=i;bn(a,(b[a+166>>1]&1^1)&65535);i=c;return}function Pl(a){a=a|0;var c=0;c=i;bn(a,b[a+166>>1]&1);i=c;return}function Ql(a){a=a|0;var b=0;b=i;bn(a,((e[a+166>>1]|0)>>>2&1^1)&65535);i=b;return}function Rl(a){a=a|0;var b=0;b=i;bn(a,(e[a+166>>1]|0)>>>2&1);i=b;return}function Sl(a){a=a|0;var b=0;b=i;bn(a,((e[a+166>>1]|0)>>>1&1^1)&65535);i=b;return}function Tl(a){a=a|0;var b=0;b=i;bn(a,(e[a+166>>1]|0)>>>1&1);i=b;return}function Ul(a){a=a|0;var b=0;b=i;bn(a,((e[a+166>>1]|0)>>>3&1^1)&65535);i=b;return}function Vl(a){a=a|0;var b=0;b=i;bn(a,(e[a+166>>1]|0)>>>3&1);i=b;return}function Wl(a){a=a|0;var b=0,c=0;b=i;c=e[a+166>>1]|0;bn(a,(c>>>3^c>>>1)&1^1);i=b;return}function Xl(a){a=a|0;var b=0,c=0;b=i;c=e[a+166>>1]|0;bn(a,(c>>>3^c>>>1)&1);i=b;return}function Yl(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;if(((c>>>3^c>>>1)&1|0)==0){d=(c&4|0)==0}else{d=0}bn(a,d&1);i=b;return}function Zl(a){a=a|0;var b=0,c=0,d=0;b=i;c=e[a+166>>1]|0;if(((c>>>3^c>>>1)&1|0)==0){d=(c&4|0)!=0}else{d=1}bn(a,d&1);i=b;return}function _l(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;h=f+160|0;j=e[h>>1]|0;k=(j&128|0)!=0?j|-256:j&255;j=f+372|0;c[j>>2]=(c[j>>2]|0)+4;eo(f,15,k);c[f+(((e[h>>1]|0)>>>9&7)<<2)+88>>2]=k;k=f+156|0;h=c[k>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;l=h&16777215;h=l+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+h>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[j>>1]=n;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function $l(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=d[h>>0]|c[k>>2];h=f+372|0;c[h>>2]=(c[h>>2]|0)+8;bo(f,15,j&255);h=f+156|0;l=c[h>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;c[k>>2]=c[k>>2]&-256|j&255;i=g;return}else{Kj(f);i=g;return}}function am(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=e[h>>1]|c[k>>2];h=f+372|0;c[h>>2]=(c[h>>2]|0)+8;co(f,15,j&65535);h=f+156|0;l=c[h>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;c[k>>2]=c[k>>2]&-65536|j&65535;i=g;return}else{Kj(f);i=g;return}}function bm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=c[h>>2]|c[k>>2];h=f+372|0;c[h>>2]=(c[h>>2]|0)+10;eo(f,15,j);h=f+156|0;l=c[h>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;c[k>>2]=j;i=g;return}else{Kj(f);i=g;return}}function cm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=c[k>>2]|0;l=b[h>>1]|0;h=l&65535;if(l<<16>>16==0){l=f+156|0;m=c[l>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}n=f+164|0;b[f+162>>1]=b[n>>1]|0;o=m&16777215;m=o+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+o>>0]<<8|d[p+m>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[n>>1]=q;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;Oj(f);i=g;return}else{Kj(f);i=g;return}}l=(j>>>0)/(h>>>0)|0;if(l>>>0>65535){q=f+166|0;b[q>>1]=b[q>>1]&65532|2}else{c[k>>2]=((j>>>0)%(h>>>0)|0)<<16|l&65535;co(f,15,l&65535)}l=f+372|0;c[l>>2]=(c[l>>2]|0)+144;l=f+156|0;h=c[l>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+k>>0]<<8|d[q+h>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,k)|0}b[j>>1]=r;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function dm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+16|0;h=g+2|0;j=g+1|0;k=g;l=e[f+160>>1]|0;if((l&48|0)!=0){m=c[f+((l>>>9&7)<<2)+88>>2]|0;n=l&63;if((nc[c[46024+(n<<2)>>2]&63](f,n,508,8)|0)!=0){i=g;return}if((Jo(f,k)|0)!=0){i=g;return}n=(d[k>>0]|m)&255;m=f+372|0;c[m>>2]=(c[m>>2]|0)+8;bo(f,15,n);m=f+156|0;k=c[m>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}o=f+164|0;b[f+162>>1]=b[o>>1]|0;p=k&16777215;k=p+1|0;if(k>>>0<(c[f+36>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+p>>0]<<8|d[q+k>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=r;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;Mo(f,n)|0;i=g;return}else{Kj(f);i=g;return}}n=l&7;m=l>>>9&7;if((l&8|0)==0){s=n;t=m}else{s=n|32;t=m|32}if((nc[c[46024+(s<<2)>>2]&63](f,s,17,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}if((nc[c[46024+(t<<2)>>2]&63](f,t,17,8)|0)!=0){i=g;return}if((Jo(f,j)|0)!=0){i=g;return}t=d[j>>0]|0;j=d[h>>0]|0;h=f+166|0;s=b[h>>1]|0;m=t-j-((s&65535)>>>4&1)|0;n=(t&15)>>>0<(j&15)>>>0?m+ -6|0:m;m=n&65535;if((m&65535)>159){u=n+65440&65535}else{u=m}m=f+372|0;c[m>>2]=(c[m>>2]|0)+10;m=u&65535;n=s&65535;s=(m&65280|0)==0?n&65518:n|17;b[h>>1]=(m&255|0)==0?s:s&65531;s=f+156|0;m=c[s>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}h=f+164|0;b[f+162>>1]=b[h>>1]|0;n=m&16777215;m=n+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){j=c[f+32>>2]|0;v=(d[j+n>>0]<<8|d[j+m>>0])&65535}else{v=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[h>>1]=v;if((a[f+336>>0]|0)==0){c[s>>2]=(c[s>>2]|0)+2;s=f+152|0;c[s>>2]=(c[s>>2]|0)+2;Mo(f,u&255)|0;i=g;return}else{Kj(f);i=g;return}}function em(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=c[f+((j>>>9&7)<<2)+88>>2]|0;l=j&63;if((nc[c[46024+(l<<2)>>2]&63](f,l,508,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}l=(e[h>>1]|k)&65535;k=f+372|0;c[k>>2]=(c[k>>2]|0)+8;co(f,15,l);k=f+156|0;h=c[k>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+h>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[j>>1]=o;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;No(f,l)|0;i=g;return}else{Kj(f);i=g;return}}function fm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=c[f+((j>>>9&7)<<2)+88>>2]|0;l=j&63;if((nc[c[46024+(l<<2)>>2]&63](f,l,508,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}l=c[h>>2]|k;k=f+372|0;c[k>>2]=(c[k>>2]|0)+10;eo(f,15,l);k=f+156|0;h=c[k>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+h>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[j>>1]=o;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;Oo(f,l)|0;i=g;return}else{Kj(f);i=g;return}}function gm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=c[k>>2]|0;l=b[h>>1]|0;if(l<<16>>16==0){m=f+156|0;n=c[m>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);i=g;return}o=f+164|0;b[f+162>>1]=b[o>>1]|0;p=n&16777215;n=p+1|0;if(n>>>0<(c[f+36>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+p>>0]<<8|d[q+n>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=r;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;Oj(f);i=g;return}else{Kj(f);i=g;return}}m=j>>>31;r=(j|0)<0?0-j|0:j;j=l&65535;if((j&32768|0)==0){s=l;t=0}else{l=0-j&65535;b[h>>1]=l;s=l;t=1}l=s&65535;s=(r>>>0)/(l>>>0)|0;h=(r>>>0)%(l>>>0)|0;if((m|0)==0){u=h}else{u=0-h&65535}h=(t|0)==(m|0)?s:0-s|0;s=f+372|0;c[s>>2]=(c[s>>2]|0)+162;s=h&-32768;if((s|0)==-32768|(s|0)==0){c[k>>2]=u<<16|h&65535;co(f,15,h&65535)}else{h=f+166|0;b[h>>1]=b[h>>1]&65532|2}h=f+156|0;u=c[h>>2]|0;if((u&1|0)!=0){Mj(f,u,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;s=u&16777215;u=s+1|0;if(u>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;v=(d[m+s>>0]<<8|d[m+u>>0])&65535}else{v=oc[c[f+12>>2]&31](c[f+4>>2]|0,s)|0}b[k>>1]=v;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function hm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=c[k>>2]|0;l=a[h>>0]|0;h=j-(l&255)|0;m=f+372|0;c[m>>2]=(c[m>>2]|0)+8;oo(f,h&255,l,j&255);j=f+156|0;l=c[j>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;j=f+152|0;c[j>>2]=(c[j>>2]|0)+2;c[k>>2]=c[k>>2]&-256|h&255;i=g;return}else{Kj(f);i=g;return}}function im(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=c[k>>2]|0;l=b[h>>1]|0;h=j-(l&65535)|0;m=f+372|0;c[m>>2]=(c[m>>2]|0)+8;po(f,h&65535,l,j&65535);j=f+156|0;l=c[j>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;j=f+152|0;c[j>>2]=(c[j>>2]|0)+2;c[k>>2]=c[k>>2]&-65536|h&65535;i=g;return}else{Kj(f);i=g;return}}function jm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=c[k>>2]|0;l=c[h>>2]|0;h=j-l|0;m=f+372|0;c[m>>2]=(c[m>>2]|0)+10;qo(f,h,l,j);j=f+156|0;l=c[j>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;j=f+152|0;c[j>>2]=(c[j>>2]|0)+2;c[k>>2]=h;i=g;return}else{Kj(f);i=g;return}}function km(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=e[h>>1]|0;h=f+((j>>>9&7)<<2)+120|0;j=c[h>>2]|0;l=f+372|0;c[l>>2]=(c[l>>2]|0)+8;l=f+156|0;m=c[l>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}n=f+164|0;b[f+162>>1]=b[n>>1]|0;o=m&16777215;m=o+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+o>>0]<<8|d[p+m>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[n>>1]=q;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;c[h>>2]=j-((k&32768|0)!=0?k|-65536:k);i=g;return}else{Kj(f);i=g;return}}function lm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+16|0;h=g+2|0;j=g+1|0;k=g;l=e[f+160>>1]|0;if((l&48|0)!=0){m=c[f+((l>>>9&7)<<2)+88>>2]|0;n=l&63;if((nc[c[46024+(n<<2)>>2]&63](f,n,508,8)|0)!=0){i=g;return}if((Jo(f,k)|0)!=0){i=g;return}n=a[k>>0]|0;k=(n&255)-m&255;o=f+372|0;c[o>>2]=(c[o>>2]|0)+8;oo(f,k,m&255,n);n=f+156|0;m=c[n>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}o=f+164|0;b[f+162>>1]=b[o>>1]|0;p=m&16777215;m=p+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+p>>0]<<8|d[q+m>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=r;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;Mo(f,k)|0;i=g;return}else{Kj(f);i=g;return}}k=l&7;n=l>>>9&7;if((l&8|0)==0){s=k;t=n}else{s=k|32;t=n|32}if((nc[c[46024+(s<<2)>>2]&63](f,s,17,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}if((nc[c[46024+(t<<2)>>2]&63](f,t,17,8)|0)!=0){i=g;return}if((Jo(f,j)|0)!=0){i=g;return}t=a[j>>0]|0;j=a[h>>0]|0;h=(t&255)-(j&255)-((e[f+166>>1]|0)>>>4&1)&255;s=f+372|0;c[s>>2]=(c[s>>2]|0)+8;ro(f,h,j,t);t=f+156|0;j=c[t>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}s=f+164|0;b[f+162>>1]=b[s>>1]|0;n=j&16777215;j=n+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){k=c[f+32>>2]|0;u=(d[k+n>>0]<<8|d[k+j>>0])&65535}else{u=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[s>>1]=u;if((a[f+336>>0]|0)==0){c[t>>2]=(c[t>>2]|0)+2;t=f+152|0;c[t>>2]=(c[t>>2]|0)+2;Mo(f,h)|0;i=g;return}else{Kj(f);i=g;return}}function mm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+16|0;h=g+4|0;j=g+2|0;k=g;l=e[f+160>>1]|0;if((l&48|0)!=0){m=c[f+((l>>>9&7)<<2)+88>>2]|0;n=l&63;if((nc[c[46024+(n<<2)>>2]&63](f,n,508,16)|0)!=0){i=g;return}if((Ko(f,k)|0)!=0){i=g;return}n=b[k>>1]|0;k=(n&65535)-m&65535;o=f+372|0;c[o>>2]=(c[o>>2]|0)+8;po(f,k,m&65535,n);n=f+156|0;m=c[n>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}o=f+164|0;b[f+162>>1]=b[o>>1]|0;p=m&16777215;m=p+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+p>>0]<<8|d[q+m>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=r;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;No(f,k)|0;i=g;return}else{Kj(f);i=g;return}}k=l&7;n=l>>>9&7;if((l&8|0)==0){s=k;t=n}else{s=k|32;t=n|32}if((nc[c[46024+(s<<2)>>2]&63](f,s,17,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}if((nc[c[46024+(t<<2)>>2]&63](f,t,17,16)|0)!=0){i=g;return}if((Ko(f,j)|0)!=0){i=g;return}t=b[j>>1]|0;j=b[h>>1]|0;h=(t&65535)-(j&65535)-((e[f+166>>1]|0)>>>4&1)&65535;s=f+372|0;c[s>>2]=(c[s>>2]|0)+8;so(f,h,j,t);t=f+156|0;j=c[t>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}s=f+164|0;b[f+162>>1]=b[s>>1]|0;n=j&16777215;j=n+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){k=c[f+32>>2]|0;u=(d[k+n>>0]<<8|d[k+j>>0])&65535}else{u=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[s>>1]=u;if((a[f+336>>0]|0)==0){c[t>>2]=(c[t>>2]|0)+2;t=f+152|0;c[t>>2]=(c[t>>2]|0)+2;No(f,h)|0;i=g;return}else{Kj(f);i=g;return}}function nm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+16|0;h=g+8|0;j=g+4|0;k=g;l=e[f+160>>1]|0;if((l&48|0)!=0){m=c[f+((l>>>9&7)<<2)+88>>2]|0;n=l&63;if((nc[c[46024+(n<<2)>>2]&63](f,n,508,32)|0)!=0){i=g;return}if((Lo(f,k)|0)!=0){i=g;return}n=c[k>>2]|0;k=n-m|0;o=f+372|0;c[o>>2]=(c[o>>2]|0)+12;qo(f,k,m,n);n=f+156|0;m=c[n>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}o=f+164|0;b[f+162>>1]=b[o>>1]|0;p=m&16777215;m=p+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+p>>0]<<8|d[q+m>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=r;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;Oo(f,k)|0;i=g;return}else{Kj(f);i=g;return}}k=l&7;n=l>>>9&7;if((l&8|0)==0){s=k;t=n}else{s=k|32;t=n|32}if((nc[c[46024+(s<<2)>>2]&63](f,s,17,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}if((nc[c[46024+(t<<2)>>2]&63](f,t,17,32)|0)!=0){i=g;return}if((Lo(f,j)|0)!=0){i=g;return}t=c[j>>2]|0;j=c[h>>2]|0;h=t-j-((e[f+166>>1]|0)>>>4&1)|0;s=f+372|0;c[s>>2]=(c[s>>2]|0)+12;to(f,h,j,t);t=f+156|0;j=c[t>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}s=f+164|0;b[f+162>>1]=b[s>>1]|0;n=j&16777215;j=n+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){k=c[f+32>>2]|0;u=(d[k+n>>0]<<8|d[k+j>>0])&65535}else{u=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[s>>1]=u;if((a[f+336>>0]|0)==0){c[t>>2]=(c[t>>2]|0)+2;t=f+152|0;c[t>>2]=(c[t>>2]|0)+2;Oo(f,h)|0;i=g;return}else{Kj(f);i=g;return}}function om(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+120|0;j=c[k>>2]|0;l=c[h>>2]|0;h=f+372|0;c[h>>2]=(c[h>>2]|0)+10;h=f+156|0;m=c[h>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}n=f+164|0;b[f+162>>1]=b[n>>1]|0;o=m&16777215;m=o+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+o>>0]<<8|d[p+m>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[n>>1]=q;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;c[k>>2]=j-l;i=g;return}else{Kj(f);i=g;return}}function pm(a){a=a|0;var c=0;c=i;b[a+328>>1]=b[a+160>>1]|0;Sj(a);i=c;return}function qm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=f+160|0;k=b[j>>1]&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}k=c[f+(((e[j>>1]|0)>>>9&7)<<2)+88>>2]|0;j=f+372|0;c[j>>2]=(c[j>>2]|0)+4;j=a[h>>0]|0;lo(f,k-(j&255)&255,j,k&255);k=f+156|0;j=c[k>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}h=f+164|0;b[f+162>>1]=b[h>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[h>>1]=n;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function rm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=f+160|0;k=b[j>>1]&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=c[f+(((e[j>>1]|0)>>>9&7)<<2)+88>>2]|0;j=f+372|0;c[j>>2]=(c[j>>2]|0)+4;j=b[h>>1]|0;mo(f,k-(j&65535)&65535,j,k&65535);k=f+156|0;j=c[k>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}h=f+164|0;b[f+162>>1]=b[h>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[h>>1]=n;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function sm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=f+160|0;k=b[j>>1]&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}k=c[f+(((e[j>>1]|0)>>>9&7)<<2)+88>>2]|0;j=f+372|0;c[j>>2]=(c[j>>2]|0)+6;j=c[h>>2]|0;no(f,k-j|0,j,k);k=f+156|0;j=c[k>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}h=f+164|0;b[f+162>>1]=b[h>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[h>>1]=n;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function tm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=f+160|0;k=b[j>>1]&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=e[h>>1]|0;h=(k&32768|0)!=0?k|-65536:k;k=c[f+(((e[j>>1]|0)>>>9&7)<<2)+120>>2]|0;j=f+372|0;c[j>>2]=(c[j>>2]|0)+8;no(f,k-h|0,h,k);k=f+156|0;h=c[k>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;l=h&16777215;h=l+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+h>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[j>>1]=n;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function um(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g+2|0;j=g+1|0;k=g;l=f+160|0;m=e[l>>1]|0;if((m&56|0)!=8){n=c[f+((m>>>9&7)<<2)+88>>2]|0;o=m&63;if((nc[c[46024+(o<<2)>>2]&63](f,o,509,8)|0)!=0){i=g;return}if((Jo(f,k)|0)!=0){i=g;return}o=(d[k>>0]^n)&255;n=f+372|0;c[n>>2]=(c[n>>2]|0)+8;bo(f,15,o);n=f+156|0;k=c[n>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}p=f+164|0;b[f+162>>1]=b[p>>1]|0;q=k&16777215;k=q+1|0;if(k>>>0<(c[f+36>>2]|0)>>>0){r=c[f+32>>2]|0;s=(d[r+q>>0]<<8|d[r+k>>0])&65535}else{s=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[p>>1]=s;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;Mo(f,o)|0;i=g;return}else{Kj(f);i=g;return}}o=m&7|24;if((nc[c[46024+(o<<2)>>2]&63](f,o,8,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}o=(e[l>>1]|0)>>>9&7|24;if((nc[c[46024+(o<<2)>>2]&63](f,o,8,8)|0)!=0){i=g;return}if((Jo(f,j)|0)!=0){i=g;return}o=f+372|0;c[o>>2]=(c[o>>2]|0)+16;o=a[j>>0]|0;j=a[h>>0]|0;lo(f,(o&255)-(j&255)&255,j,o);o=f+156|0;j=c[o>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}h=f+164|0;b[f+162>>1]=b[h>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;t=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[h>>1]=t;if((a[f+336>>0]|0)==0){c[o>>2]=(c[o>>2]|0)+2;o=f+152|0;c[o>>2]=(c[o>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function vm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g+4|0;j=g+2|0;k=g;l=f+160|0;m=e[l>>1]|0;if((m&56|0)!=8){n=c[f+((m>>>9&7)<<2)+88>>2]|0;o=m&63;if((nc[c[46024+(o<<2)>>2]&63](f,o,509,16)|0)!=0){i=g;return}if((Ko(f,k)|0)!=0){i=g;return}o=(e[k>>1]^n)&65535;n=f+372|0;c[n>>2]=(c[n>>2]|0)+8;co(f,15,o);n=f+156|0;k=c[n>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}p=f+164|0;b[f+162>>1]=b[p>>1]|0;q=k&16777215;k=q+1|0;if(k>>>0<(c[f+36>>2]|0)>>>0){r=c[f+32>>2]|0;s=(d[r+q>>0]<<8|d[r+k>>0])&65535}else{s=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[p>>1]=s;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;No(f,o)|0;i=g;return}else{Kj(f);i=g;return}}o=m&7|24;if((nc[c[46024+(o<<2)>>2]&63](f,o,8,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}o=(e[l>>1]|0)>>>9&7|24;if((nc[c[46024+(o<<2)>>2]&63](f,o,8,16)|0)!=0){i=g;return}if((Ko(f,j)|0)!=0){i=g;return}o=f+372|0;c[o>>2]=(c[o>>2]|0)+12;o=b[j>>1]|0;j=b[h>>1]|0;mo(f,(o&65535)-(j&65535)&65535,j,o);o=f+156|0;j=c[o>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}h=f+164|0;b[f+162>>1]=b[h>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;t=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[h>>1]=t;if((a[f+336>>0]|0)==0){c[o>>2]=(c[o>>2]|0)+2;o=f+152|0;c[o>>2]=(c[o>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function wm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;i=i+16|0;h=g+8|0;j=g+4|0;k=g;l=f+160|0;m=e[l>>1]|0;if((m&56|0)!=8){n=c[f+((m>>>9&7)<<2)+88>>2]|0;o=m&63;if((nc[c[46024+(o<<2)>>2]&63](f,o,509,32)|0)!=0){i=g;return}if((Lo(f,k)|0)!=0){i=g;return}o=c[k>>2]^n;n=f+372|0;c[n>>2]=(c[n>>2]|0)+12;eo(f,15,o);n=f+156|0;k=c[n>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}p=f+164|0;b[f+162>>1]=b[p>>1]|0;q=k&16777215;k=q+1|0;if(k>>>0<(c[f+36>>2]|0)>>>0){r=c[f+32>>2]|0;s=(d[r+q>>0]<<8|d[r+k>>0])&65535}else{s=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[p>>1]=s;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;Oo(f,o)|0;i=g;return}else{Kj(f);i=g;return}}o=m&7|24;if((nc[c[46024+(o<<2)>>2]&63](f,o,8,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}o=(e[l>>1]|0)>>>9&7|24;if((nc[c[46024+(o<<2)>>2]&63](f,o,8,32)|0)!=0){i=g;return}if((Lo(f,j)|0)!=0){i=g;return}o=f+372|0;c[o>>2]=(c[o>>2]|0)+20;o=c[j>>2]|0;j=c[h>>2]|0;no(f,o-j|0,j,o);o=f+156|0;j=c[o>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}h=f+164|0;b[f+162>>1]=b[h>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;t=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{t=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[h>>1]=t;if((a[f+336>>0]|0)==0){c[o>>2]=(c[o>>2]|0)+2;o=f+152|0;c[o>>2]=(c[o>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function xm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0;g=i;i=i+16|0;h=g;j=f+160|0;k=b[j>>1]&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}k=c[f+(((e[j>>1]|0)>>>9&7)<<2)+120>>2]|0;j=f+372|0;c[j>>2]=(c[j>>2]|0)+8;j=c[h>>2]|0;no(f,k-j|0,j,k);k=f+156|0;j=c[k>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}h=f+164|0;b[f+162>>1]=b[h>>1]|0;l=j&16777215;j=l+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;n=(d[m+l>>0]<<8|d[m+j>>0])&65535}else{n=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[h>>1]=n;if((a[f+336>>0]|0)==0){c[k>>2]=(c[k>>2]|0)+2;k=f+152|0;c[k>>2]=(c[k>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}function ym(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=d[h>>0]&c[k>>2];h=f+372|0;c[h>>2]=(c[h>>2]|0)+4;bo(f,15,j&255);h=f+156|0;l=c[h>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;c[k>>2]=c[k>>2]&-256|j;i=g;return}else{Kj(f);i=g;return}}function zm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=e[h>>1]&c[k>>2];h=f+372|0;c[h>>2]=(c[h>>2]|0)+4;co(f,15,j&65535);h=f+156|0;l=c[h>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;c[k>>2]=c[k>>2]&-65536|j;i=g;return}else{Kj(f);i=g;return}}function Am(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=c[h>>2]&c[k>>2];h=f+372|0;c[h>>2]=(c[h>>2]|0)+6;eo(f,15,j);h=f+156|0;l=c[h>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;c[k>>2]=j;i=g;return}else{Kj(f);i=g;return}}function Bm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=ca(e[h>>1]|0,c[k>>2]&65535)|0;h=f+372|0;c[h>>2]=(c[h>>2]|0)+74;eo(f,15,j);h=f+156|0;l=c[h>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;c[k>>2]=j;i=g;return}else{Kj(f);i=g;return}}function Cm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;g=i;i=i+16|0;h=g+2|0;j=g+1|0;k=g;l=e[f+160>>1]|0;if((l&48|0)!=0){m=c[f+((l>>>9&7)<<2)+88>>2]|0;n=l&63;if((nc[c[46024+(n<<2)>>2]&63](f,n,508,8)|0)!=0){i=g;return}if((Jo(f,k)|0)!=0){i=g;return}n=d[k>>0]&m&255;m=f+372|0;c[m>>2]=(c[m>>2]|0)+4;bo(f,15,n);m=f+156|0;k=c[m>>2]|0;if((k&1|0)!=0){Mj(f,k,0,0);i=g;return}o=f+164|0;b[f+162>>1]=b[o>>1]|0;p=k&16777215;k=p+1|0;if(k>>>0<(c[f+36>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+p>>0]<<8|d[q+k>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=r;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;Mo(f,n)|0;i=g;return}else{Kj(f);i=g;return}}n=l&7;m=l>>>9&7;if((l&8|0)==0){s=n;t=m}else{s=n|32;t=m|32}if((nc[c[46024+(s<<2)>>2]&63](f,s,17,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}if((nc[c[46024+(t<<2)>>2]&63](f,t,17,8)|0)!=0){i=g;return}if((Jo(f,j)|0)!=0){i=g;return}t=d[h>>0]|0;h=d[j>>0]|0;j=f+166|0;s=b[j>>1]|0;m=h+t+((s&65535)>>>4&1)|0;n=((h&15)+(t&15)|0)>9?m+6|0:m;m=n&65535;if((m&65535)>159){u=n+96&65535;v=s&65535|17}else{u=m;v=s&65518}b[j>>1]=(u&255)==0?v:v&65531;v=f+372|0;c[v>>2]=(c[v>>2]|0)+6;v=f+156|0;j=c[v>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}s=f+164|0;b[f+162>>1]=b[s>>1]|0;m=j&16777215;j=m+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;w=(d[n+m>>0]<<8|d[n+j>>0])&65535}else{w=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[s>>1]=w;if((a[f+336>>0]|0)==0){c[v>>2]=(c[v>>2]|0)+2;v=f+152|0;c[v>>2]=(c[v>>2]|0)+2;Mo(f,u&255)|0;i=g;return}else{Kj(f);i=g;return}}function Dm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j>>>3&7;if((k|0)==1){l=f+((j>>>9&7)<<2)+120|0;m=c[l>>2]|0;n=f+((j&7)<<2)+120|0;c[l>>2]=c[n>>2];c[n>>2]=m;m=f+372|0;c[m>>2]=(c[m>>2]|0)+10;m=f+156|0;n=c[m>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;o=n&16777215;n=o+1|0;if(n>>>0<(c[f+36>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+o>>0]<<8|d[p+n>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[l>>1]=q;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else if((k|0)==0){k=f+((j>>>9&7)<<2)+88|0;m=c[k>>2]|0;q=f+((j&7)<<2)+88|0;c[k>>2]=c[q>>2];c[q>>2]=m;m=f+372|0;c[m>>2]=(c[m>>2]|0)+10;m=f+156|0;q=c[m>>2]|0;if((q&1|0)!=0){Mj(f,q,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;l=q&16777215;q=l+1|0;if(q>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;r=(d[o+l>>0]<<8|d[o+q>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,l)|0}b[k>>1]=r;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}else{m=c[f+((j>>>9&7)<<2)+88>>2]|0;r=j&63;if((nc[c[46024+(r<<2)>>2]&63](f,r,508,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}r=e[h>>1]&m&65535;m=f+372|0;c[m>>2]=(c[m>>2]|0)+4;co(f,15,r);m=f+156|0;h=c[m>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;k=h&16777215;h=k+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){l=c[f+32>>2]|0;s=(d[l+k>>0]<<8|d[l+h>>0])&65535}else{s=oc[c[f+12>>2]&31](c[f+4>>2]|0,k)|0}b[j>>1]=s;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;No(f,r)|0;i=g;return}else{Kj(f);i=g;return}}}function Em(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j>>>9&7;if((j&56|0)==8){l=f+(k<<2)+88|0;m=c[l>>2]|0;n=f+((j&7)<<2)+120|0;c[l>>2]=c[n>>2];c[n>>2]=m;m=f+372|0;c[m>>2]=(c[m>>2]|0)+10;m=f+156|0;n=c[m>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;o=n&16777215;n=o+1|0;if(n>>>0<(c[f+36>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+o>>0]<<8|d[p+n>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[l>>1]=q;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;i=g;return}else{Kj(f);i=g;return}}m=c[f+(k<<2)+88>>2]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,508,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}k=c[h>>2]&m;m=f+372|0;c[m>>2]=(c[m>>2]|0)+6;eo(f,15,k);m=f+156|0;h=c[m>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;q=h&16777215;h=q+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){l=c[f+32>>2]|0;r=(d[l+q>>0]<<8|d[l+h>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[j>>1]=r;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;Oo(f,k)|0;i=g;return}else{Kj(f);i=g;return}}function Fm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=c[k>>2]|0;l=b[h>>1]|0;m=l&65535;if((m&32768|0)==0){n=l;o=0}else{l=0-m&65535;b[h>>1]=l;n=l;o=1}if((j&32768|0)==0){p=0;q=j}else{p=1;q=(j^65535)+1&65535}j=ca(n&65535,q&65535)|0;q=(o|0)==(p|0)?j:0-j|0;j=f+372|0;c[j>>2]=(c[j>>2]|0)+74;eo(f,15,q);j=f+156|0;p=c[j>>2]|0;if((p&1|0)!=0){Mj(f,p,0,0);i=g;return}o=f+164|0;b[f+162>>1]=b[o>>1]|0;n=p&16777215;p=n+1|0;if(p>>>0<(c[f+36>>2]|0)>>>0){l=c[f+32>>2]|0;r=(d[l+n>>0]<<8|d[l+p>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[o>>1]=r;if((a[f+336>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;j=f+152|0;c[j>>2]=(c[j>>2]|0)+2;c[k>>2]=q;i=g;return}else{Kj(f);i=g;return}}function Gm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4093,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=c[k>>2]|0;l=a[h>>0]|0;h=(l&255)+j|0;m=f+372|0;c[m>>2]=(c[m>>2]|0)+4;fo(f,h&255,l,j&255);j=f+156|0;l=c[j>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;j=f+152|0;c[j>>2]=(c[j>>2]|0)+2;c[k>>2]=c[k>>2]&-256|h&255;i=g;return}else{Kj(f);i=g;return}}function Hm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=c[k>>2]|0;l=b[h>>1]|0;h=(l&65535)+j|0;m=f+372|0;c[m>>2]=(c[m>>2]|0)+4;go(f,h&65535,l,j&65535);j=f+156|0;l=c[j>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;j=f+152|0;c[j>>2]=(c[j>>2]|0)+2;c[k>>2]=c[k>>2]&-65536|h&65535;i=g;return}else{Kj(f);i=g;return}}function Im(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+88|0;j=c[k>>2]|0;l=c[h>>2]|0;h=l+j|0;m=f+372|0;c[m>>2]=(c[m>>2]|0)+6;ho(f,h,l,j);j=f+156|0;l=c[j>>2]|0;if((l&1|0)!=0){Mj(f,l,0,0);i=g;return}m=f+164|0;b[f+162>>1]=b[m>>1]|0;n=l&16777215;l=n+1|0;if(l>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;p=(d[o+n>>0]<<8|d[o+l>>0])&65535}else{p=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[m>>1]=p;if((a[f+336>>0]|0)==0){c[j>>2]=(c[j>>2]|0)+2;j=f+152|0;c[j>>2]=(c[j>>2]|0)+2;c[k>>2]=h;i=g;return}else{Kj(f);i=g;return}}function Jm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}k=e[h>>1]|0;h=f+((j>>>9&7)<<2)+120|0;j=c[h>>2]|0;l=f+372|0;c[l>>2]=(c[l>>2]|0)+8;l=f+156|0;m=c[l>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}n=f+164|0;b[f+162>>1]=b[n>>1]|0;o=m&16777215;m=o+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+o>>0]<<8|d[p+m>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[n>>1]=q;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;c[h>>2]=((k&32768|0)!=0?k|-65536:k)+j;i=g;return}else{Kj(f);i=g;return}}function Km(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+16|0;h=g+2|0;j=g+1|0;k=g;l=e[f+160>>1]|0;if((l&48|0)!=0){m=c[f+((l>>>9&7)<<2)+88>>2]|0;n=l&63;if((nc[c[46024+(n<<2)>>2]&63](f,n,508,8)|0)!=0){i=g;return}if((Jo(f,k)|0)!=0){i=g;return}n=a[k>>0]|0;k=(n&255)+m&255;o=f+372|0;c[o>>2]=(c[o>>2]|0)+8;fo(f,k,m&255,n);n=f+156|0;m=c[n>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}o=f+164|0;b[f+162>>1]=b[o>>1]|0;p=m&16777215;m=p+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+p>>0]<<8|d[q+m>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=r;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;Mo(f,k)|0;i=g;return}else{Kj(f);i=g;return}}k=l&7;n=l>>>9&7;if((l&8|0)==0){s=k;t=n}else{s=k|32;t=n|32}if((nc[c[46024+(s<<2)>>2]&63](f,s,17,8)|0)!=0){i=g;return}if((Jo(f,h)|0)!=0){i=g;return}if((nc[c[46024+(t<<2)>>2]&63](f,t,17,8)|0)!=0){i=g;return}if((Jo(f,j)|0)!=0){i=g;return}t=a[h>>0]|0;h=a[j>>0]|0;j=(h&255)+(t&255)+((e[f+166>>1]|0)>>>4&1)&255;s=f+372|0;c[s>>2]=(c[s>>2]|0)+8;io(f,j,t,h);h=f+156|0;t=c[h>>2]|0;if((t&1|0)!=0){Mj(f,t,0,0);i=g;return}s=f+164|0;b[f+162>>1]=b[s>>1]|0;n=t&16777215;t=n+1|0;if(t>>>0<(c[f+36>>2]|0)>>>0){k=c[f+32>>2]|0;u=(d[k+n>>0]<<8|d[k+t>>0])&65535}else{u=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[s>>1]=u;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;Mo(f,j)|0;i=g;return}else{Kj(f);i=g;return}}function Lm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+16|0;h=g+4|0;j=g+2|0;k=g;l=e[f+160>>1]|0;if((l&48|0)!=0){m=c[f+((l>>>9&7)<<2)+88>>2]|0;n=l&63;if((nc[c[46024+(n<<2)>>2]&63](f,n,508,16)|0)!=0){i=g;return}if((Ko(f,k)|0)!=0){i=g;return}n=b[k>>1]|0;k=(n&65535)+m&65535;o=f+372|0;c[o>>2]=(c[o>>2]|0)+8;go(f,k,m&65535,n);n=f+156|0;m=c[n>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}o=f+164|0;b[f+162>>1]=b[o>>1]|0;p=m&16777215;m=p+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+p>>0]<<8|d[q+m>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=r;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;No(f,k)|0;i=g;return}else{Kj(f);i=g;return}}k=l&7;n=l>>>9&7;if((l&8|0)==0){s=k;t=n}else{s=k|32;t=n|32}if((nc[c[46024+(s<<2)>>2]&63](f,s,17,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}if((nc[c[46024+(t<<2)>>2]&63](f,t,17,16)|0)!=0){i=g;return}if((Ko(f,j)|0)!=0){i=g;return}t=b[h>>1]|0;h=b[j>>1]|0;j=(h&65535)+(t&65535)+((e[f+166>>1]|0)>>>4&1)&65535;s=f+372|0;c[s>>2]=(c[s>>2]|0)+8;jo(f,j,t,h);h=f+156|0;t=c[h>>2]|0;if((t&1|0)!=0){Mj(f,t,0,0);i=g;return}s=f+164|0;b[f+162>>1]=b[s>>1]|0;n=t&16777215;t=n+1|0;if(t>>>0<(c[f+36>>2]|0)>>>0){k=c[f+32>>2]|0;u=(d[k+n>>0]<<8|d[k+t>>0])&65535}else{u=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[s>>1]=u;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;No(f,j)|0;i=g;return}else{Kj(f);i=g;return}}function Mm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;i=i+16|0;h=g+8|0;j=g+4|0;k=g;l=e[f+160>>1]|0;if((l&48|0)!=0){m=c[f+((l>>>9&7)<<2)+88>>2]|0;n=l&63;if((nc[c[46024+(n<<2)>>2]&63](f,n,508,32)|0)!=0){i=g;return}if((Lo(f,k)|0)!=0){i=g;return}n=c[k>>2]|0;k=n+m|0;o=f+372|0;c[o>>2]=(c[o>>2]|0)+12;ho(f,k,m,n);n=f+156|0;m=c[n>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}o=f+164|0;b[f+162>>1]=b[o>>1]|0;p=m&16777215;m=p+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){q=c[f+32>>2]|0;r=(d[q+p>>0]<<8|d[q+m>>0])&65535}else{r=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[o>>1]=r;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;Oo(f,k)|0;i=g;return}else{Kj(f);i=g;return}}k=l&7;n=l>>>9&7;if((l&8|0)==0){s=k;t=n}else{s=k|32;t=n|32}if((nc[c[46024+(s<<2)>>2]&63](f,s,17,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}if((nc[c[46024+(t<<2)>>2]&63](f,t,17,32)|0)!=0){i=g;return}if((Lo(f,j)|0)!=0){i=g;return}t=c[h>>2]|0;h=c[j>>2]|0;j=h+t+((e[f+166>>1]|0)>>>4&1)|0;s=f+372|0;c[s>>2]=(c[s>>2]|0)+12;ko(f,j,t,h);h=f+156|0;t=c[h>>2]|0;if((t&1|0)!=0){Mj(f,t,0,0);i=g;return}s=f+164|0;b[f+162>>1]=b[s>>1]|0;n=t&16777215;t=n+1|0;if(t>>>0<(c[f+36>>2]|0)>>>0){k=c[f+32>>2]|0;u=(d[k+n>>0]<<8|d[k+t>>0])&65535}else{u=oc[c[f+12>>2]&31](c[f+4>>2]|0,n)|0}b[s>>1]=u;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;Oo(f,j)|0;i=g;return}else{Kj(f);i=g;return}}function Nm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+16|0;h=g;j=e[f+160>>1]|0;k=j&63;if((nc[c[46024+(k<<2)>>2]&63](f,k,4095,32)|0)!=0){i=g;return}if((Lo(f,h)|0)!=0){i=g;return}k=f+((j>>>9&7)<<2)+120|0;j=c[k>>2]|0;l=c[h>>2]|0;h=f+372|0;c[h>>2]=(c[h>>2]|0)+6;h=f+156|0;m=c[h>>2]|0;if((m&1|0)!=0){Mj(f,m,0,0);i=g;return}n=f+164|0;b[f+162>>1]=b[n>>1]|0;o=m&16777215;m=o+1|0;if(m>>>0<(c[f+36>>2]|0)>>>0){p=c[f+32>>2]|0;q=(d[p+o>>0]<<8|d[p+m>>0])&65535}else{q=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[n>>1]=q;if((a[f+336>>0]|0)==0){c[h>>2]=(c[h>>2]|0)+2;h=f+152|0;c[h>>2]=(c[h>>2]|0)+2;c[k>>2]=l+j;i=g;return}else{Kj(f);i=g;return}}function Om(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;g=i;h=e[f+160>>1]|0;j=h>>>3&3;if((j|0)==1){k=f+((h&7)<<2)+88|0;l=c[k>>2]|0;m=h>>>9&7;if((h&32|0)==0){n=(m|0)==0?8:m;o=25}else{p=c[f+(m<<2)+88>>2]&63;if((p|0)==0){m=f+166|0;b[m>>1]=b[m>>1]&65534;q=0;r=l&255}else{n=p;o=25}}do{if((o|0)==25){if(n>>>0<8){p=l&255;m=p>>>n&255;s=f+166|0;t=e[s>>1]|0;if((1<<n+ -1&p|0)==0){b[s>>1]=t&65518;q=n;r=m;break}else{b[s>>1]=t|17;q=n;r=m;break}}if((n|0)==8){if((l&128|0)!=0){m=f+166|0;b[m>>1]=e[m>>1]|17;q=8;r=0;break}}m=f+166|0;b[m>>1]=b[m>>1]&65518;q=n;r=0}}while(0);n=f+372|0;c[n>>2]=(q<<1)+6+(c[n>>2]|0);bo(f,14,r);n=f+156|0;q=c[n>>2]|0;if((q&1|0)!=0){Mj(f,q,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;m=q&16777215;q=m+1|0;if(q>>>0<(c[f+36>>2]|0)>>>0){t=c[f+32>>2]|0;u=(d[t+m>>0]<<8|d[t+q>>0])&65535}else{u=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=u;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;c[k>>2]=c[k>>2]&-256|r&255;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==0){r=h&7;k=h>>>9&7;if((h&32|0)==0){n=f+(r<<2)+88|0;v=(k|0)==0?8:k;w=c[n>>2]|0;x=n;o=6}else{n=c[f+(k<<2)+88>>2]&63;k=f+(r<<2)+88|0;r=c[k>>2]|0;if((n|0)==0){u=f+166|0;b[u>>1]=b[u>>1]&65534;y=0;z=k;A=r&255}else{v=n;w=r;x=k;o=6}}do{if((o|0)==6){k=w&255;r=(w&128|0)!=0;if(v>>>0<8){n=(r?k|65280:k)>>>v&255;u=f+166|0;l=e[u>>1]|0;if((1<<v+ -1&k|0)==0){b[u>>1]=l&65518;y=v;z=x;A=n;break}else{b[u>>1]=l|17;y=v;z=x;A=n;break}}else{n=f+166|0;l=e[n>>1]|0;if(r){b[n>>1]=l|17;y=v;z=x;A=-1;break}else{b[n>>1]=l&65518;y=v;z=x;A=0;break}}}}while(0);x=f+372|0;c[x>>2]=(y<<1)+6+(c[x>>2]|0);bo(f,14,A);x=f+156|0;y=c[x>>2]|0;if((y&1|0)!=0){Mj(f,y,0,0);i=g;return}v=f+164|0;b[f+162>>1]=b[v>>1]|0;w=y&16777215;y=w+1|0;if(y>>>0<(c[f+36>>2]|0)>>>0){l=c[f+32>>2]|0;B=(d[l+w>>0]<<8|d[l+y>>0])&65535}else{B=oc[c[f+12>>2]&31](c[f+4>>2]|0,w)|0}b[v>>1]=B;if((a[f+336>>0]|0)==0){c[x>>2]=(c[x>>2]|0)+2;x=f+152|0;c[x>>2]=(c[x>>2]|0)+2;c[z>>2]=c[z>>2]&-256|A&255;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==2){A=f+((h&7)<<2)+88|0;z=c[A>>2]&255;x=f+166|0;B=(e[x>>1]|0)>>>4&1;v=h>>>9&7;if((h&32|0)==0){C=(v|0)==0?8:v;o=44}else{w=c[f+(v<<2)+88>>2]&63;if((w|0)==0){D=0;E=z;F=B}else{C=w;o=44}}if((o|0)==44){o=0;w=z;z=B;while(1){B=w&1;v=(z&65535)<<7|w>>>1&32767;y=o+1|0;if((y|0)==(C|0)){D=C;E=v;F=B;break}else{o=y;w=v;z=B}}}z=f+372|0;c[z>>2]=(D<<1)+6+(c[z>>2]|0);bo(f,14,E&255);z=e[x>>1]|0;b[x>>1]=F<<16>>16==0?z&65518:z|17;z=f+156|0;F=c[z>>2]|0;if((F&1|0)!=0){Mj(f,F,0,0);i=g;return}x=f+164|0;b[f+162>>1]=b[x>>1]|0;D=F&16777215;F=D+1|0;if(F>>>0<(c[f+36>>2]|0)>>>0){w=c[f+32>>2]|0;G=(d[w+D>>0]<<8|d[w+F>>0])&65535}else{G=oc[c[f+12>>2]&31](c[f+4>>2]|0,D)|0}b[x>>1]=G;if((a[f+336>>0]|0)==0){c[z>>2]=(c[z>>2]|0)+2;z=f+152|0;c[z>>2]=(c[z>>2]|0)+2;c[A>>2]=c[A>>2]&-256|E&255;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==3){j=f+((h&7)<<2)+88|0;E=c[j>>2]|0;A=E&255;z=h>>>9&7;if((h&32|0)==0){H=(z|0)==0?8:z}else{H=c[f+(z<<2)+88>>2]&63}z=H&7;do{if((z|0)==0){if((H|0)!=0){if((E&128|0)!=0){h=f+166|0;b[h>>1]=e[h>>1]|1;I=A;break}}h=f+166|0;b[h>>1]=b[h>>1]&65534;I=A}else{h=E&255;G=h<<8-z|h>>>z;h=G&255;x=f+166|0;D=e[x>>1]|0;if((G&128|0)==0){b[x>>1]=D&65534;I=h;break}else{b[x>>1]=D|1;I=h;break}}}while(0);z=f+372|0;c[z>>2]=(H<<1)+6+(c[z>>2]|0);bo(f,14,I);z=f+156|0;H=c[z>>2]|0;if((H&1|0)!=0){Mj(f,H,0,0);i=g;return}E=f+164|0;b[f+162>>1]=b[E>>1]|0;A=H&16777215;H=A+1|0;if(H>>>0<(c[f+36>>2]|0)>>>0){h=c[f+32>>2]|0;J=(d[h+A>>0]<<8|d[h+H>>0])&65535}else{J=oc[c[f+12>>2]&31](c[f+4>>2]|0,A)|0}b[E>>1]=J;if((a[f+336>>0]|0)==0){c[z>>2]=(c[z>>2]|0)+2;z=f+152|0;c[z>>2]=(c[z>>2]|0)+2;c[j>>2]=c[j>>2]&-256|I&255;i=g;return}else{Kj(f);i=g;return}}else{Nj(f);I=f+372|0;c[I>>2]=(c[I>>2]|0)+2;i=g;return}}function Pm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=i;h=e[f+160>>1]|0;j=h>>>3&3;if((j|0)==2){k=f+((h&7)<<2)+88|0;l=c[k>>2]|0;m=h>>>9&7;if((h&32|0)==0){n=f+166|0;o=(m|0)==0?8:m;p=(e[n>>1]|0)>>>4&1;q=n;r=44}else{n=c[f+(m<<2)+88>>2]&63;m=f+166|0;s=(e[m>>1]|0)>>>4&1;if((n|0)==0){t=0;u=m;v=l;w=s}else{o=n;p=s;q=m;r=44}}if((r|0)==44){m=l;l=0;s=p;while(1){p=m&1;n=(s&65535)<<15|m>>>1&32767;x=l+1|0;if((x|0)==(o|0)){t=o;u=q;v=n;w=p;break}else{m=n;l=x;s=p}}}s=f+372|0;c[s>>2]=(t<<1)+6+(c[s>>2]|0);co(f,14,v&65535);s=e[u>>1]|0;b[u>>1]=w<<16>>16==0?s&65518:s|17;s=f+156|0;w=c[s>>2]|0;if((w&1|0)!=0){Mj(f,w,0,0);i=g;return}u=f+164|0;b[f+162>>1]=b[u>>1]|0;t=w&16777215;w=t+1|0;if(w>>>0<(c[f+36>>2]|0)>>>0){l=c[f+32>>2]|0;y=(d[l+t>>0]<<8|d[l+w>>0])&65535}else{y=oc[c[f+12>>2]&31](c[f+4>>2]|0,t)|0}b[u>>1]=y;if((a[f+336>>0]|0)==0){c[s>>2]=(c[s>>2]|0)+2;s=f+152|0;c[s>>2]=(c[s>>2]|0)+2;c[k>>2]=c[k>>2]&-65536|v&65535;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==1){v=f+((h&7)<<2)+88|0;k=c[v>>2]|0;s=h>>>9&7;do{if((h&32|0)==0){z=(s|0)==0?8:s;r=26}else{y=c[f+(s<<2)+88>>2]&63;if((y|0)==0){u=f+166|0;b[u>>1]=b[u>>1]&65534;A=0;B=k&65535;break}if(y>>>0<16){z=y;r=26}else{if((y|0)==16){if((k&32768|0)!=0){u=f+166|0;b[u>>1]=e[u>>1]|17;A=16;B=0;break}}u=f+166|0;b[u>>1]=b[u>>1]&65518;A=y;B=0}}}while(0);do{if((r|0)==26){s=k&65535;y=s>>>z&65535;u=f+166|0;t=e[u>>1]|0;if((1<<z+ -1&s|0)==0){b[u>>1]=t&65518;A=z;B=y;break}else{b[u>>1]=t|17;A=z;B=y;break}}}while(0);z=f+372|0;c[z>>2]=(A<<1)+6+(c[z>>2]|0);co(f,14,B);z=f+156|0;A=c[z>>2]|0;if((A&1|0)!=0){Mj(f,A,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;y=A&16777215;A=y+1|0;if(A>>>0<(c[f+36>>2]|0)>>>0){t=c[f+32>>2]|0;C=(d[t+y>>0]<<8|d[t+A>>0])&65535}else{C=oc[c[f+12>>2]&31](c[f+4>>2]|0,y)|0}b[k>>1]=C;if((a[f+336>>0]|0)==0){c[z>>2]=(c[z>>2]|0)+2;z=f+152|0;c[z>>2]=(c[z>>2]|0)+2;c[v>>2]=c[v>>2]&-65536|B&65535;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==0){B=f+((h&7)<<2)+88|0;v=c[B>>2]|0;z=h>>>9&7;do{if((h&32|0)==0){D=(z|0)==0?8:z;E=(v&32768|0)!=0;r=7}else{C=c[f+(z<<2)+88>>2]&63;if((C|0)==0){k=f+166|0;b[k>>1]=b[k>>1]&65534;F=0;G=v&65535;break}k=(v&32768|0)!=0;if(C>>>0<16){D=C;E=k;r=7}else{y=f+166|0;A=e[y>>1]|0;if(k){b[y>>1]=A|17;F=C;G=-1;break}else{b[y>>1]=A&65518;F=C;G=0;break}}}}while(0);do{if((r|0)==7){z=v&65535;C=(E?v|-65536:z)>>>D&65535;A=f+166|0;y=e[A>>1]|0;if((1<<D+ -1&z|0)==0){b[A>>1]=y&65518;F=D;G=C;break}else{b[A>>1]=y|17;F=D;G=C;break}}}while(0);D=f+372|0;c[D>>2]=(F<<1)+6+(c[D>>2]|0);co(f,14,G);D=f+156|0;F=c[D>>2]|0;if((F&1|0)!=0){Mj(f,F,0,0);i=g;return}v=f+164|0;b[f+162>>1]=b[v>>1]|0;E=F&16777215;F=E+1|0;if(F>>>0<(c[f+36>>2]|0)>>>0){r=c[f+32>>2]|0;H=(d[r+E>>0]<<8|d[r+F>>0])&65535}else{H=oc[c[f+12>>2]&31](c[f+4>>2]|0,E)|0}b[v>>1]=H;if((a[f+336>>0]|0)==0){c[D>>2]=(c[D>>2]|0)+2;D=f+152|0;c[D>>2]=(c[D>>2]|0)+2;c[B>>2]=c[B>>2]&-65536|G&65535;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==3){j=f+((h&7)<<2)+88|0;G=c[j>>2]|0;B=G&65535;D=h>>>9&7;if((h&32|0)==0){I=(D|0)==0?8:D}else{I=c[f+(D<<2)+88>>2]&63}do{if((I&15|0)==0){if((I|0)!=0){if((G&32768|0)!=0){D=f+166|0;b[D>>1]=e[D>>1]|1;J=B;break}}D=f+166|0;b[D>>1]=b[D>>1]&65534;J=B}else{D=G&65535;h=D<<16-I|D>>>I;D=h&65535;H=f+166|0;v=e[H>>1]|0;if((h&32768|0)==0){b[H>>1]=v&65534;J=D;break}else{b[H>>1]=v|1;J=D;break}}}while(0);G=f+372|0;c[G>>2]=(I<<1)+6+(c[G>>2]|0);co(f,14,J);G=f+156|0;I=c[G>>2]|0;if((I&1|0)!=0){Mj(f,I,0,0);i=g;return}B=f+164|0;b[f+162>>1]=b[B>>1]|0;D=I&16777215;I=D+1|0;if(I>>>0<(c[f+36>>2]|0)>>>0){v=c[f+32>>2]|0;K=(d[v+D>>0]<<8|d[v+I>>0])&65535}else{K=oc[c[f+12>>2]&31](c[f+4>>2]|0,D)|0}b[B>>1]=K;if((a[f+336>>0]|0)==0){c[G>>2]=(c[G>>2]|0)+2;G=f+152|0;c[G>>2]=(c[G>>2]|0)+2;c[j>>2]=c[j>>2]&-65536|J&65535;i=g;return}else{Kj(f);i=g;return}}else{Nj(f);J=f+372|0;c[J>>2]=(c[J>>2]|0)+2;i=g;return}}function Qm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=i;h=e[f+160>>1]|0;j=h>>>3&3;if((j|0)==3){k=f+((h&7)<<2)+88|0;l=c[k>>2]|0;m=h>>>9&7;if((h&32|0)==0){n=(m|0)==0?8:m}else{n=c[f+(m<<2)+88>>2]&63}m=n&31;do{if((m|0)==0){o=f+166|0;p=e[o>>1]|0;if((n|0)!=0&(l|0)<0){b[o>>1]=p|1;q=l;break}else{b[o>>1]=p&65534;q=l;break}}else{p=l<<32-m|l>>>m;o=f+166|0;r=e[o>>1]|0;if((p|0)<0){b[o>>1]=r|1;q=p;break}else{b[o>>1]=r&65534;q=p;break}}}while(0);m=f+372|0;c[m>>2]=(n<<1)+8+(c[m>>2]|0);eo(f,14,q);m=f+156|0;n=c[m>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;p=n&16777215;n=p+1|0;if(n>>>0<(c[f+36>>2]|0)>>>0){r=c[f+32>>2]|0;s=(d[r+p>>0]<<8|d[r+n>>0])&65535}else{s=oc[c[f+12>>2]&31](c[f+4>>2]|0,p)|0}b[l>>1]=s;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;c[k>>2]=q;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==1){q=f+((h&7)<<2)+88|0;k=c[q>>2]|0;m=h>>>9&7;do{if((h&32|0)==0){t=(m|0)==0?8:m;u=28}else{s=c[f+(m<<2)+88>>2]&63;if((s|0)==0){l=f+166|0;b[l>>1]=b[l>>1]&65534;v=0;w=k;break}if(s>>>0<32){t=s;u=28}else{l=f+166|0;p=e[l>>1]|0;if((s|0)==32&(k|0)<0){b[l>>1]=p|17;v=32;w=0;break}else{b[l>>1]=p&65518;v=s;w=0;break}}}}while(0);do{if((u|0)==28){m=k>>>t;s=f+166|0;p=e[s>>1]|0;if((1<<t+ -1&k|0)==0){b[s>>1]=p&65518;v=t;w=m;break}else{b[s>>1]=p|17;v=t;w=m;break}}}while(0);t=f+372|0;c[t>>2]=(v<<1)+8+(c[t>>2]|0);eo(f,14,w);t=f+156|0;v=c[t>>2]|0;if((v&1|0)!=0){Mj(f,v,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;m=v&16777215;v=m+1|0;if(v>>>0<(c[f+36>>2]|0)>>>0){p=c[f+32>>2]|0;x=(d[p+m>>0]<<8|d[p+v>>0])&65535}else{x=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[k>>1]=x;if((a[f+336>>0]|0)==0){c[t>>2]=(c[t>>2]|0)+2;t=f+152|0;c[t>>2]=(c[t>>2]|0)+2;c[q>>2]=w;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==0){w=f+((h&7)<<2)+88|0;q=c[w>>2]|0;t=h>>>9&7;do{if((h&32|0)==0){x=(t|0)==0?8:t;k=q>>>x;if((q|0)<0){y=x;z=k;u=8}else{A=x;B=k;u=9}}else{k=c[f+(t<<2)+88>>2]&63;if((k|0)==0){x=f+166|0;b[x>>1]=b[x>>1]&65534;C=0;D=q;break}x=(q|0)<0;if(k>>>0<32){m=q>>>k;if(x){y=k;z=m;u=8;break}else{A=k;B=m;u=9;break}}m=f+166|0;v=e[m>>1]|0;if(x){b[m>>1]=v|17;C=k;D=-1;break}else{b[m>>1]=v&65518;C=k;D=0;break}}}while(0);if((u|0)==8){A=y;B=-1<<32-y|z;u=9}do{if((u|0)==9){z=f+166|0;y=e[z>>1]|0;if((1<<A+ -1&q|0)==0){b[z>>1]=y&65518;C=A;D=B;break}else{b[z>>1]=y|17;C=A;D=B;break}}}while(0);B=f+372|0;c[B>>2]=(C<<1)+8+(c[B>>2]|0);eo(f,14,D);B=f+156|0;C=c[B>>2]|0;if((C&1|0)!=0){Mj(f,C,0,0);i=g;return}A=f+164|0;b[f+162>>1]=b[A>>1]|0;q=C&16777215;C=q+1|0;if(C>>>0<(c[f+36>>2]|0)>>>0){y=c[f+32>>2]|0;E=(d[y+q>>0]<<8|d[y+C>>0])&65535}else{E=oc[c[f+12>>2]&31](c[f+4>>2]|0,q)|0}b[A>>1]=E;if((a[f+336>>0]|0)==0){c[B>>2]=(c[B>>2]|0)+2;B=f+152|0;c[B>>2]=(c[B>>2]|0)+2;c[w>>2]=D;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==2){j=f+((h&7)<<2)+88|0;D=c[j>>2]|0;w=h>>>9&7;if((h&32|0)==0){h=f+166|0;F=(w|0)==0?8:w;G=(e[h>>1]|0)>>>4&1;H=h;u=45}else{h=c[f+(w<<2)+88>>2]&63;w=f+166|0;B=(e[w>>1]|0)>>>4&1;if((h|0)==0){I=0;J=w;K=D;L=B}else{F=h;G=B;H=w;u=45}}if((u|0)==45){u=D;D=0;w=G;while(1){G=u&1;B=w<<31|u>>>1;h=D+1|0;if((h|0)==(F|0)){I=F;J=H;K=B;L=G;break}else{u=B;D=h;w=G}}}w=f+372|0;c[w>>2]=(I<<1)+8+(c[w>>2]|0);eo(f,14,K);w=e[J>>1]|0;b[J>>1]=(L|0)==0?w&65518:w|17;w=f+156|0;L=c[w>>2]|0;if((L&1|0)!=0){Mj(f,L,0,0);i=g;return}J=f+164|0;b[f+162>>1]=b[J>>1]|0;I=L&16777215;L=I+1|0;if(L>>>0<(c[f+36>>2]|0)>>>0){D=c[f+32>>2]|0;M=(d[D+I>>0]<<8|d[D+L>>0])&65535}else{M=oc[c[f+12>>2]&31](c[f+4>>2]|0,I)|0}b[J>>1]=M;if((a[f+336>>0]|0)==0){c[w>>2]=(c[w>>2]|0)+2;w=f+152|0;c[w>>2]=(c[w>>2]|0)+2;c[j>>2]=K;i=g;return}else{Kj(f);i=g;return}}else{Nj(f);K=f+372|0;c[K>>2]=(c[K>>2]|0)+2;i=g;return}}function Rm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,508,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}j=e[h>>1]|0;k=(j>>>1|j&32768)&65535;j=f+372|0;c[j>>2]=(c[j>>2]|0)+8;co(f,14,k);j=f+166|0;l=e[j>>1]|0;b[j>>1]=(b[h>>1]&1)==0?l&65518:l|17;l=f+156|0;h=c[l>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+h>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[j>>1]=o;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;No(f,k)|0;i=g;return}else{Kj(f);i=g;return}}function Sm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=i;h=e[f+160>>1]|0;j=h>>>3&3;if((j|0)==3){k=f+((h&7)<<2)+88|0;l=c[k>>2]|0;m=l&255;n=h>>>9&7;if((h&32|0)==0){o=(n|0)==0?8:n}else{o=c[f+(n<<2)+88>>2]&63}n=o&7;do{if((n|0)==0){if((o|0)!=0){if((l&1|0)!=0){p=f+166|0;b[p>>1]=e[p>>1]|1;q=m;break}}p=f+166|0;b[p>>1]=b[p>>1]&65534;q=m}else{p=l&255;r=p>>>(8-n|0)|p<<n;p=r&255;s=f+166|0;t=e[s>>1]|0;if((r&1|0)==0){b[s>>1]=t&65534;q=p;break}else{b[s>>1]=t|1;q=p;break}}}while(0);n=f+372|0;c[n>>2]=(o<<1)+6+(c[n>>2]|0);bo(f,14,q);n=f+156|0;o=c[n>>2]|0;if((o&1|0)!=0){Mj(f,o,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;m=o&16777215;o=m+1|0;if(o>>>0<(c[f+36>>2]|0)>>>0){p=c[f+32>>2]|0;u=(d[p+m>>0]<<8|d[p+o>>0])&65535}else{u=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[l>>1]=u;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;c[k>>2]=c[k>>2]&-256|q&255;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==0){q=f+((h&7)<<2)+88|0;k=c[q>>2]|0;n=h>>>9&7;if((h&32|0)==0){v=(n|0)==0?8:n;w=6}else{u=c[f+(n<<2)+88>>2]&63;if((u|0)==0){n=f+166|0;b[n>>1]=b[n>>1]&65532;x=0;y=k&255}else{v=u;w=6}}do{if((w|0)==6){if(v>>>0<8){u=k&255;n=u<<v&255;l=f+166|0;m=e[l>>1]|0;o=(1<<8-v&u|0)==0?m&65518:m|17;b[l>>1]=o;m=255<<7-v&255;u=m&k;if((u|0)==0|(u|0)==(m|0)){b[l>>1]=o&65533;x=v;y=n;break}else{b[l>>1]=o|2;x=v;y=n;break}}if((v|0)==8){if((k&1|0)==0){w=13}else{n=f+166|0;o=e[n>>1]|17;b[n>>1]=o;z=o}}else{w=13}if((w|0)==13){o=f+166|0;n=b[o>>1]&65518;b[o>>1]=n;z=n}n=f+166|0;if((k&255|0)==0){b[n>>1]=z&65533;x=v;y=0;break}else{b[n>>1]=z|2;x=v;y=0;break}}}while(0);v=f+372|0;c[v>>2]=(x<<1)+6+(c[v>>2]|0);bo(f,12,y);v=f+156|0;x=c[v>>2]|0;if((x&1|0)!=0){Mj(f,x,0,0);i=g;return}z=f+164|0;b[f+162>>1]=b[z>>1]|0;k=x&16777215;x=k+1|0;if(x>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;A=(d[n+k>>0]<<8|d[n+x>>0])&65535}else{A=oc[c[f+12>>2]&31](c[f+4>>2]|0,k)|0}b[z>>1]=A;if((a[f+336>>0]|0)==0){c[v>>2]=(c[v>>2]|0)+2;v=f+152|0;c[v>>2]=(c[v>>2]|0)+2;c[q>>2]=c[q>>2]&-256|y&255;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==1){y=f+((h&7)<<2)+88|0;q=c[y>>2]|0;v=h>>>9&7;if((h&32|0)==0){B=(v|0)==0?8:v;w=29}else{A=c[f+(v<<2)+88>>2]&63;if((A|0)==0){v=f+166|0;b[v>>1]=b[v>>1]&65534;C=0;D=q&255}else{B=A;w=29}}do{if((w|0)==29){if(B>>>0<8){A=q&255;v=A<<B&255;z=f+166|0;k=e[z>>1]|0;if((1<<8-B&A|0)==0){b[z>>1]=k&65518;C=B;D=v;break}else{b[z>>1]=k|17;C=B;D=v;break}}if((B|0)==8){if((q&1|0)!=0){v=f+166|0;b[v>>1]=e[v>>1]|17;C=8;D=0;break}}v=f+166|0;b[v>>1]=b[v>>1]&65518;C=B;D=0}}while(0);B=f+372|0;c[B>>2]=(C<<1)+6+(c[B>>2]|0);bo(f,14,D);B=f+156|0;C=c[B>>2]|0;if((C&1|0)!=0){Mj(f,C,0,0);i=g;return}q=f+164|0;b[f+162>>1]=b[q>>1]|0;v=C&16777215;C=v+1|0;if(C>>>0<(c[f+36>>2]|0)>>>0){k=c[f+32>>2]|0;E=(d[k+v>>0]<<8|d[k+C>>0])&65535}else{E=oc[c[f+12>>2]&31](c[f+4>>2]|0,v)|0}b[q>>1]=E;if((a[f+336>>0]|0)==0){c[B>>2]=(c[B>>2]|0)+2;B=f+152|0;c[B>>2]=(c[B>>2]|0)+2;c[y>>2]=c[y>>2]&-256|D&255;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==2){j=f+((h&7)<<2)+88|0;D=c[j>>2]&255;y=h>>>9&7;if((h&32|0)==0){h=f+166|0;F=(y|0)==0?8:y;G=(e[h>>1]|0)>>>4&1;H=h;w=48}else{h=c[f+(y<<2)+88>>2]&63;y=f+166|0;B=(e[y>>1]|0)>>>4&1;if((h|0)==0){I=0;J=y;K=D;L=B}else{F=h;G=B;H=y;w=48}}if((w|0)==48){w=D;D=0;y=G;while(1){G=w>>>7&1;B=y&65535|w<<1&131070;h=D+1|0;if((h|0)==(F|0)){I=F;J=H;K=B;L=G;break}else{w=B;D=h;y=G}}}y=f+372|0;c[y>>2]=(I<<1)+6+(c[y>>2]|0);bo(f,14,K&255);y=e[J>>1]|0;b[J>>1]=L<<16>>16==0?y&65518:y|17;y=f+156|0;L=c[y>>2]|0;if((L&1|0)!=0){Mj(f,L,0,0);i=g;return}J=f+164|0;b[f+162>>1]=b[J>>1]|0;I=L&16777215;L=I+1|0;if(L>>>0<(c[f+36>>2]|0)>>>0){D=c[f+32>>2]|0;M=(d[D+I>>0]<<8|d[D+L>>0])&65535}else{M=oc[c[f+12>>2]&31](c[f+4>>2]|0,I)|0}b[J>>1]=M;if((a[f+336>>0]|0)==0){c[y>>2]=(c[y>>2]|0)+2;y=f+152|0;c[y>>2]=(c[y>>2]|0)+2;c[j>>2]=c[j>>2]&-256|K&255;i=g;return}else{Kj(f);i=g;return}}else{Nj(f);K=f+372|0;c[K>>2]=(c[K>>2]|0)+2;i=g;return}}function Tm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;g=i;h=e[f+160>>1]|0;j=h>>>3&3;if((j|0)==2){k=f+((h&7)<<2)+88|0;l=c[k>>2]|0;m=h>>>9&7;if((h&32|0)==0){n=f+166|0;o=(m|0)==0?8:m;p=(e[n>>1]|0)>>>4&1;q=n;r=48}else{n=c[f+(m<<2)+88>>2]&63;m=f+166|0;s=(e[m>>1]|0)>>>4&1;if((n|0)==0){t=0;u=m;v=l;w=s}else{o=n;p=s;q=m;r=48}}if((r|0)==48){m=l;l=0;s=p;while(1){p=m>>>15&1;n=s&65535|m<<1&131070;x=l+1|0;if((x|0)==(o|0)){t=o;u=q;v=n;w=p;break}else{m=n;l=x;s=p}}}s=f+372|0;c[s>>2]=(t<<1)+6+(c[s>>2]|0);co(f,14,v&65535);s=e[u>>1]|0;b[u>>1]=w<<16>>16==0?s&65518:s|17;s=f+156|0;w=c[s>>2]|0;if((w&1|0)!=0){Mj(f,w,0,0);i=g;return}u=f+164|0;b[f+162>>1]=b[u>>1]|0;t=w&16777215;w=t+1|0;if(w>>>0<(c[f+36>>2]|0)>>>0){l=c[f+32>>2]|0;y=(d[l+t>>0]<<8|d[l+w>>0])&65535}else{y=oc[c[f+12>>2]&31](c[f+4>>2]|0,t)|0}b[u>>1]=y;if((a[f+336>>0]|0)==0){c[s>>2]=(c[s>>2]|0)+2;s=f+152|0;c[s>>2]=(c[s>>2]|0)+2;c[k>>2]=c[k>>2]&-65536|v&65535;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==0){v=f+((h&7)<<2)+88|0;k=c[v>>2]|0;s=h>>>9&7;do{if((h&32|0)==0){z=(s|0)==0?8:s;r=7}else{y=c[f+(s<<2)+88>>2]&63;if((y|0)==0){u=f+166|0;b[u>>1]=b[u>>1]&65532;A=0;B=k&65535;break}if(y>>>0<16){z=y;r=7}else{if((y|0)==16){if((k&1|0)==0){r=13}else{u=f+166|0;t=e[u>>1]|17;b[u>>1]=t;C=t}}else{r=13}if((r|0)==13){t=f+166|0;u=b[t>>1]&65518;b[t>>1]=u;C=u}u=f+166|0;if((k&65535|0)==0){b[u>>1]=C&65533;A=y;B=0;break}else{b[u>>1]=C|2;A=y;B=0;break}}}}while(0);do{if((r|0)==7){C=k&65535;s=C<<z&65535;y=f+166|0;u=e[y>>1]|0;t=(1<<16-z&C|0)==0?u&65518:u|17;b[y>>1]=t;u=65535<<15-z&65535;C=u&k;if((C|0)==0|(C|0)==(u|0)){b[y>>1]=t&65533;A=z;B=s;break}else{b[y>>1]=t|2;A=z;B=s;break}}}while(0);z=f+372|0;c[z>>2]=(A<<1)+6+(c[z>>2]|0);co(f,12,B);z=f+156|0;A=c[z>>2]|0;if((A&1|0)!=0){Mj(f,A,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;s=A&16777215;A=s+1|0;if(A>>>0<(c[f+36>>2]|0)>>>0){t=c[f+32>>2]|0;D=(d[t+s>>0]<<8|d[t+A>>0])&65535}else{D=oc[c[f+12>>2]&31](c[f+4>>2]|0,s)|0}b[k>>1]=D;if((a[f+336>>0]|0)==0){c[z>>2]=(c[z>>2]|0)+2;z=f+152|0;c[z>>2]=(c[z>>2]|0)+2;c[v>>2]=c[v>>2]&-65536|B&65535;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==3){B=f+((h&7)<<2)+88|0;v=c[B>>2]|0;z=v&65535;D=h>>>9&7;if((h&32|0)==0){E=(D|0)==0?8:D}else{E=c[f+(D<<2)+88>>2]&63}D=E&15;do{if((D|0)==0){if((E|0)!=0){if((v&1|0)!=0){k=f+166|0;b[k>>1]=e[k>>1]|1;F=z;break}}k=f+166|0;b[k>>1]=b[k>>1]&65534;F=z}else{k=v&65535;s=k>>>(16-D|0)|k<<D;k=s&65535;A=f+166|0;t=e[A>>1]|0;if((s&1|0)==0){b[A>>1]=t&65534;F=k;break}else{b[A>>1]=t|1;F=k;break}}}while(0);D=f+372|0;c[D>>2]=(E<<1)+6+(c[D>>2]|0);co(f,14,F);D=f+156|0;E=c[D>>2]|0;if((E&1|0)!=0){Mj(f,E,0,0);i=g;return}v=f+164|0;b[f+162>>1]=b[v>>1]|0;z=E&16777215;E=z+1|0;if(E>>>0<(c[f+36>>2]|0)>>>0){k=c[f+32>>2]|0;G=(d[k+z>>0]<<8|d[k+E>>0])&65535}else{G=oc[c[f+12>>2]&31](c[f+4>>2]|0,z)|0}b[v>>1]=G;if((a[f+336>>0]|0)==0){c[D>>2]=(c[D>>2]|0)+2;D=f+152|0;c[D>>2]=(c[D>>2]|0)+2;c[B>>2]=c[B>>2]&-65536|F&65535;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==1){j=f+((h&7)<<2)+88|0;F=c[j>>2]|0;B=h>>>9&7;do{if((h&32|0)==0){H=(B|0)==0?8:B;r=30}else{D=c[f+(B<<2)+88>>2]&63;if((D|0)==0){G=f+166|0;b[G>>1]=b[G>>1]&65534;I=0;J=F&65535;break}if(D>>>0<16){H=D;r=30}else{if((D|0)==16){if((F&1|0)!=0){G=f+166|0;b[G>>1]=e[G>>1]|17;I=16;J=0;break}}G=f+166|0;b[G>>1]=b[G>>1]&65518;I=D;J=0}}}while(0);do{if((r|0)==30){B=F&65535;h=B<<H&65535;D=f+166|0;G=e[D>>1]|0;if((1<<16-H&B|0)==0){b[D>>1]=G&65518;I=H;J=h;break}else{b[D>>1]=G|17;I=H;J=h;break}}}while(0);H=f+372|0;c[H>>2]=(I<<1)+6+(c[H>>2]|0);co(f,14,J);H=f+156|0;I=c[H>>2]|0;if((I&1|0)!=0){Mj(f,I,0,0);i=g;return}F=f+164|0;b[f+162>>1]=b[F>>1]|0;r=I&16777215;I=r+1|0;if(I>>>0<(c[f+36>>2]|0)>>>0){h=c[f+32>>2]|0;K=(d[h+r>>0]<<8|d[h+I>>0])&65535}else{K=oc[c[f+12>>2]&31](c[f+4>>2]|0,r)|0}b[F>>1]=K;if((a[f+336>>0]|0)==0){c[H>>2]=(c[H>>2]|0)+2;H=f+152|0;c[H>>2]=(c[H>>2]|0)+2;c[j>>2]=c[j>>2]&-65536|J&65535;i=g;return}else{Kj(f);i=g;return}}else{Nj(f);J=f+372|0;c[J>>2]=(c[J>>2]|0)+2;i=g;return}}function Um(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;g=i;h=e[f+160>>1]|0;j=h>>>3&3;if((j|0)==3){k=f+((h&7)<<2)+88|0;l=c[k>>2]|0;m=h>>>9&7;if((h&32|0)==0){n=(m|0)==0?8:m}else{n=c[f+(m<<2)+88>>2]&63}m=n&31;do{if((m|0)==0){if((n|0)!=0){if((l&1|0)!=0){o=f+166|0;b[o>>1]=e[o>>1]|1;p=l;break}}o=f+166|0;b[o>>1]=b[o>>1]&65534;p=l}else{o=l>>>(32-m|0)|l<<m;q=f+166|0;r=e[q>>1]|0;if((o&1|0)==0){b[q>>1]=r&65534;p=o;break}else{b[q>>1]=r|1;p=o;break}}}while(0);m=f+372|0;c[m>>2]=(n<<1)+8+(c[m>>2]|0);eo(f,14,p);m=f+156|0;n=c[m>>2]|0;if((n&1|0)!=0){Mj(f,n,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;o=n&16777215;n=o+1|0;if(n>>>0<(c[f+36>>2]|0)>>>0){r=c[f+32>>2]|0;s=(d[r+o>>0]<<8|d[r+n>>0])&65535}else{s=oc[c[f+12>>2]&31](c[f+4>>2]|0,o)|0}b[l>>1]=s;if((a[f+336>>0]|0)==0){c[m>>2]=(c[m>>2]|0)+2;m=f+152|0;c[m>>2]=(c[m>>2]|0)+2;c[k>>2]=p;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==0){p=f+((h&7)<<2)+88|0;k=c[p>>2]|0;m=h>>>9&7;do{if((h&32|0)==0){t=(m|0)==0?8:m;u=7}else{s=c[f+(m<<2)+88>>2]&63;if((s|0)==0){l=f+166|0;b[l>>1]=b[l>>1]&65532;v=0;w=k;break}if(s>>>0<32){t=s;u=7}else{if((s|0)==32){if((k&1|0)==0){u=13}else{l=f+166|0;o=e[l>>1]|17;b[l>>1]=o;x=o}}else{u=13}if((u|0)==13){o=f+166|0;l=b[o>>1]&65518;b[o>>1]=l;x=l}l=f+166|0;if((k|0)==0){b[l>>1]=x&65533;v=s;w=0;break}else{b[l>>1]=x|2;v=s;w=0;break}}}}while(0);do{if((u|0)==7){x=k<<t;m=-1<<31-t;s=f+166|0;l=e[s>>1]|0;o=(1<<32-t&k|0)==0?l&65518:l|17;b[s>>1]=o;l=m&k;if((l|0)==0|(l|0)==(m|0)){b[s>>1]=o&65533;v=t;w=x;break}else{b[s>>1]=o|2;v=t;w=x;break}}}while(0);t=f+372|0;c[t>>2]=(v<<1)+8+(c[t>>2]|0);eo(f,12,w);t=f+156|0;v=c[t>>2]|0;if((v&1|0)!=0){Mj(f,v,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;x=v&16777215;v=x+1|0;if(v>>>0<(c[f+36>>2]|0)>>>0){o=c[f+32>>2]|0;y=(d[o+x>>0]<<8|d[o+v>>0])&65535}else{y=oc[c[f+12>>2]&31](c[f+4>>2]|0,x)|0}b[k>>1]=y;if((a[f+336>>0]|0)==0){c[t>>2]=(c[t>>2]|0)+2;t=f+152|0;c[t>>2]=(c[t>>2]|0)+2;c[p>>2]=w;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==1){w=f+((h&7)<<2)+88|0;p=c[w>>2]|0;t=h>>>9&7;do{if((h&32|0)==0){z=(t|0)==0?8:t;u=30}else{y=c[f+(t<<2)+88>>2]&63;if((y|0)==0){k=f+166|0;b[k>>1]=b[k>>1]&65534;A=0;B=p;break}if(y>>>0<32){z=y;u=30}else{if((y|0)==32){if((p&1|0)!=0){k=f+166|0;b[k>>1]=e[k>>1]|17;A=32;B=0;break}}k=f+166|0;b[k>>1]=b[k>>1]&65518;A=y;B=0}}}while(0);do{if((u|0)==30){t=p<<z;y=f+166|0;k=e[y>>1]|0;if((1<<32-z&p|0)==0){b[y>>1]=k&65518;A=z;B=t;break}else{b[y>>1]=k|17;A=z;B=t;break}}}while(0);z=f+372|0;c[z>>2]=(A<<1)+8+(c[z>>2]|0);eo(f,14,B);z=f+156|0;A=c[z>>2]|0;if((A&1|0)!=0){Mj(f,A,0,0);i=g;return}p=f+164|0;b[f+162>>1]=b[p>>1]|0;u=A&16777215;A=u+1|0;if(A>>>0<(c[f+36>>2]|0)>>>0){t=c[f+32>>2]|0;C=(d[t+u>>0]<<8|d[t+A>>0])&65535}else{C=oc[c[f+12>>2]&31](c[f+4>>2]|0,u)|0}b[p>>1]=C;if((a[f+336>>0]|0)==0){c[z>>2]=(c[z>>2]|0)+2;z=f+152|0;c[z>>2]=(c[z>>2]|0)+2;c[w>>2]=B;i=g;return}else{Kj(f);i=g;return}}else if((j|0)==2){j=h>>>9&7;if((h&32|0)==0){D=(j|0)==0?8:j}else{D=c[f+(j<<2)+88>>2]&63}j=f+((h&7)<<2)+88|0;h=c[j>>2]|0;B=f+166|0;w=(e[B>>1]|0)>>>4&1;if((D|0)==0){E=h;F=w}else{z=h;h=0;C=w;while(1){w=z>>>31;p=C|z<<1;u=h+1|0;if((u|0)==(D|0)){E=p;F=w;break}else{z=p;h=u;C=w}}}C=f+372|0;c[C>>2]=(D<<1)+8+(c[C>>2]|0);eo(f,14,E);C=e[B>>1]|0;b[B>>1]=(F|0)==0?C&65518:C|17;C=f+156|0;F=c[C>>2]|0;if((F&1|0)!=0){Mj(f,F,0,0);i=g;return}B=f+164|0;b[f+162>>1]=b[B>>1]|0;D=F&16777215;F=D+1|0;if(F>>>0<(c[f+36>>2]|0)>>>0){h=c[f+32>>2]|0;G=(d[h+D>>0]<<8|d[h+F>>0])&65535}else{G=oc[c[f+12>>2]&31](c[f+4>>2]|0,D)|0}b[B>>1]=G;if((a[f+336>>0]|0)==0){c[C>>2]=(c[C>>2]|0)+2;C=f+152|0;c[C>>2]=(c[C>>2]|0)+2;c[j>>2]=E;i=g;return}else{Kj(f);i=g;return}}else{Nj(f);E=f+372|0;c[E>>2]=(c[E>>2]|0)+2;i=g;return}}function Vm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,508,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}j=e[h>>1]<<1;k=j&65535;l=f+372|0;c[l>>2]=(c[l>>2]|0)+8;co(f,12,k);l=b[h>>1]|0;h=f+166|0;m=e[h>>1]|0;n=l<<16>>16<0?m|17:m&65518;b[h>>1]=((l&65535^j)&32768|0)==0?n&65533:n|2;n=f+156|0;j=c[n>>2]|0;if((j&1|0)!=0){Mj(f,j,0,0);i=g;return}l=f+164|0;b[f+162>>1]=b[l>>1]|0;h=j&16777215;j=h+1|0;if(j>>>0<(c[f+36>>2]|0)>>>0){m=c[f+32>>2]|0;o=(d[m+h>>0]<<8|d[m+j>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,h)|0}b[l>>1]=o;if((a[f+336>>0]|0)==0){c[n>>2]=(c[n>>2]|0)+2;n=f+152|0;c[n>>2]=(c[n>>2]|0)+2;No(f,k)|0;i=g;return}else{Kj(f);i=g;return}}function Wm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,508,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}j=(e[h>>1]|0)>>>1;k=f+372|0;c[k>>2]=(c[k>>2]|0)+8;co(f,14,j);k=f+166|0;l=e[k>>1]|0;b[k>>1]=(b[h>>1]&1)==0?l&65518:l|17;l=f+156|0;h=c[l>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+h>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[k>>1]=o;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;No(f,j)|0;i=g;return}else{Kj(f);i=g;return}}function Xm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,508,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}j=e[h>>1]<<1&65535;k=f+372|0;c[k>>2]=(c[k>>2]|0)+8;co(f,14,j);k=f+166|0;l=e[k>>1]|0;b[k>>1]=(b[h>>1]|0)<0?l|17:l&65518;l=f+156|0;h=c[l>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}k=f+164|0;b[f+162>>1]=b[k>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+h>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[k>>1]=o;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;No(f,j)|0;i=g;return}else{Kj(f);i=g;return}}function Ym(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,508,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}j=f+166|0;k=((e[h>>1]|0)>>>1|((e[j>>1]|0)>>>4&65535)<<15)&65535;l=f+372|0;c[l>>2]=(c[l>>2]|0)+8;co(f,14,k);l=e[j>>1]|0;b[j>>1]=(b[h>>1]&1)==0?l&65518:l|17;l=f+156|0;h=c[l>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+h>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[j>>1]=o;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;No(f,k)|0;i=g;return}else{Kj(f);i=g;return}}function Zm(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,508,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}j=f+166|0;k=(e[h>>1]<<1|(e[j>>1]|0)>>>4&1)&65535;l=f+372|0;c[l>>2]=(c[l>>2]|0)+8;co(f,14,k);l=e[j>>1]|0;b[j>>1]=(b[h>>1]|0)<0?l|17:l&65518;l=f+156|0;h=c[l>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+h>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[j>>1]=o;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;No(f,k)|0;i=g;return}else{Kj(f);i=g;return}}function _m(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;g=i;i=i+16|0;h=g;j=b[f+160>>1]&63;if((nc[c[46024+(j<<2)>>2]&63](f,j,508,16)|0)!=0){i=g;return}if((Ko(f,h)|0)!=0){i=g;return}j=e[h>>1]|0;k=(j>>>1|j<<15)&65535;j=f+372|0;c[j>>2]=(c[j>>2]|0)+8;co(f,14,k);j=f+166|0;l=e[j>>1]|0;b[j>>1]=(b[h>>1]&1)==0?l&65534:l|1;l=f+156|0;h=c[l>>2]|0;if((h&1|0)!=0){Mj(f,h,0,0);i=g;return}j=f+164|0;b[f+162>>1]=b[j>>1]|0;m=h&16777215;h=m+1|0;if(h>>>0<(c[f+36>>2]|0)>>>0){n=c[f+32>>2]|0;o=(d[n+m>>0]<<8|d[n+h>>0])&65535}else{o=oc[c[f+12>>2]&31](c[f+4>>2]|0,m)|0}b[j>>1]=o;if((a[f+336>>0]|0)==0){c[l>>2]=(c[l>>2]|0)+2;l=f+152|0;c[l>>2]=(c[l>>2]|0)+2;No(f,k)|0;i=g;return}else{Kj(f);i=g;return}}



function vs(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0;f=i;i=i+1072|0;g=f;h=f+536|0;j=f+12|0;k=Et(e)|0;if((k|0)==0){l=0;i=f;return l|0}Ls(b,0);e=b+16|0;if((a[e>>0]|0)!=0){l=k;i=f;return l|0}m=b+12|0;n=j+1|0;p=j+2|0;q=h+524|0;r=h+525|0;s=h+526|0;t=j+12|0;u=c[o>>2]|0;v=0;w=0;while(1){Ms(b,g,8)|0;x=c[g>>2]|0;if((x&128|0)==0){y=8;z=x;do{Ms(b,g,1)|0;A=z<<1;z=c[g>>2]&1|A;y=y+1|0}while((A&128|0)==0&y>>>0<64);B=y>>>0>63?0:z}else{B=x}A=B&255;C=c[m>>2]|0;D=a[e>>0]|0;if(v<<24>>24==-43&w<<24>>24==-86){if((B&255|0)==150){Ms(b,g,8)|0;E=c[g>>2]|0;if((E&128|0)==0){F=8;G=E;do{Ms(b,g,1)|0;H=G<<1;G=c[g>>2]&1|H;F=F+1|0}while((H&128|0)==0&F>>>0<64);I=F>>>0>63?0:G}else{I=E}x=a[47232+(I&255)>>0]|0;z=x&255;Ms(b,g,8)|0;y=c[g>>2]|0;if((y&128|0)==0){H=8;J=y;do{Ms(b,g,1)|0;K=J<<1;J=c[g>>2]&1|K;H=H+1|0}while((K&128|0)==0&H>>>0<64);L=H>>>0>63?0:J}else{L=y}E=a[47232+(L&255)>>0]|0;G=E&255;Ms(b,g,8)|0;F=c[g>>2]|0;if((F&128|0)==0){K=8;M=F;do{Ms(b,g,1)|0;N=M<<1;M=c[g>>2]&1|N;K=K+1|0}while((N&128|0)==0&K>>>0<64);O=K>>>0>63?0:M}else{O=F}y=a[47232+(O&255)>>0]|0;J=y&255;Ms(b,g,8)|0;H=c[g>>2]|0;if((H&128|0)==0){N=8;P=H;do{Ms(b,g,1)|0;Q=P<<1;P=c[g>>2]&1|Q;N=N+1|0}while((Q&128|0)==0&N>>>0<64);R=N>>>0>63?0:P}else{R=H}F=a[47232+(R&255)>>0]|0;Ms(b,g,8)|0;M=c[g>>2]|0;if((M&128|0)==0){K=8;Q=M;do{Ms(b,g,1)|0;S=Q<<1;Q=c[g>>2]&1|S;K=K+1|0}while((S&128|0)==0&K>>>0<64);T=K>>>0>63?0:Q}else{T=M}H=a[47232+(T&255)>>0]|0;P=J<<6&1984|z&63;N=J>>>5&3;S=kt(P,N,G,512)|0;if((S|0)!=0){tt(S,3);st(S,8,1);At(S,F);if(!(H<<24>>24==(E^x^y^F)<<24>>24)){st(S,1,1)}a[j>>0]=0;a[n>>0]=0;a[p>>0]=0;H=0;U=0;V=0;while(1){a[j>>0]=H;a[n>>0]=U;Ms(b,g,8)|0;W=c[g>>2]|0;if((W&128|0)==0){X=8;Y=W;do{Ms(b,g,1)|0;Z=Y<<1;Y=c[g>>2]&1|Z;X=X+1|0}while((Z&128|0)==0&X>>>0<64);_=a[j>>0]|0;$=X>>>0>63?0:Y}else{_=H;$=W}Z=$&255;a[p>>0]=Z;if(_<<24>>24==-43){if((a[n>>0]|0)==-86){aa=33;break}}ba=V+1|0;if(!(ba>>>0<64)){break}H=a[n>>0]|0;U=Z;V=ba}if((aa|0)==33){aa=0;if(($&255|0)==173){Ms(b,g,8)|0;U=c[g>>2]|0;if((U&128|0)==0){H=8;F=U;do{Ms(b,g,1)|0;y=F<<1;F=c[g>>2]&1|y;H=H+1|0}while((y&128|0)==0&H>>>0<64);ca=H>>>0>63?0:F}else{ca=U}y=a[47232+(ca&255)>>0]|0;a[p>>0]=y;if(!(y<<24>>24!=E<<24>>24|V>>>0>63)){st(S,8,0);y=0;x=0;while(1){if(((x>>>0)%3|0|0)==0){Ms(b,g,8)|0;J=c[g>>2]|0;if((J&128|0)==0){z=8;M=J;do{Ms(b,g,1)|0;Q=M<<1;M=c[g>>2]&1|Q;z=z+1|0}while((Q&128|0)==0&z>>>0<64);da=z>>>0>63?0:M}else{da=J}ea=d[47232+(da&255)>>0]<<2}else{ea=y}Ms(b,g,8)|0;W=c[g>>2]|0;if((W&128|0)==0){Y=8;X=W;do{Ms(b,g,1)|0;Q=X<<1;X=c[g>>2]&1|Q;Y=Y+1|0}while((Q&128|0)==0&Y>>>0<64);fa=Y>>>0>63?0:X}else{fa=W}a[h+x>>0]=a[47232+(fa&255)>>0]&63|ea&192;x=x+1|0;if((x|0)==524){break}else{y=ea<<2&1020}}Ms(b,g,8)|0;y=c[g>>2]|0;if((y&128|0)==0){x=8;V=y;do{Ms(b,g,1)|0;E=V<<1;V=c[g>>2]&1|E;x=x+1|0}while((E&128|0)==0&x>>>0<64);ga=x>>>0>63?0:V}else{ga=y}E=d[47232+(ga&255)>>0]|0;U=E<<2;Ms(b,g,8)|0;F=c[g>>2]|0;if((F&128|0)==0){H=8;J=F;do{Ms(b,g,1)|0;M=J<<1;J=c[g>>2]&1|M;H=H+1|0}while((M&128|0)==0&H>>>0<64);ha=H>>>0>63?0:J}else{ha=F}y=(a[47232+(ha&255)>>0]&63|U&192)&255;a[q>>0]=y;Ms(b,g,8)|0;V=c[g>>2]|0;if((V&128|0)==0){x=8;M=V;do{Ms(b,g,1)|0;z=M<<1;M=c[g>>2]&1|z;x=x+1|0}while((z&128|0)==0&x>>>0<64);ia=x>>>0>63?0:M}else{ia=V}U=(a[47232+(ia&255)>>0]&63|E<<4&192)&255;a[r>>0]=U;Ms(b,g,8)|0;F=c[g>>2]|0;if((F&128|0)==0){J=8;H=F;do{Ms(b,g,1)|0;z=H<<1;H=c[g>>2]&1|z;J=J+1|0}while((z&128|0)==0&J>>>0<64);ja=J>>>0>63?0:H}else{ja=F}V=a[47232+(ja&255)>>0]&63|E<<6;a[s>>0]=V;M=0;x=0;z=0;Q=0;while(1){if(((Q>>>0)%3|0|0)==0){ka=M<<1&510|M>>>7&1}else{ka=M}K=d[h+Q>>0]^ka;M=(ka>>>8&1)+z+(K&255)|0;a[j+Q>>0]=K;Q=Q+1|0;if((Q|0)==524){break}else{K=x;x=ka&255;z=K}}if(y<<24>>24==(ka&255)<<24>>24){if(U<<24>>24==(M&255)<<24>>24){if((V&255|0)!=(x|0)){aa=69}}else{aa=69}}else{aa=69}if((aa|0)==69){aa=0;c[g>>2]=P;c[g+4>>2]=N;c[g+8>>2]=G;hb(u|0,47200,g|0)|0;st(S,2,1)}Mz(c[S+24>>2]|0,t|0,512)|0;Ct(S,j,12)|0}}}Gt(k,S)|0}c[m>>2]=C;a[e>>0]=D}}if(D<<24>>24==0){z=w;w=A;v=z}else{l=k;break}}i=f;return l|0}function ws(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;e=Kt()|0;if((e|0)==0){f=0;i=d;return f|0}g=c[a>>2]|0;if((g|0)==0){f=e;i=d;return f|0}h=a+4|0;j=g;g=0;a:while(1){k=c[(c[h>>2]|0)+(g<<2)>>2]|0;if((k|0)==0){l=j}else{if((c[k>>2]|0)==0){l=j}else{m=k+4|0;n=0;while(1){o=c[(c[m>>2]|0)+(n<<2)>>2]|0;if((o|0)==0){p=Et(n)|0}else{p=vs(o,n)|0}if((b[p+2>>1]|0)==0){o=n+1|0;if((o|0)==(c[k>>2]|0)){Ft(p);q=o}else{r=13}}else{r=13}if((r|0)==13){r=0;if((p|0)==0){break a}Nt(e,p,g)|0;q=n+1|0}if(q>>>0<(c[k>>2]|0)>>>0){n=q}else{break}}l=c[a>>2]|0}}n=g+1|0;if(n>>>0<l>>>0){j=l;g=n}else{f=e;r=19;break}}if((r|0)==19){i=d;return f|0}Lt(e);f=0;i=d;return f|0}function xs(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;j=i;i=i+1056|0;k=j+524|0;l=j;Ls(f,0);m=0;do{Ns(f,255,10)|0;m=m+1|0}while((m|0)!=32);m=g+2|0;if((b[m>>1]|0)!=0){n=g+4|0;g=l+12|0;o=k+524|0;p=k+525|0;q=k+526|0;r=k+1|0;s=k+522|0;t=k+523|0;u=0;do{v=c[(c[n>>2]|0)+(u<<2)>>2]|0;w=b[v+10>>1]|0;x=c[v+24>>2]|0;if((w&65535)<512){Mz(g|0,x|0,w&65535|0)|0}else{Mz(g|0,x|0,512)|0}x=Bt(v)|0;w=(x|0)==0;Dt(v,l,12)|0;y=b[v+4>>1]|0;z=y&65535;A=b[v+6>>1]|0;B=b[v+8>>1]|0;v=z>>>6;C=0;do{Ns(f,255,10)|0;C=C+1|0}while((C|0)!=38);C=w?h:x;D=(A&65535)<<5|v&31;Ns(f,14002838,24)|0;Ns(f,d[47136+(z&63)>>0]|0,8)|0;E=d[47136+(B&63)>>0]|0;Ns(f,E,8)|0;Ns(f,d[47136+(D&63)>>0]|0,8)|0;Ns(f,d[47136+(C&63)>>0]|0,8)|0;Ns(f,d[47136+((D^C^(B^y)&65535)&63)>>0]|0,8)|0;Ns(f,57002,16)|0;Ns(f,255,10)|0;Ns(f,255,10)|0;Ns(f,255,10)|0;Ns(f,255,10)|0;Ns(f,255,10)|0;Ns(f,255,10)|0;Ns(f,255,10)|0;Ns(f,255,10)|0;Ns(f,14002861,24)|0;Ns(f,E,8)|0;E=0;C=0;D=0;F=0;while(1){if(((F>>>0)%3|0|0)==0){G=E<<1&510|E>>>7&1}else{G=E}H=d[l+F>>0]|0;E=(G>>>8&1)+D+H|0;a[k+F>>0]=H^G;F=F+1|0;if((F|0)==524){break}else{H=C;C=G&255;D=H}}a[o>>0]=G;a[p>>0]=E;a[q>>0]=C;D=r;F=(d[r>>0]|0)>>>4&12|(d[k>>0]|0)>>>2&48;y=0;B=k;do{z=B+2|0;Ns(f,d[47136+((d[z>>0]|0)>>>6|F)>>0]|0,8)|0;Ns(f,d[47136+(a[B>>0]&63)>>0]|0,8)|0;Ns(f,d[47136+(a[D>>0]&63)>>0]|0,8)|0;Ns(f,d[47136+(a[z>>0]&63)>>0]|0,8)|0;z=B;B=B+3|0;y=y+3|0;D=z+4|0;F=(d[D>>0]|0)>>>4&12|(d[B>>0]|0)>>>2&48}while(y>>>0<522);Ns(f,d[47136+F>>0]|0,8)|0;Ns(f,d[47136+(a[s>>0]&63)>>0]|0,8)|0;Ns(f,d[47136+(a[t>>0]&63)>>0]|0,8)|0;Ns(f,d[47136+(G>>>2&48|C>>>6|E>>>4&12)>>0]|0,8)|0;Ns(f,d[47136+(G&63)>>0]|0,8)|0;Ns(f,d[47136+(E&63)>>0]|0,8)|0;Ns(f,d[47136+(C&63)>>0]|0,8)|0;Ns(f,57002,16)|0;u=u+1|0}while(u>>>0<(e[m>>1]|0)>>>0)}if((a[f+16>>0]|0)!=0){I=1;i=j;return I|0}m=c[f+4>>2]|0;u=c[f+12>>2]|0;if((m|0)==(u|0)){I=0;i=j;return I|0}G=m-u|0;while(1){u=G>>>0<10?G:10;Ns(f,255>>>(10-u|0),u)|0;if((G|0)==(u|0)){I=0;break}else{G=G-u|0}}i=j;return I|0}function ys(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;g=b[d>>1]|0;h=g<<16>>16==0;if(h){j=0;i=f;return j|0}k=c[d+4>>2]|0;l=g&65535;m=0;while(1){n=m+1|0;if((e[(c[k+(m<<2)>>2]|0)+2>>1]|0)>1){o=34;break}if(n>>>0<l>>>0){m=n}else{o=2;break}}if(h){j=0;i=f;return j|0}h=d+4|0;m=g;g=0;a:while(1){l=c[(c[h>>2]|0)+(g<<2)>>2]|0;if(g>>>0<80){p=c[47112+(g>>>4<<2)>>2]|0}else{p=0}k=l+2|0;if((b[k>>1]|0)==0){q=m}else{n=l+4|0;l=0;do{r=c[(c[n>>2]|0)+(l<<2)>>2]|0;s=Us(a,g,l,1)|0;if((s|0)==0){j=1;t=17;break a}if((Ks(s,p)|0)!=0){j=1;t=17;break a}Js(s,5e5);l=l+1|0;if((xs(s,r,o)|0)!=0){j=1;t=17;break a}}while(l>>>0<(e[k>>1]|0)>>>0);q=b[d>>1]|0}k=g+1|0;if(k>>>0<(q&65535)>>>0){m=q;g=k}else{j=0;t=17;break}}if((t|0)==17){i=f;return j|0}return 0}function zs(a){a=a|0;var b=0,c=0,d=0;b=i;c=Qs()|0;if((c|0)==0){d=0}else{if((ys(c,a)|0)==0){d=c}else{Rs(c);d=0}}i=b;return d|0}function As(a,b){a=a|0;b=b|0;return(d[a+b>>0]|0)<<8|(d[a+(b+1)>>0]|0)|0}function Bs(a,b){a=a|0;b=b|0;return(d[a+(b+1)>>0]|0)<<8|(d[a+b>>0]|0)|0}function Cs(a,b){a=a|0;b=b|0;return(((d[a+b>>0]|0)<<8|(d[a+(b+1)>>0]|0))<<8|(d[a+(b+2)>>0]|0))<<8|(d[a+(b+3)>>0]|0)|0}function Ds(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c>>0]=d>>>24;a[b+(c+1)>>0]=d>>>16;a[b+(c+2)>>0]=d>>>8;a[b+(c+3)>>0]=d;return}function Es(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=(ta(b|0,1,c|0,a|0)|0)!=(c|0)|0;i=d;return e|0}function Fs(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;if((xb(a|0,b|0,0)|0)!=0){f=1;i=e;return f|0}f=(ta(c|0,1,d|0,a|0)|0)!=(d|0)|0;i=e;return f|0}function Gs(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=(fb(b|0,1,c|0,a|0)|0)!=(c|0)|0;i=d;return e|0}function Hs(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;if((c|0)==0){e=47504;f=0;while(1){g=b+f|0;h=a[g>>0]|0;if(h<<24>>24==0){break}else if(h<<24>>24==46){j=g}else{j=e}e=j;f=f+1|0}if((Ez(e,47512)|0)==0){k=1}else{if((Ez(e,47520)|0)==0){k=2}else{f=(Ez(e,47528)|0)==0;k=f?3:2}}}else{k=c}c=Ib(b|0,47488)|0;if((c|0)==0){l=0;i=d;return l|0}if((k|0)==1){m=Xs(c)|0}else if((k|0)==2){m=_s(c)|0}else if((k|0)==3){m=ct(c)|0}else{m=0}zb(c|0)|0;l=m;i=d;return l|0}function Is(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;if((d|0)==0){f=47504;g=0;while(1){h=b+g|0;j=a[h>>0]|0;if(j<<24>>24==46){k=h}else if(j<<24>>24==0){break}else{k=f}f=k;g=g+1|0}if((Ez(f,47512)|0)==0){l=1}else{if((Ez(f,47520)|0)==0){l=2}else{g=(Ez(f,47528)|0)==0;l=g?3:2}}}else{l=d}d=Ib(b|0,47496)|0;if((d|0)==0){m=1;i=e;return m|0}if((l|0)==3){n=dt(d,c)|0}else if((l|0)==1){n=Ys(d,c)|0}else if((l|0)==2){n=$s(d,c)|0}else{n=1}zb(d|0)|0;m=n;i=e;return m|0}function Js(a,b){a=a|0;b=b|0;c[a>>2]=b;return}function Ks(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;g=b+4|0;if((c[g>>2]|0)==(e|0)){h=0;i=f;return h|0}c[b+12>>2]=0;a[b+16>>0]=0;j=b+8|0;b=c[j>>2]|0;if((e|0)==0){zz(b);c[g>>2]=0;c[j>>2]=0;h=0;i=f;return h|0}k=Az(b,(e+7|0)>>>3)|0;if((k|0)==0){h=1;i=f;return h|0}b=c[g>>2]|0;l=b>>>0>e>>>0?e:b;b=e+ -1|0;if(!((b|7)>>>0<l>>>0)){m=l>>>3;n=b>>>3;b=k+m|0;a[b>>0]=(d[b>>0]|0)&(255>>>(l&7)^255);if((m|0)!=(n|0)){l=m+1|0;if(l>>>0<n>>>0){Oz(k+l|0,0,n+ -1-m|0)|0}a[k+n>>0]=0}}c[g>>2]=e;c[j>>2]=k;h=0;i=f;return h|0}function Ls(b,d){b=b|0;d=d|0;var e=0,f=0;e=i;f=c[b+4>>2]|0;if((f|0)==0){i=e;return}c[b+12>>2]=(d>>>0)%(f>>>0)|0;a[b+16>>0]=0;i=e;return}function Ms(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=c[b+4>>2]|0;if((h|0)==0){c[e>>2]=0;j=1;i=g;return j|0}k=b+12|0;l=c[k>>2]|0;if((f|0)==0){m=b+16|0;n=0}else{o=c[b+8>>2]|0;p=b+16|0;b=f;f=l;q=128>>>(l&7);r=o+(l>>>3)|0;l=0;while(1){s=q&255;t=(d[r>>0]&s|0)!=0|l<<1;u=s>>>1;s=f+1|0;c[k>>2]=s;if(s>>>0<h>>>0){v=(u|0)==0;w=s;x=v?128:u;y=v?r+1|0:r}else{c[k>>2]=0;a[p>>0]=1;w=0;x=128;y=o}v=b+ -1|0;if((v|0)==0){m=p;n=t;break}else{b=v;f=w;q=x;r=y;l=t}}}c[e>>2]=n;j=a[m>>0]|0;i=g;return j|0}function Ns(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;h=b+4|0;if((c[h>>2]|0)==0){j=1;i=g;return j|0}k=b+8|0;l=b+12|0;m=c[l>>2]|0;if((f|0)==0){n=b+16|0}else{o=b+16|0;b=f;f=128>>>(m&7);p=(c[k>>2]|0)+(m>>>3)|0;while(1){m=b+ -1|0;q=f&255;if((1<<m&e|0)==0){r=d[p>>0]&(f^255)}else{r=d[p>>0]|q}a[p>>0]=r;s=q>>>1;q=(c[l>>2]|0)+1|0;c[l>>2]=q;if(q>>>0<(c[h>>2]|0)>>>0){q=(s|0)==0;t=q?128:s;u=q?p+1|0:p}else{q=c[k>>2]|0;c[l>>2]=0;a[o>>0]=1;t=128;u=q}if((m|0)==0){n=o;break}else{b=m;f=t;p=u}}}j=a[n>>0]|0;i=g;return j|0}function Os(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;g=b+4|0;h=c[g>>2]|0;if(!(h>>>0>e>>>0)){j=1;i=f;return j|0}if((e|0)==0){j=0;i=f;return j|0}k=(h+7|0)>>>3;l=yz(k)|0;if((l|0)==0){j=1;i=f;return j|0}Oz(l|0,0,k|0)|0;k=b+8|0;if((h|0)!=0){b=e;m=h;h=-128;n=l;o=0;p=128>>>(e&7);q=(c[k>>2]|0)+(e>>>3)|0;while(1){e=p&255;if(((d[q>>0]|0)&e|0)==0){r=m}else{a[n>>0]=a[n>>0]|h;r=c[g>>2]|0}s=(h&255)>>>1;t=s<<24>>24==0;u=b+1|0;if(u>>>0<r>>>0){v=e>>>1;e=(v|0)==0;w=u;x=e?128:v;y=e?q+1|0:q}else{w=0;x=128;y=c[k>>2]|0}o=o+1|0;if(!(o>>>0<r>>>0)){break}else{b=w;m=r;h=t?-128:s;n=t?n+1|0:n;p=x;q=y}}}zz(c[k>>2]|0);c[k>>2]=l;j=0;i=f;return j|0}function Ps(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;g=(c[b>>2]|0)>>>0>d>>>0;if(g){h=c[(c[b+4>>2]|0)+(d<<2)>>2]|0;if((h|0)!=0){j=h;i=f;return j|0}}if((e|0)==0){j=0;i=f;return j|0}e=yz(20)|0;if((e|0)==0){j=0;i=f;return j|0}h=e+8|0;c[e+0>>2]=0;c[e+4>>2]=0;c[e+8>>2]=0;c[e+12>>2]=0;a[e+16>>0]=0;k=b+4|0;l=c[k>>2]|0;if(g){g=c[l+(d<<2)>>2]|0;if((g|0)==0){m=l}else{zz(c[g+8>>2]|0);zz(g);m=c[k>>2]|0}c[m+(d<<2)>>2]=e;j=e;i=f;return j|0}m=d+1|0;g=Az(l,m<<2)|0;if((g|0)==0){zz(c[h>>2]|0);zz(e);j=0;i=f;return j|0}h=c[b>>2]|0;if(h>>>0<d>>>0){Oz(g+(h<<2)|0,0,d-h<<2|0)|0}c[g+(d<<2)>>2]=e;c[k>>2]=g;c[b>>2]=m;j=e;i=f;return j|0}function Qs(){var a=0,b=0,d=0;a=i;b=yz(16)|0;if((b|0)==0){d=0;i=a;return d|0}c[b+0>>2]=0;c[b+4>>2]=0;c[b+8>>2]=0;c[b+12>>2]=0;d=b;i=a;return d|0}function Rs(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;b=i;if((a|0)==0){i=b;return}d=c[a>>2]|0;e=a+4|0;if((d|0)!=0){f=d;d=0;while(1){g=c[(c[e>>2]|0)+(d<<2)>>2]|0;if((g|0)==0){h=f}else{j=c[g>>2]|0;k=g+4|0;l=c[k>>2]|0;if((j|0)==0){m=l}else{n=l;l=j;j=0;while(1){o=c[n+(j<<2)>>2]|0;if((o|0)==0){p=l;q=n}else{zz(c[o+8>>2]|0);zz(o);p=c[g>>2]|0;q=c[k>>2]|0}o=j+1|0;if(o>>>0<p>>>0){n=q;l=p;j=o}else{m=q;break}}}zz(m);zz(g);h=c[a>>2]|0}d=d+1|0;if(!(d>>>0<h>>>0)){break}else{f=h}}}zz(c[a+12>>2]|0);zz(c[e>>2]|0);zz(a);i=b;return}function Ss(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;if((c[a>>2]|0)>>>0>b>>>0){f=c[(c[a+4>>2]|0)+(b<<2)>>2]|0;if((f|0)!=0){g=f;i=e;return g|0}}if((d|0)==0){g=0;i=e;return g|0}d=yz(8)|0;if((d|0)==0){g=0;i=e;return g|0}c[d>>2]=0;f=d+4|0;c[f>>2]=0;if((Ts(a,d,b)|0)==0){g=d;i=e;return g|0}b=c[d>>2]|0;a=c[f>>2]|0;if((b|0)==0){h=a}else{j=a;a=b;b=0;while(1){k=c[j+(b<<2)>>2]|0;if((k|0)==0){l=a;m=j}else{zz(c[k+8>>2]|0);zz(k);l=c[d>>2]|0;m=c[f>>2]|0}k=b+1|0;if(k>>>0<l>>>0){j=m;a=l;b=k}else{h=m;break}}}zz(h);zz(d);g=0;i=e;return g|0}function Ts(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;f=c[a>>2]|0;g=a+4|0;h=c[g>>2]|0;if(!(f>>>0>d>>>0)){j=d+1|0;k=Az(h,j<<2)|0;if((k|0)==0){l=1;i=e;return l|0}m=c[a>>2]|0;if(m>>>0<d>>>0){Oz(k+(m<<2)|0,0,d-m<<2|0)|0}c[k+(d<<2)>>2]=b;c[g>>2]=k;c[a>>2]=j;if((j|0)==0){l=0;i=e;return l|0}else{n=j}while(1){j=n+ -1|0;if((c[k+(j<<2)>>2]|0)!=0){l=0;o=18;break}c[a>>2]=j;if((j|0)==0){l=0;o=18;break}else{n=j}}if((o|0)==18){i=e;return l|0}}n=c[h+(d<<2)>>2]|0;if((n|0)==0){p=h;q=f}else{f=c[n>>2]|0;h=n+4|0;k=c[h>>2]|0;if((f|0)==0){r=k}else{j=k;k=f;f=0;while(1){m=c[j+(f<<2)>>2]|0;if((m|0)==0){s=k;t=j}else{zz(c[m+8>>2]|0);zz(m);s=c[n>>2]|0;t=c[h>>2]|0}m=f+1|0;if(m>>>0<s>>>0){j=t;k=s;f=m}else{r=t;break}}}zz(r);zz(n);p=c[g>>2]|0;q=c[a>>2]|0}c[p+(d<<2)>>2]=b;if((q|0)==0){l=0;i=e;return l|0}b=c[g>>2]|0;g=q;while(1){q=g+ -1|0;if((c[b+(q<<2)>>2]|0)!=0){l=0;o=18;break}c[a>>2]=q;if((q|0)==0){l=0;o=18;break}else{g=q}}if((o|0)==18){i=e;return l|0}return 0}function Us(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=i;f=Ss(a,b,d)|0;if((f|0)==0){g=0}else{g=Ps(f,c,d)|0}i=e;return g|0}function Vs(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a+12|0;g=a+8|0;a=Az(c[f>>2]|0,(c[g>>2]|0)+d|0)|0;if((a|0)==0){h=1;i=e;return h|0}j=c[g>>2]|0;Mz(a+j|0,b|0,d|0)|0;c[g>>2]=j+d;c[f>>2]=a;h=0;i=e;return h|0}function Ws(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a+12|0;zz(c[f>>2]|0);g=a+8|0;c[g>>2]=0;c[f>>2]=0;if((b|0)==0|(d|0)==0){h=0;i=e;return h|0}a=Az(0,d)|0;if((a|0)==0){h=1;i=e;return h|0}j=c[g>>2]|0;Mz(a+j|0,b|0,d|0)|0;c[g>>2]=j+d;c[f>>2]=a;h=0;i=e;return h|0}function Xs(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;e=i;i=i+560|0;f=e;g=e+536|0;h=e+280|0;j=e+272|0;k=e+264|0;l=e+256|0;m=Qs()|0;if((m|0)==0){n=0;i=e;return n|0}if((Es(b,l,4)|0)!=0){n=m;i=e;return n|0}a:do{if((Cs(l,0)|0)==1346521428){p=l+4|0;if((Es(b,p,4)|0)==0){q=Cs(l,4)|0;if((c[11884]|0)==0){r=0;do{s=r<<25;t=(r&128|0)!=0?s^517762881:s;s=t<<1;u=(t|0)<0?s^517762881:s;s=u<<1;t=(u|0)<0?s^517762881:s;s=t<<1;u=(t|0)<0?s^517762881:s;s=u<<1;t=(u|0)<0?s^517762881:s;s=t<<1;u=(t|0)<0?s^517762881:s;s=u<<1;t=(u|0)<0?s^517762881:s;s=t<<1;c[47544+(r<<2)>>2]=(t|0)<0?s^517762881:s;r=r+1|0}while((r|0)!=256);c[11884]=1}r=l+1|0;s=c[47544+(d[l>>0]<<2)>>2]|0;t=l+2|0;u=c[47544+((d[r>>0]^s>>>24)<<2)>>2]^s<<8;s=l+3|0;v=c[47544+((d[t>>0]^u>>>24)<<2)>>2]^u<<8;u=c[47544+((d[s>>0]^v>>>24)<<2)>>2]^v<<8;v=l+5|0;w=c[47544+((d[p>>0]^u>>>24)<<2)>>2]^u<<8;u=l+6|0;x=c[47544+((d[v>>0]^w>>>24)<<2)>>2]^w<<8;w=l+7|0;y=c[47544+((d[u>>0]^x>>>24)<<2)>>2]^x<<8;x=c[47544+((d[w>>0]^y>>>24)<<2)>>2]^y<<8;if(!(q>>>0<8)){if((Es(b,k,8)|0)==0){if((c[11884]|0)==0){y=0;do{z=y<<25;A=(y&128|0)!=0?z^517762881:z;z=A<<1;B=(A|0)<0?z^517762881:z;z=B<<1;A=(B|0)<0?z^517762881:z;z=A<<1;B=(A|0)<0?z^517762881:z;z=B<<1;A=(B|0)<0?z^517762881:z;z=A<<1;B=(A|0)<0?z^517762881:z;z=B<<1;A=(B|0)<0?z^517762881:z;z=A<<1;c[47544+(y<<2)>>2]=(A|0)<0?z^517762881:z;y=y+1|0}while((y|0)!=256);c[11884]=1}y=c[47544+((d[k>>0]^x>>>24)<<2)>>2]^x<<8;z=c[47544+((d[k+1>>0]^y>>>24)<<2)>>2]^y<<8;y=c[47544+((d[k+2>>0]^z>>>24)<<2)>>2]^z<<8;z=c[47544+((d[k+3>>0]^y>>>24)<<2)>>2]^y<<8;y=c[47544+((d[k+4>>0]^z>>>24)<<2)>>2]^z<<8;z=c[47544+((d[k+5>>0]^y>>>24)<<2)>>2]^y<<8;y=c[47544+((d[k+6>>0]^z>>>24)<<2)>>2]^z<<8;z=c[47544+((d[k+7>>0]^y>>>24)<<2)>>2]|0;A=Cs(k,0)|0;if((A|0)!=0){B=c[o>>2]|0;c[f>>2]=A;hb(B|0,48584,f|0)|0;break}if((Zs(b,q+ -8|0,z^y<<8)|0)==0){y=m+8|0;z=0;b:while(1){if((Es(b,l,8)|0)!=0){break a}B=(z|0)==0;A=z+4|0;C=z+8|0;c:while(1){D=Cs(l,0)|0;E=Cs(l,4)|0;if((c[11884]|0)==0){F=0;do{G=F<<25;H=(F&128|0)!=0?G^517762881:G;G=H<<1;I=(H|0)<0?G^517762881:G;G=I<<1;H=(I|0)<0?G^517762881:G;G=H<<1;I=(H|0)<0?G^517762881:G;G=I<<1;H=(I|0)<0?G^517762881:G;G=H<<1;I=(H|0)<0?G^517762881:G;G=I<<1;H=(I|0)<0?G^517762881:G;G=H<<1;c[47544+(F<<2)>>2]=(H|0)<0?G^517762881:G;F=F+1|0}while((F|0)!=256);c[11884]=1}F=c[47544+(d[l>>0]<<2)>>2]|0;G=c[47544+((d[r>>0]^F>>>24)<<2)>>2]^F<<8;F=c[47544+((d[t>>0]^G>>>24)<<2)>>2]^G<<8;G=c[47544+((d[s>>0]^F>>>24)<<2)>>2]^F<<8;F=c[47544+((d[p>>0]^G>>>24)<<2)>>2]^G<<8;G=c[47544+((d[v>>0]^F>>>24)<<2)>>2]^F<<8;F=c[47544+((d[u>>0]^G>>>24)<<2)>>2]^G<<8;J=c[47544+((d[w>>0]^F>>>24)<<2)>>2]^F<<8;do{if((D|0)==1145132097){if(B){break a}F=((c[A>>2]|0)+7|0)>>>3;G=F>>>0<E>>>0?E:F;if((Es(b,c[C>>2]|0,G)|0)!=0){break a}F=c[C>>2]|0;if((c[11884]|0)==0){H=0;do{I=H<<25;K=(H&128|0)!=0?I^517762881:I;I=K<<1;L=(K|0)<0?I^517762881:I;I=L<<1;K=(L|0)<0?I^517762881:I;I=K<<1;L=(K|0)<0?I^517762881:I;I=L<<1;K=(L|0)<0?I^517762881:I;I=K<<1;L=(K|0)<0?I^517762881:I;I=L<<1;K=(L|0)<0?I^517762881:I;I=K<<1;c[47544+(H<<2)>>2]=(K|0)<0?I^517762881:I;H=H+1|0}while((H|0)!=256);c[11884]=1}if((G|0)==0){M=J}else{H=G;I=J;K=F;while(1){L=c[47544+((d[K>>0]^I>>>24)<<2)>>2]^I<<8;N=H+ -1|0;if((N|0)==0){M=L;break}else{H=N;I=L;K=K+1|0}}}if((Zs(b,E-G|0,M)|0)!=0){break a}}else if((D|0)==1413830740){if((E|0)==0){if((Es(b,f,4)|0)!=0){break a}if((Cs(f,0)|0)==(J|0)){break}else{O=26;break b}}P=yz(E)|0;if((P|0)==0){break a}if((Es(b,P,E)|0)!=0){O=29;break b}if((c[11884]|0)==0){K=0;do{I=K<<25;H=(K&128|0)!=0?I^517762881:I;I=H<<1;F=(H|0)<0?I^517762881:I;I=F<<1;H=(F|0)<0?I^517762881:I;I=H<<1;F=(H|0)<0?I^517762881:I;I=F<<1;H=(F|0)<0?I^517762881:I;I=H<<1;F=(H|0)<0?I^517762881:I;I=F<<1;H=(F|0)<0?I^517762881:I;I=H<<1;c[47544+(K<<2)>>2]=(H|0)<0?I^517762881:I;K=K+1|0}while((K|0)!=256);c[11884]=1;Q=E;R=J;S=P}else{Q=E;R=J;S=P}while(1){T=c[47544+((d[S>>0]^R>>>24)<<2)>>2]^R<<8;K=Q+ -1|0;if((K|0)==0){U=0;break}else{Q=K;R=T;S=S+1|0}}while(1){K=a[P+U>>0]|0;if(!(K<<24>>24==0|K<<24>>24==10|K<<24>>24==13)){V=U;break}K=U+1|0;if(K>>>0<E>>>0){U=K}else{V=K;break}}d:do{if(V>>>0<E>>>0){K=E;while(1){G=K+ -1|0;I=a[P+G>>0]|0;if(I<<24>>24==0){W=K+1|0}else if(I<<24>>24==10|I<<24>>24==13){W=G}else{X=K;break d}if(W>>>0>V>>>0){K=W}else{X=W;break}}}else{X=E}}while(0);if((V|0)==(X|0)){if((Es(b,h,4)|0)!=0){break a}if((Cs(h,0)|0)==(T|0)){break}else{O=44;break b}}if(V>>>0<X>>>0){K=V;G=V;while(1){I=a[P+G>>0]|0;do{if(I<<24>>24==13){H=G+1|0;if(H>>>0<X>>>0){if((a[P+H>>0]|0)==10){Y=K;Z=H;break}}a[P+K>>0]=10;Y=K+1|0;Z=G}else{a[P+K>>0]=I;Y=K+1|0;Z=G}}while(0);I=Z+1|0;if(I>>>0<X>>>0){K=Y;G=I}else{_=Y;break}}}else{_=V}if((c[y>>2]|0)!=0){a[j>>0]=10;if((Vs(m,j,1)|0)!=0){break a}}G=(Vs(m,P+V|0,_-V|0)|0)==0;zz(P);if(!G){break a}if((Es(b,h,4)|0)!=0){break a}if((Cs(h,0)|0)!=(T|0)){O=56;break b}}else if((D|0)==1414676811){break c}else if((D|0)==1162757152){O=76;break b}else{if((Zs(b,E,J)|0)!=0){break a}}}while(0);if((Es(b,l,8)|0)!=0){break a}}if(E>>>0<20){break a}if((Es(b,g,20)|0)!=0){break a}if((c[11884]|0)==0){C=0;do{A=C<<25;B=(C&128|0)!=0?A^517762881:A;A=B<<1;D=(B|0)<0?A^517762881:A;A=D<<1;B=(D|0)<0?A^517762881:A;A=B<<1;D=(B|0)<0?A^517762881:A;A=D<<1;B=(D|0)<0?A^517762881:A;A=B<<1;D=(B|0)<0?A^517762881:A;A=D<<1;B=(D|0)<0?A^517762881:A;A=B<<1;c[47544+(C<<2)>>2]=(B|0)<0?A^517762881:A;C=C+1|0}while((C|0)!=256);c[11884]=1;$=20;aa=J;ba=g}else{$=20;aa=J;ba=g}while(1){aa=c[47544+((d[ba>>0]^aa>>>24)<<2)>>2]^aa<<8;$=$+ -1|0;if(($|0)==0){break}else{ba=ba+1|0}}C=Cs(g,0)|0;A=Cs(g,4)|0;B=Cs(g,8)|0;D=Cs(g,12)|0;z=Us(m,C,A,1)|0;if((z|0)==0){break a}if((Ks(z,B)|0)!=0){break a}Js(z,D);if((Zs(b,E+ -20|0,aa)|0)!=0){break a}}if((O|0)==26){fb(48568,15,1,c[o>>2]|0)|0;break}else if((O|0)==29){zz(P);break}else if((O|0)==44){fb(48568,15,1,c[o>>2]|0)|0;break}else if((O|0)==56){fb(48568,15,1,c[o>>2]|0)|0;break}else if((O|0)==76){if((Zs(b,E,J)|0)==0){n=m}else{break}i=e;return n|0}}}}}}}while(0);Rs(m);n=0;i=e;return n|0}function Ys(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=i;i=i+64|0;g=f+40|0;h=f+32|0;j=f;Ds(j,0,1346521428);Ds(j,4,8);Ds(j,8,0);Ds(j,12,0);if((c[11884]|0)==0){k=0;do{l=k<<25;m=(k&128|0)!=0?l^517762881:l;l=m<<1;n=(m|0)<0?l^517762881:l;l=n<<1;m=(n|0)<0?l^517762881:l;l=m<<1;n=(m|0)<0?l^517762881:l;l=n<<1;m=(n|0)<0?l^517762881:l;l=m<<1;n=(m|0)<0?l^517762881:l;l=n<<1;m=(n|0)<0?l^517762881:l;l=m<<1;c[47544+(k<<2)>>2]=(m|0)<0?l^517762881:l;k=k+1|0}while((k|0)!=256);c[11884]=1;o=16;p=0;q=j}else{o=16;p=0;q=j}while(1){p=c[47544+((d[q>>0]^p>>>24)<<2)>>2]^p<<8;o=o+ -1|0;if((o|0)==0){break}else{q=q+1|0}}Ds(j,16,p);if((Gs(b,j,20)|0)!=0){r=1;i=f;return r|0}p=c[e+8>>2]|0;do{if((p|0)!=0){q=yz(p+2|0)|0;if((q|0)==0){r=1;i=f;return r|0}o=c[e+12>>2]|0;a[q>>0]=10;k=0;while(1){l=a[o+k>>0]|0;if(!(l<<24>>24==0|l<<24>>24==10|l<<24>>24==13)){s=k;break}l=k+1|0;if(l>>>0<p>>>0){k=l}else{s=l;break}}if(s>>>0<p>>>0){k=s;l=1;while(1){m=a[o+k>>0]|0;do{if(m<<24>>24==13){n=k+1|0;if(n>>>0<p>>>0){if((a[o+n>>0]|0)==10){t=n;u=l;break}}a[q+l>>0]=10;t=k;u=l+1|0}else{a[q+l>>0]=m;t=k;u=l+1|0}}while(0);k=t+1|0;if(!(k>>>0<p>>>0)){break}else{l=u}}a:do{if(u>>>0>1){l=u;while(1){k=l+ -1|0;o=a[q+k>>0]|0;if(!(o<<24>>24==0|o<<24>>24==10)){v=l;break a}if(k>>>0>1){l=k}else{v=k;break}}}else{v=u}}while(0);if((v|0)!=1){l=v+1|0;a[q+v>>0]=10;Ds(h,0,1413830740);Ds(h,4,l);if((c[11884]|0)==0){k=0;do{o=k<<25;m=(k&128|0)!=0?o^517762881:o;o=m<<1;n=(m|0)<0?o^517762881:o;o=n<<1;m=(n|0)<0?o^517762881:o;o=m<<1;n=(m|0)<0?o^517762881:o;o=n<<1;m=(n|0)<0?o^517762881:o;o=m<<1;n=(m|0)<0?o^517762881:o;o=n<<1;m=(n|0)<0?o^517762881:o;o=m<<1;c[47544+(k<<2)>>2]=(m|0)<0?o^517762881:o;k=k+1|0}while((k|0)!=256);c[11884]=1}k=c[47544+(d[h>>0]<<2)>>2]|0;o=c[47544+((d[h+1>>0]^k>>>24)<<2)>>2]^k<<8;k=c[47544+((d[h+2>>0]^o>>>24)<<2)>>2]^o<<8;o=c[47544+((d[h+3>>0]^k>>>24)<<2)>>2]^k<<8;k=c[47544+((d[h+4>>0]^o>>>24)<<2)>>2]^o<<8;o=c[47544+((d[h+5>>0]^k>>>24)<<2)>>2]^k<<8;k=c[47544+((d[h+6>>0]^o>>>24)<<2)>>2]^o<<8;o=c[47544+((d[h+7>>0]^k>>>24)<<2)>>2]^k<<8;if((Gs(b,h,8)|0)!=0){r=1;i=f;return r|0}if((c[11884]|0)==0){k=0;do{m=k<<25;n=(k&128|0)!=0?m^517762881:m;m=n<<1;w=(n|0)<0?m^517762881:m;m=w<<1;n=(w|0)<0?m^517762881:m;m=n<<1;w=(n|0)<0?m^517762881:m;m=w<<1;n=(w|0)<0?m^517762881:m;m=n<<1;w=(n|0)<0?m^517762881:m;m=w<<1;n=(w|0)<0?m^517762881:m;m=n<<1;c[47544+(k<<2)>>2]=(n|0)<0?m^517762881:m;k=k+1|0}while((k|0)!=256);c[11884]=1}if((l|0)==0){x=o}else{k=l;m=o;n=q;while(1){w=c[47544+((d[n>>0]^m>>>24)<<2)>>2]^m<<8;y=k+ -1|0;if((y|0)==0){x=w;break}else{k=y;m=w;n=n+1|0}}}if((Gs(b,q,l)|0)!=0){r=1;i=f;return r|0}Ds(h,0,x);if((Gs(b,h,4)|0)==0){break}else{r=1}i=f;return r|0}}zz(q)}}while(0);h=c[e>>2]|0;b:do{if((h|0)!=0){x=e+4|0;v=j+1|0;u=j+2|0;p=j+3|0;t=j+4|0;s=j+5|0;n=j+6|0;m=j+7|0;k=h;o=0;c:while(1){w=c[(c[x>>2]|0)+(o<<2)>>2]|0;if((w|0)==0){z=k}else{if((c[w>>2]|0)==0){z=k}else{y=w+4|0;A=0;do{B=c[(c[y>>2]|0)+(A<<2)>>2]|0;if((B|0)!=0){Ds(j,0,1414676811);Ds(j,4,20);Ds(j,8,o);Ds(j,12,A);C=B+4|0;Ds(j,16,c[C>>2]|0);Ds(j,20,c[B>>2]|0);Ds(j,24,0);if((c[11884]|0)==0){D=0;do{E=D<<25;F=(D&128|0)!=0?E^517762881:E;E=F<<1;G=(F|0)<0?E^517762881:E;E=G<<1;F=(G|0)<0?E^517762881:E;E=F<<1;G=(F|0)<0?E^517762881:E;E=G<<1;F=(G|0)<0?E^517762881:E;E=F<<1;G=(F|0)<0?E^517762881:E;E=G<<1;F=(G|0)<0?E^517762881:E;E=F<<1;c[47544+(D<<2)>>2]=(F|0)<0?E^517762881:E;D=D+1|0}while((D|0)!=256);c[11884]=1;H=28;I=0;J=j}else{H=28;I=0;J=j}while(1){I=c[47544+((d[J>>0]^I>>>24)<<2)>>2]^I<<8;H=H+ -1|0;if((H|0)==0){break}else{J=J+1|0}}Ds(j,28,I);if((Gs(b,j,32)|0)!=0){r=1;K=64;break c}D=c[C>>2]|0;if((D|0)!=0){E=(D+7|0)>>>3;Ds(j,0,1145132097);Ds(j,4,E);if((c[11884]|0)==0){D=0;do{F=D<<25;G=(D&128|0)!=0?F^517762881:F;F=G<<1;L=(G|0)<0?F^517762881:F;F=L<<1;G=(L|0)<0?F^517762881:F;F=G<<1;L=(G|0)<0?F^517762881:F;F=L<<1;G=(L|0)<0?F^517762881:F;F=G<<1;L=(G|0)<0?F^517762881:F;F=L<<1;G=(L|0)<0?F^517762881:F;F=G<<1;c[47544+(D<<2)>>2]=(G|0)<0?F^517762881:F;D=D+1|0}while((D|0)!=256);c[11884]=1}D=c[47544+(d[j>>0]<<2)>>2]|0;C=c[47544+((d[v>>0]^D>>>24)<<2)>>2]^D<<8;D=c[47544+((d[u>>0]^C>>>24)<<2)>>2]^C<<8;C=c[47544+((d[p>>0]^D>>>24)<<2)>>2]^D<<8;D=c[47544+((d[t>>0]^C>>>24)<<2)>>2]^C<<8;C=c[47544+((d[s>>0]^D>>>24)<<2)>>2]^D<<8;D=c[47544+((d[n>>0]^C>>>24)<<2)>>2]^C<<8;C=c[47544+((d[m>>0]^D>>>24)<<2)>>2]^D<<8;if((Gs(b,j,8)|0)!=0){r=1;K=64;break c}D=c[B+8>>2]|0;if((c[11884]|0)==0){F=0;do{G=F<<25;L=(F&128|0)!=0?G^517762881:G;G=L<<1;M=(L|0)<0?G^517762881:G;G=M<<1;L=(M|0)<0?G^517762881:G;G=L<<1;M=(L|0)<0?G^517762881:G;G=M<<1;L=(M|0)<0?G^517762881:G;G=L<<1;M=(L|0)<0?G^517762881:G;G=M<<1;L=(M|0)<0?G^517762881:G;G=L<<1;c[47544+(F<<2)>>2]=(L|0)<0?G^517762881:G;F=F+1|0}while((F|0)!=256);c[11884]=1}if((E|0)==0){N=C}else{F=E;B=C;G=D;while(1){L=c[47544+((d[G>>0]^B>>>24)<<2)>>2]^B<<8;M=F+ -1|0;if((M|0)==0){N=L;break}else{F=M;B=L;G=G+1|0}}}if((Gs(b,D,E)|0)!=0){r=1;K=64;break c}Ds(j,0,N);if((Gs(b,j,4)|0)!=0){r=1;K=64;break c}}}A=A+1|0}while(A>>>0<(c[w>>2]|0)>>>0);z=c[e>>2]|0}}o=o+1|0;if(!(o>>>0<z>>>0)){break b}else{k=z}}if((K|0)==64){i=f;return r|0}}}while(0);Ds(g,0,1162757152);Ds(g,4,0);if((c[11884]|0)==0){K=0;do{z=K<<25;e=(K&128|0)!=0?z^517762881:z;z=e<<1;j=(e|0)<0?z^517762881:z;z=j<<1;e=(j|0)<0?z^517762881:z;z=e<<1;j=(e|0)<0?z^517762881:z;z=j<<1;e=(j|0)<0?z^517762881:z;z=e<<1;j=(e|0)<0?z^517762881:z;z=j<<1;e=(j|0)<0?z^517762881:z;z=e<<1;c[47544+(K<<2)>>2]=(e|0)<0?z^517762881:z;K=K+1|0}while((K|0)!=256);c[11884]=1}K=c[47544+(d[g>>0]<<2)>>2]|0;z=c[47544+((d[g+1>>0]^K>>>24)<<2)>>2]^K<<8;K=c[47544+((d[g+2>>0]^z>>>24)<<2)>>2]^z<<8;z=c[47544+((d[g+3>>0]^K>>>24)<<2)>>2]^K<<8;K=c[47544+((d[g+4>>0]^z>>>24)<<2)>>2]^z<<8;z=c[47544+((d[g+5>>0]^K>>>24)<<2)>>2]^K<<8;K=c[47544+((d[g+6>>0]^z>>>24)<<2)>>2]^z<<8;Ds(g,8,c[47544+((d[g+7>>0]^K>>>24)<<2)>>2]^K<<8);r=(Gs(b,g,12)|0)!=0|0;i=f;return r|0}function Zs(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+256|0;g=f;a:do{if((b|0)==0){h=e}else{j=e;k=b;while(1){l=k>>>0<256?k:256;if((Es(a,g,l)|0)!=0){m=1;break}if((c[11884]|0)==0){n=0;do{p=n<<25;q=(n&128|0)!=0?p^517762881:p;p=q<<1;r=(q|0)<0?p^517762881:p;p=r<<1;q=(r|0)<0?p^517762881:p;p=q<<1;r=(q|0)<0?p^517762881:p;p=r<<1;q=(r|0)<0?p^517762881:p;p=q<<1;r=(q|0)<0?p^517762881:p;p=r<<1;q=(r|0)<0?p^517762881:p;p=q<<1;c[47544+(n<<2)>>2]=(q|0)<0?p^517762881:p;n=n+1|0}while((n|0)!=256);c[11884]=1}if((l|0)==0){s=j}else{n=l;p=j;q=g;while(1){r=c[47544+(((d[q>>0]|0)^p>>>24)<<2)>>2]^p<<8;t=n+ -1|0;if((t|0)==0){s=r;break}else{n=t;p=r;q=q+1|0}}}if((k|0)==(l|0)){h=s;break a}else{j=s;k=k-l|0}}i=f;return m|0}}while(0);if((Es(a,g,4)|0)!=0){m=1;i=f;return m|0}if((Cs(g,0)|0)==(h|0)){m=0;i=f;return m|0}fb(48568,15,1,c[o>>2]|0)|0;m=1;i=f;return m|0}function _s(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;e=i;i=i+288|0;f=e;g=e+32|0;h=e+24|0;j=e+16|0;k=Qs()|0;if((k|0)==0){l=0;i=e;return l|0}if((Es(b,j,4)|0)!=0){l=k;i=e;return l|0}if((c[12156]|0)==0){m=0;do{n=m<<25;p=(m&128|0)!=0?n^517762881:n;n=p<<1;q=(p|0)<0?n^517762881:n;n=q<<1;p=(q|0)<0?n^517762881:n;n=p<<1;q=(p|0)<0?n^517762881:n;n=q<<1;p=(q|0)<0?n^517762881:n;n=p<<1;q=(p|0)<0?n^517762881:n;n=q<<1;p=(q|0)<0?n^517762881:n;n=p<<1;c[48632+(m<<2)>>2]=(p|0)<0?n^517762881:n;m=m+1|0}while((m|0)!=256);c[12156]=1}m=j+1|0;n=c[48632+(d[j>>0]<<2)>>2]|0;p=j+2|0;q=c[48632+((d[m>>0]^n>>>24)<<2)>>2]^n<<8;n=j+3|0;r=c[48632+((d[p>>0]^q>>>24)<<2)>>2]^q<<8;q=c[48632+((d[n>>0]^r>>>24)<<2)>>2]^r<<8;a:do{if((Cs(j,0)|0)==1347569952){r=j+4|0;if((Es(b,r,4)|0)==0){if((c[12156]|0)==0){s=0;do{t=s<<25;u=(s&128|0)!=0?t^517762881:t;t=u<<1;v=(u|0)<0?t^517762881:t;t=v<<1;u=(v|0)<0?t^517762881:t;t=u<<1;v=(u|0)<0?t^517762881:t;t=v<<1;u=(v|0)<0?t^517762881:t;t=u<<1;v=(u|0)<0?t^517762881:t;t=v<<1;u=(v|0)<0?t^517762881:t;t=u<<1;c[48632+(s<<2)>>2]=(u|0)<0?t^517762881:t;s=s+1|0}while((s|0)!=256);c[12156]=1}s=j+5|0;t=c[48632+((d[r>>0]^q>>>24)<<2)>>2]^q<<8;u=j+6|0;v=c[48632+((d[s>>0]^t>>>24)<<2)>>2]^t<<8;t=j+7|0;w=c[48632+((d[u>>0]^v>>>24)<<2)>>2]^v<<8;v=c[48632+((d[t>>0]^w>>>24)<<2)>>2]^w<<8;w=Cs(j,4)|0;if(!(w>>>0<4)){if((Es(b,h,4)|0)==0){if((c[12156]|0)==0){x=0;do{y=x<<25;z=(x&128|0)!=0?y^517762881:y;y=z<<1;A=(z|0)<0?y^517762881:y;y=A<<1;z=(A|0)<0?y^517762881:y;y=z<<1;A=(z|0)<0?y^517762881:y;y=A<<1;z=(A|0)<0?y^517762881:y;y=z<<1;A=(z|0)<0?y^517762881:y;y=A<<1;z=(A|0)<0?y^517762881:y;y=z<<1;c[48632+(x<<2)>>2]=(z|0)<0?y^517762881:y;x=x+1|0}while((x|0)!=256);c[12156]=1}x=c[48632+((d[h>>0]^v>>>24)<<2)>>2]^v<<8;y=c[48632+((d[h+1>>0]^x>>>24)<<2)>>2]^x<<8;x=c[48632+((d[h+2>>0]^y>>>24)<<2)>>2]^y<<8;y=c[48632+((d[h+3>>0]^x>>>24)<<2)>>2]^x<<8;x=As(h,0)|0;if((x|0)!=0){z=c[o>>2]|0;c[f>>2]=x;hb(z|0,49672,f|0)|0;break}z=w+ -4|0;if((z|0)==0){B=y}else{x=y;y=z;while(1){z=y>>>0<256?y:256;if((Es(b,g,z)|0)!=0){break a}if((c[12156]|0)==0){A=0;do{C=A<<25;D=(A&128|0)!=0?C^517762881:C;C=D<<1;E=(D|0)<0?C^517762881:C;C=E<<1;D=(E|0)<0?C^517762881:C;C=D<<1;E=(D|0)<0?C^517762881:C;C=E<<1;D=(E|0)<0?C^517762881:C;C=D<<1;E=(D|0)<0?C^517762881:C;C=E<<1;D=(E|0)<0?C^517762881:C;C=D<<1;c[48632+(A<<2)>>2]=(D|0)<0?C^517762881:C;A=A+1|0}while((A|0)!=256);c[12156]=1}if((z|0)==0){F=x}else{A=z;C=x;D=g;while(1){E=c[48632+((d[D>>0]^C>>>24)<<2)>>2]^C<<8;G=A+ -1|0;if((G|0)==0){F=E;break}else{A=G;C=E;D=D+1|0}}}if((y|0)==(z|0)){B=F;break}else{x=F;y=y-z|0}}}if((Es(b,g,4)|0)==0){y=(Cs(g,0)|0)==(B|0);x=c[o>>2]|0;if(!y){fb(49656,15,1,x|0)|0;break}y=0;b:while(1){if((Es(b,j,8)|0)!=0){break a}w=(y|0)==0;v=y+4|0;D=y+8|0;c:while(1){if((c[12156]|0)==0){C=0;do{A=C<<25;E=(C&128|0)!=0?A^517762881:A;A=E<<1;G=(E|0)<0?A^517762881:A;A=G<<1;E=(G|0)<0?A^517762881:A;A=E<<1;G=(E|0)<0?A^517762881:A;A=G<<1;E=(G|0)<0?A^517762881:A;A=E<<1;G=(E|0)<0?A^517762881:A;A=G<<1;E=(G|0)<0?A^517762881:A;A=E<<1;c[48632+(C<<2)>>2]=(E|0)<0?A^517762881:A;C=C+1|0}while((C|0)!=256);c[12156]=1}C=c[48632+(d[j>>0]<<2)>>2]|0;A=c[48632+((d[m>>0]^C>>>24)<<2)>>2]^C<<8;C=c[48632+((d[p>>0]^A>>>24)<<2)>>2]^A<<8;A=c[48632+((d[n>>0]^C>>>24)<<2)>>2]^C<<8;C=c[48632+((d[r>>0]^A>>>24)<<2)>>2]^A<<8;A=c[48632+((d[s>>0]^C>>>24)<<2)>>2]^C<<8;C=c[48632+((d[u>>0]^A>>>24)<<2)>>2]^A<<8;H=c[48632+((d[t>>0]^C>>>24)<<2)>>2]^C<<8;C=Cs(j,0)|0;I=Cs(j,4)|0;do{if((C|0)==1414676811){break c}else if((C|0)==1162757152){J=34;break b}else if((C|0)==1413830740){if((I|0)==0){if((Es(b,g,4)|0)!=0){break a}if((Cs(g,0)|0)==(H|0)){break}else{J=48;break b}}K=yz(I)|0;if((K|0)==0){break a}if((Es(b,K,I)|0)!=0){J=55;break b}if((c[12156]|0)==0){A=0;do{E=A<<25;G=(A&128|0)!=0?E^517762881:E;E=G<<1;L=(G|0)<0?E^517762881:E;E=L<<1;G=(L|0)<0?E^517762881:E;E=G<<1;L=(G|0)<0?E^517762881:E;E=L<<1;G=(L|0)<0?E^517762881:E;E=G<<1;L=(G|0)<0?E^517762881:E;E=L<<1;G=(L|0)<0?E^517762881:E;E=G<<1;c[48632+(A<<2)>>2]=(G|0)<0?E^517762881:E;A=A+1|0}while((A|0)!=256);c[12156]=1;M=I;N=H;O=K}else{M=I;N=H;O=K}while(1){N=c[48632+((d[O>>0]^N>>>24)<<2)>>2]^N<<8;M=M+ -1|0;if((M|0)==0){break}else{O=O+1|0}}A=(a[K>>0]|0)==10;E=(A<<31>>31)+I|0;if((E|0)==0){P=0}else{G=E+ -1|0;P=(a[K+G>>0]|0)==10?G:E}E=Vs(k,K+(A&1)|0,P)|0;zz(K);if((Es(b,g,4)|0)==0){if((Cs(g,0)|0)==(N|0)){Q=0}else{fb(49656,15,1,x|0)|0;Q=1}}else{Q=1}if((Q|E|0)!=0){break a}}else if((C|0)==1145132097){if(w){break a}E=((c[v>>2]|0)+7|0)>>>3;A=E>>>0>I>>>0?I:E;E=c[D>>2]|0;if((Es(b,E,A)|0)!=0){break a}if((c[12156]|0)==0){G=0;do{L=G<<25;R=(G&128|0)!=0?L^517762881:L;L=R<<1;S=(R|0)<0?L^517762881:L;L=S<<1;R=(S|0)<0?L^517762881:L;L=R<<1;S=(R|0)<0?L^517762881:L;L=S<<1;R=(S|0)<0?L^517762881:L;L=R<<1;S=(R|0)<0?L^517762881:L;L=S<<1;R=(S|0)<0?L^517762881:L;L=R<<1;c[48632+(G<<2)>>2]=(R|0)<0?L^517762881:L;G=G+1|0}while((G|0)!=256);c[12156]=1}if((A|0)==0){T=H}else{G=A;L=H;R=E;while(1){S=c[48632+((d[R>>0]^L>>>24)<<2)>>2]^L<<8;U=G+ -1|0;if((U|0)==0){T=S;break}else{G=U;L=S;R=R+1|0}}}if((A|0)==(I|0)){V=T}else{R=T;L=I-A|0;while(1){G=L>>>0<256?L:256;if((Es(b,g,G)|0)!=0){break a}if((c[12156]|0)==0){E=0;do{S=E<<25;U=(E&128|0)!=0?S^517762881:S;S=U<<1;W=(U|0)<0?S^517762881:S;S=W<<1;U=(W|0)<0?S^517762881:S;S=U<<1;W=(U|0)<0?S^517762881:S;S=W<<1;U=(W|0)<0?S^517762881:S;S=U<<1;W=(U|0)<0?S^517762881:S;S=W<<1;U=(W|0)<0?S^517762881:S;S=U<<1;c[48632+(E<<2)>>2]=(U|0)<0?S^517762881:S;E=E+1|0}while((E|0)!=256);c[12156]=1}if((G|0)==0){X=R}else{E=G;S=R;U=g;while(1){W=c[48632+((d[U>>0]^S>>>24)<<2)>>2]^S<<8;Y=E+ -1|0;if((Y|0)==0){X=W;break}else{E=Y;S=W;U=U+1|0}}}if((L|0)==(G|0)){V=X;break}else{R=X;L=L-G|0}}}if((Es(b,g,4)|0)!=0){break a}if((Cs(g,0)|0)!=(V|0)){J=102;break b}}else{if((I|0)==0){Z=H}else{L=H;R=I;while(1){A=R>>>0<256?R:256;if((Es(b,g,A)|0)!=0){break a}if((c[12156]|0)==0){U=0;do{S=U<<25;E=(U&128|0)!=0?S^517762881:S;S=E<<1;W=(E|0)<0?S^517762881:S;S=W<<1;E=(W|0)<0?S^517762881:S;S=E<<1;W=(E|0)<0?S^517762881:S;S=W<<1;E=(W|0)<0?S^517762881:S;S=E<<1;W=(E|0)<0?S^517762881:S;S=W<<1;E=(W|0)<0?S^517762881:S;S=E<<1;c[48632+(U<<2)>>2]=(E|0)<0?S^517762881:S;U=U+1|0}while((U|0)!=256);c[12156]=1}if((A|0)==0){_=L}else{U=A;G=L;S=g;while(1){E=c[48632+((d[S>>0]^G>>>24)<<2)>>2]^G<<8;W=U+ -1|0;if((W|0)==0){_=E;break}else{U=W;G=E;S=S+1|0}}}if((R|0)==(A|0)){Z=_;break}else{L=_;R=R-A|0}}}if((Es(b,g,4)|0)!=0){break a}if((Cs(g,0)|0)!=(Z|0)){J=113;break b}}}while(0);if((Es(b,j,8)|0)!=0){break a}}if(I>>>0<16){break a}if((Es(b,f,16)|0)!=0){break a}if((c[12156]|0)==0){D=0;do{v=D<<25;w=(D&128|0)!=0?v^517762881:v;v=w<<1;z=(w|0)<0?v^517762881:v;v=z<<1;w=(z|0)<0?v^517762881:v;v=w<<1;z=(w|0)<0?v^517762881:v;v=z<<1;w=(z|0)<0?v^517762881:v;v=w<<1;z=(w|0)<0?v^517762881:v;v=z<<1;w=(z|0)<0?v^517762881:v;v=w<<1;c[48632+(D<<2)>>2]=(w|0)<0?v^517762881:v;D=D+1|0}while((D|0)!=256);c[12156]=1;$=16;aa=H;ba=f}else{$=16;aa=H;ba=f}while(1){aa=c[48632+((d[ba>>0]^aa>>>24)<<2)>>2]^aa<<8;$=$+ -1|0;if(($|0)==0){break}else{ba=ba+1|0}}D=Cs(f,0)|0;v=Cs(f,4)|0;w=Cs(f,8)|0;z=Cs(f,12)|0;C=Us(k,D,v,1)|0;if((C|0)==0){break a}if((Ks(C,w)|0)!=0){break a}Js(C,z);z=I+ -16|0;if((z|0)==0){ca=aa}else{w=aa;v=z;while(1){z=v>>>0<256?v:256;if((Es(b,g,z)|0)!=0){break a}if((c[12156]|0)==0){D=0;do{R=D<<25;L=(D&128|0)!=0?R^517762881:R;R=L<<1;S=(L|0)<0?R^517762881:R;R=S<<1;L=(S|0)<0?R^517762881:R;R=L<<1;S=(L|0)<0?R^517762881:R;R=S<<1;L=(S|0)<0?R^517762881:R;R=L<<1;S=(L|0)<0?R^517762881:R;R=S<<1;L=(S|0)<0?R^517762881:R;R=L<<1;c[48632+(D<<2)>>2]=(L|0)<0?R^517762881:R;D=D+1|0}while((D|0)!=256);c[12156]=1}if((z|0)==0){da=w}else{D=z;R=w;L=g;while(1){S=c[48632+((d[L>>0]^R>>>24)<<2)>>2]^R<<8;G=D+ -1|0;if((G|0)==0){da=S;break}else{D=G;R=S;L=L+1|0}}}if((v|0)==(z|0)){ca=da;break}else{w=da;v=v-z|0}}}if((Es(b,g,4)|0)!=0){break a}if((Cs(g,0)|0)==(ca|0)){y=C}else{J=83;break}}if((J|0)==34){if((I|0)==0){ea=H}else{y=H;t=I;while(1){u=t>>>0<256?t:256;if((Es(b,g,u)|0)!=0){break a}if((c[12156]|0)==0){s=0;do{r=s<<25;v=(s&128|0)!=0?r^517762881:r;r=v<<1;w=(v|0)<0?r^517762881:r;r=w<<1;v=(w|0)<0?r^517762881:r;r=v<<1;w=(v|0)<0?r^517762881:r;r=w<<1;v=(w|0)<0?r^517762881:r;r=v<<1;w=(v|0)<0?r^517762881:r;r=w<<1;v=(w|0)<0?r^517762881:r;r=v<<1;c[48632+(s<<2)>>2]=(v|0)<0?r^517762881:r;s=s+1|0}while((s|0)!=256);c[12156]=1}if((u|0)==0){fa=y}else{s=u;C=y;r=g;while(1){v=c[48632+((d[r>>0]^C>>>24)<<2)>>2]^C<<8;w=s+ -1|0;if((w|0)==0){fa=v;break}else{s=w;C=v;r=r+1|0}}}if((t|0)==(u|0)){ea=fa;break}else{y=fa;t=t-u|0}}}if((Es(b,g,4)|0)!=0){break}if((Cs(g,0)|0)==(ea|0)){l=k;i=e;return l|0}else{fb(49656,15,1,x|0)|0;break}}else if((J|0)==48){fb(49656,15,1,x|0)|0;break}else if((J|0)==55){zz(K);break}else if((J|0)==83){fb(49656,15,1,x|0)|0;break}else if((J|0)==102){fb(49656,15,1,x|0)|0;break}else if((J|0)==113){fb(49656,15,1,x|0)|0;break}}}}}}}while(0);Rs(k);l=0;i=e;return l|0}function $s(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;i=i+48|0;f=e+8|0;g=e+4|0;h=e+32|0;j=e;k=e+16|0;Ds(f,0,0);if((at(b,1347569952,4,f)|0)!=0){l=1;i=e;return l|0}m=d+8|0;if((c[m>>2]|0)!=0){Ds(k,0,1413830740);Ds(k,4,(c[m>>2]|0)+2|0);n=k+8|0;a[n>>0]=10;c[j>>2]=0;o=bt(b,k,9,j)|0;p=bt(b,c[d+12>>2]|0,c[m>>2]|0,j)|0|o;o=p|(bt(b,n,1,j)|0);Ds(k,0,c[j>>2]|0);if((o|(Gs(b,k,4)|0)|0)!=0){l=1;i=e;return l|0}}o=c[d>>2]|0;a:do{if((o|0)==0){q=h}else{j=d+4|0;n=o;p=0;b:while(1){m=c[(c[j>>2]|0)+(p<<2)>>2]|0;if((m|0)==0){r=n}else{if((c[m>>2]|0)==0){r=n}else{s=m+4|0;t=0;do{u=c[(c[s>>2]|0)+(t<<2)>>2]|0;if((u|0)!=0){Ds(k,0,p);Ds(k,4,t);v=u+4|0;Ds(k,8,c[v>>2]|0);Ds(k,12,c[u>>2]|0);if((at(b,1414676811,16,k)|0)!=0){l=1;w=22;break b}x=c[v>>2]|0;if((x|0)!=0){c[g>>2]=0;v=(x+7|0)>>>3;Ds(h,0,1145132097);Ds(h,4,v);if((bt(b,h,8,g)|0)!=0){l=1;w=22;break b}if((bt(b,c[u+8>>2]|0,v,g)|0)!=0){l=1;w=22;break b}Ds(h,0,c[g>>2]|0);if((Gs(b,h,4)|0)!=0){l=1;w=22;break b}}}t=t+1|0}while(t>>>0<(c[m>>2]|0)>>>0);r=c[d>>2]|0}}m=p+1|0;if(m>>>0<r>>>0){n=r;p=m}else{q=h;break a}}if((w|0)==22){i=e;return l|0}}}while(0);Ds(q,0,1162757152);Ds(q,4,0);c[f>>2]=0;if((bt(b,q,8,f)|0)==0){Ds(q,0,c[f>>2]|0);y=(Gs(b,q,4)|0)==0}else{y=0}l=y&1^1;i=e;return l|0}function at(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f;h=f+8|0;Ds(h,0,b);Ds(h,4,d);c[g>>2]=0;if((bt(a,h,8,g)|0)!=0){j=1;i=f;return j|0}if((d|0)!=0){if((bt(a,e,d,g)|0)!=0){j=1;i=f;return j|0}}Ds(h,0,c[g>>2]|0);j=(Gs(a,h,4)|0)!=0|0;i=f;return j|0}function bt(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;if((f|0)==0){h=Gs(a,b,e)|0;j=(h|0)!=0;k=j&1;i=g;return k|0}l=c[f>>2]|0;if((c[12156]|0)==0){m=0;do{n=m<<25;o=(m&128|0)!=0?n^517762881:n;n=o<<1;p=(o|0)<0?n^517762881:n;n=p<<1;o=(p|0)<0?n^517762881:n;n=o<<1;p=(o|0)<0?n^517762881:n;n=p<<1;o=(p|0)<0?n^517762881:n;n=o<<1;p=(o|0)<0?n^517762881:n;n=p<<1;o=(p|0)<0?n^517762881:n;n=o<<1;c[48632+(m<<2)>>2]=(o|0)<0?n^517762881:n;m=m+1|0}while((m|0)!=256);c[12156]=1}if((e|0)==0){q=l}else{m=e;n=l;l=b;while(1){o=c[48632+(((d[l>>0]|0)^n>>>24)<<2)>>2]^n<<8;p=m+ -1|0;if((p|0)==0){q=o;break}else{m=p;n=o;l=l+1|0}}}c[f>>2]=q;h=Gs(a,b,e)|0;j=(h|0)!=0;k=j&1;i=g;return k|0}function ct(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;i=i+2048|0;g=f+1536|0;h=f;j=f+1024|0;k=Qs()|0;if((k|0)==0){l=0;i=f;return l|0}if((Fs(e,0,g,512)|0)==0){if((As(g,0)|0)==23205){m=(d[g+258>>0]|0)+1|0;n=a[g+259>>0]|0;o=n&255;p=2;while(1){q=p+1|0;if((a[g+p>>0]|0)==0){r=7;break}if(q>>>0<66){p=q}else{s=q;r=8;break}}if((r|0)==7){if(p>>>0>2){s=p;r=8}}if((r|0)==8){Ws(k,g+2|0,s+ -2|0)|0}if((Fs(e,773,g,512)|0)==0){s=0;do{c[h+(s<<2)>>2]=(As(g,s<<1)|0)<<8;s=s+1|0}while((s|0)!=256);if((Fs(e,1285,g,512)|0)==0){s=0;do{b[j+(s<<1)>>1]=Bs(g,s<<1)|0;s=s+1|0}while((s|0)!=256);if(m>>>0>99|(n&255)>2){Rs(k);l=0;i=f;return l|0}if(n<<24>>24==0){n=0;while(1){s=n+1|0;if(s>>>0<m>>>0){n=s}else{l=k;break}}i=f;return l|0}else{t=0}a:while(1){n=0;s=t<<1;while(1){if(s>>>0>255){r=26;break a}g=c[h+(s<<2)>>2]|0;if((g|0)!=0){p=b[j+(s<<1)>>1]|0;if(!(p<<16>>16==0)){q=Us(k,t,n,1)|0;if((q|0)==0){r=27;break a}if((Ks(q,(p&65535)<<3)|0)!=0){r=27;break a}Js(q,(p&65535)<8e3?25e4:5e5);if((Fs(e,g,c[q+8>>2]|0,((c[q+4>>2]|0)+7|0)>>>3)|0)!=0){r=27;break a}}}n=n+1|0;if(!(n>>>0<o>>>0)){break}else{s=s+1|0}}s=t+1|0;if(s>>>0<m>>>0){t=s}else{l=k;r=29;break}}if((r|0)==26){Rs(k);l=0;i=f;return l|0}else if((r|0)==27){Rs(k);l=0;i=f;return l|0}else if((r|0)==29){i=f;return l|0}}}}}Rs(k);l=0;i=f;return l|0}function dt(a,b){a=a|0;b=b|0;return 1}function et(b){b=b|0;var c=0,d=0,e=0,f=0,g=0;c=i;d=b;b=49848;while(1){e=a[d>>0]|0;if(e<<24>>24==0){break}else if(e<<24>>24==46){f=d}else{f=b}d=d+1|0;b=f}if((Ez(b,49712)|0)==0){g=1}else{if((Ez(b,49720)|0)==0){g=2}else{if((Ez(b,49728)|0)==0){g=3}else{if((Ez(b,49736)|0)==0){g=12}else{if((Ez(b,49744)|0)==0){g=4}else{if((Ez(b,49752)|0)==0){g=12}else{if((Ez(b,49760)|0)==0){g=5}else{if((Ez(b,49768)|0)==0){g=6}else{if((Ez(b,49776)|0)==0){g=11}else{if((Ez(b,49784)|0)==0){g=12}else{if((Ez(b,49792)|0)==0){g=13}else{if((Ez(b,49800)|0)==0){g=14}else{if((Ez(b,49808)|0)==0){g=15}else{if((Ez(b,49816)|0)==0){g=16}else{f=(Ez(b,49824)|0)==0;g=f?17:11}}}}}}}}}}}}}}i=c;return g|0}function ft(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;do{switch(b|0){case 2:{d=_t(a)|0;break};case 4:{d=fu(a)|0;break};case 11:{d=Cu(a)|0;break};case 1:{d=Yt(a)|0;break};case 13:{d=Iu(a)|0;break};case 14:{d=Ou(a)|0;break};case 3:{d=au(a)|0;break};case 5:{d=iu(a)|0;break};case 15:{d=Ru(a)|0;break};case 17:{d=Wu(a)|0;break};case 16:{d=Tu(a)|0;break};case 12:{d=Ku(a)|0;break};case 10:case 9:case 8:case 7:case 6:{d=lu(a)|0;break};default:{d=0}}}while(0);i=c;return d|0}function gt(b){b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,j=0;c=i;d=Ib(b|0,49832)|0;if((d|0)==0){e=0;i=c;return e|0}f=jt(d)|0;zb(d|0)|0;if((f|0)==12){g=b;h=49848}else{e=f;i=c;return e|0}while(1){e=a[g>>0]|0;if(e<<24>>24==46){j=g}else if(e<<24>>24==0){break}else{j=h}g=g+1|0;h=j}j=(Ez(h,49792)|0)==0;i=c;return(j?13:12)|0}function ht(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;do{switch(c|0){case 9:{e=mu(a,b,2)|0;break};case 1:{e=Zt(a,b)|0;break};case 4:{e=gu(a,b)|0;break};case 10:{e=mu(a,b,4)|0;break};case 6:{e=mu(a,b,-1)|0;break};case 7:{e=mu(a,b,0)|0;break};case 12:{e=Mu(a,b)|0;break};case 2:{e=$t(a,b)|0;break};case 8:{e=mu(a,b,1)|0;break};case 16:{e=Uu(a,b)|0;break};case 13:{e=Lu(a,b)|0;break};case 14:{e=Pu(a,b)|0;break};case 5:{e=ju(a,b)|0;break};case 11:{e=Du(a,b)|0;break};case 17:{e=Xu(a,b)|0;break};case 3:{e=bu(a,b)|0;break};default:{e=1}}}while(0);i=d;return e|0}function it(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=i;if((c|0)==0){e=et(a)|0}else{e=c}c=Ib(a|0,49840)|0;if((c|0)==0){f=1;i=d;return f|0}a=ht(c,b,e)|0;zb(c|0)|0;f=a;i=d;return f|0}function jt(a){a=a|0;var b=0,c=0,d=0;b=i;if((Fu(a)|0)==0){if((nu(a)|0)==0){if((Vu(a)|0)==0){if((hu(a)|0)==0){if((cu(a)|0)==0){if((ku(a)|0)==0){if((Qu(a)|0)==0){c=(Nu(a)|0)==0;d=c?0:12}else{d=14}}else{d=5}}else{d=3}}else{d=4}}else{d=16}}else{d=6}}else{d=11}i=b;return d|0}function kt(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;j=yz(60)|0;if((j|0)==0){k=0;i=h;return k|0}c[j>>2]=0;b[j+4>>1]=d;b[j+6>>1]=e;b[j+8>>1]=f;b[j+10>>1]=g;c[j+12>>2]=0;b[j+16>>1]=2;c[j+20>>2]=0;if((g|0)==0){c[j+24>>2]=0}else{f=yz(g)|0;c[j+24>>2]=f;if((f|0)==0){zz(j);k=0;i=h;return k|0}}b[j+28>>1]=0;c[j+48>>2]=-1;c[j+52>>2]=0;a[j+56>>0]=0;a[j+58>>0]=0;k=j;i=h;return k|0}function lt(a){a=a|0;var b=0,d=0;b=i;if((a|0)==0){i=b;return}else{d=a}do{a=d;d=c[d>>2]|0;zz(c[a+24>>2]|0);zz(a)}while((d|0)!=0);i=b;return}function mt(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=i;g=b[d+4>>1]|0;h=b[d+6>>1]|0;j=b[d+8>>1]|0;k=b[d+10>>1]|0;l=k&65535;m=yz(60)|0;if((m|0)==0){n=0;i=f;return n|0}c[m>>2]=0;b[m+4>>1]=g;b[m+6>>1]=h;b[m+8>>1]=j;b[m+10>>1]=k;j=m+12|0;c[j>>2]=0;h=m+16|0;b[h>>1]=2;g=m+20|0;c[g>>2]=0;if(k<<16>>16==0){c[m+24>>2]=0;o=0}else{k=yz(l)|0;c[m+24>>2]=k;if((k|0)==0){zz(m);n=0;i=f;return n|0}else{o=k}}k=m+28|0;b[k>>1]=0;p=m+48|0;c[p>>2]=-1;q=m+52|0;c[q>>2]=0;r=m+56|0;a[r>>0]=0;s=m+58|0;a[s>>0]=0;c[j>>2]=c[d+12>>2];b[h>>1]=b[d+16>>1]|0;Mz(o|0,c[d+24>>2]|0,l|0)|0;l=b[d+28>>1]|0;b[k>>1]=l;if(!(l<<16>>16==0)){Mz(m+30|0,d+30|0,l&65535|0)|0}c[p>>2]=c[d+48>>2];c[q>>2]=c[d+52>>2];if((a[d+56>>0]|0)!=0){a[r>>0]=1;a[m+57>>0]=a[d+57>>0]|0}if((a[d+58>>0]|0)!=0){a[s>>0]=1;a[m+59>>0]=a[d+59>>0]|0}if((e|0)==0){c[g>>2]=0;n=m;i=f;return n|0}c[g>>2]=c[d+20>>2];g=d;while(1){d=c[g>>2]|0;if((d|0)==0){n=m;t=18;break}e=mt(d,0)|0;c[m>>2]=e;if((e|0)==0){u=m;break}else{g=d}}if((t|0)==18){i=f;return n|0}while(1){t=c[u>>2]|0;zz(c[u+24>>2]|0);zz(u);if((t|0)==0){n=0;break}else{u=t}}i=f;return n|0}function nt(a,b){a=a|0;b=b|0;var d=0,e=0;d=i;e=a;while(1){a=c[e>>2]|0;if((a|0)==0){break}else{e=a}}c[e>>2]=b;i=d;return}function ot(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;a:do{if((b|0)==0){e=a}else{f=a;g=b;while(1){if((f|0)==0){e=0;break a}h=c[f>>2]|0;j=g+ -1|0;if((j|0)==0){e=h;break}else{f=h;g=j}}}}while(0);i=d;return e|0}function pt(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0;g=i;h=a+10|0;if(!((e[h>>1]|0)>>>0<d>>>0)){b[h>>1]=d;j=0;i=g;return j|0}k=a+24|0;a=Az(c[k>>2]|0,d)|0;if((a|0)==0){j=1;i=g;return j|0}l=e[h>>1]|0;if(l>>>0<d>>>0){Oz(a+l|0,f&255|0,d-l|0)|0}b[h>>1]=d;c[k>>2]=a;j=0;i=g;return j|0}function qt(d,f){d=d|0;f=f|0;var g=0,h=0,j=0;g=i;h=d+10|0;if((b[h>>1]|0)==0){i=g;return}j=f&255;f=d+24|0;d=0;do{a[(c[f>>2]|0)+d>>0]=j;d=d+1|0}while(d>>>0<(e[h>>1]|0)>>>0);i=g;return}function rt(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0;e=i;f=b[d+10>>1]|0;if(!((f&65535)>1)){g=1;i=e;return g|0}h=c[d+24>>2]|0;d=a[h>>0]|0;j=1;while(1){k=j+1|0;if(!(d<<24>>24==(a[h+j>>0]|0))){g=0;l=5;break}if(k>>>0<(f&65535)>>>0){j=k}else{g=1;l=5;break}}if((l|0)==5){i=e;return g|0}return 0}function st(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=i;if((d|0)==0){d=a+12|0;c[d>>2]=c[d>>2]&~b;i=e;return}else{d=a+12|0;c[d>>2]=c[d>>2]|b;i=e;return}}function tt(a,d){a=a|0;d=d|0;var e=0,f=0;e=i;if((a|0)==0){i=e;return}f=d&65535;d=a;do{b[d+16>>1]=f;d=c[d>>2]|0}while((d|0)!=0);i=e;return}function ut(a,b){a=a|0;b=b|0;c[a+48>>2]=b;return}function vt(a){a=a|0;return c[a+48>>2]|0}function wt(a,b){a=a|0;b=b|0;c[a+52>>2]=b;return}function xt(a){a=a|0;return c[a+52>>2]|0}function yt(b,c){b=b|0;c=c|0;a[b+56>>0]=1;a[b+57>>0]=c;return}function zt(b){b=b|0;var c=0,f=0,g=0;c=i;if((a[b+56>>0]|0)!=0){f=d[b+57>>0]|0;i=c;return f|0}g=e[b+10>>1]|0;b=0;while(1){if((128<<b|0)<(g|0)){b=b+1|0}else{f=b;break}}i=c;return f|0}function At(b,c){b=b|0;c=c|0;a[b+58>>0]=1;a[b+59>>0]=c;return}function Bt(b){b=b|0;var c=0,e=0;c=i;if((a[b+58>>0]|0)==0){e=0;i=c;return e|0}e=d[b+59>>0]|0;i=c;return e|0}function Ct(c,d,e){c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=i;g=e>>>0>16?16:e;b[c+28>>1]=g;if((g|0)==0){i=f;return g|0}h=e>>>0<16?e:16;e=0;do{a[c+e+30>>0]=a[d+e>>0]|0;e=e+1|0}while((e|0)!=(h|0));i=f;return g|0}function Dt(b,c,d){b=b|0;c=c|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0;f=i;g=e[b+28>>1]|0;h=g>>>0>d>>>0?d:g;if((h|0)!=0){j=~d;k=~g;l=~(j>>>0>k>>>0?j:k);k=0;do{a[c+k>>0]=a[b+k+30>>0]|0;k=k+1|0}while((k|0)!=(l|0))}if(!(h>>>0<d>>>0)){i=f;return h|0}l=~d;k=~g;g=l>>>0>k>>>0?l:k;Oz(c+~g|0,0,g+d+1|0)|0;i=f;return h|0}function Et(a){a=a|0;var d=0,e=0,f=0;d=i;e=yz(8)|0;if((e|0)==0){f=0;i=d;return f|0}b[e>>1]=a;b[e+2>>1]=0;c[e+4>>2]=0;f=e;i=d;return f|0}function Ft(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;if((a|0)==0){i=d;return}e=a+2|0;f=b[e>>1]|0;g=a+4|0;h=c[g>>2]|0;if(f<<16>>16==0){j=h}else{k=f;f=h;h=0;while(1){l=c[f+(h<<2)>>2]|0;if((l|0)==0){m=k;n=f}else{o=l;do{l=o;o=c[o>>2]|0;zz(c[l+24>>2]|0);zz(l)}while((o|0)!=0);m=b[e>>1]|0;n=c[g>>2]|0}o=h+1|0;if(o>>>0<(m&65535)>>>0){k=m;f=n;h=o}else{j=n;break}}}zz(j);zz(a);i=d;return}function Gt(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0;f=i;g=a+4|0;h=a+2|0;a=Az(c[g>>2]|0,((e[h>>1]|0)<<2)+4|0)|0;if((a|0)==0){j=1;i=f;return j|0}c[g>>2]=a;g=e[h>>1]|0;c[a+(g<<2)>>2]=d;b[h>>1]=g+1;j=0;i=f;return j|0}function Ht(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;g=i;h=b[a+2>>1]|0;j=h&65535;if(h<<16>>16==0){k=0;i=g;return k|0}if((f|0)!=0){if(!(j>>>0>d>>>0)){k=0;i=g;return k|0}k=c[(c[a+4>>2]|0)+(d<<2)>>2]|0;i=g;return k|0}f=a+4|0;a=d;d=h;l=0;a:while(1){m=c[f>>2]|0;n=d&65535;o=0;p=0;q=0;while(1){r=b[(c[m+(o<<2)>>2]|0)+8>>1]|0;if((r&65535)>>>0<l>>>0){s=p;t=q}else{if((p|0)==0){s=1;t=o}else{u=b[(c[m+(q<<2)>>2]|0)+8>>1]|0;if((r&65535)<(u&65535)){s=1;t=o}else{s=(r<<16>>16==u<<16>>16)+p|0;t=q}}}o=o+1|0;if(!(o>>>0<n>>>0)){break}else{p=s;q=t}}if((s|0)==0){k=0;v=22;break}if(a>>>0<s>>>0){if(d<<16>>16==0){w=a;x=0}else{q=c[f>>2]|0;p=b[(c[q+(t<<2)>>2]|0)+8>>1]|0;n=a;o=0;while(1){m=c[q+(o<<2)>>2]|0;if((b[m+8>>1]|0)==p<<16>>16){if((n|0)==0){k=m;v=22;break a}y=n+ -1|0}else{y=n}m=o+1|0;if(m>>>0<j>>>0){n=y;o=m}else{w=y;x=h;break}}}}else{w=a-s|0;x=d}a=w;d=x;l=(e[(c[(c[f>>2]|0)+(t<<2)>>2]|0)+8>>1]|0)+1|0}if((v|0)==22){i=g;return k|0}return 0}function It(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=i;g=b[a+2>>1]|0;h=g&65535;if((g&65535)<2){j=0;i=f;return j|0}g=yz(h<<2)|0;if((g|0)==0){j=1;i=f;return j|0}k=a+4|0;l=0;do{m=(c[k>>2]|0)+(l<<2)|0;n=c[m>>2]|0;c[m>>2]=0;a:do{if((l|0)==0){o=0}else{m=b[n+8>>1]|0;p=l;while(1){q=p+ -1|0;r=c[g+(q<<2)>>2]|0;if(!((m&65535)<(e[r+8>>1]|0))){o=p;break a}c[g+(p<<2)>>2]=r;if((q|0)==0){o=0;break}else{p=q}}}}while(0);c[g+(o<<2)>>2]=n;l=l+1|0}while((l|0)!=(h|0));l=a+4|0;a=0;o=0;while(1){k=c[l>>2]|0;p=k+(o<<2)|0;if((c[p>>2]|0)==0){s=p;t=o}else{p=o;while(1){m=((p+1|0)>>>0)%(h>>>0)|0;q=k+(m<<2)|0;if((c[q>>2]|0)==0){s=q;t=m;break}else{p=m}}}c[s>>2]=c[g+(a<<2)>>2];a=a+1|0;if((a|0)==(h|0)){break}else{o=((t+d|0)>>>0)%(h>>>0)|0}}zz(g);j=0;i=f;return j|0}function Jt(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;d=i;e=a+2|0;f=b[e>>1]|0;g=a+4|0;a=c[g>>2]|0;if(f<<16>>16==0){h=a;zz(h);b[e>>1]=0;c[g>>2]=0;i=d;return}else{j=f;k=a;l=0}while(1){a=c[k+(l<<2)>>2]|0;if((a|0)==0){m=j;n=k}else{f=a+2|0;o=b[f>>1]|0;p=a+4|0;q=c[p>>2]|0;if(o<<16>>16==0){r=q}else{s=q;q=o;o=0;while(1){t=c[s+(o<<2)>>2]|0;if((t|0)==0){u=q;v=s}else{w=t;do{t=w;w=c[w>>2]|0;zz(c[t+24>>2]|0);zz(t)}while((w|0)!=0);u=b[f>>1]|0;v=c[p>>2]|0}w=o+1|0;if(w>>>0<(u&65535)>>>0){s=v;q=u;o=w}else{r=v;break}}}zz(r);zz(a);m=b[e>>1]|0;n=c[g>>2]|0}o=l+1|0;if(o>>>0<(m&65535)>>>0){j=m;k=n;l=o}else{h=n;break}}zz(h);b[e>>1]=0;c[g>>2]=0;i=d;return}function Kt(){var a=0,d=0,e=0;a=i;d=yz(16)|0;if((d|0)==0){e=0;i=a;return e|0}b[d>>1]=0;c[d+4>>2]=0;c[d+8>>2]=0;c[d+12>>2]=0;e=d;i=a;return e|0}function Lt(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;if((a|0)==0){i=d;return}e=b[a>>1]|0;f=a+4|0;g=c[f>>2]|0;if(e<<16>>16==0){h=g}else{j=e;e=g;g=0;while(1){k=c[e+(g<<2)>>2]|0;if((k|0)==0){l=j;m=e}else{Jt(k);zz(k);l=b[a>>1]|0;m=c[f>>2]|0}k=g+1|0;if(k>>>0<(l&65535)>>>0){j=l;e=m;g=k}else{h=m;break}}}zz(h);b[a>>1]=0;c[f>>2]=0;zz(c[a+12>>2]|0);zz(a);i=d;return}function Mt(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;e=b[a>>1]|0;f=a+4|0;g=c[f>>2]|0;if(e<<16>>16==0){h=g}else{j=e;e=g;g=0;while(1){k=c[e+(g<<2)>>2]|0;if((k|0)==0){l=j;m=e}else{Jt(k);zz(k);l=b[a>>1]|0;m=c[f>>2]|0}k=g+1|0;if(k>>>0<(l&65535)>>>0){j=l;e=m;g=k}else{h=m;break}}}zz(h);b[a>>1]=0;c[f>>2]=0;f=a+12|0;zz(c[f>>2]|0);c[a+8>>2]=0;c[f>>2]=0;i=d;return}function Nt(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;g=i;h=e[a>>1]|0;j=a+4|0;k=c[j>>2]|0;a:do{if(h>>>0>f>>>0){l=k}else{m=h;n=k;while(1){o=Az(n,(m<<2)+4|0)|0;if((o|0)==0){p=1;q=11;break}c[j>>2]=o;r=b[a>>1]|0;s=yz(8)|0;if((s|0)==0){p=1;q=11;break}b[s>>1]=r;b[s+2>>1]=0;c[s+4>>2]=0;t=r&65535;c[o+(t<<2)>>2]=s;s=t+1|0;b[a>>1]=s;t=s&65535;if(t>>>0>f>>>0){l=o;break a}else{m=t;n=o}}if((q|0)==11){i=g;return p|0}}}while(0);q=c[l+(f<<2)>>2]|0;if((q|0)==0){p=1;i=g;return p|0}f=q+4|0;l=q+2|0;q=Az(c[f>>2]|0,((e[l>>1]|0)<<2)+4|0)|0;if((q|0)==0){p=1;i=g;return p|0}c[f>>2]=q;f=b[l>>1]|0;do{if((d|0)==0){a=yz(8)|0;if((a|0)==0){p=1;i=g;return p|0}else{b[a>>1]=f;b[a+2>>1]=0;c[a+4>>2]=0;u=a;break}}else{u=d}}while(0);d=f&65535;c[q+(d<<2)>>2]=u;b[l>>1]=d+1;p=0;i=g;return p|0}function Ot(a,d,f){a=a|0;d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=i;h=e[a>>1]|0;if(h>>>0>d>>>0){j=c[(c[a+4>>2]|0)+(d<<2)>>2]|0;i=g;return j|0}if((f|0)==0){j=0;i=g;return j|0}f=a+4|0;k=h;h=c[f>>2]|0;while(1){l=Az(h,(k<<2)+4|0)|0;if((l|0)==0){j=0;m=9;break}c[f>>2]=l;n=b[a>>1]|0;o=yz(8)|0;if((o|0)==0){j=0;m=9;break}b[o>>1]=n;b[o+2>>1]=0;c[o+4>>2]=0;p=n&65535;c[l+(p<<2)>>2]=o;o=p+1|0;b[a>>1]=o;p=o&65535;if(p>>>0>d>>>0){m=8;break}else{k=p;h=l}}if((m|0)==8){j=c[l+(d<<2)>>2]|0;i=g;return j|0}else if((m|0)==9){i=g;return j|0}return 0}function Pt(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0;h=i;j=Qt(a,f,g,1)|0;if((j|0)==0){k=1;i=h;return k|0}g=j+4|0;f=j+2|0;j=Az(c[g>>2]|0,((e[f>>1]|0)<<2)+4|0)|0;if((j|0)==0){k=1;i=h;return k|0}c[g>>2]=j;g=e[f>>1]|0;c[j+(g<<2)>>2]=d;b[f>>1]=g+1;k=0;i=h;return k|0}function Qt(a,d,f,g){a=a|0;d=d|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;h=i;j=e[a>>1]|0;a:do{if(j>>>0>d>>>0){k=c[a+4>>2]|0}else{if((g|0)==0){l=0;i=h;return l|0}m=a+4|0;n=c[m>>2]|0;o=j;while(1){p=Az(n,(o<<2)+4|0)|0;if((p|0)==0){l=0;q=17;break}c[m>>2]=p;r=b[a>>1]|0;s=yz(8)|0;if((s|0)==0){l=0;q=17;break}b[s>>1]=r;b[s+2>>1]=0;c[s+4>>2]=0;t=r&65535;c[p+(t<<2)>>2]=s;s=t+1|0;b[a>>1]=s;t=s&65535;if(t>>>0>d>>>0){k=p;break a}else{n=p;o=t}}if((q|0)==17){i=h;return l|0}}}while(0);a=c[k+(d<<2)>>2]|0;if((a|0)==0){l=0;i=h;return l|0}d=a+2|0;k=e[d>>1]|0;if(k>>>0>f>>>0){l=c[(c[a+4>>2]|0)+(f<<2)>>2]|0;i=h;return l|0}if((g|0)==0){l=0;i=h;return l|0}g=a+4|0;a=k;k=c[g>>2]|0;while(1){u=Az(k,(a<<2)+4|0)|0;if((u|0)==0){l=0;q=17;break}c[g>>2]=u;j=b[d>>1]|0;o=yz(8)|0;if((o|0)==0){l=0;q=17;break}b[o>>1]=j;b[o+2>>1]=0;c[o+4>>2]=0;n=j&65535;c[u+(n<<2)>>2]=o;o=n+1|0;b[d>>1]=o;n=o&65535;if(n>>>0>f>>>0){q=16;break}else{a=n;k=u}}if((q|0)==16){l=c[u+(f<<2)>>2]|0;i=h;return l|0}else if((q|0)==17){i=h;return l|0}return 0}function Rt(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=b[a>>1]|0;if(g<<16>>16==0){i=f;return}h=a+4|0;j=g;g=0;while(1){k=c[(c[h>>2]|0)+(g<<2)>>2]|0;l=k+2|0;if((b[l>>1]|0)==0){m=j}else{n=k+4|0;k=0;do{o=c[(c[n>>2]|0)+(k<<2)>>2]|0;p=o+2|0;q=b[p>>1]|0;if(q<<16>>16==0){r=0}else{s=o+4|0;o=q&65535;q=0;t=0;while(1){u=c[s>>2]|0;v=c[u+(t<<2)>>2]|0;if((v|0)==(d|0)){w=q}else{c[u+(q<<2)>>2]=v;w=q+1|0}v=t+1|0;if(v>>>0<o>>>0){q=w;t=v}else{r=w;break}}}b[p>>1]=r;k=k+1|0}while(k>>>0<(e[l>>1]|0)>>>0);m=b[a>>1]|0}g=g+1|0;if(!(g>>>0<(m&65535)>>>0)){break}else{j=m}}i=f;return}function St(a,d,f,g,h){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0;j=i;a:do{if((e[a>>1]|0)>>>0>d>>>0){k=c[(c[a+4>>2]|0)+(d<<2)>>2]|0;if((k|0)==0){l=0}else{if((e[k+2>>1]|0)>>>0>f>>>0){m=c[(c[k+4>>2]|0)+(f<<2)>>2]|0;if((m|0)==0){l=0}else{k=b[m+2>>1]|0;if((h|0)!=0){if(!((k&65535)>>>0>g>>>0)){l=0;break}l=c[(c[m+4>>2]|0)+(g<<2)>>2]|0;break}if(k<<16>>16==0){l=0}else{n=c[m+4>>2]|0;m=0;while(1){o=c[n+(m<<2)>>2]|0;p=m+1|0;if((e[o+8>>1]|0|0)==(g|0)){l=o;break a}if(p>>>0<(k&65535)>>>0){m=p}else{l=0;break}}}}}else{l=0}}}else{l=0}}while(0);i=j;return l|0}function Tt(a,d,e,f,g){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;j=b[a>>1]|0;if(j<<16>>16==0){k=1;i=h;return k|0}l=c[a+4>>2]|0;a=d;d=0;a:while(1){m=c[l+(d<<2)>>2]|0;n=b[m+2>>1]|0;if(n<<16>>16==0){o=a}else{p=c[m+4>>2]|0;q=a;r=0;while(1){s=c[p+(r<<2)>>2]|0;t=b[s+2>>1]|0;u=t&65535;if(q>>>0<u>>>0){break a}m=q-u|0;v=r+1|0;if(v>>>0<(n&65535)>>>0){q=m;r=v}else{o=m;break}}}n=d+1|0;if(n>>>0<(j&65535)>>>0){a=o;d=n}else{k=1;w=13;break}}if((w|0)==13){i=h;return k|0}o=Ht(s,q,0)|0;if((o|0)==0){k=1;i=h;return k|0}c[e>>2]=d;c[f>>2]=r;c[g>>2]=0;if(t<<16>>16==0){k=1;i=h;return k|0}t=c[s+4>>2]|0;s=0;r=0;while(1){if((c[t+(r<<2)>>2]|0)==(o|0)){k=0;w=13;break}f=s+1|0;c[g>>2]=f;d=r+1|0;if(d>>>0<u>>>0){s=f;r=d}else{k=1;w=13;break}}if((w|0)==13){i=h;return k|0}return 0}function Ut(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a+12|0;g=a+8|0;a=Az(c[f>>2]|0,(c[g>>2]|0)+d|0)|0;if((a|0)==0){h=1;i=e;return h|0}j=c[g>>2]|0;Mz(a+j|0,b|0,d|0)|0;c[g>>2]=j+d;c[f>>2]=a;h=0;i=e;return h|0}function Vt(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a+12|0;zz(c[f>>2]|0);g=a+8|0;c[g>>2]=0;c[f>>2]=0;if((b|0)==0|(d|0)==0){h=0;i=e;return h|0}a=Az(0,d)|0;if((a|0)==0){h=1;i=e;return h|0}j=c[g>>2]|0;Mz(a+j|0,b|0,d|0)|0;c[g>>2]=j+d;c[f>>2]=a;h=0;i=e;return h|0}function Wt(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=i;e=b+8|0;f=c[e>>2]|0;g=b+12|0;b=c[g>>2]|0;a:do{if((f|0)==0){h=0}else{j=0;while(1){k=j+1|0;if((a[b+j>>0]|0)!=10){h=j;break a}if(k>>>0<f>>>0){j=k}else{h=k;break}}}}while(0);if(h>>>0<f>>>0){j=h;h=0;while(1){k=a[b+j>>0]|0;if(k<<24>>24==0){a[b+h>>0]=10;l=j;m=h+1|0}else if(k<<24>>24==13){n=h+1|0;a[b+h>>0]=10;o=j+1|0;if(o>>>0<f>>>0){l=(a[b+o>>0]|0)==10?o:j;m=n}else{l=j;m=n}}else{a[b+h>>0]=k;l=j;m=h+1|0}k=l+1|0;if(k>>>0<f>>>0){j=k;h=m}else{p=m;break}}}else{p=0}while(1){if((p|0)==0){q=14;break}m=p+ -1|0;if((a[b+m>>0]|0)==10){p=m}else{q=13;break}}if((q|0)==13){c[e>>2]=p;i=d;return}else if((q|0)==14){c[e>>2]=0;zz(c[g>>2]|0);c[g>>2]=0;i=d;return}}function Xt(a){a=a|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;e=b[a>>1]|0;if(e<<16>>16==0){f=0;i=d;return f|0}g=c[a+4>>2]|0;a=e&65535;e=0;h=0;while(1){j=c[g+(e<<2)>>2]|0;k=b[j+2>>1]|0;if(k<<16>>16==0){l=h}else{m=c[j+4>>2]|0;j=k&65535;k=h;n=0;while(1){o=c[m+(n<<2)>>2]|0;p=b[o+2>>1]|0;if(p<<16>>16==0){q=k}else{r=c[o+4>>2]|0;o=p&65535;p=k;s=0;while(1){t=c[r+(s<<2)>>2]|0;if((t|0)==0){u=p}else{v=p;w=t;while(1){t=v+1|0;x=c[w>>2]|0;if((x|0)==0){u=t;break}else{v=t;w=x}}}w=s+1|0;if(w>>>0<o>>>0){p=u;s=w}else{q=u;break}}}s=n+1|0;if(s>>>0<j>>>0){k=q;n=s}else{l=q;break}}}n=e+1|0;if(n>>>0<a>>>0){e=n;h=l}else{f=l;break}}i=d;return f|0}function Yt(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=i;i=i+16|0;f=e;g=Kt()|0;if((g|0)==0){h=0;i=e;return h|0}j=f+1|0;k=f+7|0;l=f+6|0;m=f+2|0;n=f+3|0;o=f+4|0;p=f+5|0;do{q=ta(f|0,1,8,b|0)|0;if((q|0)==0){h=g;r=9;break}else if((q|0)!=8){break}q=a[f>>0]|0;s=a[j>>0]|0;t=(d[k>>0]|0)<<8|(d[l>>0]|0);u=kt(d[m>>0]|0,d[n>>0]|0,d[o>>0]|0,t)|0;if((u|0)==0){break}yt(u,a[p>>0]|0);if((Pt(g,u,q&255,s&255)|0)!=0){r=6;break}}while((ta(c[u+24>>2]|0,1,t|0,b|0)|0)==(t|0));if((r|0)==6){lt(u)}else if((r|0)==9){i=e;return h|0}Lt(g);h=0;i=e;return h|0}function Zt(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;g=i;i=i+16|0;h=g;j=b[f>>1]|0;a:do{if(!(j<<16>>16==0)){k=f+4|0;l=h+1|0;m=h+2|0;n=h+3|0;o=h+4|0;p=h+5|0;q=h+6|0;r=h+7|0;s=j;t=0;b:while(1){u=c[(c[k>>2]|0)+(t<<2)>>2]|0;v=u+2|0;w=b[v>>1]|0;if(w<<16>>16==0){x=s}else{y=u+4|0;u=t&255;z=w;w=0;while(1){A=c[(c[y>>2]|0)+(w<<2)>>2]|0;B=A+2|0;if((b[B>>1]|0)==0){C=z}else{D=A+4|0;A=w&255;E=0;do{F=c[(c[D>>2]|0)+(E<<2)>>2]|0;G=zt(F)|0;a[h>>0]=u;a[l>>0]=A;a[m>>0]=b[F+4>>1];a[n>>0]=b[F+6>>1];a[o>>0]=b[F+8>>1];a[p>>0]=G;G=F+10|0;H=b[G>>1]|0;a[q>>0]=H;a[r>>0]=(H&65535)>>>8;if((fb(h|0,1,8,d|0)|0)!=8){I=1;J=15;break b}H=fb(c[F+24>>2]|0,1,e[G>>1]|0,d|0)|0;E=E+1|0;if((H|0)!=(e[G>>1]|0)){I=1;J=15;break b}}while(E>>>0<(e[B>>1]|0)>>>0);C=b[v>>1]|0}w=w+1|0;if(!(w>>>0<(C&65535)>>>0)){break}else{z=C}}x=b[f>>1]|0}t=t+1|0;if(!(t>>>0<(x&65535)>>>0)){break a}else{s=x}}if((J|0)==15){i=g;return I|0}}}while(0);Nb(d|0)|0;I=0;i=g;return I|0}function _t(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;e=i;i=i+448|0;f=e;g=e+48|0;h=e+16|0;j=Kt()|0;if((j|0)==0){k=0;i=e;return k|0}a:do{if((ev(b,0,h,30)|0)==0){if((Dz(h,49936,16)|0)!=0){fb(49952,20,1,c[o>>2]|0)|0;break}l=h+16|0;m=0;while(1){n=m+1|0;if((Dz(l,c[49976+(m<<2)>>2]|0,14)|0)==0){break}if((n|0)==5){p=8;break}else{m=n}}if((p|0)==8){fb(5e4,34,1,c[o>>2]|0)|0}m=f+1|0;l=g+3|0;n=g+2|0;q=g+1|0;r=c[o>>2]|0;s=30;b:while(1){if((ev(b,s,f,2)|0)!=0){k=j;p=60;break}t=d[m>>0]<<8|d[f>>0];if((t|0)==0){k=j;p=60;break}u=s+2|0;if((ev(b,t+u|0,f,2)|0)!=0){break a}v=d[m>>0]<<8|d[f>>0];w=t+4|0;if(!(t>>>0<387)){x=w+s|0;y=387;z=0;while(1){if((ev(b,z+u|0,g,387)|0)!=0){break a}A=a[n>>0]|0;B=A&255;if(!(A<<24>>24==0)){if((A&255)>24){break a}A=Qt(j,d[g>>0]|0,d[q>>0]|0,1)|0;if((A|0)==0){break a}else{C=0;D=l}while(1){C=C+1|0;E=D+9|0;F=D+8|0;G=d[E>>0]<<8|d[F>>0];H=D+2|0;if((a[H>>0]&-106)<<24>>24==0){if((a[D+10>>0]|0)==0){if((a[D+11>>0]|0)==0){if((a[D+14>>0]&127)==0){if((a[D+15>>0]|0)==0){I=a[D+7>>0]|0;if((I&255)<7&G>>>0>5804){J=I}else{p=26}}else{p=26}}else{p=26}}else{p=26}}else{p=26}}else{p=26}if((p|0)==26){p=0;I=d[q>>0]|0;c[f>>2]=d[g>>0]|0;c[f+4>>2]=I;c[f+8>>2]=C;hb(r|0,49904,f|0)|0;I=0;do{if((I|0)==8){fb(49920,2,1,r|0)|0}else{if((I&3|0)==0){$b(32,r|0)|0}}c[f>>2]=d[D+I>>0]|0;hb(r|0,49928,f|0)|0;I=I+1|0}while((I|0)!=16);$b(10,r|0)|0;Nb(r|0)|0;J=a[D+7>>0]|0}if((J&255)<7){K=128<<(J&255)}else{K=0}L=kt(d[D+4>>0]|0,d[D+5>>0]|0,d[D+6>>0]|0,K)|0;if((L|0)==0){break a}yt(L,a[D+7>>0]|0);if((Gt(A,L)|0)!=0){p=37;break b}I=d[E>>0]<<8|d[F>>0];do{if((a[D+14>>0]&50)==0){G=D+3|0;if(!((a[G>>0]&1)==0)){qt(L,0);M=G;break}if((K+ -256|0)>>>0>3840){qt(L,0);M=G;break}if(I>>>0<5805){qt(L,0);M=G;break}N=I+ -5805|0;if((N+K|0)>>>0>v>>>0){O=d[q>>0]|0;c[f>>2]=d[g>>0]|0;c[f+4>>2]=O;c[f+8>>2]=C;c[f+12>>2]=K;hb(r|0,49856,f|0)|0;qt(L,0);M=G;break}else{if((ev(b,x+N|0,c[L+24>>2]|0,K)|0)==0){M=G;break}else{break a}}}else{qt(L,0);M=D+3|0}}while(0);do{if(!((a[H>>0]&32)==0)){if((a[M>>0]&32)==0){st(L,1,1);break}else{st(L,2,1);break}}}while(0);H=a[M>>0]|0;if((H&1)==0){P=H}else{st(L,8,1);P=a[M>>0]|0}if(!((P&64)==0)){st(L,4,1)}if(!(C>>>0<B>>>0)){break}else{D=D+16|0}}}B=y+387|0;if(B>>>0>t>>>0){break}else{A=y;y=B;z=A}}}z=v+w|0;if((z|0)==0){k=j;p=60;break}else{s=z+s|0}}if((p|0)==37){lt(L);break}else if((p|0)==60){i=e;return k|0}}}while(0);Lt(j);k=0;i=e;return k|0}function $t(a,b){a=a|0;b=b|0;return 1}function au(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;g=i;i=i+160|0;h=g+136|0;j=g;k=g+8|0;l=Kt()|0;if((l|0)==0){m=0;i=g;return m|0}a:do{if((dv(f,k,84)|0)==0){n=(Yu(k,82)|0)!=256;if(!(n|(d[k>>0]|0)>63)){n=Zu(k,64)|0;p=Zu(k,68)|0;q=Zu(k,72)|0;r=Zu(k,76)|0;s=a[k+81>>0]|0;if((n|0)==409600){t=du(f,l,1,j,s&255)|0}else if((n|0)==1474560){t=eu(f,l,18,j)|0}else if((n|0)==737280){t=eu(f,l,9,j)|0}else if((n|0)==819200){t=du(f,l,2,j,s&255)|0}else{break}if((t|0)==0){if((q|0)!=(c[j>>2]|0)){fb(50128,26,1,c[o>>2]|0)|0;break}if((p|0)==0){m=l;i=g;return m|0}c[j>>2]=0;q=b[l>>1]|0;if(q<<16>>16==0){u=p;v=0}else{s=l+4|0;n=h+1|0;w=h+2|0;x=h+3|0;y=h+4|0;z=h+5|0;A=h+6|0;B=h+7|0;C=h+8|0;D=h+9|0;E=h+10|0;F=h+11|0;G=p;p=0;H=q;q=0;while(1){I=c[(c[s>>2]|0)+(q<<2)>>2]|0;J=I+2|0;K=b[J>>1]|0;if(K<<16>>16==0){L=G;M=H;N=p}else{O=I+4|0;I=G;P=p;Q=K;K=0;while(1){R=(c[(c[O>>2]|0)+(K<<2)>>2]|0)+2|0;if((b[R>>1]|0)==0){S=I;T=Q;U=P}else{V=K|q;W=I;X=P;Y=0;while(1){Z=St(l,q,K,Y,0)|0;if((Z|0)==0|W>>>0<12){break a}if((dv(f,h,12)|0)!=0){break a}Ct(Z,h,12)|0;if((V|Y|0)==0){_=X}else{Z=(d[h>>0]<<8|d[n>>0])+X|0;$=(Z>>>1|Z<<31)+(d[w>>0]<<8|d[x>>0])|0;Z=($>>>1|$<<31)+(d[y>>0]<<8|d[z>>0])|0;$=(Z>>>1|Z<<31)+(d[A>>0]<<8|d[B>>0])|0;Z=($>>>1|$<<31)+(d[C>>0]<<8|d[D>>0])|0;$=(Z>>>1|Z<<31)+(d[E>>0]<<8|d[F>>0])|0;Z=$>>>1|$<<31;c[j>>2]=Z;_=Z}W=W+ -12|0;Y=Y+1|0;if(!(Y>>>0<(e[R>>1]|0)>>>0)){break}else{X=_}}S=W;T=b[J>>1]|0;U=_}K=K+1|0;if(!(K>>>0<(T&65535)>>>0)){break}else{I=S;P=U;Q=T}}L=S;M=b[l>>1]|0;N=U}Q=q+1|0;if(Q>>>0<(M&65535)>>>0){G=L;p=N;H=M;q=Q}else{u=L;v=N;break}}}if((u|0)==0){if((r|0)==(v|0)){m=l;i=g;return m|0}else{fb(50160,25,1,c[o>>2]|0)|0;break}}}}}}while(0);Lt(l);m=0;i=g;return m|0}function bu(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;h=i;i=i+144|0;j=h+128|0;k=h;if((b[g>>1]|0)!=80){l=1;i=h;return l|0}m=c[g+4>>2]|0;n=0;a:while(1){o=c[m+(n<<2)>>2]|0;if((b[o+2>>1]|0)!=1){p=0;q=19;break}r=12-(n>>>4)|0;s=c[c[o+4>>2]>>2]|0;o=b[s+2>>1]|0;if((o&65535|0)!=(r|0)){p=0;q=19;break}if(!(o<<16>>16==0)){o=c[s+4>>2]|0;s=0;do{t=c[o+(s<<2)>>2]|0;if((b[t+10>>1]|0)!=512){p=0;q=19;break a}s=s+1|0;if(!((e[t+8>>1]|0)>>>0<r>>>0)){p=0;q=19;break a}}while(s>>>0<r>>>0)}r=n+1|0;if(r>>>0<80){n=r}else{u=0;q=11;break}}b:do{if((q|0)==11){while(1){q=0;n=c[m+(u<<2)>>2]|0;r=b[n+2>>1]|0;if(!(r<<16>>16==0)){s=c[n+4>>2]|0;n=r&65535;r=0;do{o=c[s+(r<<2)>>2]|0;t=b[o+2>>1]|0;if(!(t<<16>>16==0)){v=c[o+4>>2]|0;o=t&65535;t=0;do{w=t;t=t+1|0;if((b[(c[v+(w<<2)>>2]|0)+28>>1]|0)!=0){x=409600;y=2;z=1;A=0;B=9600;break b}}while(t>>>0<o>>>0)}r=r+1|0}while(r>>>0<n>>>0)}n=u+1|0;if(n>>>0<80){u=n;q=11}else{x=409600;y=2;z=1;A=0;B=0;break}}}else if((q|0)==19){c:while(1){q=0;n=c[m+(p<<2)>>2]|0;if((b[n+2>>1]|0)!=2){C=0;break}r=12-(p>>>4)|0;s=c[n+4>>2]|0;n=0;do{o=c[s+(n<<2)>>2]|0;t=b[o+2>>1]|0;if((t&65535|0)!=(r|0)){C=0;break c}if(!(t<<16>>16==0)){t=c[o+4>>2]|0;o=0;do{v=c[t+(o<<2)>>2]|0;if((b[v+10>>1]|0)!=512){C=0;break c}o=o+1|0;if(!((e[v+8>>1]|0)>>>0<r>>>0)){C=0;break c}}while(o>>>0<r>>>0)}n=n+1|0}while(n>>>0<2);n=p+1|0;if(n>>>0<80){p=n;q=19}else{D=0;q=29;break}}if((q|0)==29){while(1){q=0;n=c[m+(D<<2)>>2]|0;r=b[n+2>>1]|0;if(!(r<<16>>16==0)){s=c[n+4>>2]|0;n=r&65535;r=0;do{o=c[s+(r<<2)>>2]|0;t=b[o+2>>1]|0;if(!(t<<16>>16==0)){v=c[o+4>>2]|0;o=t&65535;t=0;do{w=t;t=t+1|0;if((b[(c[v+(w<<2)>>2]|0)+28>>1]|0)!=0){x=819200;y=290;z=2;A=0;B=19200;break b}}while(t>>>0<o>>>0)}r=r+1|0}while(r>>>0<n>>>0)}n=D+1|0;if(n>>>0<80){D=n;q=29}else{x=819200;y=290;z=2;A=0;B=0;break b}}}d:while(1){n=c[m+(C<<2)>>2]|0;if((b[n+2>>1]|0)!=2){E=0;break}r=c[n+4>>2]|0;n=0;do{s=c[r+(n<<2)>>2]|0;if((b[s+2>>1]|0)!=9){E=0;break d}o=c[s+4>>2]|0;s=0;do{t=c[o+(s<<2)>>2]|0;if((b[t+10>>1]|0)!=512){E=0;break d}v=b[t+8>>1]|0;s=s+1|0;if(v<<16>>16==0|(v&65535)>9){E=0;break d}}while(s>>>0<9);n=n+1|0}while(n>>>0<2);n=C+1|0;if(n>>>0<80){C=n}else{x=737280;y=546;z=2;A=9;B=0;break b}}e:while(1){n=c[m+(E<<2)>>2]|0;if((b[n+2>>1]|0)!=2){l=1;q=98;break}r=c[n+4>>2]|0;n=0;do{s=c[r+(n<<2)>>2]|0;if((b[s+2>>1]|0)!=18){l=1;q=98;break e}o=c[s+4>>2]|0;s=0;do{v=c[o+(s<<2)>>2]|0;if((b[v+10>>1]|0)!=512){l=1;q=98;break e}t=b[v+8>>1]|0;s=s+1|0;if(t<<16>>16==0|(t&65535)>18){l=1;q=98;break e}}while(s>>>0<18);n=n+1|0}while(n>>>0<2);n=E+1|0;if(n>>>0<80){E=n}else{x=1474560;y=802;z=2;A=18;B=0;break b}}if((q|0)==98){i=h;return l|0}}}while(0);E=(A|0)==0;m=E&1^1;C=A+1|0;A=j+1|0;D=j+2|0;p=j+3|0;u=j+4|0;n=j+5|0;r=j+6|0;s=j+7|0;o=j+8|0;t=j+9|0;v=j+10|0;w=j+11|0;F=0;G=0;H=0;f:while(1){if(E){I=12-(H>>>4)|0}else{I=C}J=m>>>0<I>>>0;K=F;L=G;M=0;while(1){if(J){N=M|H;O=K;P=L;Q=m;while(1){R=St(g,H,M,Q,0)|0;if((R|0)==0){l=1;q=98;break f}S=(e[R+10>>1]|0)>>>1;if((S|0)==0){T=O}else{U=O;V=S;S=c[R+24>>2]|0;while(1){W=(d[S>>0]<<8|d[S+1>>0])+U|0;X=W>>>1|W<<31;W=V+ -1|0;if((W|0)==0){T=X;break}else{U=X;V=W;S=S+2|0}}}if((N|Q|0)==0){Y=P}else{Dt(R,j,12)|0;S=(d[j>>0]<<8|d[A>>0])+P|0;V=(S>>>1|S<<31)+(d[D>>0]<<8|d[p>>0])|0;S=(V>>>1|V<<31)+(d[u>>0]<<8|d[n>>0])|0;V=(S>>>1|S<<31)+(d[r>>0]<<8|d[s>>0])|0;S=(V>>>1|V<<31)+(d[o>>0]<<8|d[t>>0])|0;V=(S>>>1|S<<31)+(d[v>>0]<<8|d[w>>0])|0;Y=V>>>1|V<<31}V=Q+1|0;if(V>>>0<I>>>0){O=T;P=Y;Q=V}else{Z=T;_=Y;break}}}else{Z=K;_=L}M=M+1|0;if(!(M>>>0<z>>>0)){break}else{K=Z;L=_}}H=H+1|0;if(!(H>>>0<80)){break}else{F=Z;G=_}}if((q|0)==98){i=h;return l|0}G=k+0|0;F=G+128|0;do{a[G>>0]=0;G=G+1|0}while((G|0)<(F|0));G=St(g,0,0,E?2:3,0)|0;do{if((G|0)==0){$=50120}else{F=c[G+24>>2]|0;H=a[F>>0]|0;if(H<<24>>24==-46){$=(a[F+1>>0]|0)==-41?F+36|0:50120;break}else if(H<<24>>24==66){$=(a[F+1>>0]|0)==68?F+36|0:50120;break}else{$=50120;break}}}while(0);G=a[$>>0]|0;F=G&255;H=F>>>0>63?63:F;if((H|0)!=0){Y=(G&255)<63?F:63;F=0;do{F=F+1|0;a[k+F>>0]=a[$+F>>0]|0}while((F|0)!=(Y|0))}a[k>>0]=H;$u(k,64,x);$u(k,68,B);$u(k,72,Z);$u(k,76,_);_u(k,80,y);_u(k,82,256);if((fv(f,k,84)|0)==0){aa=0}else{l=1;i=h;return l|0}g:while(1){if(E){ba=12-(aa>>>4)|0}else{ba=C}if(m>>>0<ba>>>0){k=0;do{y=m;do{_=St(g,aa,k,y,0)|0;if((_|0)==0){l=1;q=98;break g}y=y+1|0;if((fv(f,c[_+24>>2]|0,e[_+10>>1]|0)|0)!=0){l=1;q=98;break g}}while(y>>>0<ba>>>0);k=k+1|0}while(k>>>0<z>>>0)}k=aa+1|0;if(k>>>0<80){aa=k}else{q=87;break}}if((q|0)==87){h:do{if((B|0)!=0){aa=0;i:while(1){if(E){ca=12-(aa>>>4)|0}else{ca=C}ba=m>>>0<ca>>>0;k=0;do{if(ba){y=m;do{_=St(g,aa,k,y,0)|0;if((_|0)==0){l=1;q=98;break i}Dt(_,j,12)|0;y=y+1|0;if((fv(f,j,12)|0)!=0){l=1;q=98;break i}}while(y>>>0<ca>>>0)}k=k+1|0}while(k>>>0<z>>>0);aa=aa+1|0;if(!(aa>>>0<80)){break h}}if((q|0)==98){i=h;return l|0}}}while(0);Nb(f|0)|0;l=0;i=h;return l|0}else if((q|0)==98){i=h;return l|0}return 0}function cu(a){a=a|0;var b=0,c=0,e=0;b=i;i=i+128|0;c=b;if((xb(a|0,0,0)|0)==0){if((dv(a,c,84)|0)==0){if((Yu(c,82)|0)==256){e=(d[c>>0]|0)<64|0}else{e=0}}else{e=0}}else{e=0}i=b;return e|0}function du(a,b,e,f,g){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;h=i;c[f>>2]=0;j=(e|0)==0;k=g&255;g=0;a:while(1){l=g>>>4;m=12-l|0;b:do{if(!j){if((l|0)==12){n=0;while(1){o=Qt(b,g,n,0)|0;if((o|0)!=0){It(o,2)|0}n=n+1|0;if(!(n>>>0<e>>>0)){break b}}}else{p=0}do{n=0;do{q=kt(g,p,n,512)|0;if((q|0)==0){r=1;s=19;break a}At(q,k);tt(q,3);if((Pt(b,q,g,p)|0)!=0){s=14;break a}o=q+24|0;if((dv(a,c[o>>2]|0,512)|0)!=0){r=1;s=19;break a}t=c[f>>2]|0;u=256;v=c[o>>2]|0;while(1){o=((d[v>>0]|0)<<8|(d[v+1>>0]|0))+t|0;t=o>>>1|o<<31;u=u+ -1|0;if((u|0)==0){break}else{v=v+2|0}}c[f>>2]=t;n=n+1|0}while(n>>>0<m>>>0);n=Qt(b,g,p,0)|0;if((n|0)!=0){It(n,2)|0}p=p+1|0}while(p>>>0<e>>>0)}}while(0);m=g+1|0;if(m>>>0<80){g=m}else{r=0;s=19;break}}if((s|0)==14){lt(q);r=1;i=h;return r|0}else if((s|0)==19){i=h;return r|0}return 0}function eu(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;g=i;c[f>>2]=0;h=e>>>0<14?2:32770;j=(e|0)==0;k=0;a:while(1){l=0;do{if(!j){m=0;do{m=m+1|0;n=kt(k,l,m,512)|0;if((n|0)==0){o=1;p=13;break a}tt(n,h);if((Pt(b,n,k,l)|0)!=0){p=6;break a}q=n+24|0;if((dv(a,c[q>>2]|0,512)|0)!=0){o=1;p=13;break a}r=c[f>>2]|0;s=256;t=c[q>>2]|0;while(1){q=((d[t>>0]|0)<<8|(d[t+1>>0]|0))+r|0;r=q>>>1|q<<31;s=s+ -1|0;if((s|0)==0){break}else{t=t+2|0}}c[f>>2]=r}while(m>>>0<e>>>0)}l=l+1|0}while(l>>>0<2);l=k+1|0;if(l>>>0<80){k=l}else{o=0;p=13;break}}if((p|0)==6){lt(n);o=1;i=g;return o|0}else if((p|0)==13){i=g;return o|0}return 0}function fu(b){b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;i=i+784|0;g=f+776|0;h=f+520|0;j=f+264|0;k=f+8|0;l=f;m=Kt()|0;if((m|0)==0){n=0;i=f;return n|0}a:do{if((ta(l|0,1,4,b|0)|0)==4){if((Zu(l,0)|0)==1229800480){Ut(m,l,4)|0;while(1){o=_b(b|0)|0;if((o|0)==26){break}else if((o|0)==-1){break a}a[l>>0]=o;Ut(m,l,1)|0}Wt(m);o=l+1|0;p=l+2|0;q=l+3|0;r=l+4|0;b:while(1){s=ta(l|0,1,5,b|0)|0;if((s|0)==0){n=m;t=41;break}else if((s|0)!=5){break a}s=d[o>>0]|0;u=a[p>>0]&1;v=a[q>>0]|0;w=v&255;x=a[r>>0]|0;if(v<<24>>24==0){continue}if((x&255)>6){break a}v=128<<(x&255);if((ta(h|0,1,w|0,b|0)|0)!=(w|0)){break a}y=a[p>>0]|0;if(y<<24>>24<0){if((ta(j|0,1,w|0,b|0)|0)!=(w|0)){break a}z=a[p>>0]|0}else{z=y}if((z&64)==0){A=0}else{if((ta(k|0,1,w|0,b|0)|0)==(w|0)){A=0}else{break a}}while(1){y=a[p>>0]|0;if(y<<24>>24<0){B=d[j+A>>0]|0}else{B=s}if((y&64)==0){C=u}else{C=d[k+A>>0]|0}y=a[h+A>>0]|0;if((ta(g|0,1,1,b|0)|0)!=1){break a}D=kt(B,C,y&255,v)|0;if((D|0)==0){break a}yt(D,x);if((Pt(m,D,s,u)|0)!=0){t=24;break b}switch(d[l>>0]|0|0){case 0:{E=32769;break};case 1:{E=1;break};case 3:{E=32770;break};case 2:{E=1;break};case 5:{E=2;break};case 4:{E=2;break};default:{break a}}tt(D,E);y=a[g>>0]|0;if((y+ -5<<24>>24&255)<4){st(D,2,1)}switch(y<<24>>24){case 8:case 7:case 4:case 3:{st(D,4,1);switch(y<<24>>24){case 7:case 5:case 3:{t=38;break};case 8:case 6:case 4:{t=36;break};default:{break a}}break};case 5:case 1:{t=38;break};case 0:{st(D,2,1);qt(D,0);break};case 6:case 2:{t=36;break};default:{break a}}if((t|0)==36){t=0;if((ta(g|0,1,1,b|0)|0)!=1){break a}qt(D,d[g>>0]|0)}else if((t|0)==38){t=0;y=D+10|0;F=ta(c[D+24>>2]|0,1,e[y>>1]|0|0,b|0)|0;if((F|0)!=(e[y>>1]|0|0)){break a}}y=A+1|0;if(y>>>0<w>>>0){A=y}else{continue b}}}if((t|0)==24){lt(D);break}else if((t|0)==41){i=f;return n|0}}}}while(0);Lt(m);n=0;i=f;return n|0}function gu(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;h=i;i=i+784|0;j=h;k=h+776|0;l=g+12|0;m=c[l>>2]|0;n=g+8|0;if((c[n>>2]|0)>>>0<29){o=10}else{if((a[m>>0]|0)==73){if((a[m+1>>0]|0)==77){if((a[m+2>>0]|0)==68){if((a[m+12>>0]|0)==47){if((a[m+15>>0]|0)==47){if((a[m+20>>0]|0)==32){fv(f,m,29)|0;if((c[n>>2]|0)>>>0>29){p=(a[(c[l>>2]|0)+29>>0]|0)==10?30:29}else{p=29}}else{o=10}}else{o=10}}else{o=10}}else{o=10}}else{o=10}}else{o=10}}if((o|0)==10){c[k>>2]=gb(0)|0;m=cb(k|0)|0;k=(c[m+16>>2]|0)+1|0;q=(c[m+20>>2]|0)+1900|0;r=c[m+8>>2]|0;s=c[m+4>>2]|0;t=c[m>>2]|0;c[j>>2]=c[m+12>>2];c[j+4>>2]=k;c[j+8>>2]=q;c[j+12>>2]=r;c[j+16>>2]=s;c[j+20>>2]=t;hb(f|0,50192,j|0)|0;p=0}$b(13,f|0)|0;$b(10,f|0)|0;if(p>>>0<(c[n>>2]|0)>>>0){t=p;do{p=a[(c[l>>2]|0)+t>>0]|0;if(p<<24>>24==10){$b(13,f|0)|0;$b(10,f|0)|0}else{$b(p&255|0,f|0)|0}t=t+1|0}while(t>>>0<(c[n>>2]|0)>>>0)}$b(26,f|0)|0;n=b[g>>1]|0;a:do{if(!(n<<16>>16==0)){t=g+4|0;l=j+1|0;p=j+2|0;s=j+3|0;r=j+4|0;q=n;k=0;b:while(1){m=c[(c[t>>2]|0)+(k<<2)>>2]|0;u=m+2|0;if((b[u>>1]|0)==0){v=q}else{w=m+4|0;m=k&255;x=0;do{y=c[(c[w>>2]|0)+(x<<2)>>2]|0;z=b[y+2>>1]|0;A=z&65535;if(!(z<<16>>16==0)){B=y+4|0;y=c[B>>2]|0;C=c[y>>2]|0;if((z&65535)>1){D=b[C+10>>1]|0;E=C+16|0;F=1;G=0;H=0;while(1){I=c[y+(F<<2)>>2]|0;if(!((b[I+10>>1]|0)==D<<16>>16)){J=1;o=61;break b}K=(e[I+6>>1]|0)==(x|0)?H:1;L=(e[I+4>>1]|0)==(k|0)?G:1;M=b[I+16>>1]|0;I=F+1|0;if(!(M<<16>>16==(b[E>>1]|0))){J=1;o=61;break b}if(I>>>0<A>>>0){F=I;G=L;H=K}else{N=M;O=L;P=K;break}}}else{N=b[C+16>>1]|0;O=0;P=0}H=N&65535;if((H|0)==32770){a[j>>0]=3}else if((H|0)==32769){a[j>>0]=0}else if((H|0)==2){a[j>>0]=5}else if((H|0)==1){a[j>>0]=2}else{a[j>>0]=5}a[l>>0]=m;a[p>>0]=x;a[s>>0]=z;H=b[C+10>>1]|0;G=H&65535;if((G+65535&G|0)!=0|(H&65535)>8192){J=1;o=61;break b}a[r>>0]=0;if((H&65535)>255){H=0;F=G;while(1){H=(H&255)+1|0;if(!(F>>>0>511)){break}else{F=F>>>1}}a[r>>0]=H}F=A+5|0;if((O|0)==0){Q=x;R=F;S=0}else{C=x|128;a[p>>0]=C;Q=C;R=F+A|0;S=j+F|0}if((P|0)==0){T=R;U=0}else{a[p>>0]=Q|64;T=R+A|0;U=j+R|0}F=(U|0)==0;if((S|0)==0){if(F){C=0;do{a[j+(C+5)>>0]=b[(c[y+(C<<2)>>2]|0)+8>>1];C=C+1|0}while((C|0)!=(A|0))}else{C=0;do{H=c[y+(C<<2)>>2]|0;a[j+(C+5)>>0]=b[H+8>>1];a[U+C>>0]=b[H+6>>1];C=C+1|0}while((C|0)!=(A|0))}}else{if(F){C=0;do{H=c[y+(C<<2)>>2]|0;a[j+(C+5)>>0]=b[H+8>>1];a[S+C>>0]=b[H+4>>1];C=C+1|0}while((C|0)!=(A|0))}else{C=0;do{F=c[y+(C<<2)>>2]|0;a[j+(C+5)>>0]=b[F+8>>1];a[S+C>>0]=b[F+4>>1];a[U+C>>0]=b[F+6>>1];C=C+1|0}while((C|0)!=(A|0))}}if((fb(j|0,1,T|0,f|0)|0)==(T|0)){V=0}else{J=1;o=61;break b}do{C=c[(c[B>>2]|0)+(V<<2)>>2]|0;if((rt(C)|0)==0){W=0}else{W=(b[C+10>>1]|0)!=0}y=c[C+12>>2]|0;F=(y&6|0)==6;if(F|(y&2|0)!=0){X=F?7:5}else{X=y>>>1&2|1}$b(X+(W&1)|0,f|0)|0;y=c[C+24>>2]|0;if(W){$b(d[y>>0]|0,f|0)|0}else{F=C+10|0;C=fb(y|0,1,e[F>>1]|0,f|0)|0;if((C|0)!=(e[F>>1]|0)){J=1;o=61;break b}}V=V+1|0}while(V>>>0<A>>>0)}x=x+1|0}while(x>>>0<(e[u>>1]|0)>>>0);v=b[g>>1]|0}k=k+1|0;if(!(k>>>0<(v&65535)>>>0)){break a}else{q=v}}if((o|0)==61){i=h;return J|0}}}while(0);Nb(f|0)|0;J=0;i=h;return J|0}function hu(a){a=a|0;var b=0,c=0,d=0;b=i;i=i+16|0;c=b;if((xb(a|0,0,0)|0)==0){if((ta(c|0,1,4,a|0)|0)==4){d=(Zu(c,0)|0)==1229800480|0}else{d=0}}else{d=0}i=b;return d|0}function iu(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;d=i;i=i+16|0;e=d;f=Kt()|0;if((f|0)==0){g=0;i=d;return g|0}if((ev(b,0,e,10)|0)!=0){g=f;i=d;return g|0}if((Yu(e,0)|0)!=3599){g=f;i=d;return g|0}h=Yu(e,2)|0;j=(Yu(e,4)|0)+1|0;k=Yu(e,6)|0;l=Yu(e,8)|0;do{if(!((h|0)==0|h>>>0>127)){if(!(j>>>0>16|l>>>0<k>>>0)){e=h<<9;m=yz(e)|0;if((m|0)!=0){n=(j|0)==0;o=(e|0)==0;p=k;a:while(1){if(!n){q=0;do{r=Qt(f,p,q,1)|0;if((r|0)==0){s=10;break a}if((dv(b,m,2)|0)!=0){s=25;break a}t=Yu(m,0)|0;if((t|0)==(e|0)){if((dv(b,m,e)|0)==0){u=0}else{s=25;break a}}else{if(o){u=0}else{v=m;w=e;x=t;while(1){if((x|0)==0){s=25;break a}t=_b(b|0)|0;if((t|0)==-1){s=25;break a}y=x+ -1|0;if((t|0)==229){if(y>>>0<3){s=25;break a}z=_b(b|0)|0;A=_b(b|0)|0;B=_b(b|0)|0;if((z|0)==-1|(A|0)==-1|(B|0)==-1){s=25;break a}C=A<<8&65280|B&255;if((w|0)==0|(C|0)==0){D=v;E=w}else{B=0-w|0;A=0-C|0;C=B>>>0>A>>>0?B:A;A=0-C|0;Oz(v|0,z&255|0,A|0)|0;D=v+A|0;E=C+w|0}F=D;G=E;H=x+ -4|0}else{a[v>>0]=t;F=v+1|0;G=w+ -1|0;H=y}if((G|0)==0){u=0;break}else{v=F;w=G;x=H}}}}do{x=u;u=u+1|0;I=kt(p,q,u,512)|0;if((I|0)==0){s=27;break a}tt(I,2);if((Gt(r,I)|0)!=0){s=29;break a}Mz(c[I+24>>2]|0,m+(x<<9)|0,512)|0}while(u>>>0<h>>>0);q=q+1|0}while(q>>>0<j>>>0)}q=p+1|0;if(q>>>0>l>>>0){s=33;break}else{p=q}}if((s|0)==10){zz(m);break}else if((s|0)==25){zz(m);break}else if((s|0)==27){zz(m);break}else if((s|0)==29){lt(I);break}else if((s|0)==33){zz(m);g=f;i=d;return g|0}}}}}while(0);Lt(f);g=0;i=d;return g|0}function ju(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;i=i+16|0;g=f;h=Ot(d,0,0)|0;if((h|0)==0){j=1;i=f;return j|0}k=Qt(d,0,0,0)|0;if((k|0)==0){j=1;i=f;return j|0}_u(g,0,3599);l=k+2|0;_u(g,2,e[l>>1]|0);k=h+2|0;_u(g,4,(e[k>>1]|0)+ -1|0);_u(g,6,0);_u(g,8,(e[d>>1]|0)+ -1|0);if((fv(a,g,10)|0)!=0){j=1;i=f;return j|0}_u(g,0,e[l>>1]<<9);h=b[d>>1]|0;a:do{if(!(h<<16>>16==0)){m=b[k>>1]|0;n=h;o=0;b:while(1){if(m<<16>>16==0){p=n;q=0}else{r=0;do{if((fv(a,g,2)|0)==0){s=0}else{j=1;t=16;break b}while(1){if(!(s>>>0<(e[l>>1]|0)>>>0)){break}u=s+1|0;v=St(d,o,r,u,0)|0;if((v|0)==0){j=1;t=16;break b}if((b[v+10>>1]|0)!=512){j=1;t=16;break b}if((fv(a,c[v+24>>2]|0,512)|0)==0){s=u}else{j=1;t=16;break b}}r=r+1|0;w=b[k>>1]|0}while(r>>>0<(w&65535)>>>0);p=b[d>>1]|0;q=w}o=o+1|0;if(!(o>>>0<(p&65535)>>>0)){break a}else{m=q;n=p}}if((t|0)==16){i=f;return j|0}}}while(0);Nb(a|0)|0;j=0;i=f;return j|0}function ku(a){a=a|0;var b=0,c=0,d=0;b=i;i=i+16|0;c=b;if((ev(a,0,c,10)|0)!=0){d=0;i=b;return d|0}d=(Yu(c,0)|0)==3599|0;i=b;return d|0}function lu(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=i;i=i+16|0;c=b;d=Kt()|0;if((d|0)==0){e=0;i=b;return e|0}if((dv(a,c,8)|0)==0){f=Zu(c,0)|0;g=Zu(c,4)|0;if((f|0)==1346782275){if((g|0)==131072){h=tu(a,d,1346782275,131072)|0}else if((g|0)==65536){h=qu(a,d,1346782275,65536)|0}else if((g|0)==0){h=ou(a,d,1346782275,0)|0}else{h=xu(a,d,1346782275,g)|0}if((h|0)==0){e=d;i=b;return e|0}}}Lt(d);e=0;i=b;return e|0}function mu(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;if((c|0)==1){e=ru(a,b)|0}else if((c|0)==0){e=pu(a,b)|0}else if((c|0)==2){e=uu(a,b)|0}else{e=yu(a,b)|0}i=d;return e|0}function nu(a){a=a|0;var b=0,c=0,d=0;b=i;i=i+16|0;c=b;if((ev(a,0,c,4)|0)!=0){d=0;i=b;return d|0}d=(Zu(c,0)|0)==1346782275|0;i=b;return d|0}function ou(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;g=i;i=i+32|0;f=g+8|0;h=g;fb(50232,49,1,c[o>>2]|0)|0;if((dv(b,h,8)|0)!=0){j=1;i=g;return j|0}k=Zu(h,0)|0;l=Zu(h,4)|0;if(l>>>0<16){j=1;i=g;return j|0}if((hv(b,l+ -16|0)|0)!=0){j=1;i=g;return j|0}if((k|0)==0){j=0;i=g;return j|0}l=f+1|0;h=f+5|0;m=f+2|0;n=f+3|0;p=f+4|0;q=f+12|0;r=0;while(1){if((dv(b,f,12)|0)!=0){j=1;s=21;break}t=a[f>>0]|0;u=a[l>>0]|0;v=d[h>>0]|0;w=Yu(f,6)|0;x=kt(d[m>>0]|0,d[n>>0]|0,d[p>>0]|0,w)|0;if((x|0)==0){j=1;s=21;break}if((Pt(e,x,t&255,u&255)|0)!=0){s=9;break}tt(x,(v&1|0)==0?v&2:1);if((v&4|0)!=0){u=x+12|0;c[u>>2]=c[u>>2]|1}if((v&8|0)!=0){u=x+12|0;c[u>>2]=c[u>>2]|2}if((v&16|0)!=0){u=x+12|0;c[u>>2]=c[u>>2]|4}if((v&128|0)==0){if((dv(b,c[x+24>>2]|0,w)|0)!=0){j=1;s=21;break}}else{if((dv(b,q,1)|0)!=0){j=1;s=21;break}qt(x,d[q>>0]|0)}w=r+1|0;if(w>>>0<k>>>0){r=w}else{j=0;s=21;break}}if((s|0)==9){lt(x);j=1;i=g;return j|0}else if((s|0)==21){i=g;return j|0}return 0}function pu(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;h=i;i=i+32|0;j=h+16|0;k=h;l=Xt(g)|0;$u(k,0,1346782275);$u(k,4,0);$u(k,8,l);$u(k,12,16);if((fv(f,k,16)|0)!=0){m=1;i=h;return m|0}k=b[g>>1]|0;a:do{if(!(k<<16>>16==0)){l=g+4|0;n=j+1|0;o=j+2|0;p=j+3|0;q=j+4|0;r=j+5|0;s=j+6|0;t=j+7|0;u=j+12|0;v=k;w=0;b:while(1){x=c[(c[l>>2]|0)+(w<<2)>>2]|0;y=x+2|0;z=b[y>>1]|0;if(z<<16>>16==0){A=v}else{B=x+4|0;x=w&255;C=z;z=0;while(1){D=c[(c[B>>2]|0)+(z<<2)>>2]|0;E=D+2|0;if((b[E>>1]|0)==0){F=C}else{G=D+4|0;D=z&255;H=0;do{I=c[(c[G>>2]|0)+(H<<2)>>2]|0;J=e[I+16>>1]|0;if((J|0)==32769){K=1;L=25e4}else if((J|0)==2){K=2;L=25e4}else if((J|0)==1){K=1;L=125e3}else if((J|0)==32770){K=2;L=5e5}else if((J|0)==16386){K=2;L=1e6}else{K=0;L=0}J=c[I+12>>2]<<2;a[j>>0]=x;a[n>>0]=D;a[o>>0]=b[I+4>>1];a[p>>0]=b[I+6>>1];a[q>>0]=b[I+8>>1];a[r>>0]=J&4|K|J&8|J&16;J=I+10|0;M=b[J>>1]|0;a[s>>0]=(M&65535)>>>8;a[t>>0]=M;$u(j,8,L);if((rt(I)|0)==0){N=17}else{if((b[J>>1]|0)==0){N=17}else{a[r>>0]=d[r>>0]|128;a[u>>0]=a[c[I+24>>2]>>0]|0;if((fv(f,j,13)|0)!=0){m=1;N=25;break b}}}if((N|0)==17){N=0;if((fv(f,j,12)|0)!=0){m=1;N=25;break b}if((fv(f,c[I+24>>2]|0,e[J>>1]|0)|0)!=0){m=1;N=25;break b}}H=H+1|0}while(H>>>0<(e[E>>1]|0)>>>0);F=b[y>>1]|0}z=z+1|0;if(!(z>>>0<(F&65535)>>>0)){break}else{C=F}}A=b[g>>1]|0}w=w+1|0;if(!(w>>>0<(A&65535)>>>0)){break a}else{v=A}}if((N|0)==25){i=h;return m|0}}}while(0);Nb(f|0)|0;m=0;i=h;return m|0}function qu(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=i;i=i+48|0;f=g+8|0;h=g;fb(50288,49,1,c[o>>2]|0)|0;if((dv(b,h,8)|0)!=0){j=1;i=g;return j|0}k=Zu(h,0)|0;l=Zu(h,4)|0;if(l>>>0<16){j=1;i=g;return j|0}if((hv(b,l+ -16|0)|0)!=0){j=1;i=g;return j|0}if((k|0)==0){j=0;i=g;return j|0}l=f+1|0;h=f+2|0;m=f+3|0;n=f+4|0;p=f+5|0;q=f+8|0;r=f+16|0;s=0;t=0;while(1){u=(dv(b,f,16)|0)==0;if(!(u&(a[f>>0]|0)==83)){j=1;v=28;break}u=d[l>>0]|0;w=d[h>>0]|0;x=Yu(f,6)|0;y=kt(d[m>>0]|0,d[n>>0]|0,d[p>>0]|0,x)|0;if((y|0)==0){j=1;v=28;break}z=Zu(f,12)|0;A=(Zu(f,8)|0)&16777215;if((z&4|0)!=0){B=y+12|0;c[B>>2]=c[B>>2]|1}if((z&8|0)!=0){B=y+12|0;c[B>>2]=c[B>>2]|2}if((z&16|0)!=0){B=y+12|0;c[B>>2]=c[B>>2]|4}B=d[q>>0]|0;if((B|0)==2){C=A>>>0<375e3?2:32770}else if((B|0)==1){C=A>>>0<375e3?1:32769}else{C=0}tt(y,C);if((z&1|0)==0){if((Pt(e,y,u,w)|0)!=0){v=22;break}}else{if((s|0)==0){v=19;break}nt(s,y)}if((z&128|0)==0){if((dv(b,c[y+24>>2]|0,x)|0)!=0){j=1;v=28;break}}else{if((dv(b,r,1)|0)!=0){j=1;v=28;break}qt(y,d[r>>0]|0)}x=t+1|0;if(x>>>0<k>>>0){s=y;t=x}else{j=0;v=28;break}}if((v|0)==19){lt(y);j=1;i=g;return j|0}else if((v|0)==22){lt(y);j=1;i=g;return j|0}else if((v|0)==28){i=g;return j|0}return 0}function ru(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=i;i=i+16|0;g=f;h=Xt(d)|0;$u(g,0,1346782275);_u(g,4,1);_u(g,6,0);$u(g,8,h);$u(g,12,16);if((fv(a,g,16)|0)!=0){j=1;i=f;return j|0}g=b[d>>1]|0;a:do{if(!(g<<16>>16==0)){h=d+4|0;k=g;l=0;b:while(1){m=c[(c[h>>2]|0)+(l<<2)>>2]|0;n=m+2|0;o=b[n>>1]|0;if(o<<16>>16==0){p=k}else{q=m+4|0;m=o;o=0;while(1){r=c[(c[q>>2]|0)+(o<<2)>>2]|0;s=r+2|0;if((b[s>>1]|0)==0){t=m}else{u=r+4|0;r=0;do{v=c[(c[u>>2]|0)+(r<<2)>>2]|0;if((su(a,v,l,o,0)|0)==0){w=v}else{j=1;x=17;break b}while(1){v=c[w>>2]|0;if((v|0)==0){break}if((su(a,v,l,o,1)|0)==0){w=v}else{j=1;x=17;break b}}r=r+1|0}while(r>>>0<(e[s>>1]|0)>>>0);t=b[n>>1]|0}o=o+1|0;if(!(o>>>0<(t&65535)>>>0)){break}else{m=t}}p=b[d>>1]|0}l=l+1|0;if(!(l>>>0<(p&65535)>>>0)){break a}else{k=p}}if((x|0)==17){i=f;return j|0}}}while(0);Nb(a|0)|0;j=0;i=f;return j|0}function su(d,f,g,h,j){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=i;i=i+32|0;l=k;m=c[f+12>>2]<<2&28;if((rt(f)|0)==0){n=m}else{n=(b[f+10>>1]|0)==0?m:m|128}m=n|(j|0)!=0;j=e[f+16>>1]|0;if((j|0)==1){o=125e3;p=1}else if((j|0)==32770){o=5e5;p=2}else if((j|0)==16386){o=1e6;p=2}else if((j|0)==2){o=25e4;p=2}else if((j|0)==32769){o=25e4;p=1}else{o=0;p=0}$u(l,8,o);a[l>>0]=83;a[l+1>>0]=g;a[l+2>>0]=h;a[l+3>>0]=b[f+4>>1];a[l+4>>0]=b[f+6>>1];a[l+5>>0]=b[f+8>>1];h=f+10|0;g=b[h>>1]|0;a[l+6>>0]=(g&65535)>>>8;a[l+7>>0]=g;a[l+8>>0]=p;$u(l,12,m);if((n&128|0)==0){if((fv(d,l,16)|0)!=0){q=1;i=k;return q|0}if((fv(d,c[f+24>>2]|0,e[h>>1]|0)|0)!=0){q=1;i=k;return q|0}}else{a[l+16>>0]=a[c[f+24>>2]>>0]|0;if((fv(d,l,17)|0)!=0){q=1;i=k;return q|0}}q=0;i=k;return q|0}function tu(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0;j=i;i=i+576|0;k=j+536|0;l=j+280|0;m=j+272|0;n=j+16|0;p=j;fb(50344,49,1,c[o>>2]|0)|0;$u(p,0,g);$u(p,4,h);h=-1;g=8;q=p;while(1){r=d[q>>0]<<24^h;s=r<<1;t=(r|0)<0?s^79764919:s;s=t<<1;r=(t|0)<0?s^79764919:s;s=r<<1;t=(r|0)<0?s^79764919:s;s=t<<1;r=(t|0)<0?s^79764919:s;s=r<<1;t=(r|0)<0?s^79764919:s;s=t<<1;r=(t|0)<0?s^79764919:s;s=r<<1;t=(r|0)<0?s^79764919:s;s=t<<1;h=(t|0)<0?s^79764919:s;g=g+ -1|0;if((g|0)==0){break}else{q=q+1|0}}c[12600]=h;h=p+8|0;if((dv(b,h,8)|0)!=0){u=1;i=j;return u|0}q=c[12600]|0;g=8;s=h;while(1){h=d[s>>0]<<24^q;t=h<<1;r=(h|0)<0?t^79764919:t;t=r<<1;h=(r|0)<0?t^79764919:t;t=h<<1;r=(h|0)<0?t^79764919:t;t=r<<1;h=(r|0)<0?t^79764919:t;t=h<<1;r=(h|0)<0?t^79764919:t;t=r<<1;h=(r|0)<0?t^79764919:t;t=h<<1;r=(h|0)<0?t^79764919:t;t=r<<1;q=(r|0)<0?t^79764919:t;g=g+ -1|0;if((g|0)==0){break}else{s=s+1|0}}c[12600]=q;q=Zu(p,12)|0;if(q>>>0<16){u=1;i=j;return u|0}s=q+ -16|0;a:do{if((s|0)!=0){q=s;while(1){g=q>>>0<256?q:256;if((dv(b,n,g)|0)!=0){u=1;break}t=c[12600]|0;if((g|0)==0){v=t}else{r=t;t=g;h=n;while(1){w=d[h>>0]<<24^r;x=w<<1;y=(w|0)<0?x^79764919:x;x=y<<1;w=(y|0)<0?x^79764919:x;x=w<<1;y=(w|0)<0?x^79764919:x;x=y<<1;w=(y|0)<0?x^79764919:x;x=w<<1;y=(w|0)<0?x^79764919:x;x=y<<1;w=(y|0)<0?x^79764919:x;x=w<<1;y=(w|0)<0?x^79764919:x;x=y<<1;w=(y|0)<0?x^79764919:x;x=t+ -1|0;if((x|0)==0){v=w;break}else{r=w;t=x;h=h+1|0}}}c[12600]=v;if((q|0)==(g|0)){break a}else{q=q-g|0}}i=j;return u|0}}while(0);v=k+1|0;s=k+2|0;q=k+3|0;h=k+4|0;t=k+5|0;r=k+8|0;x=0;b:while(1){if((dv(b,m,4)|0)!=0){u=1;z=137;break}w=(x|0)==0;while(1){y=c[12600]|0;A=4;B=m;while(1){C=d[B>>0]<<24^y;D=C<<1;E=(C|0)<0?D^79764919:D;D=E<<1;C=(E|0)<0?D^79764919:D;D=C<<1;E=(C|0)<0?D^79764919:D;D=E<<1;C=(E|0)<0?D^79764919:D;D=C<<1;E=(C|0)<0?D^79764919:D;D=E<<1;C=(E|0)<0?D^79764919:D;D=C<<1;E=(C|0)<0?D^79764919:D;D=E<<1;y=(E|0)<0?D^79764919:D;A=A+ -1|0;if((A|0)==0){break}else{B=B+1|0}}c[12600]=y;B=Yu(m,0)|0;F=Yu(m,2)|0;G=0;A=4;g=m;while(1){D=d[g>>0]<<24^G;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;D=(C|0)<0?E^79764919:E;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;D=(C|0)<0?E^79764919:E;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;D=(C|0)<0?E^79764919:E;E=D<<1;C=(D|0)<0?E^79764919:E;E=C<<1;G=(C|0)<0?E^79764919:E;A=A+ -1|0;if((A|0)==0){break}else{g=g+1|0}}if((B|0)==17742){z=20;break b}else if((B|0)==21315){break}else if((B|0)==21575){if(w){u=1;z=137;break b}g=F>>>0<256?F:256;if((dv(b,n,g)|0)!=0){u=1;z=137;break b}A=c[12600]|0;if((g|0)==0){c[12600]=A;H=G}else{y=A;A=g;E=n;while(1){C=d[E>>0]<<24^y;D=C<<1;I=(C|0)<0?D^79764919:D;D=I<<1;C=(I|0)<0?D^79764919:D;D=C<<1;I=(C|0)<0?D^79764919:D;D=I<<1;C=(I|0)<0?D^79764919:D;D=C<<1;I=(C|0)<0?D^79764919:D;D=I<<1;C=(I|0)<0?D^79764919:D;D=C<<1;I=(C|0)<0?D^79764919:D;D=I<<1;y=(I|0)<0?D^79764919:D;A=A+ -1|0;if((A|0)==0){break}else{E=E+1|0}}c[12600]=y;E=G;A=g;D=n;while(1){I=d[D>>0]<<24^E;C=I<<1;J=(I|0)<0?C^79764919:C;C=J<<1;I=(J|0)<0?C^79764919:C;C=I<<1;J=(I|0)<0?C^79764919:C;C=J<<1;I=(J|0)<0?C^79764919:C;C=I<<1;J=(I|0)<0?C^79764919:C;C=J<<1;I=(J|0)<0?C^79764919:C;C=I<<1;J=(I|0)<0?C^79764919:C;C=J<<1;I=(J|0)<0?C^79764919:C;C=A+ -1|0;if((C|0)==0){H=I;break}else{E=I;A=C;D=D+1|0}}}Ct(x,n,g)|0;if((g|0)==(F|0)){K=H}else{D=H;A=F-g|0;while(1){E=A>>>0<256?A:256;if((dv(b,l,E)|0)!=0){u=1;z=137;break b}y=c[12600]|0;if((E|0)==0){c[12600]=y;L=D}else{C=y;y=E;I=l;while(1){J=d[I>>0]<<24^C;M=J<<1;N=(J|0)<0?M^79764919:M;M=N<<1;J=(N|0)<0?M^79764919:M;M=J<<1;N=(J|0)<0?M^79764919:M;M=N<<1;J=(N|0)<0?M^79764919:M;M=J<<1;N=(J|0)<0?M^79764919:M;M=N<<1;J=(N|0)<0?M^79764919:M;M=J<<1;N=(J|0)<0?M^79764919:M;M=N<<1;C=(N|0)<0?M^79764919:M;y=y+ -1|0;if((y|0)==0){break}else{I=I+1|0}}c[12600]=C;I=D;y=E;M=l;while(1){N=d[M>>0]<<24^I;J=N<<1;O=(N|0)<0?J^79764919:J;J=O<<1;N=(O|0)<0?J^79764919:J;J=N<<1;O=(N|0)<0?J^79764919:J;J=O<<1;N=(O|0)<0?J^79764919:J;J=N<<1;O=(N|0)<0?J^79764919:J;J=O<<1;N=(O|0)<0?J^79764919:J;J=N<<1;O=(N|0)<0?J^79764919:J;J=O<<1;N=(O|0)<0?J^79764919:J;J=y+ -1|0;if((J|0)==0){L=N;break}else{I=N;y=J;M=M+1|0}}}if((A|0)==(E|0)){K=L;break}else{D=L;A=A-E|0}}}if((dv(b,l,4)|0)!=0){u=1;z=137;break b}A=c[12600]|0;D=4;g=l;while(1){M=d[g>>0]<<24^A;y=M<<1;I=(M|0)<0?y^79764919:y;y=I<<1;M=(I|0)<0?y^79764919:y;y=M<<1;I=(M|0)<0?y^79764919:y;y=I<<1;M=(I|0)<0?y^79764919:y;y=M<<1;I=(M|0)<0?y^79764919:y;y=I<<1;M=(I|0)<0?y^79764919:y;y=M<<1;I=(M|0)<0?y^79764919:y;y=I<<1;A=(I|0)<0?y^79764919:y;D=D+ -1|0;if((D|0)==0){break}else{g=g+1|0}}c[12600]=A;if((Zu(l,0)|0)!=(K|0)){u=1;z=137;break b}}else if((B|0)==17229){if((F|0)==0){if((dv(b,l,4)|0)!=0){u=1;z=137;break b}g=c[12600]|0;D=4;y=l;while(1){I=d[y>>0]<<24^g;M=I<<1;C=(I|0)<0?M^79764919:M;M=C<<1;I=(C|0)<0?M^79764919:M;M=I<<1;C=(I|0)<0?M^79764919:M;M=C<<1;I=(C|0)<0?M^79764919:M;M=I<<1;C=(I|0)<0?M^79764919:M;M=C<<1;I=(C|0)<0?M^79764919:M;M=I<<1;C=(I|0)<0?M^79764919:M;M=C<<1;g=(C|0)<0?M^79764919:M;D=D+ -1|0;if((D|0)==0){break}else{y=y+1|0}}c[12600]=g;P=(Zu(l,0)|0)!=(G|0)|0}else{Q=yz(F)|0;if((Q|0)==0){u=1;z=137;break b}if((dv(b,Q,F)|0)!=0){z=109;break b}y=c[12600]|0;D=F;B=Q;while(1){A=d[B>>0]<<24^y;M=A<<1;C=(A|0)<0?M^79764919:M;M=C<<1;A=(C|0)<0?M^79764919:M;M=A<<1;C=(A|0)<0?M^79764919:M;M=C<<1;A=(C|0)<0?M^79764919:M;M=A<<1;C=(A|0)<0?M^79764919:M;M=C<<1;A=(C|0)<0?M^79764919:M;M=A<<1;C=(A|0)<0?M^79764919:M;M=C<<1;y=(C|0)<0?M^79764919:M;D=D+ -1|0;if((D|0)==0){break}else{B=B+1|0}}c[12600]=y;B=G;D=F;g=Q;while(1){M=d[g>>0]<<24^B;C=M<<1;A=(M|0)<0?C^79764919:C;C=A<<1;M=(A|0)<0?C^79764919:C;C=M<<1;A=(M|0)<0?C^79764919:C;C=A<<1;M=(A|0)<0?C^79764919:C;C=M<<1;A=(M|0)<0?C^79764919:C;C=A<<1;M=(A|0)<0?C^79764919:C;C=M<<1;A=(M|0)<0?C^79764919:C;C=A<<1;B=(A|0)<0?C^79764919:C;D=D+ -1|0;if((D|0)==0){break}else{g=g+1|0}}g=(a[Q>>0]|0)==10;D=(g<<31>>31)+F|0;if((D|0)==0){R=0}else{y=D+ -1|0;R=(a[Q+y>>0]|0)==10?y:D}D=Ut(f,Q+(g&1)|0,R)|0;zz(Q);if((dv(b,l,4)|0)==0){g=c[12600]|0;y=4;C=l;while(1){A=d[C>>0]<<24^g;M=A<<1;I=(A|0)<0?M^79764919:M;M=I<<1;A=(I|0)<0?M^79764919:M;M=A<<1;I=(A|0)<0?M^79764919:M;M=I<<1;A=(I|0)<0?M^79764919:M;M=A<<1;I=(A|0)<0?M^79764919:M;M=I<<1;A=(I|0)<0?M^79764919:M;M=A<<1;I=(A|0)<0?M^79764919:M;M=I<<1;g=(I|0)<0?M^79764919:M;y=y+ -1|0;if((y|0)==0){break}else{C=C+1|0}}c[12600]=g;S=(Zu(l,0)|0)!=(B|0)|0}else{S=1}P=S|D}if((P|0)!=0){u=1;z=137;break b}}else{if((F|0)==0){T=G}else{C=G;y=F;while(1){M=y>>>0<256?y:256;if((dv(b,l,M)|0)!=0){u=1;z=137;break b}I=c[12600]|0;if((M|0)==0){c[12600]=I;U=C}else{A=I;I=M;J=l;while(1){N=d[J>>0]<<24^A;O=N<<1;V=(N|0)<0?O^79764919:O;O=V<<1;N=(V|0)<0?O^79764919:O;O=N<<1;V=(N|0)<0?O^79764919:O;O=V<<1;N=(V|0)<0?O^79764919:O;O=N<<1;V=(N|0)<0?O^79764919:O;O=V<<1;N=(V|0)<0?O^79764919:O;O=N<<1;V=(N|0)<0?O^79764919:O;O=V<<1;A=(V|0)<0?O^79764919:O;I=I+ -1|0;if((I|0)==0){break}else{J=J+1|0}}c[12600]=A;J=C;I=M;E=l;while(1){O=d[E>>0]<<24^J;V=O<<1;N=(O|0)<0?V^79764919:V;V=N<<1;O=(N|0)<0?V^79764919:V;V=O<<1;N=(O|0)<0?V^79764919:V;V=N<<1;O=(N|0)<0?V^79764919:V;V=O<<1;N=(O|0)<0?V^79764919:V;V=N<<1;O=(N|0)<0?V^79764919:V;V=O<<1;N=(O|0)<0?V^79764919:V;V=N<<1;O=(N|0)<0?V^79764919:V;V=I+ -1|0;if((V|0)==0){U=O;break}else{J=O;I=V;E=E+1|0}}}if((y|0)==(M|0)){T=U;break}else{C=U;y=y-M|0}}}if((dv(b,l,4)|0)!=0){u=1;z=137;break b}y=c[12600]|0;C=4;D=l;while(1){B=d[D>>0]<<24^y;g=B<<1;E=(B|0)<0?g^79764919:g;g=E<<1;B=(E|0)<0?g^79764919:g;g=B<<1;E=(B|0)<0?g^79764919:g;g=E<<1;B=(E|0)<0?g^79764919:g;g=B<<1;E=(B|0)<0?g^79764919:g;g=E<<1;B=(E|0)<0?g^79764919:g;g=B<<1;E=(B|0)<0?g^79764919:g;g=E<<1;y=(E|0)<0?g^79764919:g;C=C+ -1|0;if((C|0)==0){break}else{D=D+1|0}}c[12600]=y;if((Zu(l,0)|0)!=(T|0)){u=1;z=137;break b}}if((dv(b,m,4)|0)!=0){u=1;z=137;break b}}if(F>>>0<12){u=1;z=137;break}if((dv(b,k,12)|0)!=0){u=1;z=137;break}D=c[12600]|0;C=12;g=k;while(1){E=d[g>>0]<<24^D;B=E<<1;I=(E|0)<0?B^79764919:B;B=I<<1;E=(I|0)<0?B^79764919:B;B=E<<1;I=(E|0)<0?B^79764919:B;B=I<<1;E=(I|0)<0?B^79764919:B;B=E<<1;I=(E|0)<0?B^79764919:B;B=I<<1;E=(I|0)<0?B^79764919:B;B=E<<1;I=(E|0)<0?B^79764919:B;B=I<<1;D=(I|0)<0?B^79764919:B;C=C+ -1|0;if((C|0)==0){break}else{g=g+1|0}}c[12600]=D;g=d[k>>0]|0;C=d[v>>0]|0;B=d[s>>0]|0;I=Yu(k,6)|0;W=kt(d[q>>0]|0,d[h>>0]|0,d[t>>0]|0,I)|0;if((W|0)==0){u=1;z=137;break}E=(Zu(k,8)|0)&16777215;if((g&1|0)!=0){J=W+12|0;c[J>>2]=c[J>>2]|1}if((g&2|0)!=0){J=W+12|0;c[J>>2]=c[J>>2]|2}if((g&4|0)!=0){J=W+12|0;c[J>>2]=c[J>>2]|4}if((g&8|0)!=0){J=W+12|0;c[J>>2]=c[J>>2]|8}J=d[r>>0]|0;if((J|0)==3){X=3}else if((J|0)==1){X=E>>>0<375e3?1:32769}else if((J|0)==2){X=E>>>0<375e3?2:32770}else{X=0}tt(W,X);if((g&64|0)==0){if((Pt(f,W,C,B)|0)==0){Y=G;Z=12;_=k}else{z=54;break}}else{if(w){z=51;break}nt(x,W);Y=G;Z=12;_=k}while(1){B=d[_>>0]<<24^Y;C=B<<1;E=(B|0)<0?C^79764919:C;C=E<<1;B=(E|0)<0?C^79764919:C;C=B<<1;E=(B|0)<0?C^79764919:C;C=E<<1;B=(E|0)<0?C^79764919:C;C=B<<1;E=(B|0)<0?C^79764919:C;C=E<<1;B=(E|0)<0?C^79764919:C;C=B<<1;E=(B|0)<0?C^79764919:C;C=E<<1;Y=(E|0)<0?C^79764919:C;Z=Z+ -1|0;if((Z|0)==0){break}else{_=_+1|0}}w=F+ -12|0;if((g&128|0)==0){D=W+10|0;if(w>>>0<(e[D>>1]|0)>>>0){u=1;z=137;break}C=W+24|0;E=c[C>>2]|0;if((dv(b,E,I)|0)!=0){u=1;z=137;break}B=c[12600]|0;if((I|0)==0){c[12600]=B;$=Y}else{J=B;B=I;A=E;while(1){E=d[A>>0]<<24^J;V=E<<1;O=(E|0)<0?V^79764919:V;V=O<<1;E=(O|0)<0?V^79764919:V;V=E<<1;O=(E|0)<0?V^79764919:V;V=O<<1;E=(O|0)<0?V^79764919:V;V=E<<1;O=(E|0)<0?V^79764919:V;V=O<<1;E=(O|0)<0?V^79764919:V;V=E<<1;O=(E|0)<0?V^79764919:V;V=O<<1;J=(O|0)<0?V^79764919:V;B=B+ -1|0;if((B|0)==0){break}else{A=A+1|0}}c[12600]=J;A=Y;B=I;g=c[C>>2]|0;while(1){V=d[g>>0]<<24^A;O=V<<1;E=(V|0)<0?O^79764919:O;O=E<<1;V=(E|0)<0?O^79764919:O;O=V<<1;E=(V|0)<0?O^79764919:O;O=E<<1;V=(E|0)<0?O^79764919:O;O=V<<1;E=(V|0)<0?O^79764919:O;O=E<<1;V=(E|0)<0?O^79764919:O;O=V<<1;E=(V|0)<0?O^79764919:O;O=E<<1;V=(E|0)<0?O^79764919:O;O=B+ -1|0;if((O|0)==0){$=V;break}else{A=V;B=O;g=g+1|0}}}aa=w-(e[D>>1]|0)|0;ba=$}else{if((w|0)==0){u=1;z=137;break}if((dv(b,k,1)|0)!=0){u=1;z=137;break}g=d[k>>0]|0;B=g<<24;A=B^c[12600];C=A<<1;I=(A|0)<0?C^79764919:C;C=I<<1;A=(I|0)<0?C^79764919:C;C=A<<1;I=(A|0)<0?C^79764919:C;C=I<<1;A=(I|0)<0?C^79764919:C;C=A<<1;I=(A|0)<0?C^79764919:C;C=I<<1;A=(I|0)<0?C^79764919:C;C=A<<1;I=(A|0)<0?C^79764919:C;C=I<<1;c[12600]=(I|0)<0?C^79764919:C;C=B^Y;B=C<<1;I=(C|0)<0?B^79764919:B;B=I<<1;C=(I|0)<0?B^79764919:B;B=C<<1;I=(C|0)<0?B^79764919:B;B=I<<1;C=(I|0)<0?B^79764919:B;B=C<<1;I=(C|0)<0?B^79764919:B;B=I<<1;C=(I|0)<0?B^79764919:B;B=C<<1;I=(C|0)<0?B^79764919:B;B=I<<1;qt(W,g);aa=F+ -13|0;ba=(I|0)<0?B^79764919:B}if((aa|0)==0){ca=ba}else{B=ba;I=aa;while(1){g=I>>>0<256?I:256;if((dv(b,l,g)|0)!=0){u=1;z=137;break b}C=c[12600]|0;if((g|0)==0){c[12600]=C;da=B}else{A=C;C=g;J=l;while(1){O=d[J>>0]<<24^A;V=O<<1;E=(O|0)<0?V^79764919:V;V=E<<1;O=(E|0)<0?V^79764919:V;V=O<<1;E=(O|0)<0?V^79764919:V;V=E<<1;O=(E|0)<0?V^79764919:V;V=O<<1;E=(O|0)<0?V^79764919:V;V=E<<1;O=(E|0)<0?V^79764919:V;V=O<<1;E=(O|0)<0?V^79764919:V;V=E<<1;A=(E|0)<0?V^79764919:V;C=C+ -1|0;if((C|0)==0){break}else{J=J+1|0}}c[12600]=A;J=B;C=g;y=l;while(1){V=d[y>>0]<<24^J;E=V<<1;O=(V|0)<0?E^79764919:E;E=O<<1;V=(O|0)<0?E^79764919:E;E=V<<1;O=(V|0)<0?E^79764919:E;E=O<<1;V=(O|0)<0?E^79764919:E;E=V<<1;O=(V|0)<0?E^79764919:E;E=O<<1;V=(O|0)<0?E^79764919:E;E=V<<1;O=(V|0)<0?E^79764919:E;E=O<<1;V=(O|0)<0?E^79764919:E;E=C+ -1|0;if((E|0)==0){da=V;break}else{J=V;C=E;y=y+1|0}}}if((I|0)==(g|0)){ca=da;break}else{B=da;I=I-g|0}}}if((dv(b,l,4)|0)!=0){u=1;z=137;break}I=c[12600]|0;B=4;w=l;while(1){D=d[w>>0]<<24^I;y=D<<1;C=(D|0)<0?y^79764919:y;y=C<<1;D=(C|0)<0?y^79764919:y;y=D<<1;C=(D|0)<0?y^79764919:y;y=C<<1;D=(C|0)<0?y^79764919:y;y=D<<1;C=(D|0)<0?y^79764919:y;y=C<<1;D=(C|0)<0?y^79764919:y;y=D<<1;C=(D|0)<0?y^79764919:y;y=C<<1;I=(C|0)<0?y^79764919:y;B=B+ -1|0;if((B|0)==0){break}else{w=w+1|0}}c[12600]=I;if((Zu(l,0)|0)==(ca|0)){x=W}else{u=1;z=137;break}}if((z|0)==20){c:do{if((F|0)==0){ea=G}else{x=G;ca=F;while(1){da=ca>>>0<256?ca:256;if((dv(b,l,da)|0)!=0){u=1;break}aa=c[12600]|0;if((da|0)==0){c[12600]=aa;fa=x}else{ba=aa;aa=da;Y=l;while(1){k=d[Y>>0]<<24^ba;$=k<<1;_=(k|0)<0?$^79764919:$;$=_<<1;k=(_|0)<0?$^79764919:$;$=k<<1;_=(k|0)<0?$^79764919:$;$=_<<1;k=(_|0)<0?$^79764919:$;$=k<<1;_=(k|0)<0?$^79764919:$;$=_<<1;k=(_|0)<0?$^79764919:$;$=k<<1;_=(k|0)<0?$^79764919:$;$=_<<1;ba=(_|0)<0?$^79764919:$;aa=aa+ -1|0;if((aa|0)==0){break}else{Y=Y+1|0}}c[12600]=ba;Y=x;aa=da;g=l;while(1){$=d[g>>0]<<24^Y;_=$<<1;k=($|0)<0?_^79764919:_;_=k<<1;$=(k|0)<0?_^79764919:_;_=$<<1;k=($|0)<0?_^79764919:_;_=k<<1;$=(k|0)<0?_^79764919:_;_=$<<1;k=($|0)<0?_^79764919:_;_=k<<1;$=(k|0)<0?_^79764919:_;_=$<<1;k=($|0)<0?_^79764919:_;_=k<<1;$=(k|0)<0?_^79764919:_;_=aa+ -1|0;if((_|0)==0){fa=$;break}else{Y=$;aa=_;g=g+1|0}}}if((ca|0)==(da|0)){ea=fa;break c}else{x=fa;ca=ca-da|0}}i=j;return u|0}}while(0);if((dv(b,l,4)|0)!=0){u=1;i=j;return u|0}fa=c[12600]|0;F=4;G=l;while(1){ca=d[G>>0]<<24^fa;x=ca<<1;I=(ca|0)<0?x^79764919:x;x=I<<1;ca=(I|0)<0?x^79764919:x;x=ca<<1;I=(ca|0)<0?x^79764919:x;x=I<<1;ca=(I|0)<0?x^79764919:x;x=ca<<1;I=(ca|0)<0?x^79764919:x;x=I<<1;ca=(I|0)<0?x^79764919:x;x=ca<<1;I=(ca|0)<0?x^79764919:x;x=I<<1;fa=(I|0)<0?x^79764919:x;F=F+ -1|0;if((F|0)==0){break}else{G=G+1|0}}c[12600]=fa;if((Zu(l,0)|0)!=(ea|0)){u=1;i=j;return u|0}Wt(f);f=c[12600]|0;if((dv(b,p,4)|0)!=0){u=1;i=j;return u|0}b=c[12600]|0;ea=4;l=p;while(1){fa=d[l>>0]<<24^b;G=fa<<1;F=(fa|0)<0?G^79764919:G;G=F<<1;fa=(F|0)<0?G^79764919:G;G=fa<<1;F=(fa|0)<0?G^79764919:G;G=F<<1;fa=(F|0)<0?G^79764919:G;G=fa<<1;F=(fa|0)<0?G^79764919:G;G=F<<1;fa=(F|0)<0?G^79764919:G;G=fa<<1;F=(fa|0)<0?G^79764919:G;G=F<<1;b=(F|0)<0?G^79764919:G;ea=ea+ -1|0;if((ea|0)==0){break}else{l=l+1|0}}c[12600]=b;u=(Zu(p,0)|0)!=(f|0)|0;i=j;return u|0}else if((z|0)==51){lt(W);u=1;i=j;return u|0}else if((z|0)==54){lt(W);u=1;i=j;return u|0}else if((z|0)==109){zz(Q);u=1;i=j;return u|0}else if((z|0)==137){i=j;return u|0}return 0}function uu(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;h=i;i=i+32|0;j=h+16|0;k=h;c[12600]=-1;$u(k,0,1346782275);_u(k,4,2);_u(k,6,0);$u(k,8,0);$u(k,12,16);if((fv(f,k,16)|0)!=0){l=1;i=h;return l|0}m=c[12600]|0;n=16;o=k;while(1){p=d[o>>0]<<24^m;q=p<<1;r=(p|0)<0?q^79764919:q;q=r<<1;p=(r|0)<0?q^79764919:q;q=p<<1;r=(p|0)<0?q^79764919:q;q=r<<1;p=(r|0)<0?q^79764919:q;q=p<<1;r=(p|0)<0?q^79764919:q;q=r<<1;p=(r|0)<0?q^79764919:q;q=p<<1;r=(p|0)<0?q^79764919:q;q=r<<1;m=(r|0)<0?q^79764919:q;n=n+ -1|0;if((n|0)==0){break}else{o=o+1|0}}c[12600]=m;m=g+8|0;if((c[m>>2]|0)!=0){_u(j,0,17229);_u(j,2,(c[m>>2]|0)+2|0);o=j+4|0;a[o>>0]=10;n=0;q=5;r=j;while(1){p=d[r>>0]<<24^n;s=p<<1;t=(p|0)<0?s^79764919:s;s=t<<1;p=(t|0)<0?s^79764919:s;s=p<<1;t=(p|0)<0?s^79764919:s;s=t<<1;p=(t|0)<0?s^79764919:s;s=p<<1;t=(p|0)<0?s^79764919:s;s=t<<1;p=(t|0)<0?s^79764919:s;s=p<<1;t=(p|0)<0?s^79764919:s;s=t<<1;n=(t|0)<0?s^79764919:s;q=q+ -1|0;if((q|0)==0){break}else{r=r+1|0}}r=g+12|0;q=c[m>>2]|0;if((q|0)==0){u=n}else{s=n;n=q;q=c[r>>2]|0;while(1){t=d[q>>0]<<24^s;p=t<<1;v=(t|0)<0?p^79764919:p;p=v<<1;t=(v|0)<0?p^79764919:p;p=t<<1;v=(t|0)<0?p^79764919:p;p=v<<1;t=(v|0)<0?p^79764919:p;p=t<<1;v=(t|0)<0?p^79764919:p;p=v<<1;t=(v|0)<0?p^79764919:p;p=t<<1;v=(t|0)<0?p^79764919:p;p=v<<1;t=(v|0)<0?p^79764919:p;p=n+ -1|0;if((p|0)==0){u=t;break}else{s=t;n=p;q=q+1|0}}}q=(u>>31)+335544320&-54452809^u<<1;u=q<<1;n=(q|0)<0?u^79764919:u;u=n<<1;q=(n|0)<0?u^79764919:u;u=q<<1;n=(q|0)<0?u^79764919:u;u=n<<1;q=(n|0)<0?u^79764919:u;u=q<<1;n=(q|0)<0?u^79764919:u;u=n<<1;q=(n|0)<0?u^79764919:u;u=q<<1;n=(q|0)<0?u^79764919:u;if((fv(f,j,5)|0)==0){u=c[12600]|0;q=5;s=j;while(1){p=d[s>>0]<<24^u;t=p<<1;v=(p|0)<0?t^79764919:t;t=v<<1;p=(v|0)<0?t^79764919:t;t=p<<1;v=(p|0)<0?t^79764919:t;t=v<<1;p=(v|0)<0?t^79764919:t;t=p<<1;v=(p|0)<0?t^79764919:t;t=v<<1;p=(v|0)<0?t^79764919:t;t=p<<1;v=(p|0)<0?t^79764919:t;t=v<<1;u=(v|0)<0?t^79764919:t;q=q+ -1|0;if((q|0)==0){break}else{s=s+1|0}}c[12600]=u;w=0}else{w=1}u=c[r>>2]|0;r=c[m>>2]|0;if((fv(f,u,r)|0)==0){m=c[12600]|0;if((r|0)==0){x=m}else{s=m;m=r;r=u;while(1){u=d[r>>0]<<24^s;q=u<<1;t=(u|0)<0?q^79764919:q;q=t<<1;u=(t|0)<0?q^79764919:q;q=u<<1;t=(u|0)<0?q^79764919:q;q=t<<1;u=(t|0)<0?q^79764919:q;q=u<<1;t=(u|0)<0?q^79764919:q;q=t<<1;u=(t|0)<0?q^79764919:q;q=u<<1;t=(u|0)<0?q^79764919:q;q=t<<1;u=(t|0)<0?q^79764919:q;q=m+ -1|0;if((q|0)==0){x=u;break}else{s=u;m=q;r=r+1|0}}}c[12600]=x;y=0}else{y=1}if((fv(f,o,1)|0)==0){x=d[o>>0]<<24^c[12600];o=x<<1;r=(x|0)<0?o^79764919:o;o=r<<1;x=(r|0)<0?o^79764919:o;o=x<<1;r=(x|0)<0?o^79764919:o;o=r<<1;x=(r|0)<0?o^79764919:o;o=x<<1;r=(x|0)<0?o^79764919:o;o=r<<1;x=(r|0)<0?o^79764919:o;o=x<<1;r=(x|0)<0?o^79764919:o;o=r<<1;c[12600]=(r|0)<0?o^79764919:o;z=0}else{z=1}o=y|w|z;$u(j,0,n);if((fv(f,j,4)|0)==0){n=c[12600]|0;z=4;w=j;while(1){j=d[w>>0]<<24^n;y=j<<1;r=(j|0)<0?y^79764919:y;y=r<<1;j=(r|0)<0?y^79764919:y;y=j<<1;r=(j|0)<0?y^79764919:y;y=r<<1;j=(r|0)<0?y^79764919:y;y=j<<1;r=(j|0)<0?y^79764919:y;y=r<<1;j=(r|0)<0?y^79764919:y;y=j<<1;r=(j|0)<0?y^79764919:y;y=r<<1;n=(r|0)<0?y^79764919:y;z=z+ -1|0;if((z|0)==0){break}else{w=w+1|0}}c[12600]=n;A=0}else{A=1}if((o|A|0)!=0){l=1;i=h;return l|0}}A=b[g>>1]|0;a:do{if(!(A<<16>>16==0)){o=g+4|0;n=A;w=0;b:while(1){z=c[(c[o>>2]|0)+(w<<2)>>2]|0;y=z+2|0;r=b[y>>1]|0;if(r<<16>>16==0){B=n}else{j=z+4|0;z=r;r=0;while(1){x=c[(c[j>>2]|0)+(r<<2)>>2]|0;m=x+2|0;if((b[m>>1]|0)==0){C=z}else{s=x+4|0;x=0;do{q=c[(c[s>>2]|0)+(x<<2)>>2]|0;if((wu(f,q,w,r,0)|0)==0){D=q}else{l=1;E=44;break b}while(1){q=c[D>>2]|0;if((q|0)==0){break}if((wu(f,q,w,r,1)|0)==0){D=q}else{l=1;E=44;break b}}x=x+1|0}while(x>>>0<(e[m>>1]|0)>>>0);C=b[y>>1]|0}r=r+1|0;if(!(r>>>0<(C&65535)>>>0)){break}else{z=C}}B=b[g>>1]|0}w=w+1|0;if(!(w>>>0<(B&65535)>>>0)){break a}else{n=B}}if((E|0)==44){i=h;return l|0}}}while(0);if((vu(f,17742,0,0)|0)!=0){l=1;i=h;return l|0}$u(k,0,c[12600]|0);if((fv(f,k,4)|0)!=0){l=1;i=h;return l|0}E=c[12600]|0;B=4;g=k;while(1){k=d[g>>0]<<24^E;C=k<<1;D=(k|0)<0?C^79764919:C;C=D<<1;k=(D|0)<0?C^79764919:C;C=k<<1;D=(k|0)<0?C^79764919:C;C=D<<1;k=(D|0)<0?C^79764919:C;C=k<<1;D=(k|0)<0?C^79764919:C;C=D<<1;k=(D|0)<0?C^79764919:C;C=k<<1;D=(k|0)<0?C^79764919:C;C=D<<1;E=(D|0)<0?C^79764919:C;B=B+ -1|0;if((B|0)==0){break}else{g=g+1|0}}c[12600]=E;Nb(f|0)|0;l=0;i=h;return l|0}function vu(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+16|0;h=g;_u(h,0,b);_u(h,2,e);b=0;j=4;k=h;while(1){l=(d[k>>0]|0)<<24^b;m=l<<1;n=(l|0)<0?m^79764919:m;m=n<<1;l=(n|0)<0?m^79764919:m;m=l<<1;n=(l|0)<0?m^79764919:m;m=n<<1;l=(n|0)<0?m^79764919:m;m=l<<1;n=(l|0)<0?m^79764919:m;m=n<<1;l=(n|0)<0?m^79764919:m;m=l<<1;n=(l|0)<0?m^79764919:m;m=n<<1;b=(n|0)<0?m^79764919:m;j=j+ -1|0;if((j|0)==0){break}else{k=k+1|0}}if((fv(a,h,4)|0)!=0){o=1;i=g;return o|0}k=c[12600]|0;j=4;m=h;while(1){n=(d[m>>0]|0)<<24^k;l=n<<1;p=(n|0)<0?l^79764919:l;l=p<<1;n=(p|0)<0?l^79764919:l;l=n<<1;p=(n|0)<0?l^79764919:l;l=p<<1;n=(p|0)<0?l^79764919:l;l=n<<1;p=(n|0)<0?l^79764919:l;l=p<<1;n=(p|0)<0?l^79764919:l;l=n<<1;p=(n|0)<0?l^79764919:l;l=p<<1;k=(p|0)<0?l^79764919:l;j=j+ -1|0;if((j|0)==0){break}else{m=m+1|0}}c[12600]=k;if((e|0)==0){q=b}else{k=b;b=e;m=f;while(1){j=(d[m>>0]|0)<<24^k;l=j<<1;p=(j|0)<0?l^79764919:l;l=p<<1;j=(p|0)<0?l^79764919:l;l=j<<1;p=(j|0)<0?l^79764919:l;l=p<<1;j=(p|0)<0?l^79764919:l;l=j<<1;p=(j|0)<0?l^79764919:l;l=p<<1;j=(p|0)<0?l^79764919:l;l=j<<1;p=(j|0)<0?l^79764919:l;l=p<<1;k=(p|0)<0?l^79764919:l;b=b+ -1|0;if((b|0)==0){break}else{m=m+1|0}}if((fv(a,f,e)|0)!=0){o=1;i=g;return o|0}m=c[12600]|0;b=e;e=f;while(1){f=(d[e>>0]|0)<<24^m;l=f<<1;p=(f|0)<0?l^79764919:l;l=p<<1;f=(p|0)<0?l^79764919:l;l=f<<1;p=(f|0)<0?l^79764919:l;l=p<<1;f=(p|0)<0?l^79764919:l;l=f<<1;p=(f|0)<0?l^79764919:l;l=p<<1;f=(p|0)<0?l^79764919:l;l=f<<1;p=(f|0)<0?l^79764919:l;l=p<<1;m=(p|0)<0?l^79764919:l;b=b+ -1|0;if((b|0)==0){break}else{e=e+1|0}}c[12600]=m;q=k}$u(h,0,q);if((fv(a,h,4)|0)!=0){o=1;i=g;return o|0}a=c[12600]|0;q=4;k=h;while(1){h=(d[k>>0]|0)<<24^a;m=h<<1;e=(h|0)<0?m^79764919:m;m=e<<1;h=(e|0)<0?m^79764919:m;m=h<<1;e=(h|0)<0?m^79764919:m;m=e<<1;h=(e|0)<0?m^79764919:m;m=h<<1;e=(h|0)<0?m^79764919:m;m=e<<1;h=(e|0)<0?m^79764919:m;m=h<<1;e=(h|0)<0?m^79764919:m;m=e<<1;a=(e|0)<0?m^79764919:m;q=q+ -1|0;if((q|0)==0){break}else{k=k+1|0}}c[12600]=a;o=0;i=g;return o|0}function wu(f,g,h,j,k){f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;l=i;i=i+256|0;m=l;n=c[g+12>>2]&15;o=(rt(g)|0)==0;p=b[g+10>>1]|0;if(o){q=p;r=4}else{if(p<<16>>16==0){q=0;r=4}else{s=13;t=n|128}}if((r|0)==4){s=(q&65535)+12|0;t=n}n=((k|0)==0?t:t|64)&255;_u(m,0,21315);_u(m,2,s);s=e[g+16>>1]|0;if((s|0)==1){u=125e3;v=1}else if((s|0)==32770){u=5e5;v=2}else if((s|0)==3){u=5e5;v=3}else if((s|0)==32769){u=25e4;v=1}else if((s|0)==2){u=25e4;v=2}else if((s|0)==16386){u=1e6;v=2}else{u=0;v=0}$u(m,12,u);a[m+4>>0]=n;a[m+5>>0]=h;a[m+6>>0]=j;a[m+7>>0]=b[g+4>>1];a[m+8>>0]=b[g+6>>1];a[m+9>>0]=b[g+8>>1];j=g+10|0;h=b[j>>1]|0;a[m+10>>0]=(h&65535)>>>8;a[m+11>>0]=h;a[m+12>>0]=v;v=0;h=16;u=m;while(1){s=(d[u>>0]|0)<<24^v;t=s<<1;k=(s|0)<0?t^79764919:t;t=k<<1;s=(k|0)<0?t^79764919:t;t=s<<1;k=(s|0)<0?t^79764919:t;t=k<<1;s=(k|0)<0?t^79764919:t;t=s<<1;k=(s|0)<0?t^79764919:t;t=k<<1;s=(k|0)<0?t^79764919:t;t=s<<1;k=(s|0)<0?t^79764919:t;t=k<<1;v=(k|0)<0?t^79764919:t;h=h+ -1|0;if((h|0)==0){break}else{u=u+1|0}}if((fv(f,m,16)|0)!=0){w=1;i=l;return w|0}u=c[12600]|0;h=16;t=m;while(1){k=(d[t>>0]|0)<<24^u;s=k<<1;q=(k|0)<0?s^79764919:s;s=q<<1;k=(q|0)<0?s^79764919:s;s=k<<1;q=(k|0)<0?s^79764919:s;s=q<<1;k=(q|0)<0?s^79764919:s;s=k<<1;q=(k|0)<0?s^79764919:s;s=q<<1;k=(q|0)<0?s^79764919:s;s=k<<1;q=(k|0)<0?s^79764919:s;s=q<<1;u=(q|0)<0?s^79764919:s;h=h+ -1|0;if((h|0)==0){break}else{t=t+1|0}}c[12600]=u;u=c[g+24>>2]|0;do{if(n<<24>>24<0){t=a[u>>0]|0;a[m>>0]=t;h=(t&255)<<24^v;t=h<<1;s=(h|0)<0?t^79764919:t;t=s<<1;h=(s|0)<0?t^79764919:t;t=h<<1;s=(h|0)<0?t^79764919:t;t=s<<1;h=(s|0)<0?t^79764919:t;t=h<<1;s=(h|0)<0?t^79764919:t;t=s<<1;h=(s|0)<0?t^79764919:t;t=h<<1;s=(h|0)<0?t^79764919:t;t=s<<1;if((fv(f,m,1)|0)==0){h=(d[m>>0]|0)<<24^c[12600];q=h<<1;k=(h|0)<0?q^79764919:q;q=k<<1;h=(k|0)<0?q^79764919:q;q=h<<1;k=(h|0)<0?q^79764919:q;q=k<<1;h=(k|0)<0?q^79764919:q;q=h<<1;k=(h|0)<0?q^79764919:q;q=k<<1;h=(k|0)<0?q^79764919:q;q=h<<1;k=(h|0)<0?q^79764919:q;q=k<<1;x=(s|0)<0?t^79764919:t;y=(k|0)<0?q^79764919:q;break}else{w=1;i=l;return w|0}}else{q=b[j>>1]|0;k=q<<16>>16==0;if(k){z=v;A=0}else{t=q&65535;q=v;s=t;h=u;while(1){r=(d[h>>0]|0)<<24^q;p=r<<1;o=(r|0)<0?p^79764919:p;p=o<<1;r=(o|0)<0?p^79764919:p;p=r<<1;o=(r|0)<0?p^79764919:p;p=o<<1;r=(o|0)<0?p^79764919:p;p=r<<1;o=(r|0)<0?p^79764919:p;p=o<<1;r=(o|0)<0?p^79764919:p;p=r<<1;o=(r|0)<0?p^79764919:p;p=o<<1;r=(o|0)<0?p^79764919:p;p=s+ -1|0;if((p|0)==0){z=r;A=t;break}else{q=r;s=p;h=h+1|0}}}if((fv(f,u,A)|0)!=0){w=1;i=l;return w|0}h=c[12600]|0;if(k){x=z;y=h}else{s=h;h=A;q=u;while(1){t=(d[q>>0]|0)<<24^s;p=t<<1;r=(t|0)<0?p^79764919:p;p=r<<1;t=(r|0)<0?p^79764919:p;p=t<<1;r=(t|0)<0?p^79764919:p;p=r<<1;t=(r|0)<0?p^79764919:p;p=t<<1;r=(t|0)<0?p^79764919:p;p=r<<1;t=(r|0)<0?p^79764919:p;p=t<<1;r=(t|0)<0?p^79764919:p;p=r<<1;t=(r|0)<0?p^79764919:p;p=h+ -1|0;if((p|0)==0){x=z;y=t;break}else{s=t;h=p;q=q+1|0}}}}}while(0);c[12600]=y;$u(m,0,x);if((fv(f,m,4)|0)!=0){w=1;i=l;return w|0}x=c[12600]|0;y=4;z=m;while(1){u=(d[z>>0]|0)<<24^x;A=u<<1;v=(u|0)<0?A^79764919:A;A=v<<1;u=(v|0)<0?A^79764919:A;A=u<<1;v=(u|0)<0?A^79764919:A;A=v<<1;u=(v|0)<0?A^79764919:A;A=u<<1;v=(u|0)<0?A^79764919:A;A=v<<1;u=(v|0)<0?A^79764919:A;A=u<<1;v=(u|0)<0?A^79764919:A;A=v<<1;x=(v|0)<0?A^79764919:A;y=y+ -1|0;if((y|0)==0){break}else{z=z+1|0}}c[12600]=x;x=Dt(g,m,256)|0;if((x|0)!=0){if((vu(f,21575,x,m)|0)!=0){w=1;i=l;return w|0}}w=0;i=l;return w|0}



function xu(b,f,g,h){b=b|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0;j=i;i=i+560|0;k=j;l=j+528|0;m=j+520|0;n=j+264|0;p=j+256|0;$u(p,0,g);$u(p,4,h);if((c[12626]|0)==0){g=0;do{q=g<<25;r=(g&128|0)!=0?q^517762881:q;q=r<<1;s=(r|0)<0?q^517762881:q;q=s<<1;r=(s|0)<0?q^517762881:q;q=r<<1;s=(r|0)<0?q^517762881:q;q=s<<1;r=(s|0)<0?q^517762881:q;q=r<<1;s=(r|0)<0?q^517762881:q;q=s<<1;r=(s|0)<0?q^517762881:q;q=r<<1;c[50512+(g<<2)>>2]=(r|0)<0?q^517762881:q;g=g+1|0}while((g|0)!=256);c[12626]=1}g=p+1|0;q=c[50512+(d[p>>0]<<2)>>2]|0;r=p+2|0;s=c[50512+((d[g>>0]^q>>>24)<<2)>>2]^q<<8;q=p+3|0;t=c[50512+((d[r>>0]^s>>>24)<<2)>>2]^s<<8;s=p+4|0;u=c[50512+((d[q>>0]^t>>>24)<<2)>>2]^t<<8;t=p+5|0;v=c[50512+((d[s>>0]^u>>>24)<<2)>>2]^u<<8;u=p+6|0;w=c[50512+((d[t>>0]^v>>>24)<<2)>>2]^v<<8;v=p+7|0;x=c[50512+((d[u>>0]^w>>>24)<<2)>>2]^w<<8;w=c[50512+((d[v>>0]^x>>>24)<<2)>>2]^x<<8;if(h>>>0<4){y=1;i=j;return y|0}if((ta(m|0,1,4,b|0)|0)!=4){y=1;i=j;return y|0}if((c[12626]|0)==0){x=0;do{z=x<<25;A=(x&128|0)!=0?z^517762881:z;z=A<<1;B=(A|0)<0?z^517762881:z;z=B<<1;A=(B|0)<0?z^517762881:z;z=A<<1;B=(A|0)<0?z^517762881:z;z=B<<1;A=(B|0)<0?z^517762881:z;z=A<<1;B=(A|0)<0?z^517762881:z;z=B<<1;A=(B|0)<0?z^517762881:z;z=A<<1;c[50512+(x<<2)>>2]=(A|0)<0?z^517762881:z;x=x+1|0}while((x|0)!=256);c[12626]=1}x=c[50512+((d[m>>0]^w>>>24)<<2)>>2]^w<<8;w=c[50512+((d[m+1>>0]^x>>>24)<<2)>>2]^x<<8;x=c[50512+((d[m+2>>0]^w>>>24)<<2)>>2]^w<<8;w=c[50512+((d[m+3>>0]^x>>>24)<<2)>>2]^x<<8;x=Zu(m,0)|0;if((x|0)!=262144){m=c[o>>2]|0;c[k>>2]=x;hb(m|0,50472,k|0)|0;y=1;i=j;return y|0}m=h+ -4|0;a:do{if((m|0)==0){C=w}else{h=w;x=m;while(1){z=x>>>0<256?x:256;if((ta(n|0,1,z|0,b|0)|0)!=(z|0)){y=1;break}if((c[12626]|0)==0){A=0;do{B=A<<25;D=(A&128|0)!=0?B^517762881:B;B=D<<1;E=(D|0)<0?B^517762881:B;B=E<<1;D=(E|0)<0?B^517762881:B;B=D<<1;E=(D|0)<0?B^517762881:B;B=E<<1;D=(E|0)<0?B^517762881:B;B=D<<1;E=(D|0)<0?B^517762881:B;B=E<<1;D=(E|0)<0?B^517762881:B;B=D<<1;c[50512+(A<<2)>>2]=(D|0)<0?B^517762881:B;A=A+1|0}while((A|0)!=256);c[12626]=1}if((z|0)==0){F=h}else{A=z;B=h;D=n;while(1){E=c[50512+((d[D>>0]^B>>>24)<<2)>>2]^B<<8;G=A+ -1|0;if((G|0)==0){F=E;break}else{A=G;B=E;D=D+1|0}}}if((x|0)==(z|0)){C=F;break a}else{h=F;x=x-z|0}}i=j;return y|0}}while(0);if((ta(n|0,1,4,b|0)|0)!=4){y=1;i=j;return y|0}if((Zu(n,0)|0)!=(C|0)){fb(50408,16,1,c[o>>2]|0)|0;y=1;i=j;return y|0}C=c[o>>2]|0;F=l+12|0;m=l+13|0;w=0;b:while(1){if((ta(p|0,1,8,b|0)|0)!=8){y=1;H=145;break}x=(w|0)==0;h=w+10|0;D=w+24|0;c:while(1){if((c[12626]|0)==0){B=0;do{A=B<<25;E=(B&128|0)!=0?A^517762881:A;A=E<<1;G=(E|0)<0?A^517762881:A;A=G<<1;E=(G|0)<0?A^517762881:A;A=E<<1;G=(E|0)<0?A^517762881:A;A=G<<1;E=(G|0)<0?A^517762881:A;A=E<<1;G=(E|0)<0?A^517762881:A;A=G<<1;E=(G|0)<0?A^517762881:A;A=E<<1;c[50512+(B<<2)>>2]=(E|0)<0?A^517762881:A;B=B+1|0}while((B|0)!=256);c[12626]=1}B=c[50512+(d[p>>0]<<2)>>2]|0;z=c[50512+((d[g>>0]^B>>>24)<<2)>>2]^B<<8;B=c[50512+((d[r>>0]^z>>>24)<<2)>>2]^z<<8;z=c[50512+((d[q>>0]^B>>>24)<<2)>>2]^B<<8;B=c[50512+((d[s>>0]^z>>>24)<<2)>>2]^z<<8;z=c[50512+((d[t>>0]^B>>>24)<<2)>>2]^B<<8;B=c[50512+((d[u>>0]^z>>>24)<<2)>>2]^z<<8;I=c[50512+((d[v>>0]^B>>>24)<<2)>>2]^B<<8;B=Zu(p,0)|0;J=Zu(p,4)|0;do{if((B|0)==1413830740){if((J|0)==0){if((ta(n|0,1,4,b|0)|0)!=4){y=1;H=145;break b}if((Zu(n,0)|0)==(I|0)){break}else{H=119;break b}}K=yz(J)|0;if((K|0)==0){y=1;H=145;break b}if((ta(K|0,1,J|0,b|0)|0)!=(J|0)){H=126;break b}if((c[12626]|0)==0){z=0;do{A=z<<25;E=(z&128|0)!=0?A^517762881:A;A=E<<1;G=(E|0)<0?A^517762881:A;A=G<<1;E=(G|0)<0?A^517762881:A;A=E<<1;G=(E|0)<0?A^517762881:A;A=G<<1;E=(G|0)<0?A^517762881:A;A=E<<1;G=(E|0)<0?A^517762881:A;A=G<<1;E=(G|0)<0?A^517762881:A;A=E<<1;c[50512+(z<<2)>>2]=(E|0)<0?A^517762881:A;z=z+1|0}while((z|0)!=256);c[12626]=1;L=J;M=I;N=K}else{L=J;M=I;N=K}while(1){M=c[50512+((d[N>>0]^M>>>24)<<2)>>2]^M<<8;L=L+ -1|0;if((L|0)==0){break}else{N=N+1|0}}z=(a[K>>0]|0)==10;A=(z<<31>>31)+J|0;if((A|0)==0){O=0}else{E=A+ -1|0;O=(a[K+E>>0]|0)==10?E:A}A=Ut(f,K+(z&1)|0,O)|0;zz(K);if((ta(n|0,1,4,b|0)|0)==4){if((Zu(n,0)|0)==(M|0)){P=0}else{fb(50408,16,1,C|0)|0;P=1}}else{P=1}if((P|A|0)!=0){y=1;H=145;break b}}else if((B|0)==1397048148){break c}else if((B|0)==1413564243){if(x){y=1;H=145;break b}A=J>>>0<256?J:256;if((ta(k|0,1,A|0,b|0)|0)!=(A|0)){y=1;H=145;break b}if((c[12626]|0)==0){z=0;do{E=z<<25;G=(z&128|0)!=0?E^517762881:E;E=G<<1;Q=(G|0)<0?E^517762881:E;E=Q<<1;G=(Q|0)<0?E^517762881:E;E=G<<1;Q=(G|0)<0?E^517762881:E;E=Q<<1;G=(Q|0)<0?E^517762881:E;E=G<<1;Q=(G|0)<0?E^517762881:E;E=Q<<1;G=(Q|0)<0?E^517762881:E;E=G<<1;c[50512+(z<<2)>>2]=(G|0)<0?E^517762881:E;z=z+1|0}while((z|0)!=256);c[12626]=1}if((A|0)==0){R=I}else{z=A;E=I;G=k;while(1){Q=c[50512+((d[G>>0]^E>>>24)<<2)>>2]^E<<8;S=z+ -1|0;if((S|0)==0){R=Q;break}else{z=S;E=Q;G=G+1|0}}}Ct(w,k,A)|0;if((A|0)==(J|0)){T=R}else{G=R;E=J-A|0;while(1){z=E>>>0<256?E:256;if((ta(n|0,1,z|0,b|0)|0)!=(z|0)){y=1;H=145;break b}if((c[12626]|0)==0){Q=0;do{S=Q<<25;U=(Q&128|0)!=0?S^517762881:S;S=U<<1;V=(U|0)<0?S^517762881:S;S=V<<1;U=(V|0)<0?S^517762881:S;S=U<<1;V=(U|0)<0?S^517762881:S;S=V<<1;U=(V|0)<0?S^517762881:S;S=U<<1;V=(U|0)<0?S^517762881:S;S=V<<1;U=(V|0)<0?S^517762881:S;S=U<<1;c[50512+(Q<<2)>>2]=(U|0)<0?S^517762881:S;Q=Q+1|0}while((Q|0)!=256);c[12626]=1}if((z|0)==0){W=G}else{Q=z;S=G;U=n;while(1){V=c[50512+((d[U>>0]^S>>>24)<<2)>>2]^S<<8;X=Q+ -1|0;if((X|0)==0){W=V;break}else{Q=X;S=V;U=U+1|0}}}if((E|0)==(z|0)){T=W;break}else{G=W;E=E-z|0}}}if((ta(n|0,1,4,b|0)|0)!=4){y=1;H=145;break b}if((Zu(n,0)|0)!=(T|0)){H=115;break b}}else if((B|0)==1162757152){H=27;break b}else if((B|0)==1145132097){if(x){y=1;H=145;break b}E=e[h>>1]|0;G=E>>>0<J>>>0?E:J;if((G|0)==0){Y=I}else{E=c[D>>2]|0;if((ta(E|0,1,G|0,b|0)|0)!=(G|0)){y=1;H=145;break b}if((c[12626]|0)==0){A=0;do{U=A<<25;S=(A&128|0)!=0?U^517762881:U;U=S<<1;Q=(S|0)<0?U^517762881:U;U=Q<<1;S=(Q|0)<0?U^517762881:U;U=S<<1;Q=(S|0)<0?U^517762881:U;U=Q<<1;S=(Q|0)<0?U^517762881:U;U=S<<1;Q=(S|0)<0?U^517762881:U;U=Q<<1;S=(Q|0)<0?U^517762881:U;U=S<<1;c[50512+(A<<2)>>2]=(S|0)<0?U^517762881:U;A=A+1|0}while((A|0)!=256);c[12626]=1;Z=G;_=I;$=E}else{Z=G;_=I;$=E}while(1){A=c[50512+((d[$>>0]^_>>>24)<<2)>>2]^_<<8;U=Z+ -1|0;if((U|0)==0){Y=A;break}else{Z=U;_=A;$=$+1|0}}}if((G|0)==(J|0)){aa=Y}else{E=Y;A=J-G|0;while(1){U=A>>>0<256?A:256;if((ta(n|0,1,U|0,b|0)|0)!=(U|0)){y=1;H=145;break b}if((c[12626]|0)==0){S=0;do{Q=S<<25;V=(S&128|0)!=0?Q^517762881:Q;Q=V<<1;X=(V|0)<0?Q^517762881:Q;Q=X<<1;V=(X|0)<0?Q^517762881:Q;Q=V<<1;X=(V|0)<0?Q^517762881:Q;Q=X<<1;V=(X|0)<0?Q^517762881:Q;Q=V<<1;X=(V|0)<0?Q^517762881:Q;Q=X<<1;V=(X|0)<0?Q^517762881:Q;Q=V<<1;c[50512+(S<<2)>>2]=(V|0)<0?Q^517762881:Q;S=S+1|0}while((S|0)!=256);c[12626]=1}if((U|0)==0){ba=E}else{S=U;z=E;Q=n;while(1){V=c[50512+((d[Q>>0]^z>>>24)<<2)>>2]^z<<8;X=S+ -1|0;if((X|0)==0){ba=V;break}else{S=X;z=V;Q=Q+1|0}}}if((A|0)==(U|0)){aa=ba;break}else{E=ba;A=A-U|0}}}if((ta(n|0,1,4,b|0)|0)!=4){y=1;H=145;break b}if((Zu(n,0)|0)!=(aa|0)){H=96;break b}}else{if((J|0)==0){ca=I}else{A=I;E=J;while(1){G=E>>>0<256?E:256;if((ta(n|0,1,G|0,b|0)|0)!=(G|0)){y=1;H=145;break b}if((c[12626]|0)==0){Q=0;do{z=Q<<25;S=(Q&128|0)!=0?z^517762881:z;z=S<<1;V=(S|0)<0?z^517762881:z;z=V<<1;S=(V|0)<0?z^517762881:z;z=S<<1;V=(S|0)<0?z^517762881:z;z=V<<1;S=(V|0)<0?z^517762881:z;z=S<<1;V=(S|0)<0?z^517762881:z;z=V<<1;S=(V|0)<0?z^517762881:z;z=S<<1;c[50512+(Q<<2)>>2]=(S|0)<0?z^517762881:z;Q=Q+1|0}while((Q|0)!=256);c[12626]=1}if((G|0)==0){da=A}else{Q=G;U=A;z=n;while(1){S=c[50512+((d[z>>0]^U>>>24)<<2)>>2]^U<<8;V=Q+ -1|0;if((V|0)==0){da=S;break}else{Q=V;U=S;z=z+1|0}}}if((E|0)==(G|0)){ca=da;break}else{A=da;E=E-G|0}}}if((ta(n|0,1,4,b|0)|0)!=4){y=1;H=145;break b}if((Zu(n,0)|0)!=(ca|0)){H=144;break b}}}while(0);if((ta(p|0,1,8,b|0)|0)!=8){y=1;H=145;break b}}if(J>>>0<18){y=1;H=145;break}if((ta(l|0,1,18,b|0)|0)!=18){y=1;H=145;break}if((c[12626]|0)==0){D=0;do{h=D<<25;B=(D&128|0)!=0?h^517762881:h;h=B<<1;E=(B|0)<0?h^517762881:h;h=E<<1;B=(E|0)<0?h^517762881:h;h=B<<1;E=(B|0)<0?h^517762881:h;h=E<<1;B=(E|0)<0?h^517762881:h;h=B<<1;E=(B|0)<0?h^517762881:h;h=E<<1;B=(E|0)<0?h^517762881:h;h=B<<1;c[50512+(D<<2)>>2]=(B|0)<0?h^517762881:h;D=D+1|0}while((D|0)!=256);c[12626]=1;ea=18;fa=I;ga=l}else{ea=18;fa=I;ga=l}while(1){fa=c[50512+((d[ga>>0]^fa>>>24)<<2)>>2]^fa<<8;ea=ea+ -1|0;if((ea|0)==0){break}else{ga=ga+1|0}}D=Yu(l,0)|0;h=Yu(l,2)|0;B=Yu(l,4)|0;E=Yu(l,6)|0;A=Yu(l,8)|0;z=Yu(l,10)|0;U=a[F>>0]|0;Q=Yu(l,14)|0;S=Yu(l,16)|0;ha=kt(B,E,A,z)|0;if((ha|0)==0){y=1;H=145;break}if((Q&1|0)!=0){z=ha+12|0;c[z>>2]=c[z>>2]|1}if((Q&2|0)!=0){z=ha+12|0;c[z>>2]=c[z>>2]|2}if((Q&4|0)!=0){z=ha+12|0;c[z>>2]=c[z>>2]|4}if((Q&8|0)!=0){z=ha+12|0;c[z>>2]=c[z>>2]|8}tt(ha,S);z=S&4095;if((z|0)==2|(z|0)==1){yt(ha,U)}else if((z|0)==3){At(ha,U)}if((Q&16384|0)==0){if((Pt(f,ha,D,h)|0)!=0){H=62;break}}else{if(x){H=59;break}nt(w,ha)}h=J+ -18|0;if((Q&32768|0)!=0){qt(ha,d[m>>0]|0)}if((h|0)==0){ia=fa}else{Q=fa;D=h;while(1){h=D>>>0<256?D:256;if((ta(n|0,1,h|0,b|0)|0)!=(h|0)){y=1;H=145;break b}if((c[12626]|0)==0){U=0;do{z=U<<25;S=(U&128|0)!=0?z^517762881:z;z=S<<1;A=(S|0)<0?z^517762881:z;z=A<<1;S=(A|0)<0?z^517762881:z;z=S<<1;A=(S|0)<0?z^517762881:z;z=A<<1;S=(A|0)<0?z^517762881:z;z=S<<1;A=(S|0)<0?z^517762881:z;z=A<<1;S=(A|0)<0?z^517762881:z;z=S<<1;c[50512+(U<<2)>>2]=(S|0)<0?z^517762881:z;U=U+1|0}while((U|0)!=256);c[12626]=1}if((h|0)==0){ja=Q}else{U=h;z=Q;S=n;while(1){A=c[50512+((d[S>>0]^z>>>24)<<2)>>2]^z<<8;E=U+ -1|0;if((E|0)==0){ja=A;break}else{U=E;z=A;S=S+1|0}}}if((D|0)==(h|0)){ia=ja;break}else{Q=ja;D=D-h|0}}}if((ta(n|0,1,4,b|0)|0)!=4){y=1;H=145;break}if((Zu(n,0)|0)==(ia|0)){w=ha}else{H=77;break}}switch(H|0){case 27:{d:do{if((J|0)==0){ka=I}else{H=I;w=J;while(1){ia=w>>>0<256?w:256;if((ta(n|0,1,ia|0,b|0)|0)!=(ia|0)){y=1;break}if((c[12626]|0)==0){ja=0;do{fa=ja<<25;m=(ja&128|0)!=0?fa^517762881:fa;fa=m<<1;l=(m|0)<0?fa^517762881:fa;fa=l<<1;m=(l|0)<0?fa^517762881:fa;fa=m<<1;l=(m|0)<0?fa^517762881:fa;fa=l<<1;m=(l|0)<0?fa^517762881:fa;fa=m<<1;l=(m|0)<0?fa^517762881:fa;fa=l<<1;m=(l|0)<0?fa^517762881:fa;fa=m<<1;c[50512+(ja<<2)>>2]=(m|0)<0?fa^517762881:fa;ja=ja+1|0}while((ja|0)!=256);c[12626]=1}if((ia|0)==0){la=H}else{ja=ia;h=H;fa=n;while(1){m=c[50512+((d[fa>>0]^h>>>24)<<2)>>2]^h<<8;l=ja+ -1|0;if((l|0)==0){la=m;break}else{ja=l;h=m;fa=fa+1|0}}}if((w|0)==(ia|0)){ka=la;break d}else{H=la;w=w-ia|0}}i=j;return y|0}}while(0);if((ta(n|0,1,4,b|0)|0)!=4){y=1;i=j;return y|0}if((Zu(n,0)|0)==(ka|0)){Wt(f);y=0;i=j;return y|0}else{fb(50408,16,1,C|0)|0;y=1;i=j;return y|0}break};case 59:{fb(50432,32,1,C|0)|0;lt(ha);y=1;i=j;return y|0};case 62:{lt(ha);y=1;i=j;return y|0};case 77:{fb(50408,16,1,C|0)|0;y=1;i=j;return y|0};case 96:{fb(50408,16,1,C|0)|0;y=1;i=j;return y|0};case 115:{fb(50408,16,1,C|0)|0;y=1;i=j;return y|0};case 119:{fb(50408,16,1,C|0)|0;y=1;i=j;return y|0};case 126:{zz(K);y=1;i=j;return y|0};case 144:{fb(50408,16,1,C|0)|0;y=1;i=j;return y|0};case 145:{i=j;return y|0}}return 0}function yu(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;g=i;i=i+32|0;h=g+4|0;j=g+24|0;k=g;l=g+8|0;_u(h,0,4);_u(h,2,0);if((zu(d,1346782275,4,h)|0)!=0){m=1;i=g;return m|0}n=f+8|0;if((c[n>>2]|0)!=0){$u(l,0,1413830740);$u(l,4,(c[n>>2]|0)+2|0);o=l+8|0;a[o>>0]=10;c[k>>2]=0;p=Au(d,l,9,k)|0;q=Au(d,c[f+12>>2]|0,c[n>>2]|0,k)|0|p;p=q|(Au(d,o,1,k)|0);$u(l,0,c[k>>2]|0);if((p|(fb(l|0,1,4,d|0)|0)!=4|0)!=0){m=1;i=g;return m|0}}l=b[f>>1]|0;a:do{if(!(l<<16>>16==0)){p=f+4|0;k=l;o=0;b:while(1){q=c[(c[p>>2]|0)+(o<<2)>>2]|0;n=q+2|0;r=b[n>>1]|0;if(r<<16>>16==0){s=k}else{t=q+4|0;q=r;r=0;while(1){u=c[(c[t>>2]|0)+(r<<2)>>2]|0;v=u+2|0;if((b[v>>1]|0)==0){w=q}else{x=u+4|0;u=0;do{y=c[(c[x>>2]|0)+(u<<2)>>2]|0;if((Bu(d,y,o,r,0)|0)==0){z=y}else{m=1;A=21;break b}while(1){y=c[z>>2]|0;if((y|0)==0){break}if((Bu(d,y,o,r,1)|0)==0){z=y}else{m=1;A=21;break b}}u=u+1|0}while(u>>>0<(e[v>>1]|0)>>>0);w=b[n>>1]|0}r=r+1|0;if(!(r>>>0<(w&65535)>>>0)){break}else{q=w}}s=b[f>>1]|0}o=o+1|0;if(!(o>>>0<(s&65535)>>>0)){break a}else{k=s}}if((A|0)==21){i=g;return m|0}}}while(0);$u(j,0,1162757152);$u(j,4,0);c[h>>2]=0;if((Au(d,j,8,h)|0)!=0){m=1;i=g;return m|0}$u(j,0,c[h>>2]|0);if((fb(j|0,1,4,d|0)|0)!=4){m=1;i=g;return m|0}Nb(d|0)|0;m=0;i=g;return m|0}function zu(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f;h=f+8|0;$u(h,0,b);$u(h,4,d);c[g>>2]=0;if((Au(a,h,8,g)|0)!=0){j=1;i=f;return j|0}if((d|0)!=0){if((Au(a,e,d,g)|0)!=0){j=1;i=f;return j|0}}$u(h,0,c[g>>2]|0);j=(fb(h|0,1,4,a|0)|0)!=4|0;i=f;return j|0}function Au(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;if((f|0)==0){h=fb(b|0,1,e|0,a|0)|0;j=(h|0)!=(e|0);k=j&1;i=g;return k|0}l=c[f>>2]|0;if((c[12626]|0)==0){m=0;do{n=m<<25;o=(m&128|0)!=0?n^517762881:n;n=o<<1;p=(o|0)<0?n^517762881:n;n=p<<1;o=(p|0)<0?n^517762881:n;n=o<<1;p=(o|0)<0?n^517762881:n;n=p<<1;o=(p|0)<0?n^517762881:n;n=o<<1;p=(o|0)<0?n^517762881:n;n=p<<1;o=(p|0)<0?n^517762881:n;n=o<<1;c[50512+(m<<2)>>2]=(o|0)<0?n^517762881:n;m=m+1|0}while((m|0)!=256);c[12626]=1}if((e|0)==0){q=l}else{m=e;n=l;l=b;while(1){o=c[50512+(((d[l>>0]|0)^n>>>24)<<2)>>2]^n<<8;p=m+ -1|0;if((p|0)==0){q=o;break}else{m=p;n=o;l=l+1|0}}}c[f>>2]=q;h=fb(b|0,1,e|0,a|0)|0;j=(h|0)!=(e|0);k=j&1;i=g;return k|0}function Bu(d,f,g,h,j){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;k=i;i=i+256|0;l=k;m=c[f+12>>2]&15;n=f+10|0;if((rt(f)|0)==0){o=m}else{o=(b[n>>1]|0)==0?m:m|32768}m=(j|0)==0?o:o|16384;_u(l,0,g);_u(l,2,h);_u(l,4,e[f+4>>1]|0);_u(l,6,e[f+6>>1]|0);_u(l,8,e[f+8>>1]|0);_u(l,10,e[n>>1]|0);_u(l,12,0);_u(l,14,m);h=f+16|0;_u(l,16,e[h>>1]|0);if((m&32768|0)!=0){a[l+13>>0]=a[c[f+24>>2]>>0]|0}g=b[h>>1]&4095;if((g|0)==2|(g|0)==1){a[l+12>>0]=zt(f)|0}else if((g|0)==3){a[l+12>>0]=Bt(f)|0}if((zu(d,1397048148,18,l)|0)!=0){p=1;i=k;return p|0}g=Dt(f,l,256)|0;a:do{if((g|0)!=0){h=0;while(1){o=h;h=h+1|0;if((a[l+o>>0]|0)!=0){break}if(!(h>>>0<g>>>0)){break a}}if((zu(d,1413564243,g,l)|0)!=0){p=1;i=k;return p|0}}}while(0);if((m&32776|0)==0){m=b[n>>1]|0;if(!(m<<16>>16==0)){if((zu(d,1145132097,m&65535,c[f+24>>2]|0)|0)!=0){p=1;i=k;return p|0}}}p=0;i=k;return p|0}function Cu(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=0,Ca=0,Da=0,Ea=0,Fa=0,Ga=0;f=i;i=i+304|0;g=f;h=f+280|0;j=f+24|0;k=f+16|0;l=f+8|0;m=Kt()|0;if((m|0)==0){n=0;i=f;return n|0}a:do{if((ta(l|0,1,8,e|0)|0)==8){if((c[12884]|0)==0){p=0;do{q=p<<25;r=(p&128|0)!=0?q^517762881:q;q=r<<1;s=(r|0)<0?q^517762881:q;q=s<<1;r=(s|0)<0?q^517762881:q;q=r<<1;s=(r|0)<0?q^517762881:q;q=s<<1;r=(s|0)<0?q^517762881:q;q=r<<1;s=(r|0)<0?q^517762881:q;q=s<<1;r=(s|0)<0?q^517762881:q;q=r<<1;c[51544+(p<<2)>>2]=(r|0)<0?q^517762881:q;p=p+1|0}while((p|0)!=256);c[12884]=1}p=l+1|0;q=c[51544+(d[l>>0]<<2)>>2]|0;r=l+2|0;s=c[51544+((d[p>>0]^q>>>24)<<2)>>2]^q<<8;q=l+3|0;t=c[51544+((d[r>>0]^s>>>24)<<2)>>2]^s<<8;s=l+4|0;u=c[51544+((d[q>>0]^t>>>24)<<2)>>2]^t<<8;t=l+5|0;v=c[51544+((d[s>>0]^u>>>24)<<2)>>2]^u<<8;u=l+6|0;w=c[51544+((d[t>>0]^v>>>24)<<2)>>2]^v<<8;v=l+7|0;x=c[51544+((d[u>>0]^w>>>24)<<2)>>2]^w<<8;w=c[51544+((d[v>>0]^x>>>24)<<2)>>2]^x<<8;x=Zu(l,0)|0;y=Zu(l,4)|0;if((x|0)==1347635488){if(!(y>>>0<4)){if((ta(k|0,1,4,e|0)|0)==4){if((c[12884]|0)==0){x=0;do{z=x<<25;A=(x&128|0)!=0?z^517762881:z;z=A<<1;B=(A|0)<0?z^517762881:z;z=B<<1;A=(B|0)<0?z^517762881:z;z=A<<1;B=(A|0)<0?z^517762881:z;z=B<<1;A=(B|0)<0?z^517762881:z;z=A<<1;B=(A|0)<0?z^517762881:z;z=B<<1;A=(B|0)<0?z^517762881:z;z=A<<1;c[51544+(x<<2)>>2]=(A|0)<0?z^517762881:z;x=x+1|0}while((x|0)!=256);c[12884]=1}x=k+1|0;z=c[51544+((d[k>>0]^w>>>24)<<2)>>2]^w<<8;A=k+2|0;B=c[51544+((d[x>>0]^z>>>24)<<2)>>2]^z<<8;z=k+3|0;C=c[51544+((d[A>>0]^B>>>24)<<2)>>2]^B<<8;B=c[51544+((d[z>>0]^C>>>24)<<2)>>2]^C<<8;C=Yu(k,0)|0;if((C|0)!=0){D=c[o>>2]|0;c[g>>2]=C;hb(D|0,52616,g|0)|0;break}switch(Yu(k,2)|0){case 257:{E=32769;break};case 512:{E=2;break};case 513:{E=32770;break};case 514:{E=16386;break};case 256:{E=1;break};case 768:{E=3;break};default:{E=0}}D=y+ -4|0;if((D|0)==0){F=B}else{C=B;B=D;while(1){D=B>>>0<256?B:256;if((ta(j|0,1,D|0,e|0)|0)!=(D|0)){break a}if((c[12884]|0)==0){G=0;do{H=G<<25;I=(G&128|0)!=0?H^517762881:H;H=I<<1;J=(I|0)<0?H^517762881:H;H=J<<1;I=(J|0)<0?H^517762881:H;H=I<<1;J=(I|0)<0?H^517762881:H;H=J<<1;I=(J|0)<0?H^517762881:H;H=I<<1;J=(I|0)<0?H^517762881:H;H=J<<1;I=(J|0)<0?H^517762881:H;H=I<<1;c[51544+(G<<2)>>2]=(I|0)<0?H^517762881:H;G=G+1|0}while((G|0)!=256);c[12884]=1}if((D|0)==0){K=C}else{G=D;H=C;I=j;while(1){J=c[51544+((d[I>>0]^H>>>24)<<2)>>2]^H<<8;L=G+ -1|0;if((L|0)==0){K=J;break}else{G=L;H=J;I=I+1|0}}}if((B|0)==(D|0)){F=K;break}else{C=K;B=B-D|0}}}if((ta(j|0,1,4,e|0)|0)==4){if((Zu(j,0)|0)!=(F|0)){fb(52568,15,1,c[o>>2]|0)|0;break}if((ta(l|0,1,8,e|0)|0)==8){B=k+4|0;C=k+5|0;y=k+6|0;w=k+7|0;I=h+2|0;H=h+3|0;G=h+4|0;J=h+5|0;L=h+6|0;M=g+1|0;N=g+2|0;O=g+3|0;P=c[o>>2]|0;Q=0;b:while(1){if((c[12884]|0)==0){R=0;do{S=R<<25;T=(R&128|0)!=0?S^517762881:S;S=T<<1;U=(T|0)<0?S^517762881:S;S=U<<1;T=(U|0)<0?S^517762881:S;S=T<<1;U=(T|0)<0?S^517762881:S;S=U<<1;T=(U|0)<0?S^517762881:S;S=T<<1;U=(T|0)<0?S^517762881:S;S=U<<1;T=(U|0)<0?S^517762881:S;S=T<<1;c[51544+(R<<2)>>2]=(T|0)<0?S^517762881:S;R=R+1|0}while((R|0)!=256);c[12884]=1}R=c[51544+(d[l>>0]<<2)>>2]|0;D=c[51544+((d[p>>0]^R>>>24)<<2)>>2]^R<<8;R=c[51544+((d[r>>0]^D>>>24)<<2)>>2]^D<<8;D=c[51544+((d[q>>0]^R>>>24)<<2)>>2]^R<<8;R=c[51544+((d[s>>0]^D>>>24)<<2)>>2]^D<<8;D=c[51544+((d[t>>0]^R>>>24)<<2)>>2]^R<<8;R=c[51544+((d[u>>0]^D>>>24)<<2)>>2]^D<<8;V=c[51544+((d[v>>0]^R>>>24)<<2)>>2]^R<<8;R=Zu(l,0)|0;W=Zu(l,4)|0;do{if((R|0)==1229081933){if((Q|0)==0|W>>>0<6){break a}if((ta(k|0,1,6,e|0)|0)!=6){break a}if((c[12884]|0)==0){D=0;do{S=D<<25;T=(D&128|0)!=0?S^517762881:S;S=T<<1;U=(T|0)<0?S^517762881:S;S=U<<1;T=(U|0)<0?S^517762881:S;S=T<<1;U=(T|0)<0?S^517762881:S;S=U<<1;T=(U|0)<0?S^517762881:S;S=T<<1;U=(T|0)<0?S^517762881:S;S=U<<1;T=(U|0)<0?S^517762881:S;S=T<<1;c[51544+(D<<2)>>2]=(T|0)<0?S^517762881:S;D=D+1|0}while((D|0)!=256);c[12884]=1}D=a[k>>0]|0;S=c[51544+((D&255^V>>>24)<<2)>>2]^V<<8;T=a[x>>0]|0;U=c[51544+((T&255^S>>>24)<<2)>>2]^S<<8;S=a[A>>0]|0;X=c[51544+((S&255^U>>>24)<<2)>>2]^U<<8;U=a[z>>0]|0;Y=c[51544+((U&255^X>>>24)<<2)>>2]^X<<8;X=a[B>>0]|0;Z=c[51544+((X&255^Y>>>24)<<2)>>2]^Y<<8;Y=d[C>>0]|0;_=c[51544+((Y^Z>>>24)<<2)>>2]^Z<<8;b[Q+4>>1]=D&255;b[Q+6>>1]=T&255;b[Q+8>>1]=S&255;yt(Q,U);if(!((X&1)==0)){U=Q+12|0;c[U>>2]=c[U>>2]|1}if(!((X&2)==0)){U=Q+12|0;c[U>>2]=c[U>>2]|2}if(!((X&4)==0)){U=Q+12|0;c[U>>2]=c[U>>2]|4}if(!((X&8)==0)){X=Q+12|0;c[X>>2]=c[X>>2]|8}if((Y|0)==1){tt(Q,32770)}else if((Y|0)==2){tt(Q,16386)}else{tt(Q,2)}Y=W+ -6|0;if((Y|0)==0){$=_}else{X=_;_=Y;while(1){Y=_>>>0<256?_:256;if((ta(j|0,1,Y|0,e|0)|0)!=(Y|0)){break a}if((c[12884]|0)==0){U=0;do{S=U<<25;T=(U&128|0)!=0?S^517762881:S;S=T<<1;D=(T|0)<0?S^517762881:S;S=D<<1;T=(D|0)<0?S^517762881:S;S=T<<1;D=(T|0)<0?S^517762881:S;S=D<<1;T=(D|0)<0?S^517762881:S;S=T<<1;D=(T|0)<0?S^517762881:S;S=D<<1;T=(D|0)<0?S^517762881:S;S=T<<1;c[51544+(U<<2)>>2]=(T|0)<0?S^517762881:S;U=U+1|0}while((U|0)!=256);c[12884]=1}if((Y|0)==0){aa=X}else{U=Y;S=X;T=j;while(1){D=c[51544+((d[T>>0]^S>>>24)<<2)>>2]^S<<8;Z=U+ -1|0;if((Z|0)==0){aa=D;break}else{U=Z;S=D;T=T+1|0}}}if((_|0)==(Y|0)){$=aa;break}else{X=aa;_=_-Y|0}}}if((ta(j|0,1,4,e|0)|0)!=4){break a}if((Zu(j,0)|0)==($|0)){ba=Q}else{ca=130;break b}}else if((R|0)==1145132097){if((Q|0)==0){break a}if((pt(Q,W,0)|0)!=0){break a}if((W|0)==0){da=V}else{_=c[Q+24>>2]|0;if((ta(_|0,1,W|0,e|0)|0)!=(W|0)){break a}if((c[12884]|0)==0){X=0;do{T=X<<25;S=(X&128|0)!=0?T^517762881:T;T=S<<1;U=(S|0)<0?T^517762881:T;T=U<<1;S=(U|0)<0?T^517762881:T;T=S<<1;U=(S|0)<0?T^517762881:T;T=U<<1;S=(U|0)<0?T^517762881:T;T=S<<1;U=(S|0)<0?T^517762881:T;T=U<<1;S=(U|0)<0?T^517762881:T;T=S<<1;c[51544+(X<<2)>>2]=(S|0)<0?T^517762881:T;X=X+1|0}while((X|0)!=256);c[12884]=1;ea=W;fa=V;ga=_}else{ea=W;fa=V;ga=_}while(1){X=c[51544+((d[ga>>0]^fa>>>24)<<2)>>2]^fa<<8;T=ea+ -1|0;if((T|0)==0){da=X;break}else{ea=T;fa=X;ga=ga+1|0}}}if((ta(j|0,1,4,e|0)|0)!=4){break a}if((Zu(j,0)|0)==(da|0)){ba=Q}else{ca=196;break b}}else if((R|0)==1397048148){if(W>>>0<8){break a}if((ta(k|0,1,8,e|0)|0)!=8){break a}if((c[12884]|0)==0){_=0;do{X=_<<25;T=(_&128|0)!=0?X^517762881:X;X=T<<1;S=(T|0)<0?X^517762881:X;X=S<<1;T=(S|0)<0?X^517762881:X;X=T<<1;S=(T|0)<0?X^517762881:X;X=S<<1;T=(S|0)<0?X^517762881:X;X=T<<1;S=(T|0)<0?X^517762881:X;X=S<<1;T=(S|0)<0?X^517762881:X;X=T<<1;c[51544+(_<<2)>>2]=(T|0)<0?X^517762881:X;_=_+1|0}while((_|0)!=256);c[12884]=1}_=c[51544+((d[k>>0]^V>>>24)<<2)>>2]^V<<8;X=c[51544+((d[x>>0]^_>>>24)<<2)>>2]^_<<8;_=c[51544+((d[A>>0]^X>>>24)<<2)>>2]^X<<8;X=c[51544+((d[z>>0]^_>>>24)<<2)>>2]^_<<8;_=c[51544+((d[B>>0]^X>>>24)<<2)>>2]^X<<8;X=c[51544+((d[C>>0]^_>>>24)<<2)>>2]^_<<8;_=c[51544+((d[y>>0]^X>>>24)<<2)>>2]^X<<8;X=c[51544+((d[w>>0]^_>>>24)<<2)>>2]^_<<8;_=Yu(k,0)|0;T=d[A>>0]|0;S=d[z>>0]|0;U=Yu(k,4)|0;D=d[y>>0]|0;ha=kt(_,T,S,U)|0;if((ha|0)==0){break a}if((D&2|0)==0){if((Pt(m,ha,_,T)|0)!=0){ca=60;break b}}else{if((Q|0)==0){ca=57;break b}nt(Q,ha)}if((D&4|0)!=0){T=ha+12|0;c[T>>2]=c[T>>2]|2}tt(ha,E);T=W+ -8|0;if((D&1|0)!=0){qt(ha,d[w>>0]|0)}if((T|0)==0){ia=X}else{D=X;X=T;while(1){T=X>>>0<256?X:256;if((ta(j|0,1,T|0,e|0)|0)!=(T|0)){break a}if((c[12884]|0)==0){_=0;do{U=_<<25;S=(_&128|0)!=0?U^517762881:U;U=S<<1;Z=(S|0)<0?U^517762881:U;U=Z<<1;S=(Z|0)<0?U^517762881:U;U=S<<1;Z=(S|0)<0?U^517762881:U;U=Z<<1;S=(Z|0)<0?U^517762881:U;U=S<<1;Z=(S|0)<0?U^517762881:U;U=Z<<1;S=(Z|0)<0?U^517762881:U;U=S<<1;c[51544+(_<<2)>>2]=(S|0)<0?U^517762881:U;_=_+1|0}while((_|0)!=256);c[12884]=1}if((T|0)==0){ja=D}else{_=T;Y=D;U=j;while(1){S=c[51544+((d[U>>0]^Y>>>24)<<2)>>2]^Y<<8;Z=_+ -1|0;if((Z|0)==0){ja=S;break}else{_=Z;Y=S;U=U+1|0}}}if((X|0)==(T|0)){ia=ja;break}else{D=ja;X=X-T|0}}}if((ta(j|0,1,4,e|0)|0)!=4){break a}if((Zu(j,0)|0)==(ia|0)){ba=ha}else{ca=75;break b}}else if((R|0)==1162757152){ca=38;break b}else if((R|0)==1296122695){if((Q|0)==0|W>>>0<18){break a}if((ta(h|0,1,18,e|0)|0)!=18){break a}if((c[12884]|0)==0){X=0;do{D=X<<25;U=(X&128|0)!=0?D^517762881:D;D=U<<1;Y=(U|0)<0?D^517762881:D;D=Y<<1;U=(Y|0)<0?D^517762881:D;D=U<<1;Y=(U|0)<0?D^517762881:D;D=Y<<1;U=(Y|0)<0?D^517762881:D;D=U<<1;Y=(U|0)<0?D^517762881:D;D=Y<<1;U=(Y|0)<0?D^517762881:D;D=U<<1;c[51544+(X<<2)>>2]=(U|0)<0?D^517762881:D;X=X+1|0}while((X|0)!=256);c[12884]=1;ka=18;la=V;ma=h}else{ka=18;la=V;ma=h}while(1){la=c[51544+((d[ma>>0]^la>>>24)<<2)>>2]^la<<8;ka=ka+ -1|0;if((ka|0)==0){break}else{ma=ma+1|0}}b[Q+4>>1]=Yu(h,0)|0;b[Q+6>>1]=d[I>>0]|0;b[Q+8>>1]=d[H>>0]|0;At(Q,a[G>>0]|0);X=a[J>>0]|0;if(!((X&1)==0)){D=Q+12|0;c[D>>2]=c[D>>2]|1}if(!((X&2)==0)){D=Q+12|0;c[D>>2]=c[D>>2]|2}if(!((X&4)==0)){X=Q+12|0;c[X>>2]=c[X>>2]|8}tt(Q,3);Ct(Q,L,12)|0;X=W+ -18|0;if((X|0)==0){na=la}else{D=la;U=X;while(1){X=U>>>0<256?U:256;if((ta(j|0,1,X|0,e|0)|0)!=(X|0)){break a}if((c[12884]|0)==0){Y=0;do{_=Y<<25;S=(Y&128|0)!=0?_^517762881:_;_=S<<1;Z=(S|0)<0?_^517762881:_;_=Z<<1;S=(Z|0)<0?_^517762881:_;_=S<<1;Z=(S|0)<0?_^517762881:_;_=Z<<1;S=(Z|0)<0?_^517762881:_;_=S<<1;Z=(S|0)<0?_^517762881:_;_=Z<<1;S=(Z|0)<0?_^517762881:_;_=S<<1;c[51544+(Y<<2)>>2]=(S|0)<0?_^517762881:_;Y=Y+1|0}while((Y|0)!=256);c[12884]=1}if((X|0)==0){oa=D}else{Y=X;T=D;_=j;while(1){S=c[51544+((d[_>>0]^T>>>24)<<2)>>2]^T<<8;Z=Y+ -1|0;if((Z|0)==0){oa=S;break}else{Y=Z;T=S;_=_+1|0}}}if((U|0)==(X|0)){na=oa;break}else{D=oa;U=U-X|0}}}if((ta(j|0,1,4,e|0)|0)!=4){break a}if((Zu(j,0)|0)==(na|0)){ba=Q}else{ca=153;break b}}else if((R|0)==1414090053){if((Q|0)==0|W>>>0<4){break a}if((ta(g|0,1,4,e|0)|0)!=4){break a}if((c[12884]|0)==0){U=0;do{D=U<<25;_=(U&128|0)!=0?D^517762881:D;D=_<<1;T=(_|0)<0?D^517762881:D;D=T<<1;_=(T|0)<0?D^517762881:D;D=_<<1;T=(_|0)<0?D^517762881:D;D=T<<1;_=(T|0)<0?D^517762881:D;D=_<<1;T=(_|0)<0?D^517762881:D;D=T<<1;_=(T|0)<0?D^517762881:D;D=_<<1;c[51544+(U<<2)>>2]=(_|0)<0?D^517762881:D;U=U+1|0}while((U|0)!=256);c[12884]=1}U=c[51544+((d[g>>0]^V>>>24)<<2)>>2]^V<<8;D=c[51544+((d[M>>0]^U>>>24)<<2)>>2]^U<<8;U=c[51544+((d[N>>0]^D>>>24)<<2)>>2]^D<<8;D=c[51544+((d[O>>0]^U>>>24)<<2)>>2]^U<<8;wt(Q,Zu(g,0)|0);U=W+ -4|0;if((U|0)==0){pa=D}else{_=D;D=U;while(1){U=D>>>0<256?D:256;if((ta(j|0,1,U|0,e|0)|0)!=(U|0)){break a}if((c[12884]|0)==0){T=0;do{Y=T<<25;S=(T&128|0)!=0?Y^517762881:Y;Y=S<<1;Z=(S|0)<0?Y^517762881:Y;Y=Z<<1;S=(Z|0)<0?Y^517762881:Y;Y=S<<1;Z=(S|0)<0?Y^517762881:Y;Y=Z<<1;S=(Z|0)<0?Y^517762881:Y;Y=S<<1;Z=(S|0)<0?Y^517762881:Y;Y=Z<<1;S=(Z|0)<0?Y^517762881:Y;Y=S<<1;c[51544+(T<<2)>>2]=(S|0)<0?Y^517762881:Y;T=T+1|0}while((T|0)!=256);c[12884]=1}if((U|0)==0){qa=_}else{T=U;X=_;Y=j;while(1){S=c[51544+((d[Y>>0]^X>>>24)<<2)>>2]^X<<8;Z=T+ -1|0;if((Z|0)==0){qa=S;break}else{T=Z;X=S;Y=Y+1|0}}}if((D|0)==(U|0)){pa=qa;break}else{_=qa;D=D-U|0}}}if((ta(j|0,1,4,e|0)|0)!=4){break a}if((Zu(j,0)|0)==(pa|0)){ba=Q}else{ca=185;break b}}else if((R|0)==1330005587){if((Q|0)==0|W>>>0<4){break a}if((ta(g|0,1,4,e|0)|0)!=4){break a}if((c[12884]|0)==0){D=0;do{_=D<<25;Y=(D&128|0)!=0?_^517762881:_;_=Y<<1;X=(Y|0)<0?_^517762881:_;_=X<<1;Y=(X|0)<0?_^517762881:_;_=Y<<1;X=(Y|0)<0?_^517762881:_;_=X<<1;Y=(X|0)<0?_^517762881:_;_=Y<<1;X=(Y|0)<0?_^517762881:_;_=X<<1;Y=(X|0)<0?_^517762881:_;_=Y<<1;c[51544+(D<<2)>>2]=(Y|0)<0?_^517762881:_;D=D+1|0}while((D|0)!=256);c[12884]=1}D=c[51544+((d[g>>0]^V>>>24)<<2)>>2]^V<<8;_=c[51544+((d[M>>0]^D>>>24)<<2)>>2]^D<<8;D=c[51544+((d[N>>0]^_>>>24)<<2)>>2]^_<<8;_=c[51544+((d[O>>0]^D>>>24)<<2)>>2]^D<<8;ut(Q,Zu(g,0)|0);D=W+ -4|0;if((D|0)==0){ra=_}else{Y=_;_=D;while(1){D=_>>>0<256?_:256;if((ta(j|0,1,D|0,e|0)|0)!=(D|0)){break a}if((c[12884]|0)==0){X=0;do{T=X<<25;S=(X&128|0)!=0?T^517762881:T;T=S<<1;Z=(S|0)<0?T^517762881:T;T=Z<<1;S=(Z|0)<0?T^517762881:T;T=S<<1;Z=(S|0)<0?T^517762881:T;T=Z<<1;S=(Z|0)<0?T^517762881:T;T=S<<1;Z=(S|0)<0?T^517762881:T;T=Z<<1;S=(Z|0)<0?T^517762881:T;T=S<<1;c[51544+(X<<2)>>2]=(S|0)<0?T^517762881:T;X=X+1|0}while((X|0)!=256);c[12884]=1}if((D|0)==0){sa=Y}else{X=D;U=Y;T=j;while(1){S=c[51544+((d[T>>0]^U>>>24)<<2)>>2]^U<<8;Z=X+ -1|0;if((Z|0)==0){sa=S;break}else{X=Z;U=S;T=T+1|0}}}if((_|0)==(D|0)){ra=sa;break}else{Y=sa;_=_-D|0}}}if((ta(j|0,1,4,e|0)|0)!=4){break a}if((Zu(j,0)|0)==(ra|0)){ba=Q}else{ca=169;break b}}else if((R|0)==1229081926){if((Q|0)==0|W>>>0<6){break a}if((ta(k|0,1,6,e|0)|0)!=6){break a}if((c[12884]|0)==0){_=0;do{Y=_<<25;T=(_&128|0)!=0?Y^517762881:Y;Y=T<<1;U=(T|0)<0?Y^517762881:Y;Y=U<<1;T=(U|0)<0?Y^517762881:Y;Y=T<<1;U=(T|0)<0?Y^517762881:Y;Y=U<<1;T=(U|0)<0?Y^517762881:Y;Y=T<<1;U=(T|0)<0?Y^517762881:Y;Y=U<<1;T=(U|0)<0?Y^517762881:Y;Y=T<<1;c[51544+(_<<2)>>2]=(T|0)<0?Y^517762881:Y;_=_+1|0}while((_|0)!=256);c[12884]=1}_=a[k>>0]|0;Y=c[51544+((_&255^V>>>24)<<2)>>2]^V<<8;T=a[x>>0]|0;U=c[51544+((T&255^Y>>>24)<<2)>>2]^Y<<8;Y=a[A>>0]|0;X=c[51544+((Y&255^U>>>24)<<2)>>2]^U<<8;U=a[z>>0]|0;S=c[51544+((U&255^X>>>24)<<2)>>2]^X<<8;X=a[B>>0]|0;Z=c[51544+((X&255^S>>>24)<<2)>>2]^S<<8;S=a[C>>0]|0;ua=c[51544+((S&255^Z>>>24)<<2)>>2]^Z<<8;b[Q+4>>1]=_&255;b[Q+6>>1]=T&255;b[Q+8>>1]=Y&255;yt(Q,U);if(!((X&1)==0)){U=Q+12|0;c[U>>2]=c[U>>2]|1}if(!((X&2)==0)){U=Q+12|0;c[U>>2]=c[U>>2]|2}if(!((X&4)==0)){U=Q+12|0;c[U>>2]=c[U>>2]|4}if(!((X&8)==0)){X=Q+12|0;c[X>>2]=c[X>>2]|8}if(S<<24>>24==1){tt(Q,32769)}else{tt(Q,1)}S=W+ -6|0;if((S|0)==0){va=ua}else{X=ua;ua=S;while(1){S=ua>>>0<256?ua:256;if((ta(j|0,1,S|0,e|0)|0)!=(S|0)){break a}if((c[12884]|0)==0){U=0;do{Y=U<<25;T=(U&128|0)!=0?Y^517762881:Y;Y=T<<1;_=(T|0)<0?Y^517762881:Y;Y=_<<1;T=(_|0)<0?Y^517762881:Y;Y=T<<1;_=(T|0)<0?Y^517762881:Y;Y=_<<1;T=(_|0)<0?Y^517762881:Y;Y=T<<1;_=(T|0)<0?Y^517762881:Y;Y=_<<1;T=(_|0)<0?Y^517762881:Y;Y=T<<1;c[51544+(U<<2)>>2]=(T|0)<0?Y^517762881:Y;U=U+1|0}while((U|0)!=256);c[12884]=1}if((S|0)==0){wa=X}else{U=S;D=X;Y=j;while(1){T=c[51544+((d[Y>>0]^D>>>24)<<2)>>2]^D<<8;_=U+ -1|0;if((_|0)==0){wa=T;break}else{U=_;D=T;Y=Y+1|0}}}if((ua|0)==(S|0)){va=wa;break}else{X=wa;ua=ua-S|0}}}if((ta(j|0,1,4,e|0)|0)!=4){break a}if((Zu(j,0)|0)==(va|0)){ba=Q}else{ca=102;break b}}else if((R|0)==1413830740){if((W|0)==0){if((ta(j|0,1,4,e|0)|0)!=4){break a}if((Zu(j,0)|0)==(V|0)){ba=Q;break}else{ca=200;break b}}xa=yz(W)|0;if((xa|0)==0){break a}if((ta(xa|0,1,W|0,e|0)|0)!=(W|0)){ca=207;break b}if((c[12884]|0)==0){ua=0;do{X=ua<<25;Y=(ua&128|0)!=0?X^517762881:X;X=Y<<1;D=(Y|0)<0?X^517762881:X;X=D<<1;Y=(D|0)<0?X^517762881:X;X=Y<<1;D=(Y|0)<0?X^517762881:X;X=D<<1;Y=(D|0)<0?X^517762881:X;X=Y<<1;D=(Y|0)<0?X^517762881:X;X=D<<1;Y=(D|0)<0?X^517762881:X;X=Y<<1;c[51544+(ua<<2)>>2]=(Y|0)<0?X^517762881:X;ua=ua+1|0}while((ua|0)!=256);c[12884]=1;ya=W;za=V;Aa=xa}else{ya=W;za=V;Aa=xa}while(1){za=c[51544+((d[Aa>>0]^za>>>24)<<2)>>2]^za<<8;ya=ya+ -1|0;if((ya|0)==0){break}else{Aa=Aa+1|0}}ua=(a[xa>>0]|0)==10;X=(ua<<31>>31)+W|0;if((X|0)==0){Ba=0}else{Y=X+ -1|0;Ba=(a[xa+Y>>0]|0)==10?Y:X}X=Ut(m,xa+(ua&1)|0,Ba)|0;zz(xa);if((ta(j|0,1,4,e|0)|0)==4){if((Zu(j,0)|0)==(za|0)){Ca=0}else{fb(52568,15,1,P|0)|0;Ca=1}}else{Ca=1}if((Ca|X|0)==0){ba=Q}else{break a}}else{if((W|0)==0){Da=V}else{X=V;ua=W;while(1){Y=ua>>>0<256?ua:256;if((ta(j|0,1,Y|0,e|0)|0)!=(Y|0)){break a}if((c[12884]|0)==0){D=0;do{U=D<<25;T=(D&128|0)!=0?U^517762881:U;U=T<<1;_=(T|0)<0?U^517762881:U;U=_<<1;T=(_|0)<0?U^517762881:U;U=T<<1;_=(T|0)<0?U^517762881:U;U=_<<1;T=(_|0)<0?U^517762881:U;U=T<<1;_=(T|0)<0?U^517762881:U;U=_<<1;T=(_|0)<0?U^517762881:U;U=T<<1;c[51544+(D<<2)>>2]=(T|0)<0?U^517762881:U;D=D+1|0}while((D|0)!=256);c[12884]=1}if((Y|0)==0){Ea=X}else{D=Y;S=X;U=j;while(1){T=c[51544+((d[U>>0]^S>>>24)<<2)>>2]^S<<8;_=D+ -1|0;if((_|0)==0){Ea=T;break}else{D=_;S=T;U=U+1|0}}}if((ua|0)==(Y|0)){Da=Ea;break}else{X=Ea;ua=ua-Y|0}}}if((ta(j|0,1,4,e|0)|0)!=4){break a}if((Zu(j,0)|0)==(Da|0)){ba=Q}else{ca=225;break b}}}while(0);if((ta(l|0,1,8,e|0)|0)==8){Q=ba}else{break a}}switch(ca|0){case 38:{if((W|0)==0){Fa=V}else{Q=V;C=W;while(1){B=C>>>0<256?C:256;if((ta(j|0,1,B|0,e|0)|0)!=(B|0)){break a}if((c[12884]|0)==0){z=0;do{A=z<<25;x=(z&128|0)!=0?A^517762881:A;A=x<<1;O=(x|0)<0?A^517762881:A;A=O<<1;x=(O|0)<0?A^517762881:A;A=x<<1;O=(x|0)<0?A^517762881:A;A=O<<1;x=(O|0)<0?A^517762881:A;A=x<<1;O=(x|0)<0?A^517762881:A;A=O<<1;x=(O|0)<0?A^517762881:A;A=x<<1;c[51544+(z<<2)>>2]=(x|0)<0?A^517762881:A;z=z+1|0}while((z|0)!=256);c[12884]=1}if((B|0)==0){Ga=Q}else{z=B;A=Q;x=j;while(1){O=c[51544+((d[x>>0]^A>>>24)<<2)>>2]^A<<8;N=z+ -1|0;if((N|0)==0){Ga=O;break}else{z=N;A=O;x=x+1|0}}}if((C|0)==(B|0)){Fa=Ga;break}else{Q=Ga;C=C-B|0}}}if((ta(j|0,1,4,e|0)|0)!=4){break a}if((Zu(j,0)|0)!=(Fa|0)){fb(52568,15,1,P|0)|0;break a}Wt(m);n=m;i=f;return n|0};case 57:{fb(52584,31,1,P|0)|0;lt(ha);break a;break};case 60:{lt(ha);break a;break};case 75:{fb(52568,15,1,P|0)|0;break a;break};case 102:{fb(52568,15,1,P|0)|0;break a;break};case 130:{fb(52568,15,1,P|0)|0;break a;break};case 153:{fb(52568,15,1,P|0)|0;break a;break};case 169:{fb(52568,15,1,P|0)|0;break a;break};case 185:{fb(52568,15,1,P|0)|0;break a;break};case 196:{fb(52568,15,1,P|0)|0;break a;break};case 200:{fb(52568,15,1,P|0)|0;break a;break};case 207:{zz(xa);break a;break};case 225:{fb(52568,15,1,P|0)|0;break a;break}}}}}}}}}while(0);Lt(m);n=0;i=f;return n|0}function Du(d,f){d=d|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;g=i;i=i+32|0;h=g+4|0;j=g+24|0;k=g;l=g+8|0;_u(h,0,0);m=b[f>>1]|0;a:do{if(m<<16>>16==0){n=0;o=14}else{p=c[f+4>>2]|0;q=m&65535;r=0;b:while(1){s=c[p+(r<<2)>>2]|0;t=b[s+2>>1]|0;if(!(t<<16>>16==0)){u=c[s+4>>2]|0;s=t&65535;t=0;do{v=c[u+(t<<2)>>2]|0;t=t+1|0;if((b[v+2>>1]|0)!=0){break b}}while(t>>>0<s>>>0)}s=r+1|0;if(s>>>0<q>>>0){r=s}else{n=0;o=14;break a}}r=e[(c[c[v+4>>2]>>2]|0)+16>>1]|0;if((r|0)==32770){w=r;x=513;break}else if((r|0)==16386){w=r;x=514;break}else if((r|0)==1){w=1;x=256;break}else if((r|0)==32769){w=r;x=257;break}else if((r|0)==2){w=r;x=512;break}else if((r|0)==3){w=r;x=768;break}else{n=r;o=14;break}}}while(0);if((o|0)==14){w=n;x=0}_u(h,2,x);if((Eu(d,1347635488,4,h)|0)!=0){y=1;i=g;return y|0}x=f+8|0;if((c[x>>2]|0)!=0){$u(l,0,1413830740);$u(l,4,(c[x>>2]|0)+2|0);n=l+8|0;a[n>>0]=10;c[k>>2]=0;v=Gu(d,l,9,k)|0;m=Gu(d,c[f+12>>2]|0,c[x>>2]|0,k)|0|v;v=m|(Gu(d,n,1,k)|0);$u(l,0,c[k>>2]|0);if((v|(fb(l|0,1,4,d|0)|0)!=4|0)!=0){y=1;i=g;return y|0}}l=b[f>>1]|0;c:do{if(!(l<<16>>16==0)){v=f+4|0;k=l;n=0;d:while(1){m=c[(c[v>>2]|0)+(n<<2)>>2]|0;x=m+2|0;r=b[x>>1]|0;if(r<<16>>16==0){z=k}else{q=m+4|0;m=r;r=0;while(1){p=c[(c[q>>2]|0)+(r<<2)>>2]|0;s=p+2|0;if((b[s>>1]|0)==0){A=m}else{t=p+4|0;p=0;do{u=c[(c[t>>2]|0)+(p<<2)>>2]|0;if((Hu(d,u,n,r,0,w)|0)==0){B=u}else{y=1;o=35;break d}while(1){u=c[B>>2]|0;if((u|0)==0){break}if((Hu(d,u,n,r,1,w)|0)==0){B=u}else{y=1;o=35;break d}}p=p+1|0}while(p>>>0<(e[s>>1]|0)>>>0);A=b[x>>1]|0}r=r+1|0;if(!(r>>>0<(A&65535)>>>0)){break}else{m=A}}z=b[f>>1]|0}n=n+1|0;if(!(n>>>0<(z&65535)>>>0)){break c}else{k=z}}if((o|0)==35){i=g;return y|0}}}while(0);$u(j,0,1162757152);$u(j,4,0);c[h>>2]=0;if((Gu(d,j,8,h)|0)!=0){y=1;i=g;return y|0}$u(j,0,c[h>>2]|0);if((fb(j|0,1,4,d|0)|0)!=4){y=1;i=g;return y|0}Nb(d|0)|0;y=0;i=g;return y|0}function Eu(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f;h=f+8|0;$u(h,0,b);$u(h,4,d);c[g>>2]=0;if((Gu(a,h,8,g)|0)!=0){j=1;i=f;return j|0}if((d|0)!=0){if((Gu(a,e,d,g)|0)!=0){j=1;i=f;return j|0}}$u(h,0,c[g>>2]|0);j=(fb(h|0,1,4,a|0)|0)!=4|0;i=f;return j|0}function Fu(a){a=a|0;var b=0,c=0,d=0;b=i;i=i+16|0;c=b;if((ev(a,0,c,4)|0)!=0){d=0;i=b;return d|0}d=(Zu(c,0)|0)==1347635488|0;i=b;return d|0}function Gu(a,b,e,f){a=a|0;b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;if((f|0)==0){h=fb(b|0,1,e|0,a|0)|0;j=(h|0)!=(e|0);k=j&1;i=g;return k|0}l=c[f>>2]|0;if((c[12884]|0)==0){m=0;do{n=m<<25;o=(m&128|0)!=0?n^517762881:n;n=o<<1;p=(o|0)<0?n^517762881:n;n=p<<1;o=(p|0)<0?n^517762881:n;n=o<<1;p=(o|0)<0?n^517762881:n;n=p<<1;o=(p|0)<0?n^517762881:n;n=o<<1;p=(o|0)<0?n^517762881:n;n=p<<1;o=(p|0)<0?n^517762881:n;n=o<<1;c[51544+(m<<2)>>2]=(o|0)<0?n^517762881:n;m=m+1|0}while((m|0)!=256);c[12884]=1}if((e|0)==0){q=l}else{m=e;n=l;l=b;while(1){o=c[51544+(((d[l>>0]|0)^n>>>24)<<2)>>2]^n<<8;p=m+ -1|0;if((p|0)==0){q=o;break}else{m=p;n=o;l=l+1|0}}}c[f>>2]=q;h=fb(b|0,1,e|0,a|0)|0;j=(h|0)!=(e|0);k=j&1;i=g;return k|0}function Hu(d,f,g,h,j,k){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;l=i;i=i+48|0;m=l+36|0;n=l+16|0;o=l+8|0;p=l;q=(j|0)!=0?2:0;j=f+10|0;if((rt(f)|0)==0){r=q}else{r=(b[j>>1]|0)!=0|q}q=f+12|0;s=c[q>>2]<<1&4|r;_u(p,0,g);a[p+2>>0]=h;t=f+8|0;a[p+3>>0]=b[t>>1];_u(p,4,e[j>>1]|0);a[p+6>>0]=s;s=p+7|0;a[s>>0]=0;u=(r&1|0)==0;if(!u){a[s>>0]=a[c[f+24>>2]>>0]|0}if((Eu(d,1397048148,8,p)|0)!=0){v=1;i=l;return v|0}p=f+16|0;s=b[p>>1]|0;do{if((s&4095)==1){r=zt(f)|0;w=b[f+4>>1]|0;if((w&65535|0)==(g|0)){x=(e[f+6>>1]|0)!=(h|0)}else{x=1}if(r>>>0>8){y=1}else{y=(e[j>>1]|0)!=(128<<r|0)}z=c[q>>2]|0;A=b[p>>1]|0;B=A&65535;if(x|y|(z&13|0)!=0|(B|0)!=(k|0)){a[o>>0]=w;a[o+1>>0]=b[f+6>>1];a[o+2>>0]=b[t>>1];a[o+3>>0]=r;a[o+4>>0]=z&15;if((B|0)==1){a[o+5>>0]=0}else if((B|0)==32769){a[o+5>>0]=1}else{a[o+5>>0]=0}if((Eu(d,1229081926,6,o)|0)==0){C=b[p>>1]|0;break}else{v=1;i=l;return v|0}}else{C=A}}else{C=s}}while(0);do{if((C&4095)==2){s=zt(f)|0;y=b[f+4>>1]|0;if((y&65535|0)==(g|0)){D=(e[f+6>>1]|0)!=(h|0)}else{D=1}if(s>>>0>8){E=1}else{E=(e[j>>1]|0)!=(128<<s|0)}x=c[q>>2]|0;A=b[p>>1]|0;B=A&65535;if(D|E|(x&13|0)!=0|(B|0)!=(k|0)){a[o>>0]=y;a[o+1>>0]=b[f+6>>1];a[o+2>>0]=b[t>>1];a[o+3>>0]=s;a[o+4>>0]=x&15;if((B|0)==32770){a[o+5>>0]=1}else if((B|0)==16386){a[o+5>>0]=2}else if((B|0)==2){a[o+5>>0]=0}else{a[o+5>>0]=0}if((Eu(d,1229081933,6,o)|0)==0){F=b[p>>1]|0;break}else{v=1;i=l;return v|0}}else{F=A}}else{F=C}}while(0);if((F&4095)==3){C=f+4|0;if((e[C>>1]|0)==(g|0)){G=(e[f+6>>1]|0)!=(h|0)}else{G=1}h=G|(c[q>>2]&9|0)!=0|(F&65535|0)!=(k|0);k=n+6|0;if((Dt(f,k,12)|0)==0){H=h&1}else{H=((a[n+17>>0]|0)!=0|((a[n+16>>0]|0)!=0|((a[n+15>>0]|0)!=0|((a[n+14>>0]|0)!=0|((a[n+13>>0]|0)!=0|((a[n+12>>0]|0)!=0|((a[n+11>>0]|0)!=0|((a[n+10>>0]|0)!=0|((a[n+9>>0]|0)!=0|((a[n+8>>0]|0)!=0|((a[n+7>>0]|0)!=0|((a[k>>0]|0)!=0|h))))))))))))&1}if((H|0)!=0){_u(n,0,e[C>>1]|0);a[n+2>>0]=b[f+6>>1];a[n+3>>0]=b[t>>1];a[n+4>>0]=Bt(f)|0;t=c[q>>2]|0;a[n+5>>0]=t>>>1&4|t&3;if((Eu(d,1296122695,18,n)|0)!=0){v=1;i=l;return v|0}}}n=vt(f)|0;if(!((n|0)==-1)){$u(m,0,n);if((Eu(d,1330005587,4,m)|0)!=0){v=1;i=l;return v|0}}n=xt(f)|0;if((n|0)!=0){if((n|0)!=(e[j>>1]<<3|0)){$u(m,0,n);if((Eu(d,1414090053,4,m)|0)!=0){v=1;i=l;return v|0}}}if(u){u=b[j>>1]|0;if(!(u<<16>>16==0)){if((Eu(d,1145132097,u&65535,c[f+24>>2]|0)|0)!=0){v=1;i=l;return v|0}}}v=0;i=l;return v|0}function Iu(a){a=a|0;var b=0,c=0,d=0;b=i;c=Kt()|0;if((c|0)==0){d=0}else{if((Ju(a,c,52984)|0)==0){d=c}else{Lt(c);d=0}}i=b;return d|0}function Ju(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=i;f=La(a|0)|0;a:do{if((xb(a|0,0,2)|0)==0){g=La(a|0)|0;if((xb(a|0,f|0,0)|0)==0){h=c[d>>2]|0;if((h|0)==0){j=1}else{k=d;l=h;while(1){h=k+24|0;if((l|0)==(g|0)){break}m=c[h>>2]|0;if((m|0)==0){j=1;break a}else{k=h;l=m}}if((k|0)==0){j=1}else{l=k+4|0;g=c[l>>2]|0;if((g|0)==0){j=0}else{m=k+8|0;h=k+12|0;n=k+16|0;o=k+20|0;p=c[m>>2]|0;q=g;g=0;b:while(1){if((p|0)==0){r=q;s=0}else{t=0;do{u=Qt(b,g,t,1)|0;if((u|0)==0){j=1;break a}else{v=0}while(1){if(!(v>>>0<(c[h>>2]|0)>>>0)){break}w=v+1|0;x=kt(g,t,w,c[n>>2]|0)|0;if((x|0)==0){j=1;break a}tt(x,c[o>>2]|0);if((Gt(u,x)|0)!=0){break b}y=ta(c[x+24>>2]|0,1,c[n>>2]|0,a|0)|0;if((y|0)==(c[n>>2]|0)){v=w}else{j=1;break a}}t=t+1|0;z=c[m>>2]|0}while(t>>>0<z>>>0);r=c[l>>2]|0;s=z}t=g+1|0;if(t>>>0<r>>>0){p=s;q=r;g=t}else{j=0;break a}}lt(x);j=1}}}}else{j=1}}else{j=1}}while(0);i=e;return j|0}function Ku(a){a=a|0;var b=0,c=0,d=0;b=i;c=Kt()|0;if((c|0)==0){d=0}else{if((Ju(a,c,52648)|0)==0){d=c}else{Lt(c);d=0}}i=b;return d|0}function Lu(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=Mu(a,b)|0;i=c;return d|0}function Mu(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=i;g=b[d>>1]|0;a:do{if(!(g<<16>>16==0)){h=d+4|0;j=g;k=0;b:while(1){l=c[(c[h>>2]|0)+(k<<2)>>2]|0;m=l+2|0;if((b[m>>1]|0)==0){n=j}else{o=l+4|0;l=0;do{p=c[(c[o>>2]|0)+(l<<2)>>2]|0;q=p+2|0;r=b[q>>1]|0;c:do{if(!(r<<16>>16==0)){s=c[p+4>>2]|0;t=r&65535;u=0;v=65535;w=0;while(1){x=c[s+(u<<2)>>2]|0;y=e[x+8>>1]|0;z=y>>>0<v>>>0;w=z?x:w;u=u+1|0;if((u|0)==(t|0)){break}else{v=z?y:v}}if((w|0)!=0){v=p+4|0;t=e[w+8>>1]|0;u=w;while(1){s=t+1|0;y=u+10|0;z=fb(c[u+24>>2]|0,1,e[y>>1]|0,a|0)|0;if((z|0)!=(e[y>>1]|0)){A=1;break b}y=b[q>>1]|0;if(y<<16>>16==0){break c}z=c[v>>2]|0;x=y&65535;y=0;B=65535;C=0;while(1){D=c[z+(y<<2)>>2]|0;E=e[D+8>>1]|0;F=E>>>0>=s>>>0&E>>>0<B>>>0;C=F?D:C;y=y+1|0;if((y|0)==(x|0)){break}else{B=F?E:B}}if((C|0)==0){break c}t=e[C+8>>1]|0;u=C}}}}while(0);l=l+1|0}while(l>>>0<(e[m>>1]|0)>>>0);n=b[d>>1]|0}k=k+1|0;if(!(k>>>0<(n&65535)>>>0)){break a}else{j=n}}i=f;return A|0}}while(0);Nb(a|0)|0;A=0;i=f;return A|0}function Nu(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;b=i;if((xb(a|0,0,2)|0)!=0){d=0;i=b;return d|0}e=La(a|0)|0;a=c[13162]|0;a:do{if((a|0)==0){f=5}else{g=52648;h=a;while(1){j=g+24|0;if((h|0)==(e|0)){k=g;break a}l=c[j>>2]|0;if((l|0)==0){f=5;break}else{g=j;h=l}}}}while(0);b:do{if((f|0)==5){a=c[13246]|0;if((a|0)==0){k=0}else{h=52984;g=a;while(1){a=h+24|0;if((g|0)==(e|0)){k=h;break b}l=c[a>>2]|0;if((l|0)==0){k=0;break}else{h=a;g=l}}}}}while(0);d=(k|0)!=0|0;i=b;return d|0}function Ou(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;g=i;i=i+64|0;h=g;j=g+48|0;k=g+32|0;l=g+16|0;m=Kt()|0;if((m|0)==0){n=0;i=g;return n|0}a:do{if((ev(f,0,l,16)|0)==0){if((Zu(l,0)|0)!=1381193984){fb(53632,15,1,c[o>>2]|0)|0;break}p=a[l+10>>0]|0;q=p&255;if(p<<24>>24==0){n=m;i=g;return n|0}p=k+14|0;r=j+8|0;s=j+9|0;t=j+10|0;u=j+11|0;v=j+14|0;w=16;x=0;b:while(1){if((ev(f,w,k,16)|0)!=0){y=8;break}z=bv(k,0)|0;A=bv(k,4)|0;B=av(k,8)|0;C=av(k,10)|0;D=d[p>>0]|0;E=D&127;F=D>>>7;D=w+16|0;G=(B<<4)+D|0;H=G+A|0;A=Qt(m,E,F,1)|0;if((A|0)==0){break a}I=(B|0)==0;if((C&1|0)==0){if(!I){C=D;J=0;while(1){J=J+1|0;K=kt(E,F,J,512)|0;if((K|0)==0){break a}Gt(A,K)|0;if((ev(f,C,c[K+24>>2]|0,512)|0)!=0){break a}if(!(J>>>0<B>>>0)){break}else{C=C+512|0}}}}else{if(!I){C=G;J=D;F=0;while(1){if((ev(f,J,j,16)|0)!=0){y=14;break b}E=bv(j,0)|0;K=av(j,4)|0;L=av(j,6)|0;M=a[r>>0]|0;N=a[s>>0]|0;O=a[t>>0]|0;P=a[u>>0]|0;Q=Yu(j,12)|0;R=a[v>>0]|0;S=45616;T=4;U=r;while(1){V=d[U>>0]<<8^S;W=V<<1;X=(V&32768|0)==0?W:W^4129;W=X<<1;V=(X&32768|0)==0?W:W^4129;W=V<<1;X=(V&32768|0)==0?W:W^4129;W=X<<1;V=(X&32768|0)==0?W:W^4129;W=V<<1;X=(V&32768|0)==0?W:W^4129;W=X<<1;V=(X&32768|0)==0?W:W^4129;W=V<<1;X=(V&32768|0)==0?W:W^4129;W=X<<1;S=(X&32768|0)==0?W:W^4129;T=T+ -1|0;if((T|0)==0){break}else{U=U+1|0}}Y=N&255;Z=M&255;_=O&255;U=R&255;T=128<<(P&3);W=kt(Z,Y,_,T)|0;if((W|0)==0){break a}Gt(A,W)|0;ut(W,K);yt(W,P);wt(W,(L+2|0)>>>2);if((U&8|0)!=0){st(W,2,1)}if((Q|0)!=(S&65535|0)){st(W,1,1)}if((U&16|0)==0){if((ev(f,H+E|0,c[W+24>>2]|0,T)|0)!=0){y=25;break b}}else{pt(W,0,0)|0;st(W,8,1);wt(W,0)}if((U&128|0)==0){$=C}else{U=mt(W,0)|0;if((U|0)==0){break a}X=U+24|0;if((ev(f,C,c[X>>2]|0,e[U+10>>1]|0)|0)!=0){break a}V=W+10|0;if((b[V>>1]|0)!=0){aa=W+24|0;ba=0;do{ca=(c[X>>2]|0)+ba|0;a[ca>>0]=d[(c[aa>>2]|0)+ba>>0]^255^d[ca>>0];ba=ba+1|0}while(ba>>>0<(e[V>>1]|0)>>>0)}nt(W,U);$=T+C|0}F=F+1|0;if(!(F>>>0<B>>>0)){break}else{C=$;J=J+16|0}}}}J=x+1|0;if(J>>>0<q>>>0){w=z+w|0;x=J}else{n=m;y=39;break}}if((y|0)==8){fb(53648,31,1,c[o>>2]|0)|0;break}else if((y|0)==14){fb(53680,32,1,c[o>>2]|0)|0;break}else if((y|0)==25){x=c[o>>2]|0;c[h>>2]=Z;c[h+4>>2]=Y;c[h+8>>2]=_;hb(x|0,53720,h|0)|0;fb(53736,30,1,x|0)|0;break}else if((y|0)==39){i=g;return n|0}}}while(0);Lt(m);n=0;i=g;return n|0}function Pu(a,b){a=a|0;b=b|0;return 1}function Qu(a){a=a|0;var b=0,c=0,d=0;b=i;i=i+16|0;c=b;if((ev(a,0,c,8)|0)!=0){d=0;i=b;return d|0}d=(Zu(c,0)|0)==1381193984|0;i=b;return d|0}function Ru(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0;g=i;i=i+65616|0;h=g;j=g+65588|0;k=g+65600|0;l=g+28|0;m=g+65608|0;n=g+24|0;p=g+65592|0;q=g+32|0;r=Kt()|0;if((r|0)==0){s=0;i=g;return s|0}c[q>>2]=f;f=q+65540|0;c[f+0>>2]=0;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=0;t=q+65544|0;u=q+65554|0;v=q+65548|0;w=c[o>>2]|0;x=q+65555|0;y=q+65552|0;z=k+1|0;A=k+2|0;B=k+3|0;C=j+1|0;D=q+4|0;E=0;a:while(1){F=E<<1;G=0;do{c[t>>2]=0;c[f>>2]=0;a[u>>0]=0;H=G+F<<1;if((xb(c[q>>2]|0,H+773|0,0)|0)!=0){break a}if((ta(h|0,1,2,c[q>>2]|0)|0)!=2){break a}I=(Yu(h,0)|0)<<8;if((I|0)==0){J=c[t>>2]|0;K=c[f>>2]|0}else{if((xb(c[q>>2]|0,H+1285|0,0)|0)!=0){break a}if((ta(h|0,1,2,c[q>>2]|0)|0)!=2){break a}H=av(h,0)|0;if((xb(c[q>>2]|0,I|0,0)|0)!=0){break a}if((ta(D|0,1,H|0,c[q>>2]|0)|0)!=(H|0)){break a}c[t>>2]=0;I=H<<3;c[f>>2]=I;J=0;K=I}if(J>>>0<K>>>0){I=0;do{c[v>>2]=0;c[t>>2]=0;b:do{do{if((Su(q,p,n)|0)==0){if((I|0)==0){if((c[n>>2]|0)!=0){break}}else if((I|0)==1){if((c[n>>2]|0)==0){break}}if((c[v>>2]|0)!=0){break b}H=d[p>>0]|0;L=c[n>>2]|0;M=c[t>>2]|0;if((H|0)==254){N=M;O=(a[x>>0]|0)==0;P=0;Q=0;while(1){R=k+Q|0;a[R>>0]=0;if(O){S=N;T=c[f>>2]|0;U=P}else{V=N+1|0;c[t>>2]=V;W=c[f>>2]|0;if(V>>>0<W>>>0){X=V;Y=P}else{c[t>>2]=0;V=P+1|0;c[v>>2]=V;X=0;Y=V}a[x>>0]=0;S=X;T=W;U=Y}W=0;V=S;Z=U;_=1;while(1){$=d[q+(V>>>3)+4>>0]&128>>>(V&7);aa=V+1|0;c[t>>2]=aa;if(aa>>>0<T>>>0){ba=aa;ca=Z}else{c[t>>2]=0;aa=Z+1|0;c[v>>2]=aa;ba=0;ca=aa}a[x>>0]=1;W=($|0)!=0|W<<1&510;da=W&255;$=ba+1|0;c[t>>2]=$;if($>>>0<T>>>0){ea=ca;fa=$}else{c[t>>2]=0;$=ca+1|0;c[v>>2]=$;ea=$;fa=0}a[x>>0]=0;if((_|0)==8){break}else{V=fa;Z=ea;_=_+1|0}}a[R>>0]=da;Q=Q+1|0;if((Q|0)==6){break}else{N=fa;O=1;P=ea}}P=Yu(k,4)|0;O=e[y>>1]|0;N=4;Q=k;while(1){_=d[Q>>0]<<8^O;Z=_<<1;V=(_&32768|0)==0?Z:Z^4129;Z=V<<1;_=(V&32768|0)==0?Z:Z^4129;Z=_<<1;V=(_&32768|0)==0?Z:Z^4129;Z=V<<1;_=(V&32768|0)==0?Z:Z^4129;Z=_<<1;V=(_&32768|0)==0?Z:Z^4129;Z=V<<1;_=(V&32768|0)==0?Z:Z^4129;Z=_<<1;V=(_&32768|0)==0?Z:Z^4129;Z=V<<1;O=(V&32768|0)==0?Z:Z^4129;N=N+ -1|0;if((N|0)==0){break}else{Q=Q+1|0}}b[y>>1]=O;Q=a[B>>0]|0;N=kt(d[k>>0]|0,d[z>>0]|0,d[A>>0]|0,(Q&255)<6?128<<(Q&255):8192)|0;if((N|0)==0){break a}yt(N,a[B>>0]|0);st(N,8,1);if((e[y>>1]|0)!=(P|0)){st(N,1,1)}qt(N,0);if((L|0)==0){tt(N,2)}else{tt(N,1)}Pt(r,N,E,G)|0;if((Su(q,m,l)|0)==0){Q=a[m>>0]|0;if(Q<<24>>24==-5|Q<<24>>24==-8){Z=N+24|0;V=c[Z>>2]|0;_=N+10|0;W=b[_>>1]|0;$=W&65535;if(W<<16>>16==0){ga=0;ha=0}else{W=0;do{aa=V+W|0;a[aa>>0]=0;if((a[x>>0]|0)==0){ia=1}else{ja=(c[t>>2]|0)+1|0;c[t>>2]=ja;if(!(ja>>>0<(c[f>>2]|0)>>>0)){c[t>>2]=0;c[v>>2]=(c[v>>2]|0)+1}a[x>>0]=0;ia=1}while(1){a[aa>>0]=d[aa>>0]<<1;ja=c[t>>2]|0;ka=(d[q+(ja>>>3)+4>>0]&128>>>(ja&7)|0)==0;la=ja+1|0;c[t>>2]=la;ja=c[f>>2]|0;if(la>>>0<ja>>>0){ma=la}else{c[t>>2]=0;c[v>>2]=(c[v>>2]|0)+1;ma=0}a[x>>0]=(a[x>>0]|0)==0|0;if(ka){na=ma;oa=ja}else{a[aa>>0]=d[aa>>0]|1;na=c[t>>2]|0;oa=c[f>>2]|0}ja=na+1|0;c[t>>2]=ja;if(!(ja>>>0<oa>>>0)){c[t>>2]=0;c[v>>2]=(c[v>>2]|0)+1}a[x>>0]=(a[x>>0]|0)==0|0;if((ia|0)==8){break}ia=ia+1|0}W=W+1|0}while((W|0)!=($|0));ga=b[_>>1]|0;ha=$}if((ha|0)!=(ga&65535|0)){break a}a[j>>0]=0;W=c[t>>2]|0;if((a[x>>0]|0)==0){pa=W;qa=c[f>>2]|0}else{V=W+1|0;c[t>>2]=V;W=c[f>>2]|0;if(V>>>0<W>>>0){ra=V}else{c[t>>2]=0;c[v>>2]=(c[v>>2]|0)+1;ra=0}a[x>>0]=0;pa=ra;qa=W}W=0;V=pa;P=1;while(1){O=d[q+(V>>>3)+4>>0]&128>>>(V&7);aa=V+1|0;c[t>>2]=aa;if(aa>>>0<qa>>>0){sa=aa}else{c[t>>2]=0;c[v>>2]=(c[v>>2]|0)+1;sa=0}a[x>>0]=1;W=(O|0)!=0|W<<1&510;ua=W&255;O=sa+1|0;c[t>>2]=O;if(O>>>0<qa>>>0){va=O}else{c[t>>2]=0;c[v>>2]=(c[v>>2]|0)+1;va=0}a[x>>0]=0;if((P|0)==8){break}else{V=va;P=P+1|0}}a[j>>0]=ua;a[C>>0]=0;P=0;V=va;W=1;while(1){$=d[q+(V>>>3)+4>>0]&128>>>(V&7);O=V+1|0;c[t>>2]=O;if(O>>>0<qa>>>0){wa=O}else{c[t>>2]=0;c[v>>2]=(c[v>>2]|0)+1;wa=0}a[x>>0]=1;P=($|0)!=0|P<<1&510;xa=P&255;$=wa+1|0;c[t>>2]=$;if($>>>0<qa>>>0){ya=$}else{c[t>>2]=0;c[v>>2]=(c[v>>2]|0)+1;ya=0}a[x>>0]=0;if((W|0)==8){break}else{V=ya;W=W+1|0}}a[C>>0]=xa;st(N,8,0);st(N,4,Q<<24>>24==-8|0);W=Yu(j,0)|0;V=e[y>>1]|0;P=b[_>>1]|0;if(P<<16>>16==0){za=V}else{$=V;V=P&65535;P=c[Z>>2]|0;while(1){O=d[P>>0]<<8^$;aa=O<<1;R=(O&32768|0)==0?aa:aa^4129;aa=R<<1;O=(R&32768|0)==0?aa:aa^4129;aa=O<<1;R=(O&32768|0)==0?aa:aa^4129;aa=R<<1;O=(R&32768|0)==0?aa:aa^4129;aa=O<<1;R=(O&32768|0)==0?aa:aa^4129;aa=R<<1;O=(R&32768|0)==0?aa:aa^4129;aa=O<<1;R=(O&32768|0)==0?aa:aa^4129;aa=R<<1;O=(R&32768|0)==0?aa:aa^4129;aa=V+ -1|0;if((aa|0)==0){za=O;break}else{$=O;V=aa;P=P+1|0}}}b[y>>1]=za;if((za&65535|0)!=(W|0)){st(N,2,1)}}}}else if(!((H|0)==251|(H|0)==248)){P=c[f>>2]|0;c[h>>2]=H;c[h+4>>2]=(L|0)!=0?53824:53832;c[h+8>>2]=E;c[h+12>>2]=G;c[h+16>>2]=M;c[h+20>>2]=P;hb(w|0,53768,h|0)|0}c[v>>2]=0;c[t>>2]=M}}while(0)}while((c[v>>2]|0)==0);I=I+1|0}while((St(r,E,G,0,1)|0)==0&I>>>0<2)}G=G+1|0}while(G>>>0<2);G=E+1|0;if(G>>>0<80){E=G}else{s=r;Aa=89;break}}if((Aa|0)==89){i=g;return s|0}Lt(r);s=0;i=g;return s|0}function Su(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;j=i;c[h>>2]=0;a[g>>0]=0;k=f+65554|0;a[k>>0]=0;l=f+65548|0;m=c[l>>2]|0;n=m+2|0;o=f+65544|0;p=f+65540|0;q=f+65555|0;r=c[p>>2]|0;s=m;m=c[o>>2]|0;t=0;while(1){u=(d[f+(m>>>3)+4>>0]&128>>>(m&7)|0)!=0|0;v=m+1|0;c[o>>2]=v;if(v>>>0<r>>>0){w=v;x=s}else{c[o>>2]=0;v=s+1|0;c[l>>2]=v;w=0;x=v}a[q>>0]=(a[q>>0]|0)==0|0;v=u|t<<1;u=v&65535;if((u|0)==63338){y=6;break}else if((u|0)==62846){y=7;break}else if((u|0)==17545){y=5;break}else if((u|0)==62831){y=8;break}else if((u|0)==62826){y=9;break}if((a[g>>0]|0)!=0){break}if(x>>>0<n>>>0){s=x;m=w;t=v}else{z=1;y=28;break}}if((y|0)==5){a[g>>0]=-95}else if((y|0)==6){a[g>>0]=-4}else if((y|0)==7){a[g>>0]=-2}else if((y|0)==8){a[g>>0]=-5}else if((y|0)==9){a[g>>0]=-8}else if((y|0)==28){i=j;return z|0}a[k>>0]=1;a[q>>0]=1;k=d[g>>0]<<8^65535;t=k<<1;w=(k&32768|0)==0?t:t^4129;t=w<<1;k=(w&32768|0)==0?t:t^4129;t=k<<1;w=(k&32768|0)==0?t:t^4129;t=w<<1;k=(w&32768|0)==0?t:t^4129;t=k<<1;w=(k&32768|0)==0?t:t^4129;t=w<<1;k=(w&32768|0)==0?t:t^4129;t=k<<1;w=(k&32768|0)==0?t:t^4129;t=w<<1;k=f+65552|0;b[k>>1]=(w&32768|0)==0?t:t^4129;if((a[g>>0]|0)==-95){A=0}else{c[h>>2]=1;z=0;i=j;return z|0}while(1){h=A>>>0<2;a[g>>0]=0;if((a[q>>0]|0)==0){B=1}else{t=(c[o>>2]|0)+1|0;c[o>>2]=t;if(!(t>>>0<(c[p>>2]|0)>>>0)){c[o>>2]=0;c[l>>2]=(c[l>>2]|0)+1}a[q>>0]=0;B=1}while(1){a[g>>0]=d[g>>0]<<1;t=c[o>>2]|0;w=(d[f+(t>>>3)+4>>0]&128>>>(t&7)|0)==0;m=t+1|0;c[o>>2]=m;t=c[p>>2]|0;if(m>>>0<t>>>0){C=m}else{c[o>>2]=0;c[l>>2]=(c[l>>2]|0)+1;C=0}a[q>>0]=(a[q>>0]|0)==0|0;if(w){D=C;E=t}else{a[g>>0]=d[g>>0]|1;D=c[o>>2]|0;E=c[p>>2]|0}t=D+1|0;c[o>>2]=t;if(!(t>>>0<E>>>0)){c[o>>2]=0;c[l>>2]=(c[l>>2]|0)+1}a[q>>0]=(a[q>>0]|0)==0|0;if((B|0)==8){break}B=B+1|0}t=d[g>>0]<<8^e[k>>1];w=t<<1;m=(t&32768|0)==0?w:w^4129;w=m<<1;t=(m&32768|0)==0?w:w^4129;w=t<<1;m=(t&32768|0)==0?w:w^4129;w=m<<1;t=(m&32768|0)==0?w:w^4129;w=t<<1;m=(t&32768|0)==0?w:w^4129;w=m<<1;t=(m&32768|0)==0?w:w^4129;w=t<<1;m=(t&32768|0)==0?w:w^4129;w=m<<1;b[k>>1]=(m&32768|0)==0?w:w^4129;if(!h){z=0;y=28;break}if((a[g>>0]|0)==-95){A=A+1|0}else{z=0;y=28;break}}if((y|0)==28){i=j;return z|0}return 0}function Tu(f){f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0;g=i;i=i+80|0;h=g;j=g+64|0;k=g+56|0;l=g+40|0;m=g+24|0;n=Kt()|0;if((n|0)==0){p=0;i=g;return p|0}a:do{if((dv(f,m,12)|0)==0){q=a[m>>0]|0;if(q<<24>>24==116){if((a[m+1>>0]|0)!=100){break}fb(53840,40,1,c[o>>2]|0)|0;break}else if(!(q<<24>>24==84)){break}if((a[m+1>>0]|0)==68){if((a[m+2>>0]|0)==0){if((d[m+4>>0]|0)<=21){q=a[m+5>>0]|0;r=a[m+7>>0]|0;s=av(m,10)|0;t=0;u=10;v=m;while(1){w=d[v>>0]<<8^t;x=w<<1;y=(w&32768|0)==0?x:x^41111;x=y<<1;w=(y&32768|0)==0?x:x^41111;x=w<<1;y=(w&32768|0)==0?x:x^41111;x=y<<1;w=(y&32768|0)==0?x:x^41111;x=w<<1;y=(w&32768|0)==0?x:x^41111;x=y<<1;w=(y&32768|0)==0?x:x^41111;x=w<<1;y=(w&32768|0)==0?x:x^41111;x=y<<1;t=(y&32768|0)==0?x:x^41111;u=u+ -1|0;if((u|0)==0){break}else{v=v+1|0}}v=t&65535;if((s|0)!=(v|0)){u=c[o>>2]|0;c[h>>2]=s;c[h+4>>2]=v;hb(u|0,53888,h|0)|0;break}if(r<<24>>24<0){if((dv(f,l,10)|0)!=0){break}u=av(l,0)|0;v=0;x=8;y=l+2|0;while(1){w=d[y>>0]<<8^v;z=w<<1;A=(w&32768|0)==0?z:z^41111;z=A<<1;w=(A&32768|0)==0?z:z^41111;z=w<<1;A=(w&32768|0)==0?z:z^41111;z=A<<1;w=(A&32768|0)==0?z:z^41111;z=w<<1;A=(w&32768|0)==0?z:z^41111;z=A<<1;w=(A&32768|0)==0?z:z^41111;z=w<<1;A=(w&32768|0)==0?z:z^41111;z=A<<1;v=(A&32768|0)==0?z:z^41111;x=x+ -1|0;if((x|0)==0){break}else{y=y+1|0}}y=v&65535;x=av(l,2)|0;if((x|0)==0){B=y}else{r=yz(x)|0;if((r|0)==0){break}if((dv(f,r,x)|0)==0){C=y;D=x;E=r}else{zz(r);break}while(1){y=d[E>>0]<<8^C;s=y<<1;t=(y&32768|0)==0?s:s^41111;s=t<<1;y=(t&32768|0)==0?s:s^41111;s=y<<1;t=(y&32768|0)==0?s:s^41111;s=t<<1;y=(t&32768|0)==0?s:s^41111;s=y<<1;t=(y&32768|0)==0?s:s^41111;s=t<<1;y=(t&32768|0)==0?s:s^41111;s=y<<1;t=(y&32768|0)==0?s:s^41111;s=t<<1;C=(t&32768|0)==0?s:s^41111;D=D+ -1|0;if((D|0)==0){break}else{E=E+1|0}}v=C&65535;s=0;while(1){t=s+1|0;if((a[r+s>>0]|0)!=0){F=s;break}if(t>>>0<x>>>0){s=t}else{F=t;break}}s=x;while(1){if(!(F>>>0<s>>>0)){break}t=s+ -1|0;if((a[r+t>>0]|0)==0){s=t}else{G=F;H=28;break}}if((H|0)==28){while(1){H=0;x=r+G|0;if((a[x>>0]|0)==0){a[x>>0]=10}G=G+1|0;if((G|0)==(s|0)){break}else{H=28}}}Vt(n,r+F|0,s-F|0)|0;zz(r);Wt(n);B=v}if((u|0)!=(B|0)){x=c[o>>2]|0;c[h>>2]=u;c[h+4>>2]=B;hb(x|0,54240,h|0)|0;break}}if((dv(f,l,1)|0)==0){x=l+1|0;t=l+3|0;y=k+2|0;z=k+3|0;A=k+4|0;w=k+1|0;I=(q&127)==2;J=k+5|0;K=j+2|0;L=j+3|0;M=j+1|0;N=c[o>>2]|0;O=l+2|0;b:while(1){if((a[l>>0]|0)==-1){p=n;H=103;break}if((dv(f,x,3)|0)!=0){break a}P=a[l>>0]|0;Q=P&255;R=Q<<9;S=(Q&128|0)==0?R:R^41111;R=S<<1;T=(S&32768|0)==0?R:R^41111;R=T<<1;S=(T&32768|0)==0?R:R^41111;R=S<<1;T=(S&32768|0)==0?R:R^41111;R=T<<1;S=(T&32768|0)==0?R:R^41111;R=S<<1;T=(S&32768|0)==0?R:R^41111;R=T<<1;S=(T&32768|0)==0?R:R^41111;R=S<<1;U=d[x>>0]|0;T=((S&32768|0)==0?R:R^41111)^U<<8;R=T<<1;S=(T&32768|0)==0?R:R^41111;R=S<<1;T=(S&32768|0)==0?R:R^41111;R=T<<1;S=(T&32768|0)==0?R:R^41111;R=S<<1;T=(S&32768|0)==0?R:R^41111;R=T<<1;S=(T&32768|0)==0?R:R^41111;R=S<<1;T=(S&32768|0)==0?R:R^41111;R=T<<1;S=(T&32768|0)==0?R:R^41111;R=S<<1;T=a[O>>0]|0;V=T&255;W=((S&32768|0)==0?R:R^41111)^V<<8;R=W<<1;S=(W&32768|0)==0?R:R^41111;R=S<<1;W=(S&32768|0)==0?R:R^41111;R=W<<1;S=(W&32768|0)==0?R:R^41111;R=S<<1;W=(S&32768|0)==0?R:R^41111;R=W<<1;S=(W&32768|0)==0?R:R^41111;R=S<<1;W=(S&32768|0)==0?R:R^41111;R=W<<1;S=(W&32768|0)==0?R:R^41111;R=S<<1;X=(S&32768|0)==0?R:R^41111;Y=d[t>>0]|0;if((Y|0)!=(X&255|0)){H=40;break}Z=V&127;if(!(P<<24>>24==0)){P=2-(((T|q)&255)>>>7)|0;T=I?P|32768:P;P=0;do{if((dv(f,k,6)|0)!=0){break a}_=d[y>>0]|0;V=a[z>>0]|0;R=d[A>>0]|0;S=(V&255)<7;if(S){$=128<<(V&255)}else{$=0}aa=kt(d[k>>0]|0,d[w>>0]|0,_,$)|0;if((aa|0)==0){break a}yt(aa,a[z>>0]|0);if((Pt(n,aa,U,Z)|0)!=0){H=48;break b}tt(aa,T);if((R&2|0)!=0){st(aa,2,1)}if((R&4|0)!=0){st(aa,4,1)}V=a[J>>0]|0;W=0;ba=5;ca=k;while(1){da=d[ca>>0]<<8^W;ea=da<<1;fa=(da&32768|0)==0?ea:ea^41111;ea=fa<<1;da=(fa&32768|0)==0?ea:ea^41111;ea=da<<1;fa=(da&32768|0)==0?ea:ea^41111;ea=fa<<1;da=(fa&32768|0)==0?ea:ea^41111;ea=da<<1;fa=(da&32768|0)==0?ea:ea^41111;ea=fa<<1;da=(fa&32768|0)==0?ea:ea^41111;ea=da<<1;fa=(da&32768|0)==0?ea:ea^41111;ea=fa<<1;W=(fa&32768|0)==0?ea:ea^41111;ba=ba+ -1|0;if((ba|0)==0){break}else{ca=ca+1|0}}ga=V&255;ca=W&65535;if((R&48|0)==0){do{if(S){if((dv(f,k,3)|0)!=0){break a}ba=av(k,0)|0;if((ba|0)==0){H=63;break b}ea=ba+ -1|0;ha=a[y>>0]|0;if(ha<<24>>24==0){ba=aa+10|0;if((e[ba>>1]|0)!=(ea|0)){break a}if((dv(f,c[aa+24>>2]|0,ea)|0)==0){ia=ba;break}else{H=67;break b}}else if(ha<<24>>24==1){if((ea|0)!=4){break a}if((dv(f,j,4)|0)!=0){break a}ba=av(j,0)|0;fa=aa+10|0;if((ba<<1|0)!=(e[fa>>1]|0)){break a}if((ba|0)==0){ia=fa;break}da=aa+24|0;ja=0;while(1){ka=ja<<1;a[(c[da>>2]|0)+ka>>0]=a[K>>0]|0;a[(c[da>>2]|0)+(ka|1)>>0]=a[L>>0]|0;ka=ja+1|0;if((ka|0)==(ba|0)){ia=fa;break}else{ja=ka}}}else if(ha<<24>>24==2){ja=aa+10|0;if((ea|0)==0){la=0}else{fa=aa+24|0;ba=ea;da=0;while(1){if(ba>>>0<2){break a}if((dv(f,j,2)|0)!=0){break a}ka=ba+ -2|0;ma=a[j>>0]|0;if(ma<<24>>24==0){na=d[M>>0]|0;if(na>>>0>ka>>>0){break a}oa=na+da|0;if(oa>>>0>(e[ja>>1]|0)>>>0){break a}if((dv(f,(c[fa>>2]|0)+da|0,na)|0)!=0){break a}pa=ka-na|0;qa=oa}else if(ma<<24>>24==1){ma=a[M>>0]|0;oa=ma&255;if(ka>>>0<2){break a}ka=(oa<<1)+da|0;if(ka>>>0>(e[ja>>1]|0)>>>0){break a}if((dv(f,K,2)|0)!=0){break a}na=ba+ -4|0;if(ma<<24>>24==0){pa=na;qa=da}else{ma=da;ra=oa;while(1){a[(c[fa>>2]|0)+ma>>0]=a[K>>0]|0;a[(c[fa>>2]|0)+(ma+1)>>0]=a[L>>0]|0;oa=ra+ -1|0;if((oa|0)==0){pa=na;qa=ka;break}else{ma=ma+2|0;ra=oa}}}}else{break a}if((pa|0)==0){la=qa;break}else{ba=pa;da=qa}}}if(la>>>0<(e[ja>>1]|0)>>>0){break a}else{ia=ja;break}}else{H=90;break b}}else{ia=aa+10|0}}while(0);S=b[ia>>1]|0;if(S<<16>>16==0){sa=0;ta=ca;ua=ca}else{V=S&65535;S=c[aa+24>>2]|0;da=ca;ba=V;fa=S;while(1){ea=d[fa>>0]<<8^da;ra=ea<<1;ma=(ea&32768|0)==0?ra:ra^41111;ra=ma<<1;ea=(ma&32768|0)==0?ra:ra^41111;ra=ea<<1;ma=(ea&32768|0)==0?ra:ra^41111;ra=ma<<1;ea=(ma&32768|0)==0?ra:ra^41111;ra=ea<<1;ma=(ea&32768|0)==0?ra:ra^41111;ra=ma<<1;ea=(ma&32768|0)==0?ra:ra^41111;ra=ea<<1;ma=(ea&32768|0)==0?ra:ra^41111;ra=ma<<1;va=(ma&32768|0)==0?ra:ra^41111;ra=ba+ -1|0;if((ra|0)==0){wa=0;xa=V;ya=S;break}else{da=va;ba=ra;fa=fa+1|0}}while(1){fa=d[ya>>0]<<8^wa;ba=fa<<1;da=(fa&32768|0)==0?ba:ba^41111;ba=da<<1;fa=(da&32768|0)==0?ba:ba^41111;ba=fa<<1;da=(fa&32768|0)==0?ba:ba^41111;ba=da<<1;fa=(da&32768|0)==0?ba:ba^41111;ba=fa<<1;da=(fa&32768|0)==0?ba:ba^41111;ba=da<<1;fa=(da&32768|0)==0?ba:ba^41111;ba=fa<<1;da=(fa&32768|0)==0?ba:ba^41111;ba=da<<1;wa=(da&32768|0)==0?ba:ba^41111;xa=xa+ -1|0;if((xa|0)==0){break}else{ya=ya+1|0}}sa=wa;ta=va;ua=va&65535}if((ga|0)!=(sa&255|0)){fb(54080,33,1,N|0)|0;if((ga|0)!=(ta&255|0)){H=98;break b}}if((R&64|0)!=0){ba=e[aa+8>>1]|0;c[h>>2]=U;c[h+4>>2]=Z;c[h+8>>2]=ba;hb(N|0,54176,h|0)|0;Rt(n,aa);lt(aa)}}else{if((ga|0)!=(W&255|0)){H=57;break b}qt(aa,(R&16|0)!=0?246:0)}P=P+1|0}while(P>>>0<Q>>>0)}if((dv(f,l,1)|0)!=0){break a}}if((H|0)==40){L=c[o>>2]|0;c[h>>2]=Y;c[h+4>>2]=X&65535;hb(L|0,53920,h|0)|0;break}else if((H|0)==48){lt(aa);break}else if((H|0)==57){L=c[o>>2]|0;K=e[aa+8>>1]|0;c[h>>2]=U;c[h+4>>2]=Z;c[h+8>>2]=K;hb(L|0,53952,h|0)|0;break}else if((H|0)==63){L=c[o>>2]|0;c[h>>2]=U;c[h+4>>2]=Z;c[h+8>>2]=_;hb(L|0,54e3,h|0)|0;break}else if((H|0)==67){fb(54216,16,1,c[o>>2]|0)|0;break}else if((H|0)==90){L=c[o>>2]|0;c[h>>2]=U;c[h+4>>2]=Z;c[h+8>>2]=_;c[h+12>>2]=ha&255;hb(L|0,54040,h|0)|0;break}else if((H|0)==98){L=e[aa+8>>1]|0;c[h>>2]=U;c[h+4>>2]=Z;c[h+8>>2]=L;c[h+12>>2]=ga;c[h+16>>2]=sa&65535;c[h+20>>2]=ua;hb(N|0,54120,h|0)|0;break}else if((H|0)==103){i=g;return p|0}}}}}}}while(0);Lt(n);p=0;i=g;return p|0}function Uu(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0;h=i;i=i+32|0;j=h+24|0;k=h;l=h+8|0;m=h+4|0;n=b[g>>1]|0;do{if(n<<16>>16==0){o=0;p=0;q=16}else{r=c[g+4>>2]|0;s=n&65535;t=0;u=0;v=0;w=0;while(1){x=c[r+(t<<2)>>2]|0;y=b[x+2>>1]|0;z=y&65535;v=z>>>0>v>>>0?z:v;if(y<<16>>16==0){A=u;B=w}else{y=c[x+4>>2]|0;x=u;C=0;D=w;while(1){E=c[y+(C<<2)>>2]|0;F=b[E+2>>1]|0;G=F&65535;H=G>>>0>D>>>0?G:D;if(F<<16>>16==0){I=x}else{F=E+4|0;E=x;J=0;while(1){if((E|0)==0){K=e[(c[(c[F>>2]|0)+(J<<2)>>2]|0)+16>>1]|0}else{K=E}L=J+1|0;if((L|0)==(G|0)){I=K;break}else{E=K;J=L}}}J=C+1|0;if((J|0)==(z|0)){A=I;B=H;break}else{x=I;C=J;D=H}}}t=t+1|0;if((t|0)==(s|0)){break}else{u=A;w=B}}w=v&255;if((A|0)==32770){M=2;N=w;O=B;break}else if((A|0)==32769){M=-126;N=w;O=B;break}else if((A|0)==1){M=-128;N=w;O=B;break}else if((A|0)==2){M=0;N=w;O=B;break}else{o=w;p=B;q=16;break}}}while(0);if((q|0)==16){M=0;N=o;O=p}if((n&65535)<45){P=1}else{if(O>>>0<12){P=3}else{P=O>>>0<17?2:4}}a[l>>0]=84;O=l+1|0;a[O>>0]=68;n=l+2|0;a[n>>0]=0;p=l+3|0;a[p>>0]=0;o=l+4|0;a[o>>0]=21;B=l+5|0;a[B>>0]=M;M=l+6|0;a[M>>0]=P;P=l+7|0;a[P>>0]=0;A=l+8|0;a[A>>0]=0;I=l+9|0;a[I>>0]=N;N=g+8|0;if((c[N>>2]|0)==0){Q=0;R=9;S=84;T=l}else{a[P>>0]=-128;Q=0;R=9;S=84;T=l}while(1){K=Q^(S&255)<<8;w=K<<1;u=(K&32768|0)==0?w:w^41111;w=u<<1;K=(u&32768|0)==0?w:w^41111;w=K<<1;u=(K&32768|0)==0?w:w^41111;w=u<<1;K=(u&32768|0)==0?w:w^41111;w=K<<1;u=(K&32768|0)==0?w:w^41111;w=u<<1;K=(u&32768|0)==0?w:w^41111;w=K<<1;u=(K&32768|0)==0?w:w^41111;w=u<<1;U=(u&32768|0)==0?w:w^41111;w=T+1|0;if((R|0)==0){break}Q=U;R=R+ -1|0;S=a[w>>0]|0;T=w}cv(l,10,U&65535);if((fv(f,l,12)|0)!=0){V=1;i=h;return V|0}U=c[N>>2]|0;do{if((U|0)!=0){N=U>>>0>65535?65535:U;cv(l,2,N);c[k>>2]=gb(0)|0;T=_a(k|0)|0;a[o>>0]=c[T+20>>2];a[B>>0]=c[T+16>>2];a[M>>0]=c[T+12>>2];a[P>>0]=c[T+8>>2];a[A>>0]=c[T+4>>2];a[I>>0]=c[T>>2];T=yz(N)|0;if((T|0)==0){V=1;i=h;return V|0}S=(N|0)==0;if(S){W=0;X=8;Y=n}else{R=U>>>0<65535?U:65535;Q=c[g+12>>2]|0;w=0;while(1){u=a[Q+w>>0]|0;a[T+w>>0]=u<<24>>24==10?0:u;u=w+1|0;if((u|0)==(R|0)){W=0;X=8;Y=n;break}else{w=u}}}while(1){w=d[Y>>0]<<8^W;R=w<<1;Q=(w&32768|0)==0?R:R^41111;R=Q<<1;w=(Q&32768|0)==0?R:R^41111;R=w<<1;Q=(w&32768|0)==0?R:R^41111;R=Q<<1;w=(Q&32768|0)==0?R:R^41111;R=w<<1;Q=(w&32768|0)==0?R:R^41111;R=Q<<1;w=(Q&32768|0)==0?R:R^41111;R=w<<1;Q=(w&32768|0)==0?R:R^41111;R=Q<<1;W=(Q&32768|0)==0?R:R^41111;X=X+ -1|0;if((X|0)==0){break}else{Y=Y+1|0}}R=W&65535;a:do{if(S){Z=R}else{Q=R;w=N;v=T;while(1){u=d[v>>0]<<8^Q;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=w+ -1|0;if((K|0)==0){Z=u;break a}Q=u;w=K;v=v+1|0}}}while(0);cv(l,0,Z&65535);if((fv(f,l,10)|0)==0){R=fv(f,T,N)|0;zz(T);if((R|0)==0){break}else{V=1}i=h;return V|0}else{zz(T);V=1;i=h;return V|0}}}while(0);Z=b[g>>1]|0;b:do{if(!(Z<<16>>16==0)){W=g+4|0;Y=j+1|0;X=j+2|0;U=j+3|0;I=Z;A=0;c:while(1){P=c[(c[W>>2]|0)+(A<<2)>>2]|0;k=P+2|0;if((b[k>>1]|0)==0){_=I}else{R=P+4|0;P=A&255;S=A<<8&65280;v=0;do{w=c[(c[R>>2]|0)+(v<<2)>>2]|0;Q=w+2|0;K=b[Q>>1]|0;a[j>>0]=K;a[Y>>0]=P;a[X>>0]=v;u=K&255;K=u<<9;s=(u&128|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=((s&32768|0)==0?K:K^41111)^S;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=((s&32768|0)==0?K:K^41111)^v<<8&65280;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;u=(s&32768|0)==0?K:K^41111;K=u<<1;s=(u&32768|0)==0?K:K^41111;K=s<<1;a[U>>0]=(s&32768|0)==0?K:K^151;if((fv(f,j,4)|0)!=0){V=1;q=67;break c}K=w+4|0;if((b[Q>>1]|0)!=0){w=0;do{s=c[(c[K>>2]|0)+(w<<2)>>2]|0;u=s+10|0;t=e[u>>1]|0;if((t+65535&t|0)!=0){V=1;q=67;break c}a[l>>0]=b[s+4>>1];a[O>>0]=b[s+6>>1];a[n>>0]=b[s+8>>1];a[p>>0]=zt(s)|0;a[o>>0]=0;t=c[s+12>>2]|0;r=(t&2|0)==0?0:2;if((t&4|0)==0){$=r}else{$=(r&255|4)&255}a[o>>0]=$;r=s+24|0;s=b[u>>1]|0;if(s<<16>>16==0){aa=0}else{t=0;D=s&65535;s=c[r>>2]|0;while(1){C=d[s>>0]<<8^t;x=C<<1;z=(C&32768|0)==0?x:x^41111;x=z<<1;C=(z&32768|0)==0?x:x^41111;x=C<<1;z=(C&32768|0)==0?x:x^41111;x=z<<1;C=(z&32768|0)==0?x:x^41111;x=C<<1;z=(C&32768|0)==0?x:x^41111;x=z<<1;C=(z&32768|0)==0?x:x^41111;x=C<<1;z=(C&32768|0)==0?x:x^41111;x=z<<1;t=(z&32768|0)==0?x:x^41111;D=D+ -1|0;if((D|0)==0){break}else{s=s+1|0}}aa=t&255}a[B>>0]=aa;if((fv(f,l,6)|0)!=0){V=1;q=67;break c}d:do{if((d[p>>0]|0)<=6){s=b[u>>1]|0;e:do{if((s&1)!=0|(s&65535)<2){ba=s&65535}else{if((s&65535)>2){D=c[r>>2]|0;x=s&65535;z=2;do{C=z;z=z+1|0;if((a[D+C>>0]|0)!=(a[D+(C&1)>>0]|0)){ba=x;break e}}while(z>>>0<x>>>0)}cv(l,0,5);a[n>>0]=1;cv(l,3,(e[u>>1]|0)>>>1);x=c[r>>2]|0;a[B>>0]=a[x>>0]|0;a[M>>0]=a[x+1>>0]|0;if((fv(f,l,7)|0)==0){break d}else{V=1;q=67;break c}}}while(0);cv(l,0,ba+1|0);a[n>>0]=0;if((fv(f,l,3)|0)!=0){V=1;q=67;break c}if((fv(f,c[r>>2]|0,e[u>>1]|0)|0)!=0){V=1;q=67;break c}}}while(0);w=w+1|0}while(w>>>0<(e[Q>>1]|0)>>>0)}v=v+1|0}while(v>>>0<(e[k>>1]|0)>>>0);_=b[g>>1]|0}A=A+1|0;if(!(A>>>0<(_&65535)>>>0)){break b}else{I=_}}if((q|0)==67){i=h;return V|0}}}while(0);a[m>>0]=-1;a[m+1>>0]=0;a[m+2>>0]=0;a[m+3>>0]=53;if((fv(f,m,4)|0)!=0){V=1;i=h;return V|0}Nb(f|0)|0;V=0;i=h;return V|0}function Vu(b){b=b|0;var c=0,d=0,e=0,f=0;c=i;i=i+16|0;d=c;do{if((xb(b|0,0,0)|0)==0){if((dv(b,d,16)|0)==0){e=a[d>>0]|0;if(e<<24>>24==84){if((a[d+1>>0]|0)!=68){f=0;break}}else if(e<<24>>24==116){if((a[d+1>>0]|0)!=100){f=0;break}}else{f=0;break}f=(a[d+2>>0]|0)==0|0}else{f=0}}else{f=0}}while(0);i=c;return f|0}function Wu(a){a=a|0;var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;b=i;e=Kt()|0;if((e|0)==0){f=0;i=b;return f|0}a:do{if((c[54280>>2]|0)==0){g=7}else{h=0;while(1){j=c[54284>>2]|0;k=128<<(d[j+(h<<3)+2>>0]|0);l=j+(h<<3)|0;m=kt(0,d[l>>0]|0,d[j+(h<<3)+1>>0]|0,k)|0;if((m|0)==0){break a}tt(m,32770);if((Pt(e,m,0,d[l>>0]|0)|0)!=0){break a}l=h+1|0;if((ev(a,c[j+(h<<3)+4>>2]|0,c[m+24>>2]|0,k)|0)!=0){break a}if(l>>>0<(c[54280>>2]|0)>>>0){h=l}else{g=7;break}}}}while(0);b:do{if((g|0)==7){h=c[13568]|0;if(!(h>>>0>1)){f=e;i=b;return f|0}l=c[54276>>2]|0;k=c[54288>>2]|0;m=h;h=l;j=1;n=l;while(1){if((k|0)==0){o=h;p=m;q=0}else{l=0;do{r=c[54292>>2]|0;s=128<<(d[r+(l<<3)+2>>0]|0);t=r+(l<<3)|0;u=kt(j,d[t>>0]|0,d[r+(l<<3)+1>>0]|0,s)|0;if((u|0)==0){break b}tt(u,32770);if((Pt(e,u,j,d[t>>0]|0)|0)!=0){break b}t=l;l=l+1|0;if((ev(a,(c[r+(t<<3)+4>>2]|0)+n|0,c[u+24>>2]|0,s)|0)!=0){break b}v=c[54288>>2]|0}while(l>>>0<v>>>0);o=c[54276>>2]|0;p=c[13568]|0;q=v}l=j+1|0;if(l>>>0<p>>>0){k=q;m=p;h=o;j=l;n=o+n|0}else{f=e;break}}i=b;return f|0}}while(0);Lt(e);f=0;i=b;return f|0}function Xu(a,b){a=a|0;b=b|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;a:do{if((c[54280>>2]|0)!=0){g=0;while(1){h=c[54284>>2]|0;j=128<<(d[h+(g<<3)+2>>0]|0);k=St(b,0,d[h+(g<<3)>>0]|0,d[h+(g<<3)+1>>0]|0,0)|0;if((k|0)==0){l=1;m=15;break}if((e[k+10>>1]|0|0)!=(j|0)){l=1;m=15;break}n=g;g=g+1|0;if((gv(a,c[h+(n<<3)+4>>2]|0,c[k+24>>2]|0,j)|0)!=0){l=1;m=15;break}if(!(g>>>0<(c[54280>>2]|0)>>>0)){break a}}if((m|0)==15){i=f;return l|0}}}while(0);g=c[13568]|0;if(!(g>>>0>1)){l=0;i=f;return l|0}j=c[54276>>2]|0;k=c[54288>>2]|0;n=g;g=j;h=1;o=j;b:while(1){if((k|0)==0){p=g;q=n;r=0}else{j=0;do{s=c[54292>>2]|0;t=128<<(d[s+(j<<3)+2>>0]|0);u=St(b,h,d[s+(j<<3)>>0]|0,d[s+(j<<3)+1>>0]|0,0)|0;if((u|0)==0){l=1;m=15;break b}if((e[u+10>>1]|0|0)!=(t|0)){l=1;m=15;break b}v=j;j=j+1|0;if((gv(a,(c[s+(v<<3)+4>>2]|0)+o|0,c[u+24>>2]|0,t)|0)!=0){l=1;m=15;break b}w=c[54288>>2]|0}while(j>>>0<w>>>0);p=c[54276>>2]|0;q=c[13568]|0;r=w}j=h+1|0;if(j>>>0<q>>>0){k=r;n=q;g=p;h=j;o=p+o|0}else{l=0;m=15;break}}if((m|0)==15){i=f;return l|0}return 0}function Yu(a,b){a=a|0;b=b|0;return(d[a+b>>0]|0)<<8|(d[a+(b+1)>>0]|0)|0}function Zu(a,b){a=a|0;b=b|0;return(((d[a+b>>0]|0)<<8|(d[a+(b+1)>>0]|0))<<8|(d[a+(b+2)>>0]|0))<<8|(d[a+(b+3)>>0]|0)|0}function _u(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c>>0]=d>>>8;a[b+(c+1)>>0]=d;return}function $u(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c>>0]=d>>>24;a[b+(c+1)>>0]=d>>>16;a[b+(c+2)>>0]=d>>>8;a[b+(c+3)>>0]=d;return}function av(a,b){a=a|0;b=b|0;return(d[a+(b+1)>>0]|0)<<8|(d[a+b>>0]|0)|0}function bv(a,b){a=a|0;b=b|0;return(((d[a+(b+3)>>0]|0)<<8|(d[a+(b+2)>>0]|0))<<8|(d[a+(b+1)>>0]|0))<<8|(d[a+b>>0]|0)|0}function cv(b,c,d){b=b|0;c=c|0;d=d|0;a[b+c>>0]=d;a[b+(c+1)>>0]=d>>>8;return}function dv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=(ta(b|0,1,c|0,a|0)|0)!=(c|0)|0;i=d;return e|0}function ev(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;if((xb(a|0,b|0,0)|0)!=0){f=1;i=e;return f|0}f=(ta(c|0,1,d|0,a|0)|0)!=(d|0)|0;i=e;return f|0}function fv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=i;e=(fb(b|0,1,c|0,a|0)|0)!=(c|0)|0;i=d;return e|0}function gv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=i;if((xb(a|0,b|0,0)|0)!=0){f=1;i=e;return f|0}f=(fb(c|0,1,d|0,a|0)|0)!=(d|0)|0;i=e;return f|0}function hv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=i;i=i+256|0;d=c;a:do{if((b|0)==0){e=0}else{f=b;while(1){g=f>>>0<256?f:256;if((ta(d|0,1,g|0,a|0)|0)!=(g|0)){e=1;break a}if((f|0)==(g|0)){e=0;break}else{f=f-g|0}}}}while(0);i=c;return e|0}function iv(a){a=a|0;var b=0,d=0,e=0;b=i;d=a+0|0;e=d+48|0;do{c[d>>2]=0;d=d+4|0}while((d|0)<(e|0));c[a>>2]=8192;i=b;return}function jv(a){a=a|0;var b=0,d=0;b=i;d=a+24|0;c[d+0>>2]=0;c[d+4>>2]=0;c[d+8>>2]=0;c[d+12>>2]=0;c[d+16>>2]=0;c[d+20>>2]=0;i=b;return}function kv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0.0,k=0.0;e=i;f=a+0|0;g=f+48|0;do{c[f>>2]=0;f=f+4|0}while((f|0)<(g|0));c[a>>2]=8192;if((b|0)==0|(d|0)==0){i=e;return}if(b<<1>>>0<d>>>0){h=b}else{h=(d>>>1)+ -1|0}j=1.0/+W(+(+(h>>>0)*3.141592653589793/+(d>>>0)));k=j*(j+1.4142135623730951)+1.0;d=~~(8192.0/k);c[a>>2]=d;c[a+4>>2]=~~(16384.0/k);c[a+8>>2]=d;c[a+12>>2]=8192;c[a+16>>2]=~~((1.0-j*j)*16384.0/k);c[a+20>>2]=~~((j*(j+-1.4142135623730951)+1.0)*8192.0/k);i=e;return}function lv(a,d,f,g,h,j){a=a|0;d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;k=i;if((g|0)==0){i=k;return}l=(j|0)!=0?32768:0;j=a+28|0;m=a+24|0;n=a+40|0;o=a+36|0;p=c[a>>2]|0;q=c[a+4>>2]|0;r=c[a+8>>2]|0;s=c[a+16>>2]|0;t=c[a+20>>2]|0;u=f;f=g;g=d;d=c[m>>2]|0;v=c[j>>2]|0;w=c[o>>2]|0;x=c[n>>2]|0;while(1){y=((e[u>>1]|0)^l)+ -32768|0;z=((ca(d,q)|0)+(ca(y,p)|0)+(ca(v,r)|0)-(ca(w,s)|0)-(ca(x,t)|0)|0)/8192|0;A=z+32768|0;if((A|0)<0){B=0}else{B=(A|0)>65535?65535:A&65535}b[g>>1]=B^l;f=f+ -1|0;if((f|0)==0){break}else{A=w;C=d;u=u+(h<<1)|0;g=g+(h<<1)|0;d=y;w=z;x=A;v=C}}c[j>>2]=d;c[a+32>>2]=v;c[m>>2]=y;c[n>>2]=w;c[a+44>>2]=x;c[o>>2]=z;i=k;return}function mv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0;d=i;e=a+788|0;f=a+792|0;a=c[f>>2]|0;if((c[e>>2]|0)>>>0<b>>>0){g=Az(a,b)|0;if((g|0)==0){h=0}else{c[f>>2]=g;c[e>>2]=b;h=g}}else{h=a}i=d;return h|0}function nv(c,d,e,f,g){c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=i;j=(f|0)!=0?-32768:0;f=(e|0)==0;if((g|0)==0){if(f){i=h;return}else{k=d;l=c;m=0}while(1){g=b[k>>1]|0;a[l>>0]=g;a[l+1>>0]=((g^j)&65535)>>>8;m=m+1|0;if((m|0)==(e|0)){break}else{k=k+2|0;l=l+2|0}}i=h;return}else{if(f){i=h;return}else{n=c;o=d;p=0}while(1){d=b[o>>1]|0;a[n>>0]=((d^j)&65535)>>>8;a[n+1>>0]=d;p=p+1|0;if((p|0)==(e|0)){break}else{n=n+2|0;o=o+2|0}}i=h;return}}function ov(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;c[b>>2]=d;d=b+4|0;f=b+788|0;g=b+812|0;c[d+0>>2]=0;c[d+4>>2]=0;c[d+8>>2]=0;c[d+12>>2]=0;c[f+0>>2]=0;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=0;c[f+16>>2]=0;c[f+20>>2]=0;a[g>>0]=1;c[b+816>>2]=0;c[b+820>>2]=0;c[b+824>>2]=0;i=e;return}function pv(a){a=a|0;var b=0,d=0;b=i;if((a|0)==0){i=b;return}Cv(a);d=c[a+816>>2]|0;if((d|0)!=0){ic[d&511](a)}d=c[a+800>>2]|0;if((d|0)!=0){zz(d)}d=c[a+792>>2]|0;if((d|0)==0){i=b;return}zz(d);i=b;return}function qv(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=i;if((b|0)==0){g=1;i=f;return g|0}h=b+820|0;if((c[h>>2]|0)==0){g=1;i=f;return g|0}do{if((c[b+16>>2]|0)==0){j=d}else{k=b+4|0;l=ca(c[k>>2]|0,e)|0;m=b+796|0;n=b+800|0;o=c[n>>2]|0;if((c[m>>2]|0)>>>0<l>>>0){p=Az(o,l<<1)|0;if((p|0)==0){j=0;break}c[n>>2]=p;c[m>>2]=l;q=p}else{q=o}if((q|0)==0){j=0}else{o=c[k>>2]|0;if((o|0)==0){j=q}else{p=b+12|0;l=o;o=0;while(1){lv(b+(o*48|0)+20|0,q+(o<<1)|0,d+(o<<1)|0,e,l,c[p>>2]|0);m=o+1|0;n=c[k>>2]|0;if(m>>>0<n>>>0){l=n;o=m}else{j=q;break}}}}}}while(0);q=gc[c[h>>2]&63](b,j,e)|0;Ev(b,(a[b+812>>0]|0)!=0?j:d,e)|0;g=q;i=f;return g|0}function rv(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;do{if((a|0)==0){g=1}else{h=c[a+824>>2]|0;if((h|0)==0){g=1}else{j=(e|0)!=0|0;if(b>>>0>16){g=1}else{k=a+4|0;if((c[k>>2]|0)==(b|0)){if((c[a+8>>2]|0)==(d|0)){if((c[a+12>>2]|0)==(j|0)){g=0;break}}}if((nc[h&63](a,b,d,j)|0)==0){c[k>>2]=b;h=a+8|0;c[h>>2]=d;c[a+12>>2]=j;if((Fv(a,b,d,j)|0)==0){if((c[k>>2]|0)==0){g=0}else{j=a+16|0;l=0;while(1){m=a+(l*48|0)+20|0;kv(m,c[j>>2]|0,c[h>>2]|0);jv(m);m=l+1|0;if(m>>>0<(c[k>>2]|0)>>>0){l=m}else{g=0;break}}}}else{g=1}}else{g=1}}}}}while(0);i=f;return g|0}function sv(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=i;e=0;while(1){f=c[54664+(e<<3)>>2]|0;g=a[f>>0]|0;a:do{if(g<<24>>24==0){h=b;j=6}else{k=g;l=f;m=b;while(1){if(!(k<<24>>24==(a[m>>0]|0))){break}n=l+1|0;o=m+1|0;p=a[n>>0]|0;if(p<<24>>24==0){h=o;j=6;break a}else{k=p;l=n;m=o}}if(k<<24>>24==0){h=m;j=6}}}while(0);if((j|0)==6){j=0;f=a[h>>0]|0;if(f<<24>>24==0|f<<24>>24==58){break}}f=e+1|0;if((f|0)==3){q=0;j=19;break}else{e=f}}if((j|0)==19){i=d;return q|0}j=kc[c[54668+(e<<3)>>2]&15](b)|0;if((j|0)==0){q=0;i=d;return q|0}if((Gv(j,b)|0)==0){a[j+812>>0]=Iv(b,54696,1)|0;e=Jv(b,54712,0)|0;b=j+16|0;c[b>>2]=e;h=j+4|0;if((c[h>>2]|0)==0){q=j;i=d;return q|0}f=j+8|0;g=j+20|0;kv(g,e,c[f>>2]|0);jv(g);if((c[h>>2]|0)>>>0>1){r=1}else{q=j;i=d;return q|0}while(1){g=j+(r*48|0)+20|0;kv(g,c[b>>2]|0,c[f>>2]|0);jv(g);g=r+1|0;if(g>>>0<(c[h>>2]|0)>>>0){r=g}else{q=j;break}}i=d;return q|0}Cv(j);r=c[j+816>>2]|0;if((r|0)!=0){ic[r&511](j)}r=c[j+800>>2]|0;if((r|0)!=0){zz(r)}r=c[j+792>>2]|0;if((r|0)==0){q=0;i=d;return q|0}zz(r);q=0;i=d;return q|0}function tv(a){a=a|0;var b=0,d=0;a=i;b=yz(828)|0;if((b|0)==0){d=0;i=a;return d|0}ov(b,b);c[b+816>>2]=247;c[b+820>>2]=42;c[b+824>>2]=28;d=b;i=a;return d|0}function uv(a){a=a|0;var b=0;b=i;zz(c[a>>2]|0);i=b;return}function vv(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function wv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return 0}function xv(b){b=b|0;var d=0,e=0,f=0;b=i;d=yz(856)|0;if((d|0)==0){e=0;i=b;return e|0}ov(d,d);c[d+816>>2]=248;c[d+820>>2]=43;c[d+824>>2]=29;a[d+828>>0]=0;a[d+829>>0]=1;f=d+840|0;c[f+0>>2]=0;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=0;e=d;i=b;return e|0}function yv(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;e=c[b>>2]|0;if((a[e+828>>0]|0)!=0){Lb()}b=c[e+844>>2]|0;if((b|0)!=0){f=b;do{b=f;f=c[f>>2]|0;zz(c[b+16>>2]|0);zz(b)}while((f|0)!=0)}f=c[e+852>>2]|0;if((f|0)==0){zz(e);i=d;return}else{g=f}do{f=g;g=c[g>>2]|0;zz(c[f+16>>2]|0);zz(f)}while((g|0)!=0);zz(e);i=d;return}function zv(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;g=c[b>>2]|0;h=ca(c[b+4>>2]|0,e)|0;e=h<<1;Ta();j=g+852|0;k=c[j>>2]|0;if((k|0)==0){l=g+840|0;m=c[l>>2]|0;if(!(m>>>0>32)){n=yz(20)|0;if((n|0)!=0){c[n+12>>2]=0;c[n+16>>2]=0;c[l>>2]=m+1;o=n;p=6}}}else{c[j>>2]=c[k>>2];o=k;p=6}a:do{if((p|0)==6){c[o>>2]=0;k=o+4|0;c[k>>2]=0;j=o+8|0;c[j>>2]=0;n=o+12|0;do{if((c[n>>2]|0)>>>0<e>>>0){m=o+16|0;l=Az(c[m>>2]|0,e)|0;if((l|0)==0){zz(c[m>>2]|0);zz(o);q=g+840|0;c[q>>2]=(c[q>>2]|0)+ -1;break a}else{c[n>>2]=e;c[m>>2]=l;break}}}while(0);Jb();if((o|0)==0){r=1;i=f;return r|0}nv(c[o+16>>2]|0,d,h,(c[b+12>>2]|0)!=(c[g+832>>2]|0)|0,c[g+836>>2]|0);c[k>>2]=0;c[j>>2]=e;Ta();n=g+848|0;l=c[n>>2]|0;if((l|0)==0){c[g+844>>2]=o}else{c[l>>2]=o}c[n>>2]=o;Jb();n=g+829|0;if((a[n>>0]|0)==0){r=0;i=f;return r|0}ua(0);a[n>>0]=0;r=0;i=f;return r|0}}while(0);Jb();r=1;i=f;return r|0}function Av(d,e,f,g){d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0;g=i;i=i+32|0;h=g;j=g+8|0;k=c[d>>2]|0;if((Oa(16)|0)==0){if((Ha(16)|0)<0){d=c[o>>2]|0;c[h>>2]=ya()|0;hb(d|0,54744,h|0)|0;l=1;i=g;return l|0}}d=k+828|0;if((a[d>>0]|0)!=0){Lb();a[d>>0]=0}c[j>>2]=f;b[j+4>>1]=-32752;a[j+6>>0]=e;b[j+8>>1]=1024;c[j+16>>2]=19;c[j+20>>2]=k;if((Ba(j|0,0)|0)<0){j=c[o>>2]|0;c[h>>2]=ya()|0;hb(j|0,54800,h|0)|0;l=1;i=g;return l|0}else{ua(1);a[d>>0]=1;a[k+829>>0]=1;c[k+832>>2]=1;c[k+836>>2]=0;l=0;i=g;return l|0}return 0}function Bv(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;g=b+844|0;if((c[g>>2]|0)==0){ua(1);a[b+829>>0]=1;i=f;return}if((e|0)<=0){i=f;return}h=b+848|0;j=b+852|0;b=d;d=e;while(1){e=c[g>>2]|0;if((e|0)==0){k=6;break}l=e+4|0;m=c[l>>2]|0;n=(c[e+8>>2]|0)-m|0;o=(c[e+16>>2]|0)+m|0;if((n|0)>(d|0)){k=11;break}Mz(b|0,o|0,n|0)|0;m=d-n|0;p=c[e>>2]|0;c[g>>2]=p;if((p|0)==0){c[h>>2]=0}c[e>>2]=c[j>>2];c[j>>2]=e;if((m|0)>0){b=b+n|0;d=m}else{k=12;break}}if((k|0)==6){Oz(b|0,0,d|0)|0;i=f;return}else if((k|0)==11){Mz(b|0,o|0,d|0)|0;c[l>>2]=(c[l>>2]|0)+d;i=f;return}else if((k|0)==12){i=f;return}}function Cv(a){a=a|0;var b=0;b=i;if((c[a+804>>2]|0)==0){i=b;return}Dv(a)|0;i=b;return}function Dv(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0;d=i;i=i+64|0;e=d;f=b+804|0;if((xb(c[f>>2]|0,0,0)|0)!=0){g=1;i=d;return g|0}a[e>>0]=82;a[e+1>>0]=73;a[e+2>>0]=70;a[e+3>>0]=70;h=b+808|0;j=(c[h>>2]|0)+36|0;a[e+4>>0]=j;a[e+5>>0]=j>>>8;a[e+6>>0]=j>>>16;a[e+7>>0]=j>>>24;a[e+8>>0]=87;a[e+9>>0]=65;a[e+10>>0]=86;a[e+11>>0]=69;a[e+12>>0]=102;a[e+13>>0]=109;a[e+14>>0]=116;a[e+15>>0]=32;a[e+16>>0]=16;a[e+17>>0]=0;a[e+18>>0]=0;a[e+19>>0]=0;a[e+20>>0]=1;a[e+21>>0]=0;j=c[b+4>>2]|0;a[e+22>>0]=j;a[e+23>>0]=j>>>8;k=c[b+8>>2]|0;a[e+24>>0]=k;a[e+25>>0]=k>>>8;a[e+26>>0]=k>>>16;a[e+27>>0]=k>>>24;b=j<<1;l=ca(b,k)|0;a[e+28>>0]=l;a[e+29>>0]=l>>>8;a[e+30>>0]=l>>>16;a[e+31>>0]=l>>>24;a[e+32>>0]=b;a[e+33>>0]=j>>>7;a[e+34>>0]=16;a[e+35>>0]=0;a[e+36>>0]=100;a[e+37>>0]=97;a[e+38>>0]=116;a[e+39>>0]=97;j=c[h>>2]|0;a[e+40>>0]=j;a[e+41>>0]=j>>>8;a[e+42>>0]=j>>>16;a[e+43>>0]=j>>>24;if((fb(e|0,1,44,c[f>>2]|0)|0)!=44){g=1;i=d;return g|0}g=(xb(c[f>>2]|0,(c[h>>2]|0)+44|0,0)|0)!=0|0;i=d;return g|0}function Ev(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0;e=i;f=a+804|0;if((c[f>>2]|0)==0){g=0;i=e;return g|0}h=ca(c[a+4>>2]|0,d)|0;d=h<<1;j=mv(a,d)|0;if((b|0)==0){g=1;i=e;return g|0}nv(j,b,h,(c[a+12>>2]|0)==0|0,0);if((fb(j|0,1,d|0,c[f>>2]|0)|0)!=(d|0)){g=1;i=e;return g|0}f=a+808|0;c[f>>2]=(c[f>>2]|0)+d;g=0;i=e;return g|0}function Fv(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0;e=i;if((c[a+804>>2]|0)==0){f=0;i=e;return f|0}f=(Dv(a)|0)!=0|0;i=e;return f|0}function Gv(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;f=b+804|0;c[f>>2]=0;c[b+808>>2]=0;b=Hv(d,54840)|0;if((b|0)==0){g=0;i=e;return g|0}if((a[b>>0]|0)==0){g=0;i=e;return g|0}c[f>>2]=Ib(b|0,54848)|0;zz(b);g=(c[f>>2]|0)==0|0;i=e;return g|0}function Hv(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;d=i;if((b|0)==0){e=0;i=d;return e|0}f=a[c>>0]|0;a:do{if(f<<24>>24==0){g=b;b:while(1){h=g;while(1){j=a[h>>0]|0;if(!(j<<24>>24==9|j<<24>>24==32)){k=h;l=j;break}h=h+1|0}while(1){if(l<<24>>24==61){m=k;break a}else if(!(l<<24>>24==9|l<<24>>24==32)){break}h=k+1|0;k=h;l=a[h>>0]|0}h=a[g>>0]|0;if(h<<24>>24==0){e=0;n=42;break}else{o=g;p=h}while(1){h=o+1|0;if(p<<24>>24==58){if((a[h>>0]|0)!=58){g=h;continue b}q=o+2|0}else{q=h}h=a[q>>0]|0;if(h<<24>>24==0){e=0;n=42;break b}else{o=q;p=h}}}if((n|0)==42){i=d;return e|0}}else{g=b;c:while(1){h=g;while(1){r=a[h>>0]|0;if(!(r<<24>>24==9|r<<24>>24==32)){break}h=h+1|0}d:do{if(r<<24>>24==f<<24>>24){j=h;s=c;while(1){j=j+1|0;s=s+1|0;t=a[s>>0]|0;if(t<<24>>24==0){u=j;break}if(!((a[j>>0]|0)==t<<24>>24)){break d}}while(1){j=a[u>>0]|0;if(j<<24>>24==61){m=u;break a}else if(!(j<<24>>24==9|j<<24>>24==32)){break d}u=u+1|0}}}while(0);h=a[g>>0]|0;if(h<<24>>24==0){e=0;n=42;break}else{v=g;w=h}while(1){h=v+1|0;if(w<<24>>24==58){if((a[h>>0]|0)!=58){g=h;continue c}x=v+2|0}else{x=h}h=a[x>>0]|0;if(h<<24>>24==0){e=0;n=42;break c}else{v=x;w=h}}}if((n|0)==42){i=d;return e|0}}}while(0);while(1){w=m+1|0;y=a[w>>0]|0;if(y<<24>>24==0){z=0;break}else if(y<<24>>24==9|y<<24>>24==32){m=w}else{A=y;B=0;n=23;break}}e:do{if((n|0)==23){while(1){n=0;w=B+1|0;if(A<<24>>24==58){x=B+2|0;if((a[m+x>>0]|0)==58){C=x}else{D=B;break}}else{C=w}w=a[m+(C+1)>>0]|0;if(w<<24>>24==0){D=C;break}else{A=w;B=C;n=23}}if((D|0)==0){z=0}else{w=D;while(1){x=w+ -1|0;v=a[m+w>>0]|0;if(!(v<<24>>24==9|v<<24>>24==32)){z=w;break e}if((x|0)==0){z=0;break}else{w=x}}}}}while(0);D=yz(z+1|0)|0;if((D|0)==0){e=0;i=d;return e|0}f:do{if((z|0)==0){E=0}else{C=y;B=0;A=0;while(1){w=B+1|0;if(C<<24>>24==58){x=B+2|0;if((a[m+x>>0]|0)==58){a[D+A>>0]=58;F=x}else{n=33}}else{n=33}if((n|0)==33){n=0;a[D+A>>0]=C;F=w}w=A+1|0;if(!(F>>>0<z>>>0)){E=w;break f}C=a[m+(F+1)>>0]|0;B=F;A=w}}}while(0);a[D+E>>0]=0;e=D;i=d;return e|0}function Iv(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=i;e=Hv(a,b)|0;if((e|0)==0){f=c;i=d;return f|0}if((Fz(e,54856)|0)==0){g=1}else{if((Fz(e,54864)|0)==0){g=1}else{if((Fz(e,54872)|0)==0){g=1}else{if((Fz(e,54880)|0)==0){g=0}else{if((Fz(e,54888)|0)==0){g=0}else{b=(Fz(e,54896)|0)==0;g=b?0:c}}}}}zz(e);f=g;i=d;return f|0}function Jv(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f;h=Hv(b,d)|0;do{if((h|0)==0){j=e}else{d=Hb(h|0,g|0,0)|0;b=c[g>>2]|0;if((b|0)!=0){if((a[b>>0]|0)!=0){zz(h);j=e;break}}zz(h);j=d}}while(0);i=f;return j|0}function Kv(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0;f=i;i=i+16|0;g=f;h=Hv(b,d)|0;do{if((h|0)==0){j=e}else{d=Va(h|0,g|0,0)|0;b=c[g>>2]|0;if((b|0)!=0){if((a[b>>0]|0)!=0){zz(h);j=e;break}}zz(h);j=d}}while(0);i=f;return j|0}function Lv(a){a=a|0;var b=0,d=0,e=0,f=0;b=i;d=yz(36)|0;if((d|0)==0){e=0;i=b;return e|0}c[d>>2]=1;f=d+4|0;c[f+0>>2]=0;c[f+4>>2]=0;c[f+8>>2]=0;c[f+12>>2]=0;c[f+16>>2]=0;c[f>>2]=249;c[d+8>>2]=44;c[d+12>>2]=167;c[d+24>>2]=0;c[d+28>>2]=a;e=d;i=b;return e|0}function Mv(a){a=a|0;var b=0;b=i;zz(a);i=b;return}function Nv(a,b,d){a=a|0;b=b|0;d=d|0;return(c[a+28>>2]|0)==((b<<4)+d|0)|0}function Ov(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;b=i;i=i+16|0;d=b;e=c[a+16>>2]|0;f=c[a+20>>2]|0;c[d>>2]=c[a+28>>2];c[d+4>>2]=e;c[d+8>>2]=f;$a(55096,d|0)|0;i=b;return}function Pv(a){a=a|0;var b=0;b=i;zz(a);i=b;return}function Qv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0;e=i;if((c[a+24>>2]|0)==(b|0)){if((c[a+28>>2]|0)==(d|0)){f=1;i=e;return f|0}}f=0;i=e;return f|0}function Rv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;b=i;i=i+16|0;d=b;e=c[a+28>>2]|0;f=c[a+16>>2]|0;g=c[a+20>>2]|0;c[d>>2]=c[a+24>>2];c[d+4>>2]=e;c[d+8>>2]=f;c[d+12>>2]=g;$a(55064,d|0)|0;i=b;return}function Sv(a){a=a|0;var b=0;b=i;zz(c[a+32>>2]|0);zz(a);i=b;return}function Tv(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;d=i;i=i+272|0;b=d+260|0;e=d;Zv(e,c[a+32>>2]|0);a=(iw(e,b)|0)!=0;i=d;return a&(c[b>>2]|0)!=0&1|0}function Uv(a,b){a=a|0;b=b|0;var d=0;b=i;i=i+16|0;d=b;c[d>>2]=c[a+32>>2];$a(55048,d|0)|0;i=b;return}function Vv(a){a=a|0;c[a>>2]=0;c[a+4>>2]=0;return}function Wv(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;d=i;e=a+4|0;f=Az(c[e>>2]|0,(c[a>>2]<<2)+4|0)|0;if((f|0)==0){g=1;i=d;return g|0}c[e>>2]=f;e=c[a>>2]|0;c[f+(e<<2)>>2]=b;c[a>>2]=e+1;g=0;i=d;return g|0}function Xv(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;if((c[a>>2]|0)==0){g=0;i=f;return g|0}h=a+4|0;j=0;while(1){k=c[(c[h>>2]|0)+(j<<2)>>2]|0;l=c[k+8>>2]|0;if((l|0)!=0){if((gc[l&63](k,b,d)|0)!=0){m=k+16|0;l=c[m>>2]|0;if((l|0)==0){break}n=l+ -1|0;c[m>>2]=n;if((n|0)==0){break}}}n=j+1|0;if(n>>>0<(c[a>>2]|0)>>>0){j=n}else{g=0;o=24;break}}if((o|0)==24){i=f;return g|0}d=c[k+20>>2]|0;if((d|0)!=0){c[m>>2]=d}d=c[(c[h>>2]|0)+(j<<2)>>2]|0;if((d|0)==0){g=0;i=f;return g|0}j=c[d+12>>2]|0;if((j|0)!=0){jc[j&255](d,e)}if((c[d+16>>2]|0)!=0){g=1;i=f;return g|0}e=c[a>>2]|0;if((e|0)==0){g=1;i=f;return g|0}j=c[h>>2]|0;m=0;while(1){p=m+1|0;if((c[j+(m<<2)>>2]|0)==(d|0)){break}if(p>>>0<e>>>0){m=p}else{g=1;o=24;break}}if((o|0)==24){i=f;return g|0}o=c[d+4>>2]|0;if((o|0)==0){zz(d)}else{ic[o&511](d)}d=c[a>>2]|0;if(p>>>0<d>>>0){o=m;m=p;while(1){p=c[h>>2]|0;c[p+(o<<2)>>2]=c[p+(m<<2)>>2];p=m+1|0;if((p|0)==(d|0)){break}else{e=m;m=p;o=e}}}c[a>>2]=d+ -1;g=1;i=f;return g|0}function Yv(a,d){a=a|0;d=d|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+272|0;g=f;h=f+10|0;j=f+8|0;k=f+6|0;l=f+4|0;m=f+16|0;if((fw(a,54912)|0)!=0){if((ew(a)|0)==0){i=f;return}n=c[q>>2]|0;if((c[d>>2]|0)!=0){o=d+4|0;p=0;do{c[g>>2]=p;hb(n|0,54904,g|0)|0;r=c[(c[o>>2]|0)+(p<<2)>>2]|0;s=c[r+12>>2]|0;if((s|0)!=0){jc[s&255](r,n)}p=p+1|0}while(p>>>0<(c[d>>2]|0)>>>0)}Nb(n|0)|0;i=f;return}if((fw(a,54920)|0)==0){if((fw(a,54928)|0)==0){aw(a,54936);i=f;return}if((dw(a)|0)!=0){n=d+4|0;p=c[n>>2]|0;if((c[d>>2]|0)==0){t=p}else{o=p;p=0;while(1){r=c[o+(p<<2)>>2]|0;s=c[r+4>>2]|0;if((s|0)==0){zz(r)}else{ic[s&511](r)}r=p+1|0;s=c[n>>2]|0;if(r>>>0<(c[d>>2]|0)>>>0){o=s;p=r}else{t=s;break}}}zz(t);c[d>>2]=0;c[n>>2]=0;i=f;return}if((hw(a,g)|0)!=0){n=d+4|0;do{t=e[g>>1]|0;if((c[d>>2]|0)>>>0>t>>>0){p=c[(c[n>>2]|0)+(t<<2)>>2]|0;o=c[p+4>>2]|0;if((o|0)==0){zz(p)}else{ic[o&511](p)}p=t+1|0;o=c[d>>2]|0;if(p>>>0<o>>>0){s=t;t=p;while(1){p=c[n>>2]|0;c[p+(s<<2)>>2]=c[p+(t<<2)>>2];p=t+1|0;if((p|0)==(o|0)){break}else{r=t;t=p;s=r}}}c[d>>2]=o+ -1}}while((hw(a,g)|0)!=0)}ew(a)|0;i=f;return}if((fw(a,54960)|0)!=0){b[k>>1]=1;b[l>>1]=0;if((cw(a,m,256)|0)==0){aw(a,55024);i=f;return}hw(a,k)|0;hw(a,l)|0;if((ew(a)|0)==0){i=f;return}n=b[k>>1]|0;if(n<<16>>16==0){i=f;return}s=yz(36)|0;if((s|0)==0){u=0;v=n}else{c[s>>2]=3;n=s+4|0;c[n+0>>2]=0;c[n+4>>2]=0;c[n+8>>2]=0;c[n+12>>2]=0;c[n+16>>2]=0;c[n>>2]=250;c[s+8>>2]=45;c[s+12>>2]=168;c[s+32>>2]=xz(m)|0;u=s;v=b[k>>1]|0}k=e[l>>1]|0;c[u+16>>2]=v&65535;c[u+20>>2]=k;k=c[u+12>>2]|0;if((k|0)!=0){jc[k&255](u,c[q>>2]|0)}k=d+4|0;v=Az(c[k>>2]|0,(c[d>>2]<<2)+4|0)|0;if((v|0)==0){i=f;return}c[k>>2]=v;k=c[d>>2]|0;c[v+(k<<2)>>2]=u;c[d>>2]=k+1;i=f;return}b[h>>1]=1;b[j>>1]=0;c[g>>2]=0;if((iw(a,g)|0)==0){aw(a,54968);i=f;return}do{if((fw(a,54992)|0)==0){w=0;x=0}else{k=c[g>>2]|0;if((iw(a,g)|0)!=0){w=1;x=k&65535;break}aw(a,55e3);i=f;return}}while(0);hw(a,h)|0;hw(a,j)|0;if((ew(a)|0)==0){i=f;return}a=b[h>>1]|0;if(a<<16>>16==0){i=f;return}h=c[g>>2]|0;g=yz(36)|0;k=(g|0)==0;if((w|0)==0){if(k){y=0}else{c[g>>2]=1;w=g+4|0;c[w+0>>2]=0;c[w+4>>2]=0;c[w+8>>2]=0;c[w+12>>2]=0;c[w+16>>2]=0;c[w>>2]=249;c[g+8>>2]=44;c[g+12>>2]=167;c[g+24>>2]=0;c[g+28>>2]=h;y=g}}else{if(k){y=0}else{c[g>>2]=2;k=g+4|0;c[k+0>>2]=0;c[k+4>>2]=0;c[k+8>>2]=0;c[k+12>>2]=0;c[k+16>>2]=0;c[k>>2]=251;c[g+8>>2]=46;c[g+12>>2]=169;c[g+24>>2]=x;c[g+28>>2]=h&65535;y=g}}g=e[j>>1]|0;c[y+16>>2]=a&65535;c[y+20>>2]=g;g=c[y+12>>2]|0;if((g|0)!=0){jc[g&255](y,c[q>>2]|0)}g=d+4|0;a=Az(c[g>>2]|0,(c[d>>2]<<2)+4|0)|0;if((a|0)==0){i=f;return}c[g>>2]=a;g=c[d>>2]|0;c[a+(g<<2)>>2]=y;c[d>>2]=g+1;i=f;return}function Zv(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=i;c[b>>2]=0;f=0;do{g=d+f|0;a[b+f+4>>0]=a[g>>0]|0;f=f+1|0;if((a[g>>0]|0)==0){h=5;break}}while(f>>>0<256);if((h|0)==5){i=e;return}a[b+259>>0]=0;i=e;return}function _v(a){a=a|0;return a+(c[a>>2]|0)+4|0}function $v(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=i;f=a[d>>0]|0;g=(f+ -36<<24>>24&255)<2?d+1|0:d;if(!(f<<24>>24==36)){h=c[13788]|0;do{if((h|0)==0){j=f}else{if((gc[h&63](c[13790]|0,g,e)|0)==0){k=0;i=b;return k|0}else{j=a[d>>0]|0;break}}}while(0);if(j<<24>>24==37){k=1;i=b;return k|0}}j=c[13784]|0;d=c[13786]|0;do{if((j|0)==0){l=8}else{h=0;while(1){f=h+1|0;if((Fz(c[d+(h<<3)>>2]|0,g)|0)==0){break}if(f>>>0<j>>>0){h=f}else{m=10;break}}if((m|0)==10){l=(j<<3)+8|0;break}c[d+(h<<3)+4>>2]=e;k=0;i=b;return k|0}}while(0);j=Az(d,l)|0;if((j|0)==0){k=1;i=b;return k|0}l=c[13784]|0;a:do{if((l|0)==0){n=0}else{d=l;while(1){m=d+ -1|0;f=j+(m<<3)|0;if((Fz(c[f>>2]|0,g)|0)<0){n=d;break a}o=f;f=c[o+4>>2]|0;p=j+(d<<3)|0;c[p>>2]=c[o>>2];c[p+4>>2]=f;if((m|0)==0){n=0;break}else{d=m}}}}while(0);c[j+(n<<3)>>2]=xz(g)|0;c[j+(n<<3)+4>>2]=e;c[13786]=j;c[13784]=(c[13784]|0)+1;k=0;i=b;return k|0}function aw(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d;f=a+(c[a>>2]|0)+4|0;c[e>>2]=b;c[e+4>>2]=f;pw(55168,e);i=d;return}function bw(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=i;i=i+16|0;g=f;h=c[b>>2]|0;while(1){j=b+h+4|0;k=a[j>>0]|0;if(!(k<<24>>24==10|k<<24>>24==9|k<<24>>24==32|k<<24>>24==13)){break}h=h+1|0}c[b>>2]=h;k=a[j>>0]|0;if(((k<<24>>24)+ -36|0)>>>0<2){a[d>>0]=k;l=d+1|0;m=h+1|0;n=1}else{l=d;m=h;n=0}while(1){h=a[b+m+4>>0]|0;if(h<<24>>24==0){o=10;break}if(!((h+ -48<<24>>24&255)<10|(h+ -97<<24>>24&255)<26|(h+ -65<<24>>24&255)<26|h<<24>>24==95)){o=10;break}a[l>>0]=h;h=n+1|0;if(h>>>0<e>>>0){l=l+1|0;m=m+1|0;n=h}else{o=9;break}}if((o|0)==9){e=b+(c[b>>2]|0)+4|0;c[g>>2]=55184;c[g+4>>2]=e;pw(55168,g);p=0;i=f;return p|0}else if((o|0)==10){a[l>>0]=0;c[b>>2]=m;p=(n|0)!=0|0;i=f;return p|0}return 0}function cw(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+16|0;g=f;h=c[b>>2]|0;while(1){j=b+h+4|0;k=a[j>>0]|0;if(!(k<<24>>24==10|k<<24>>24==9|k<<24>>24==32|k<<24>>24==13)){break}h=h+1|0}c[b>>2]=h;k=(a[j>>0]|0)==34;j=(k&1)+h|0;a:do{if(k){h=d;l=j;m=0;while(1){n=a[b+l+4>>0]|0;if(n<<24>>24==34){break}else if(n<<24>>24==0){o=h;p=l;q=m;r=11;break a}a[h>>0]=n;n=m+1|0;if(n>>>0<e>>>0){h=h+1|0;l=l+1|0;m=n}else{r=10;break a}}o=h;p=l+1|0;q=m;r=11}else{n=d;s=j;t=0;while(1){u=a[b+s+4>>0]|0;switch(u<<24>>24){case 13:case 10:case 9:case 32:case 0:{o=n;p=s;q=t;r=11;break a;break};default:{}}a[n>>0]=u;u=t+1|0;if(u>>>0<e>>>0){n=n+1|0;s=s+1|0;t=u}else{r=10;break a}}}}while(0);if((r|0)==10){e=b+(c[b>>2]|0)+4|0;c[g>>2]=55208;c[g+4>>2]=e;pw(55168,g);v=0;i=f;return v|0}else if((r|0)==11){a[o>>0]=0;c[b>>2]=p;v=(q|0)!=0|0;i=f;return v|0}return 0}function dw(b){b=b|0;var d=0,e=0,f=0,g=0;d=i;e=c[b>>2]|0;while(1){f=b+e+4|0;g=a[f>>0]|0;if(!(g<<24>>24==10|g<<24>>24==9|g<<24>>24==32|g<<24>>24==13)){break}e=e+1|0}c[b>>2]=e;i=d;return(a[f>>0]|0)==0|0}function ew(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0;d=i;i=i+16|0;e=d;f=c[b>>2]|0;while(1){g=b+f+4|0;h=a[g>>0]|0;if(!(h<<24>>24==10|h<<24>>24==9|h<<24>>24==32|h<<24>>24==13)){break}f=f+1|0}c[b>>2]=f;if((a[g>>0]|0)==0){j=1;i=d;return j|0}c[e>>2]=55224;c[e+4>>2]=g;pw(55168,e);j=0;i=d;return j|0}function fw(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=c[b>>2]|0;while(1){g=a[b+f+4>>0]|0;if(!(g<<24>>24==10|g<<24>>24==9|g<<24>>24==32|g<<24>>24==13)){break}f=f+1|0}c[b>>2]=f;g=a[d>>0]|0;a:do{if(g<<24>>24==0){h=f}else{j=d;k=g;l=f;while(1){if(!((a[b+l+4>>0]|0)==k<<24>>24)){m=0;break}n=l+1|0;o=j+1|0;p=a[o>>0]|0;if(p<<24>>24==0){h=n;break a}else{j=o;k=p;l=n}}i=e;return m|0}}while(0);c[b>>2]=h;m=1;i=e;return m|0}function gw(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0;f=i;i=i+272|0;g=f;h=f+16|0;j=f+8|0;k=h+1|0;l=c[b>>2]|0;while(1){m=a[b+l+4>>0]|0;if(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13){l=l+1|0;continue}c[b>>2]=l;m=l;while(1){n=b+m+4|0;o=a[n>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}m=m+1|0}c[b>>2]=m;o=a[n>>0]|0;if(((o<<24>>24)+ -36|0)>>>0<2){a[h>>0]=o;p=k;q=m+1|0;r=1}else{p=h;q=m;r=0}while(1){o=a[b+q+4>>0]|0;if(o<<24>>24==0){s=13;break}if(!((o+ -48<<24>>24&255)<10|(o+ -97<<24>>24&255)<26|(o+ -65<<24>>24&255)<26|o<<24>>24==95)){s=13;break}a[p>>0]=o;o=r+1|0;if(o>>>0<256){p=p+1|0;q=q+1|0;r=o}else{s=12;break}}a:do{if((s|0)==12){s=0;m=b+(c[b>>2]|0)+4|0;c[g>>2]=55184;c[g+4>>2]=m;pw(55168,g);s=112}else if((s|0)==13){s=0;a[p>>0]=0;c[b>>2]=q;if((r|0)==0){s=112}else{m=0;while(1){t=h+m|0;u=a[t>>0]|0;v=m+1|0;if(u<<24>>24==37){m=v}else{w=q;break}}while(1){m=a[b+w+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}w=w+1|0}c[b>>2]=w;do{if((a[b+w+4>>0]|0)==61){m=w+1|0;c[b>>2]=m;x=m;y=1}else{m=w;while(1){o=a[b+m+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}m=m+1|0}c[b>>2]=m;o=55240;z=43;A=m;while(1){if(!((a[b+A+4>>0]|0)==z<<24>>24)){B=m;break}C=A+1|0;D=o+1|0;E=a[D>>0]|0;if(E<<24>>24==0){s=24;break}else{o=D;z=E;A=C}}if((s|0)==24){s=0;c[b>>2]=C;x=C;y=2;break}while(1){A=a[b+B+4>>0]|0;if(!(A<<24>>24==10|A<<24>>24==9|A<<24>>24==32|A<<24>>24==13)){break}B=B+1|0}c[b>>2]=B;A=55248;z=45;o=B;while(1){if(!((a[b+o+4>>0]|0)==z<<24>>24)){F=B;break}G=o+1|0;m=A+1|0;E=a[m>>0]|0;if(E<<24>>24==0){s=30;break}else{A=m;z=E;o=G}}if((s|0)==30){s=0;c[b>>2]=G;x=G;y=3;break}while(1){o=a[b+F+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}F=F+1|0}c[b>>2]=F;o=55256;z=42;A=F;while(1){if(!((a[b+A+4>>0]|0)==z<<24>>24)){H=F;break}I=A+1|0;E=o+1|0;m=a[E>>0]|0;if(m<<24>>24==0){s=36;break}else{o=E;z=m;A=I}}if((s|0)==36){s=0;c[b>>2]=I;x=I;y=4;break}while(1){A=a[b+H+4>>0]|0;if(!(A<<24>>24==10|A<<24>>24==9|A<<24>>24==32|A<<24>>24==13)){break}H=H+1|0}c[b>>2]=H;A=55264;z=47;o=H;while(1){if(!((a[b+o+4>>0]|0)==z<<24>>24)){J=H;break}K=o+1|0;m=A+1|0;E=a[m>>0]|0;if(E<<24>>24==0){s=42;break}else{A=m;z=E;o=K}}if((s|0)==42){s=0;c[b>>2]=K;x=K;y=5;break}while(1){o=a[b+J+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}J=J+1|0}c[b>>2]=J;o=55272;z=60;A=J;while(1){if(!((a[b+A+4>>0]|0)==z<<24>>24)){L=J;break}M=A+1|0;E=o+1|0;m=a[E>>0]|0;if(m<<24>>24==0){s=48;break}else{o=E;z=m;A=M}}if((s|0)==48){s=0;c[b>>2]=M;x=M;y=6;break}while(1){A=a[b+L+4>>0]|0;if(!(A<<24>>24==10|A<<24>>24==9|A<<24>>24==32|A<<24>>24==13)){break}L=L+1|0}c[b>>2]=L;A=55280;z=62;o=L;while(1){if(!((a[b+o+4>>0]|0)==z<<24>>24)){N=L;break}O=o+1|0;m=A+1|0;E=a[m>>0]|0;if(E<<24>>24==0){s=54;break}else{A=m;z=E;o=O}}if((s|0)==54){s=0;c[b>>2]=O;x=O;y=7;break}while(1){o=a[b+N+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}N=N+1|0}c[b>>2]=N;o=55288;z=124;A=N;while(1){if(!((a[b+A+4>>0]|0)==z<<24>>24)){P=N;break}Q=A+1|0;E=o+1|0;m=a[E>>0]|0;if(m<<24>>24==0){s=60;break}else{o=E;z=m;A=Q}}if((s|0)==60){s=0;c[b>>2]=Q;x=Q;y=8;break}while(1){A=a[b+P+4>>0]|0;if(!(A<<24>>24==10|A<<24>>24==9|A<<24>>24==32|A<<24>>24==13)){break}P=P+1|0}c[b>>2]=P;A=55296;z=38;o=P;while(1){if(!((a[b+o+4>>0]|0)==z<<24>>24)){R=P;break}S=o+1|0;m=A+1|0;E=a[m>>0]|0;if(E<<24>>24==0){s=66;break}else{A=m;z=E;o=S}}if((s|0)==66){s=0;c[b>>2]=S;x=S;y=9;break}while(1){o=a[b+R+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}R=R+1|0}c[b>>2]=R;o=55304;z=94;A=R;do{if(!((a[b+A+4>>0]|0)==z<<24>>24)){s=112;break a}A=A+1|0;o=o+1|0;z=a[o>>0]|0}while(!(z<<24>>24==0));c[b>>2]=A;x=A;y=10}}while(0);z=x;while(1){o=a[b+z+4>>0]|0;if(!(o<<24>>24==10|o<<24>>24==9|o<<24>>24==32|o<<24>>24==13)){break}z=z+1|0}c[b>>2]=z;if((a[b+z+4>>0]|0)==59){c[b>>2]=z+1;if(u<<24>>24==36){T=h+v|0}else if(u<<24>>24==37){break}else{T=t}c[d>>2]=0;o=c[13784]|0;if((o|0)==0){U=0}else{E=o;o=0;m=0;while(1){D=c[13786]|0;V=c[D+(o<<3)>>2]|0;if((Fz(V,T)|0)==0){c[d>>2]=c[D+(o<<3)+4>>2];zz(V);W=c[13784]|0;X=m}else{V=D+(o<<3)|0;Y=c[V+4>>2]|0;Z=D+(m<<3)|0;c[Z>>2]=c[V>>2];c[Z+4>>2]=Y;W=E;X=m+1|0}Y=o+1|0;if(Y>>>0<W>>>0){E=W;o=Y;m=X}else{U=X;break}}}c[13784]=U;break}m=(u+ -36<<24>>24&255)<2?h+v|0:t;do{if(u<<24>>24==36){s=90}else{o=c[13780]|0;if((o|0)==0){_=u}else{if((gc[o&63](c[13782]|0,m,d)|0)==0){break}_=a[t>>0]|0}if(_<<24>>24==37){s=95}else{s=90}}}while(0);b:do{if((s|0)==90){s=0;o=c[13784]|0;if((o|0)==0){s=95}else{E=c[13786]|0;z=0;while(1){Y=z+1|0;if((Fz(c[E+(z<<3)>>2]|0,m)|0)==0){break}if(Y>>>0<o>>>0){z=Y}else{s=95;break b}}c[d>>2]=c[E+(z<<3)+4>>2]}}}while(0);if((s|0)==95){s=0;c[d>>2]=0}if((kw(b,j,e)|0)==0){s=112}else{c:do{switch(y|0){case 1:{m=c[j>>2]|0;c[d>>2]=m;$=m;break};case 2:{m=(c[d>>2]|0)+(c[j>>2]|0)|0;c[d>>2]=m;$=m;break};case 3:{m=(c[d>>2]|0)-(c[j>>2]|0)|0;c[d>>2]=m;$=m;break};case 4:{m=ca(c[d>>2]|0,c[j>>2]|0)|0;c[d>>2]=m;$=m;break};case 5:{m=c[j>>2]|0;if((m|0)==0){c[d>>2]=-1;$=-1;break c}else{o=((c[d>>2]|0)>>>0)/(m>>>0)|0;c[d>>2]=o;$=o;break c}break};case 6:{o=c[d>>2]<<c[j>>2];c[d>>2]=o;$=o;break};case 7:{o=(c[d>>2]|0)>>>(c[j>>2]|0);c[d>>2]=o;$=o;break};case 8:{o=c[d>>2]|c[j>>2];c[d>>2]=o;$=o;break};case 9:{o=c[d>>2]&c[j>>2];c[d>>2]=o;$=o;break};case 10:{o=c[d>>2]^c[j>>2];c[d>>2]=o;$=o;break};default:{o=c[j>>2]|0;c[d>>2]=o;$=o}}}while(0);$v(0,t,$)|0}}}}while(0);if((s|0)==112){s=0;c[b>>2]=l;if((kw(b,d,e)|0)==0){aa=0;s=118;break}}o=c[b>>2]|0;while(1){m=a[b+o+4>>0]|0;if(!(m<<24>>24==10|m<<24>>24==9|m<<24>>24==32|m<<24>>24==13)){break}o=o+1|0}c[b>>2]=o;if((a[b+o+4>>0]|0)!=44){aa=1;s=118;break}m=o+1|0;c[b>>2]=m;l=m}if((s|0)==118){i=f;return aa|0}return 0}function hw(a,d){a=a|0;d=d|0;var e=0,f=0,g=0;e=i;i=i+16|0;f=e;if((gw(a,f,16)|0)==0){g=0;i=e;return g|0}b[d>>1]=c[f>>2];g=1;i=e;return g|0}function iw(a,b){a=a|0;b=b|0;var c=0,d=0;c=i;d=gw(a,b,16)|0;i=c;return d|0}function jw(a,b,d){a=a|0;b=b|0;d=d|0;c[13782]=a;c[13780]=b;c[13790]=a;c[13788]=d;return}



function Dz(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;a:do{if((d|0)==0){f=0}else{g=d;h=b;j=c;while(1){k=a[h>>0]|0;l=a[j>>0]|0;if(!(k<<24>>24==l<<24>>24)){break}m=g+ -1|0;if((m|0)==0){f=0;break a}else{g=m;h=h+1|0;j=j+1|0}}f=(k&255)-(l&255)|0}}while(0);i=e;return f|0}function Ez(b,c){b=b|0;c=c|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;f=a[b>>0]|0;a:do{if(f<<24>>24==0){g=0;h=c}else{j=f;k=f&255;l=b;m=c;while(1){n=a[m>>0]|0;if(n<<24>>24==0){g=j;h=m;break a}if(!(j<<24>>24==n<<24>>24)){n=Qz(k|0)|0;if((n|0)!=(Qz(d[m>>0]|0|0)|0)){break}}n=l+1|0;o=m+1|0;p=a[n>>0]|0;if(p<<24>>24==0){g=0;h=o;break a}else{j=p;k=p&255;l=n;m=o}}g=a[l>>0]|0;h=m}}while(0);c=Qz(g&255|0)|0;g=c-(Qz(d[h>>0]|0|0)|0)|0;i=e;return g|0}function Fz(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;e=a[b>>0]|0;f=a[c>>0]|0;if(e<<24>>24!=f<<24>>24|e<<24>>24==0|f<<24>>24==0){g=e;h=f;j=g&255;k=h&255;l=j-k|0;i=d;return l|0}else{m=b;n=c}while(1){c=m+1|0;b=n+1|0;f=a[c>>0]|0;e=a[b>>0]|0;if(f<<24>>24!=e<<24>>24|f<<24>>24==0|e<<24>>24==0){g=f;h=e;break}else{m=c;n=b}}j=g&255;k=h&255;l=j-k|0;i=d;return l|0}function Gz(b,c,e){b=b|0;c=c|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=i;if((e|0)==0){g=0;i=f;return g|0}h=a[b>>0]|0;a:do{if(h<<24>>24==0){j=0;k=c}else{l=e;m=h;n=b;o=c;while(1){p=l+ -1|0;q=a[o>>0]|0;if(!((p|0)!=0&q<<24>>24!=0&m<<24>>24==q<<24>>24)){j=m;k=o;break a}q=n+1|0;r=o+1|0;s=a[q>>0]|0;if(s<<24>>24==0){j=0;k=r;break}else{l=p;m=s;n=q;o=r}}}}while(0);g=(j&255)-(d[k>>0]|0)|0;i=f;return g|0}function Hz(){}function Iz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=b-d>>>0;e=b-d-(c>>>0>a>>>0|0)>>>0;return(G=e,a-c>>>0|0)|0}function Jz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;return(G=b+d+(e>>>0<a>>>0|0)>>>0,e|0)|0}function Kz(b){b=b|0;var c=0;c=b;while(a[c>>0]|0){c=c+1|0}return c-b|0}function Lz(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b>>>c;return a>>>c|(b&(1<<c)-1)<<32-c}G=0;return b>>>c-32|0}function Mz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;if((e|0)>=4096)return Da(b|0,d|0,e|0)|0;f=b|0;if((b&3)==(d&3)){while(b&3){if((e|0)==0)return f|0;a[b>>0]=a[d>>0]|0;b=b+1|0;d=d+1|0;e=e-1|0}while((e|0)>=4){c[b>>2]=c[d>>2];b=b+4|0;d=d+4|0;e=e-4|0}}while((e|0)>0){a[b>>0]=a[d>>0]|0;b=b+1|0;d=d+1|0;e=e-1|0}return f|0}function Nz(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b<<c|(a&(1<<c)-1<<32-c)>>>32-c;return a<<c}G=a<<c-32;return 0}function Oz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+e|0;if((e|0)>=20){d=d&255;g=b&3;h=d|d<<8|d<<16|d<<24;i=f&~3;if(g){g=b+4-g|0;while((b|0)<(g|0)){a[b>>0]=d;b=b+1|0}}while((b|0)<(i|0)){c[b>>2]=h;b=b+4|0}}while((b|0)<(f|0)){a[b>>0]=d;b=b+1|0}return b-e|0}function Pz(b,c){b=b|0;c=c|0;var d=0,e=0;d=b+(Kz(b)|0)|0;do{a[d+e>>0]=a[c+e>>0];e=e+1|0}while(a[c+(e-1)>>0]|0);return b|0}function Qz(a){a=a|0;if((a|0)<65)return a|0;if((a|0)>90)return a|0;return a-65+97|0}function Rz(b,c){b=b|0;c=c|0;var d=0;do{a[b+d>>0]=a[c+d>>0];d=d+1|0}while(a[c+(d-1)>>0]|0);return b|0}function Sz(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){G=b>>c;return a>>>c|(b&(1<<c)-1)<<32-c}G=(b|0)<0?-1:0;return b>>c-32|0}function Tz(b){b=b|0;var c=0;c=a[n+(b>>>24)>>0]|0;if((c|0)<8)return c|0;c=a[n+(b>>16&255)>>0]|0;if((c|0)<8)return c+8|0;c=a[n+(b>>8&255)>>0]|0;if((c|0)<8)return c+16|0;return(a[n+(b&255)>>0]|0)+24|0}function Uz(b){b=b|0;var c=0;c=a[m+(b&255)>>0]|0;if((c|0)<8)return c|0;c=a[m+(b>>8&255)>>0]|0;if((c|0)<8)return c+8|0;c=a[m+(b>>16&255)>>0]|0;if((c|0)<8)return c+16|0;return(a[m+(b>>>24)>>0]|0)+24|0}function Vz(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a&65535;d=b&65535;e=ca(d,c)|0;f=a>>>16;a=(e>>>16)+(ca(d,f)|0)|0;d=b>>>16;b=ca(d,c)|0;return(G=(a>>>16)+(ca(d,f)|0)+(((a&65535)+b|0)>>>16)|0,a+b<<16|e&65535|0)|0}function Wz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>31|((b|0)<0?-1:0)<<1;f=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;g=d>>31|((d|0)<0?-1:0)<<1;h=((d|0)<0?-1:0)>>31|((d|0)<0?-1:0)<<1;i=Iz(e^a,f^b,e,f)|0;b=G;a=g^e;e=h^f;f=Iz(($z(i,b,Iz(g^c,h^d,g,h)|0,G,0)|0)^a,G^e,a,e)|0;return f|0}function Xz(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=b>>31|((b|0)<0?-1:0)<<1;j=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;k=e>>31|((e|0)<0?-1:0)<<1;l=((e|0)<0?-1:0)>>31|((e|0)<0?-1:0)<<1;m=Iz(h^a,j^b,h,j)|0;b=G;$z(m,b,Iz(k^d,l^e,k,l)|0,G,g)|0;l=Iz(c[g>>2]^h,c[g+4>>2]^j,h,j)|0;j=G;i=f;return(G=j,l)|0}function Yz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=a;a=c;c=Vz(e,a)|0;f=G;return(G=(ca(b,a)|0)+(ca(d,e)|0)+f|f&0,c|0|0)|0}function Zz(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=$z(a,b,c,d,0)|0;return e|0}function _z(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;$z(a,b,d,e,g)|0;i=f;return(G=c[g+4>>2]|0,c[g>>2]|0)|0}function $z(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,H=0;g=a;h=b;i=h;j=d;k=e;l=k;if((i|0)==0){m=(f|0)!=0;if((l|0)==0){if(m){c[f>>2]=(g>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(g>>>0)/(j>>>0)>>>0;return(G=n,o)|0}else{if(!m){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=b&0;n=0;o=0;return(G=n,o)|0}}m=(l|0)==0;do{if((j|0)==0){if(m){if((f|0)!=0){c[f>>2]=(i>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(i>>>0)/(j>>>0)>>>0;return(G=n,o)|0}if((g|0)==0){if((f|0)!=0){c[f>>2]=0;c[f+4>>2]=(i>>>0)%(l>>>0)}n=0;o=(i>>>0)/(l>>>0)>>>0;return(G=n,o)|0}p=l-1|0;if((p&l|0)==0){if((f|0)!=0){c[f>>2]=a|0;c[f+4>>2]=p&i|b&0}n=0;o=i>>>((Uz(l|0)|0)>>>0);return(G=n,o)|0}p=(Tz(l|0)|0)-(Tz(i|0)|0)|0;if(p>>>0<=30){q=p+1|0;r=31-p|0;s=q;t=i<<r|g>>>(q>>>0);u=i>>>(q>>>0);v=0;w=g<<r;break}if((f|0)==0){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(G=n,o)|0}else{if(!m){r=(Tz(l|0)|0)-(Tz(i|0)|0)|0;if(r>>>0<=31){q=r+1|0;p=31-r|0;x=r-31>>31;s=q;t=g>>>(q>>>0)&x|i<<p;u=i>>>(q>>>0)&x;v=0;w=g<<p;break}if((f|0)==0){n=0;o=0;return(G=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(G=n,o)|0}p=j-1|0;if((p&j|0)!=0){x=(Tz(j|0)|0)+33-(Tz(i|0)|0)|0;q=64-x|0;r=32-x|0;y=r>>31;z=x-32|0;A=z>>31;s=x;t=r-1>>31&i>>>(z>>>0)|(i<<r|g>>>(x>>>0))&A;u=A&i>>>(x>>>0);v=g<<q&y;w=(i<<q|g>>>(z>>>0))&y|g<<r&x-33>>31;break}if((f|0)!=0){c[f>>2]=p&g;c[f+4>>2]=0}if((j|0)==1){n=h|b&0;o=a|0|0;return(G=n,o)|0}else{p=Uz(j|0)|0;n=i>>>(p>>>0)|0;o=i<<32-p|g>>>(p>>>0)|0;return(G=n,o)|0}}}while(0);if((s|0)==0){B=w;C=v;D=u;E=t;F=0;H=0}else{g=d|0|0;d=k|e&0;e=Jz(g,d,-1,-1)|0;k=G;i=w;w=v;v=u;u=t;t=s;s=0;do{j=i;i=w>>>31|i<<1;w=s|w<<1;a=u<<1|j>>>31|0;j=u>>>31|v<<1|0;Iz(e,k,a,j)|0;b=G;h=b>>31|((b|0)<0?-1:0)<<1;s=h&1;u=Iz(a,j,h&g,(((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1)&d)|0;v=G;t=t-1|0}while((t|0)!=0);B=i;C=w;D=v;E=u;F=0;H=s}s=C;C=0;if((f|0)!=0){c[f>>2]=E;c[f+4>>2]=D}n=(s|0)>>>31|(B|C)<<1|(C<<1|s>>>31)&0|F;o=(s<<1|0>>>31)&-2|H;return(G=n,o)|0}function aA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return gc[a&63](b|0,c|0,d|0)|0}function bA(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;hc[a&1](b|0,c|0,d|0,e|0,f|0)}function cA(a,b){a=a|0;b=b|0;ic[a&511](b|0)}function dA(a,b,c){a=a|0;b=b|0;c=c|0;jc[a&255](b|0,c|0)}function eA(a,b){a=a|0;b=b|0;return kc[a&15](b|0)|0}function fA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;lc[a&31](b|0,c|0,d|0)}function gA(a){a=a|0;mc[a&3]()}function hA(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nc[a&63](b|0,c|0,d|0,e|0)|0}function iA(a,b,c){a=a|0;b=b|0;c=c|0;return oc[a&31](b|0,c|0)|0}function jA(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return pc[a&3](b|0,c|0,d|0,e|0,f|0)|0}function kA(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;qc[a&3](b|0,c|0,d|0,e|0)}function lA(a,b,c){a=a|0;b=b|0;c=c|0;da(0);return 0}function mA(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;da(1)}function nA(a){a=a|0;da(2)}function oA(a,b){a=a|0;b=b|0;da(3)}function pA(a){a=a|0;da(4);return 0}function qA(a,b,c){a=a|0;b=b|0;c=c|0;da(5)}function rA(){da(6)}function sA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;da(7);return 0}function tA(a,b){a=a|0;b=b|0;da(8);return 0}function uA(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;da(9);return 0}function vA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;da(10)}




// EMSCRIPTEN_END_FUNCS
var gc=[lA,Ge,He,Ie,Je,Ke,Le,Me,Ne,Oe,Pe,Qe,Re,Se,Te,Ue,Ve,We,Xe,Ye,Ze,_e,$e,Bc,Uc,ad,Fe,we,xe,Cq,ur,Er,Yr,Zr,es,fs,ls,ms,ps,qs,ts,us,vv,zv,Nv,Tv,Qv,zy,Oy,Qy,pz,rz,lA,lA,lA,lA,lA,lA,lA,lA,lA,lA,lA,lA];var hc=[mA,Uf];var ic=[nA,dk,ek,fk,gk,hk,ik,jk,kk,lk,mk,nk,ok,pk,qk,rk,sk,tk,uk,vk,wk,xk,yk,zk,Ak,Bk,Ck,Dk,Ek,Fk,Gk,Hk,Ik,Jk,Kk,Lk,Mk,Nk,Ok,Pk,ck,Qk,Rk,Sk,Tk,Uk,Vk,Wk,Xk,Yk,Zk,_k,$k,al,bl,cl,dl,el,fl,gl,hl,il,jl,kl,ll,ml,nl,ol,pl,ql,rl,sl,tl,ul,vl,wl,xl,yl,zl,Al,Bl,Cl,Dl,El,Fl,Gl,Hl,Il,Jl,Kl,Ll,Ml,Nl,Ol,Pl,Ql,Rl,Sl,Tl,Ul,Vl,Wl,Xl,Yl,Zl,_l,$l,am,bm,cm,dm,em,fm,gm,hm,im,jm,km,lm,mm,nm,om,pm,qm,rm,sm,tm,um,vm,wm,xm,ym,zm,Am,Bm,Cm,Dm,Em,Fm,Gm,Hm,Im,Jm,Km,Lm,Mm,Nm,Om,Pm,Qm,Rm,Sm,Tm,Um,Vm,Wm,Xm,Ym,Zm,_m,$m,an,fn,gn,hn,jn,kn,ln,mn,nn,on,pn,qn,rn,sn,tn,un,vn,wn,xn,yn,zn,An,Bn,Cn,Dn,En,Fn,Gn,Hn,In,Jn,Kn,Ln,Mn,Nn,On,Pn,Qn,Rn,Sn,Tn,Un,Vn,Wn,Xn,Yn,Zn,zc,Ac,Rc,Sc,Tc,Zc,_c,$c,qe,re,se,vf,wf,xf,yf,zf,Af,Bf,Cf,Df,Ef,Ff,Gf,Hf,If,Mf,Jf,bk,en,zq,kr,qr,yr,Kr,Xr,ds,ks,os,ss,uv,yv,Mv,Sv,Pv,vy,Cy,Gy,Ny,Ry,Sy,oz,sz,tz,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA,nA];var jc=[oA,Bg,Cg,Dg,Eg,Fg,Gg,Hg,Ig,Jg,Kg,Lg,Mg,Ng,Og,Pg,Qg,Rg,Sg,Tg,Ug,Vg,Wg,Xg,Yg,Zg,_g,$g,ah,bh,ch,dh,eh,fh,gh,hh,ih,jh,kh,lh,mh,nh,oh,ph,qh,rh,sh,th,uh,vh,wh,xh,yh,zh,Ah,Bh,Ch,Dh,Eh,Fh,Gh,Hh,Ih,Jh,Kh,Lh,Mh,Nh,Oh,Ph,Qh,Rh,Sh,Th,Uh,Vh,Wh,Xh,Yh,Zh,_h,$h,ai,bi,ci,di,ei,fi,gi,hi,ii,ji,ki,li,mi,ni,oi,pi,qi,ri,si,ti,ui,vi,wi,xi,yi,zi,Ai,Bi,Ci,Di,Ei,Fi,Gi,Hi,Ii,Ji,Ki,Li,Mi,Ni,Oi,Pi,Qi,Ri,Si,Ti,Ui,Vi,Wi,Xi,Yi,Zi,_i,$i,aj,bj,cj,dj,ej,fj,gj,hj,ij,Cc,Vc,bd,ld,md,pe,me,ne,oe,je,ie,Ud,ap,Qd,Rd,Xo,he,ge,ce,Rf,Sf,Tf,Ov,Uv,Rv,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA,oA];var kc=[pA,Wr,cs,js,ns,rs,tv,xv,Wo,Py,qz,pA,pA,pA,pA,pA];var lc=[qA,id,Ce,De,Ee,oq,pq,qq,ep,fp,gp,le,Td,sf,tf,ee,Sp,Tp,Up,Bv,nq,qA,qA,qA,qA,qA,qA,qA,qA,qA,qA,qA];var mc=[rA,hd,ve,rA];var nc=[sA,uo,vo,wo,xo,yo,zo,Ao,Bo,Co,Do,Eo,Fo,Go,Ho,Io,Aq,Bq,lr,mr,rr,sr,tr,zr,Ar,Dr,Lr,Mr,wv,Av,wy,xy,yy,Dy,Ey,Hy,Iy,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA,sA];var oc=[tA,ze,Ae,Be,kq,lq,mq,od,bp,cp,dp,ke,qf,rf,jd,Pp,Qp,Rp,_r,$r,gs,hs,tA,tA,tA,tA,tA,tA,tA,tA,tA,tA];var pc=[uA,as,is,uA];var qc=[vA,Dc,Wc,fe];return{_i64Subtract:Iz,_strcat:Pz,_free:zz,_main:ue,_realloc:Az,_i64Add:Jz,_tolower:Qz,_strlen:Kz,_memset:Oz,_malloc:yz,_memcpy:Mz,_bitshift64Lshr:Lz,_strcpy:Rz,_bitshift64Shl:Nz,runPostSets:Hz,stackAlloc:rc,stackSave:sc,stackRestore:tc,setThrew:uc,setTempRet0:xc,getTempRet0:yc,dynCall_iiii:aA,dynCall_viiiii:bA,dynCall_vi:cA,dynCall_vii:dA,dynCall_ii:eA,dynCall_viii:fA,dynCall_v:gA,dynCall_iiiii:hA,dynCall_iii:iA,dynCall_iiiiii:jA,dynCall_viiii:kA}})


// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_iiii": invoke_iiii, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_ii": invoke_ii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_iiiii": invoke_iiiii, "invoke_iii": invoke_iii, "invoke_iiiiii": invoke_iiiiii, "invoke_viiii": invoke_viiii, "_fread": _fread, "_SDL_PauseAudio": _SDL_PauseAudio, "_atexit": _atexit, "_truncate": _truncate, "_fsync": _fsync, "_SDL_GetError": _SDL_GetError, "_signal": _signal, "_sbrk": _sbrk, "_SDL_OpenAudio": _SDL_OpenAudio, "_SDL_FreeSurface": _SDL_FreeSurface, "_emscripten_memcpy_big": _emscripten_memcpy_big, "_tcgetattr": _tcgetattr, "_sysconf": _sysconf, "_close": _close, "_SDL_InitSubSystem": _SDL_InitSubSystem, "_posix_openpt": _posix_openpt, "_puts": _puts, "_write": _write, "_ftell": _ftell, "_gmtime_r": _gmtime_r, "_SDL_WM_SetCaption": _SDL_WM_SetCaption, "_SDL_WasInit": _SDL_WasInit, "_send": _send, "_SDL_CreateRGBSurfaceFrom": _SDL_CreateRGBSurfaceFrom, "_SDL_GetTicks": _SDL_GetTicks, "_fcntl": _fcntl, "_SDL_LockAudio": _SDL_LockAudio, "_SDL_LockSurface": _SDL_LockSurface, "_strtol": _strtol, "___setErrNo": ___setErrNo, "_grantpt": _grantpt, "_unlink": _unlink, "_nanosleep": _nanosleep, "_gmtime": _gmtime, "_printf": _printf, "_sprintf": _sprintf, "_poll": _poll, "_localtime": _localtime, "_read": _read, "_SDL_SetVideoMode": _SDL_SetVideoMode, "_fwrite": _fwrite, "_time": _time, "_fprintf": _fprintf, "_gettimeofday": _gettimeofday, "_ptsname": _ptsname, "_exit": _exit, "_SDL_ShowCursor": _SDL_ShowCursor, "_lseek": _lseek, "_vfprintf": _vfprintf, "_pwrite": _pwrite, "_unlockpt": _unlockpt, "_localtime_r": _localtime_r, "_tzset": _tzset, "_open": _open, "_SDL_Init": _SDL_Init, "_SDL_WM_GrabInput": _SDL_WM_GrabInput, "_snprintf": _snprintf, "_ftruncate": _ftruncate, "_fseek": _fseek, "_SDL_GetMouseState": _SDL_GetMouseState, "_fclose": _fclose, "__parseInt": __parseInt, "_recv": _recv, "_tan": _tan, "_symlink": _symlink, "_abort": _abort, "_SDL_Flip": _SDL_Flip, "_isspace": _isspace, "_strtoul": _strtoul, "_fopen": _fopen, "_SDL_UnlockAudio": _SDL_UnlockAudio, "_tcflush": _tcflush, "_SDL_CloseAudio": _SDL_CloseAudio, "_usleep": _usleep, "_fflush": _fflush, "_SDL_GetVideoInfo": _SDL_GetVideoInfo, "__reallyNegative": __reallyNegative, "_SDL_PollEvent": _SDL_PollEvent, "_fileno": _fileno, "__exit": __exit, "_tcsetattr": _tcsetattr, "_fputs": _fputs, "_SDL_EventState": _SDL_EventState, "_pread": _pread, "_mkport": _mkport, "_emscripten_set_main_loop": _emscripten_set_main_loop, "___errno_location": ___errno_location, "_fgetc": _fgetc, "_fputc": _fputc, "_emscripten_cancel_main_loop": _emscripten_cancel_main_loop, "__formatString": __formatString, "_SDL_WM_ToggleFullScreen": _SDL_WM_ToggleFullScreen, "_SDL_UpperBlit": _SDL_UpperBlit, "_SDL_EnableKeyRepeat": _SDL_EnableKeyRepeat, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_stderr": _stderr, "_stdin": _stdin, "_stdout": _stdout }, buffer);
var _i64Subtract = Module["_i64Subtract"] = asm["_i64Subtract"];
var _strcat = Module["_strcat"] = asm["_strcat"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _i64Add = Module["_i64Add"] = asm["_i64Add"];
var _tolower = Module["_tolower"] = asm["_tolower"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _bitshift64Lshr = Module["_bitshift64Lshr"] = asm["_bitshift64Lshr"];
var _strcpy = Module["_strcpy"] = asm["_strcpy"];
var _bitshift64Shl = Module["_bitshift64Shl"] = asm["_bitshift64Shl"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];

Runtime.stackAlloc = asm['stackAlloc'];
Runtime.stackSave = asm['stackSave'];
Runtime.stackRestore = asm['stackRestore'];
Runtime.setTempRet0 = asm['setTempRet0'];
Runtime.getTempRet0 = asm['getTempRet0'];


// TODO: strip out parts of this we do not need

//======= begin closure i64 code =======

// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */

var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };


  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.

    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };


  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.


  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};


  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }

    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };


  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };


  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };


  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }

    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }

    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));

    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };


  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.


  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;


  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);


  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);


  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);


  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);


  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);


  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);


  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };


  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };


  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (this.isZero()) {
      return '0';
    }

    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }

    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));

    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);

      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };


  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };


  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };


  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };


  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };


  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };


  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };


  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };


  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }

    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }

    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };


  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };


  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };


  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }

    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }

    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }

    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));

      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);

      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }

      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }

      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };


  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };


  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };


  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };


  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };


  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };


  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };

  //======= begin jsbn =======

  var navigator = { appName: 'Modern Browser' }; // polyfill a little

  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/

  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */

  // Basic JavaScript BN library - subset useful for RSA encryption.

  // Bits per digit
  var dbits;

  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);

  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }

  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }

  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.

  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }

  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);

  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;

  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;

  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }

  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }

  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }

  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }

  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }

  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }

  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }

  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }

  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }

  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }

  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }

  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }

  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }

  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }

  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }

  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }

  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }

  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }

  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }

  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }

  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;

  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }

  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }

  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }

  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }

  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }

  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }

  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;

  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }

  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }

  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }

  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;

  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;

  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);

  // jsbn2 stuff

  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }

  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }

  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }

  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }

  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }

  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }

  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }

  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;

  //======= end jsbn =======

  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();

//======= end closure i64 code =======



// === Auto-generated postamble setup entry stuff ===

if (memoryInitializer) {
  if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
    var data = Module['readBinary'](memoryInitializer);
    HEAPU8.set(data, STATIC_BASE);
  } else {
    addRunDependency('memory initializer');
    Browser.asyncLoad(memoryInitializer, function(data) {
      HEAPU8.set(data, STATIC_BASE);
      removeRunDependency('memory initializer');
    }, function(data) {
      throw 'could not load memory initializer ' + memoryInitializer;
    });
  }
}

function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;

var initialStackTop;
var preloadStartTime = null;
var calledMain = false;

dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun'] && shouldRunNow) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}

Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');

  args = args || [];

  ensureInitRuntime();

  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);

  initialStackTop = STACKTOP;

  try {

    var ret = Module['_main'](argc, argv, 0);


    // if we're not running an evented main loop, it's time to exit
    if (!Module['noExitRuntime']) {
      exit(ret);
    }
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
      throw e;
    }
  } finally {
    calledMain = true;
  }
}




function run(args) {
  args = args || Module['arguments'];

  if (preloadStartTime === null) preloadStartTime = Date.now();

  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }

  preRun();

  if (runDependencies > 0) return; // a preRun added a dependency, run will be called later
  if (Module['calledRun']) return; // run may have just been called through dependencies being fulfilled just in this very frame

  function doRun() {
    if (Module['calledRun']) return; // run may have just been called while the async setStatus time below was happening
    Module['calledRun'] = true;

    ensureInitRuntime();

    preMain();

    if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
      Module.printErr('pre-main prep time: ' + (Date.now() - preloadStartTime) + ' ms');
    }

    if (Module['_main'] && shouldRunNow) {
      Module['callMain'](args);
    }

    postRun();
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;

function exit(status) {
  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;

  // exit the runtime
  exitRuntime();

  // TODO We should handle this differently based on environment.
  // In the browser, the best we can do is throw an exception
  // to halt execution, but in node we could process.exit and
  // I'd imagine SM shell would have something equivalent.
  // This would let us set a proper exit status (which
  // would be great for checking test exit statuses).
  // https://github.com/kripken/emscripten/issues/1371

  // throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;

function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }

  ABORT = true;
  EXITSTATUS = 1;

  var extra = '\nIf this abort() is unexpected, build with -s ASSERTIONS=1 which can give more information.';

  throw 'abort() at ' + stackTrace() + extra;
}
Module['abort'] = Module.abort = abort;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}


run();

// {{POST_RUN_ADDITIONS}}






// {{MODULE_ADDITIONS}}







return Module;
}